(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   3343012,      58545]
NotebookOptionsPosition[   3286048,      57121]
NotebookOutlinePosition[   3323244,      57943]
CellTagsIndexPosition[   3323123,      57937]
WindowTitle->High Performance Computing in Finance
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["High Performance Computing in Finance", "Title",
 CellMargins->{{90, 100}, {10, 40}}],

Cell[TextData[{
 StyleBox["GPU in Finance with ",
  FontSlant->"Plain",
  FontColor->GrayLevel[0]],
 StyleBox["Mathematica",
  FontColor->GrayLevel[0]]
}], "Subtitle",
 CellMargins->{{90, 100}, {20, 20}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{
   RowBox[{"ParallelMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"CUDAFinancialDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<American\>\"", ",", " ", "\"\<Put\>\""}], "}"}], ",", 
        " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", "80."}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "#"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", 
           RowBox[{"Range", "[", 
            RowBox[{"30.", ",", "130.", ",", "1"}], "]"}]}], ",", " ", 
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", "0.06"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", "0.45"}], ",", " ", 
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "0.02"}], ",", 
          RowBox[{"\"\<Rebate\>\"", "\[Rule]", "5."}]}], "}"}]}], "]"}], 
      "&"}], ",", " ", 
     RowBox[{"Range", "[", 
      RowBox[{"0.2", ",", "10", ",", "0.2"}], "]"}]}], "]"}], ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"30", ",", "130"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", "10"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Stock\>\"", ",", "\"\<Time\>\"", ",", "\"\<Option\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<American Put\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.510013346699972*^9, 3.5100133893472366`*^9}, {
  3.51001349869517*^9, 3.510013519345235*^9}, {3.510020980730299*^9, 
  3.5100211168599105`*^9}, {3.510021430278249*^9, 3.51002144799002*^9}, {
  3.510021902856502*^9, 3.510021909586175*^9}, {3.5100219757437897`*^9, 
  3.5100219927784934`*^9}, {3.510022392802492*^9, 3.510022401094321*^9}, {
  3.5100226450227113`*^9, 3.51002264951416*^9}, {3.5100226936325717`*^9, 
  3.510022777768985*^9}, {3.5105114655923204`*^9, 3.5105115604112873`*^9}, {
  3.5105126039443207`*^9, 3.510512633845974*^9}, {3.5411666978236623`*^9, 
  3.5411667014558706`*^9}},
 CellID->548981389],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxk3Xdczf3/x/EmMjPLbpihkJFR5xQKUUl7yV6ZpZDqhLKSVQiR0ZCVGVmH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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxMvQW4lMX//n/OHtmTe0LO2T2yC1KiIoqA3WATBigmCohSAlKCEpJigICF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         "]], Polygon3DBox[CompressedData["
1:eJxMnXeYVEWw9ncX2J1dNszszrB5dpIRMYNZUcwSRAQVMAASVVBBBclKEFHJ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         "]], Polygon3DBox[CompressedData["
1:eJwV1nd0luUZx/GbETYkZBH2lIpSkDLCVqkWSw8UeqCNBsJS9ECBYnHQgolM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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwd1EdwFVQYBeBjoSd0W8ASUJoCFrCBohQx2EIUQiCQkARUUBBsYAtYAgoB
aSrYwAY2sAUsoIORUXQcdKMrXaEbdEbRGctC/Z4z+XLyz5+7effcV1o3v2Le
EUlm+nWkLPw9my8401B7fLJB/k2Nf9hn/kQOPCpZxaATkt/klKOTPaw292mT
LOMnfjdPbJvspFe7pKokWSJ/YEL75EPzDtmzQ7KYvr2S7+WYjsk2lpuLOyUL
+ZafzSOLki20LU4qeidz5VcM75zsMm+S/9LQJel9YrJfDumarGOp+U85vVvy
MT+a+3dPVvIrk3sklUyhiqlMo5p2xzonZ1BDLTOpo71dvWxgFrO5nhvoYHej
nMNcbuJm5jGfW1jAQm7lNm6no3N3yDtZxGLu4m462d0j7+U+GlnCUors7pcP
8CAP0cQylvMwj7CClTSzimLnVstHWcNa1rGeznYb5GM8zhNsZBNd7J6UT/E0
z/Asm9nCczzPC7zIS2ylq3Pb5Mu8wqu8xut0s9sud/AGb/IWb9Pd7h3Zwk52
8S7v8T6T+MVdrqDspKSf3Ouuqznovv9w/2sZTKP5M/2o5x+dKTFvlMM4oFMt
+jRHtmGzzpWbR8hvdHEBh/SxSG7V1dE0mb/T30X0oNS8Xb/LOKjzu/W9UZbQ
4k1UmsvlIW+licPeS6nc7S1V0mw+7H01M6DA3Or9zeAvb7LVe1wvh/K5NzuL
BuqpK7xraqnh60J35XSqmcZUqjhQ6LysZDKTuI5r+dKuQk6knGu4mqu4kiuY
QBmXM57LCt8hzo2TYxnDaC7lEvbbjZIXcxEjGcGFfGp3gTyf8ziX4QzjHM7m
rML3E0MZwmD2OXeGPJ1BDGQA/Wm16ydP41T60odS9tqdIk9GXaICcc1xdXE9
8ZHHx5zjUL0cQ08+cs5P1CuqFXWKGkV1sqfwnqSqRD2iGlGHqEE+KHyXSNce
Vx3XHFf7//fvfy5vp8Q=
       "]]}, {Line3DBox[CompressedData["
1:eJwNzdVuFFAUBdDLX/BEQuBrcIpr26nbTHVc6+7uxd3dJcH1gf9hPZysnZ3s
nJ2RWFl0Wwjhn6vYHsKeHSGUcy8ruY8R7mcVD7CaB1nDT7tCiO8OoVY+pKvj
YdazjA08wkYeZRM/2yRsmuVjuhYeZ5QnGONJtvIU2/jFJmnTLp/WdfAMO3mW
XTzHOM8zwXImWcEUK5lmhBlWMctq5ljDPL/6lfKrINfqiqxjifXsZgN72Mhe
frNJ2/TJTbp+NnOALRxklEOMcZjfbTI2I3KrbpRtHGM7x9nBCXZykl2cYpzT
THCGSc4yxTmmOc8MF/jDr6xfi3JWt8Qcl5nnCgtcZZFr/GmTs1mXS7oNdnOT
PdxiLy+wjxf5yyZvc0nu113mAK9wkFc5xGsc5nWO8AZHeZNjvMVx3uYE73CS
dznFe/ztV8Gv+/K07gFn+JCzfMQ5PuY8n/CPTdHmqbyge8ZFPucSX3CZL7nC
V/xrU7J5La/q3nCNb7nOd9zge27yA7f4kf8BJTmKkg==
       "]], Line3DBox[CompressedData["
1:eJwV0WVWVVEABeCDndgKoiCCMR6H4AB0DnZOwkKxu5vuevB4dHc35nd+vPXt
td/a65x7b+7ps6fOpIUQEn7FGSHcyg6hiLdZwjss5V2W8R7LWcAKNuSFcC4/
hEr5vq6KD1jNQtbwIWv5iHVstDlvUy8/1jXwCRv5lE18xgSfs5lNNhdsWuQX
uiRfspWvmOJrtvEN2/mWHXzHTr5nFz+wmx/Zw0/s5Wf2MeGsi87ql7/oBviV
g/zGIX7nMH9whM02l2xG5Z+6MRZxnMWcYAknWcoptthctpmWy3QzLOcsKzjH
Ss6zigus5iJruMRaLrOOK6znavwu/BXfNX8z6awrzvoT36Xub3xO/ot3Z8h0
H6YxyTVstblqszZm3TqmuJ5t3MB2bmQHN8X/ba7ZbJY7dVvYxa3s5jb2cDt7
mc4+7mA/d3KAuzjI3RziHg5zL0e4L97BWdedtV8e1R3gGDM4zkxO8CAnmRXv
a3PD5pA8pTvMaWZzhjmc5RHOMTc+m81Nm6PyvC6PC8znIo9xice5zBNc4Un+
B5V1qPQ=
       "]], Line3DBox[CompressedData["
1:eJwNzdVSEFAUBdCL2IWtGIRg0N3dnYqd2AV2o6iIiqhg+2G+Wpi/YMF6OLP2
7Jk9J763v7svIoTw3iVHh/A7JoQk/mEK/zKV/5jG/0znJDP4ISGEp4khZMoh
NoQsRjCb05jDSOZyOvP40eaZTb48Q1fAmSzkLBZxNos5hyX8ZDNmUyrP1ZVx
Hss5nxVcwEouZBWjWM1FrOFi1nIJ67iU9VzGBi5nIz/7Ne5Xk7xC18yVbOEq
tjKabVzNdn6xeW7TIa/RdXItu7iO3YzhFsZyKydsXtj0yHG6bYzndq7nDiZw
JxO5ixu4mxu5h5u4l5u5j0ncz2QeYAoP8qtfL/3qlVN1h5jGw0znEWbwKDN5
jN9sXtkcl7N0J5jNk8zhKebyNPN4ht9tXtv0yfm6fhbwLAt5jkU8z2JeYAkv
spSXWMbLLOcVVvAqK3mNVbzOH3698euGXK27yRoOsJa3WMfbrOcgf9q8tbkj
N+juspH32MQhNvM+WzjMXzbvbB7IrbqHbOMjtnOEHXzMTo6yi084BdxIYrs=

       "]], Line3DBox[CompressedData["
1:eJwV0uVSVlEYBtDtTTjjL8fRK8JETBQDFOzuxqD7axrF7sDuxsAWxKbxClzf
jzPr2c/MO/PuM3tCdkFG/pgQQqeveFwIGeNDKOJklnAKSzmVZZzGck5nBRvG
hlDJGc5VzGQ1Z7KGWazlLNaxbyInhRCRZ+uinMMY5zLOeUxwPpPsNxMxk5Kz
dfVcwAYuZCNz2MRFbOZitnAJW7mUbczlUebxGJexnct5nM3uc4L5zidZwFNc
wdNcyTNcxbMcsFvUbufk1brzXMMLXMuLXMdLXM/LHDQTM3NF3qC7yo28xk3s
4GZe5xbe4Fbe5Dbe4nbe5g7e4U7e5S7e427eZ5v7POAe54fcy0fcx8fczyc8
wKccslvcbs/kQt1zHuQLHuJLHmYnj/AVh80kzLyWi3RvWMy3LGEXS/mOZXzP
cn5gBT+ykp9Yxc+s5hfW8Ctr2c129+lhnfM3RtjLKL8zxh+M8ydH7Ja02y85
ofvNJP8wxb+sZ1/6LbOfo2ZSZgbkRt0gmziUfh8cZgtH2MrR9H/mP/4HNeqf
dA==
       "]], Line3DBox[CompressedData["
1:eJwV0lVTVWEUBuDvEHY3GMQ52IHdomJiY937A/Q/2Y3d3a2o2Ci22AKHDp99
sed5Z828e63Zs3M2bSneHAshlHlqMkLYmxVCNfcxyf2s5QHW8SDrWcIG5iZC
OCQ3yofZxCNs5lG28BhbeZxtrIqHsFUvZIZwwizGk0zhKabyNNN4hums1tmm
004+a9ae59iB59mRF9iJF9mZl9iFl9mVV9iNV9md19iD19mTN9iLcXtuyr3l
W+zD2+zLO+zHu+zPexzAGvdt18uQ75tl8gEH8iEH8REHs5RDmNTZoZMlPzbL
5hPm8ClzWcY4nzHB58zjCw7lSw7jKw7na47gG45kOUcxYc9bebT8jmNYwbF8
z3H8wHx+5HjWum+n3gT5k9lEfuYkfuFkfuUUfuNU1uns0pkmV5pN53fO4A/O
5E/O4i/O5m/O4R8W8C/n8h/nsYrzo3+AhdG35gLm2ZOUF0a3clG0n4tZzyVs
4FI2siiau2+33jK5yWw5m7mCLVzJVq5iG1dH79DZo7NGDtkhFDPGtUzhOqZy
PdO4gencyP8tHosh
       "]], Line3DBox[CompressedData["
1:eJwV0NVWVVEABdDNix3YioogmNjdhQq2IiJdJqhgt4KN3d2tpNj1G/6MPc/D
HnONNc4ae9+bWFqZURETQvjh5MSF0CIhhGy2ZC5bMY+tmc82LGBbFnJgcgjt
5CK5PYvZgSXsyFLGcg07cS1/JoVQa7dO7qxbzy7cwK7cyG4sY3eW85dNnc0m
uYduM3tyC3uxgnGsZG9uZR9uY19uZzx3sB93MoG7mMjd7M89HOSeJHmvnMx9
HMD90e/lgegbHuRgHuJv76u3OywP0VVxKKuZwiMcxqMczmP8Y9Ngc1weoTvB
kTzJUTzF0azhGJ7mWJ7hOJ7leJ7jBJ7nRF7gJF7kZF6K3umeKfJleSqvcBqv
cjqvcQavcyZv8K/3NdrdlGfpbnE2b3MO7zCVdzmX9/jPpsnmvjxP94Dz+ZBp
fMR0PuYCPuFCPuUiPuNiPucSvuBSvuQyvuJyvo7+Z/eskGvlDNZxJeuZyQau
YiOz2MRg8yY68mpdM7P5ljl8x1y+Zx4/MMb3zc5HOV/3iQX8zEJ+YRG/spjf
WMLv/A+oZW//
       "]], Line3DBox[CompressedData["
1:eJwNzdVSEFAUBdBLg90oGDDjk8rP+AnYBbaC3aioKHZ3Jx1ii4GNmKjY3YGt
62HP2rPn3Lmp6Zm9MyJCCHVyJCmE9JQQqtiHR9mXx9iPx9mfJziAJ9mjewgD
9VP6IJ7mYFZzCM9wKM9yGM8x0psCOa9n2GqYyQsczoscwUscycuMcl8oV/RR
tqsczWscw1qO5XWOYx3H8wazeJPZvMUJvM2JvMNJvMvJrGdP/0zR7+lTeZ/T
+IDT2cAZfMiZfMRob4rksT7L9oSz+ZRz+Iw5fM65fMEY98XyUp9ne8X5fM1c
vuECvuVCvuMivmceP3AxP3IJPzGfn7mUX7iMX9nLP8v1b/oKNnIlv3MVf3A1
f3INfzHWmxL5ra+1/eE6/uV6/uMGhuQQNjKCce5LJVLfZIviZkZzC2O4lbHc
xjhuZzx3MIE72YS72JS72Yx72Jx72YJp/tmnt9T3sxUPsDUPsg0PsS0L2I7x
3pRJe73Q1oFFTGQxO7KEnVjKJCa4L5dkvczWmeXswgp2ZSW78TBTWMVU/gfZ
NZGg
       "]], Line3DBox[CompressedData["
1:eJwV0mVTUEEYBeDFFhUDc/wigoqKhN3dioHdgggm2N2KP0qUMDERFbu7u/u5
H955zpzZnb2xCTmFWQUxIYRqk9g2hJJ2IbRnKZNYxg4sZ0ceZSceYzJTk0I4
LneWT7ALT7IrTzGFFezG00xlrD2HTJp8RpfOs8zgOXbnefbgBfZkA+uLTS+5
UtebF9mHVezLS+zHy+zPKxzAag7kVQ7iNQ7mdQ7hDQ7lTQ5jmnNuycPl2xzB
OxzJuxzFexzN+xzDhvYcNmPlB7pxfMjxfMQJfMyJfMJMNrL+iJkkP9VN5jNO
4XNO5Qtm8SWn8RWn8zVn8A1n8i1n8R1n8z3n8APnMt05H+V58ifO52cu4Bcu
5Fcu4jcuZpw9JSZb/q7L4Q8u4U/m8heX8jfz2Nj6UpMv/9Et418u5z+uYEgI
YSVjuIo1uJo1WcBaLGRtrmEdrmVdrmM9rmeGc+rLG6I7xY3RPeGm6H9wc/SN
uSV6F25lE3vKzLboWXXbo4472JQ72Yy7GM/dUW99udkjN9ftZQvuY0vuZyse
YGsWsQ0P8j8Fsn52
       "]], Line3DBox[CompressedData["
1:eJwV0eVWVFEYgOHtLYj+EWsEuxsVuwNRDOwAO8COK7AbFbuwu7sIuxUDMRDb
m/A5P771vGuf9c2eORPLyE7LqhBCKDbL40OoEgthGeO5glW5ktW4itW5mjW4
hi0SQ6ip1+oY17EW1zOBG5jIjazNTWxpp47O0XW5mfW4hfW5lQ2Yy4bcxop2
8s123cjZDjbmTjbhLjblbjbjHjbn3ug7cl90L/ezFQ+wNfPYhgfZloei5+5J
0od1Ox5hex5lBx5jMo+zI09En2Wnkz6pO/MUu/A0u/IMu/Esu/Mc4+wUmPO6
h7ML7MmL7MVL7M3L7MMr7Mur7Mdr7M/rHMAbTOFNDuQtpvJ29BvdM0jf0YN5
l2nM5xAWcCgLOYxF0fuwM1zf0+m8zxF8wJF8yFF8xNF8zEp2Cs0TPcbZU47l
M47jc47nC07gS07kK2bwNTP5hpNYzMl8yyl8x6l8zyT3TNMf9HSWcAY/ciZL
OYufOJufo//TTpb+orP5lXNYxrn8xnks53x+Z2U7ReaHXuDsJxfyFxfxNxfz
D5fwL5fyH/8DxSWFZQ==
       "]], Line3DBox[CompressedData["
1:eJwVzdVSFlAYhtGN2IVJCCo/omJ30SBgx3gJXoCe293dXQgKdncriF0Y92B3
4/Lgm/XMnnlnRyZOnjApKoRQ7d4khjAlEsJrTuVbTuM7Tud7zuAHzuRHpqeG
MEt/0rP5mXP4hXP5lfP4jfP5nRk2C/QPvZA/uYi/uJi/uYR/uJR/GWtT4Wr0
Mm8hKYTljOIK1uJKRnMVa3M163AN63It63Ed63M9G3ADG3IjGzHTP5t0Y72Z
TbiFTbmVMdzGZtzO5syy2aFb6J1syV1sxd1szT2MZTHjGGdT6eL1Xm8JLGEb
ljKR+5jE/WzLMrZjOdvzAJN5kBEeYgoPswOPMJXZ/jmqO+pj7MTj7MwTTONJ
duEpdmWOzWndTZ9hd55lD55jT55nL15gb8bb3HZ99EVvfXmJ/XiZ/XmFA3iV
A3mNg3idg3mDQ3iT6bzFDFYwk5XMYu7/v3S2rmIO7zCXd5nHe8znfQ5lns0D
XaAfspCPWMTHHMYnHM6nHMEEmyo3Uj/zNorVHM3nHMMXHMuXHMdXHM9/WlyA
7w==
       "]], Line3DBox[CompressedData["
1:eJwV0UVT1WEUwOEXu7ETlYuo2F1bC1lStqLYBXZ3i4mKjd2dX8JYurG7uxXr
uYszz2/OzJn3/udGsnPTcmJCCDdNWlwItyIhpPI203mHGbzLTN5jX95nP3ZP
DOGB7q8fcgAfcSAfcxCfcDCfcgh7uHmmh+rnzOILDuNLDucrZvM1R7Cum6tm
pH5jN4pvOZrvOIbvOZYfOI4fOZ6fOIGfOZFfOIlfmcNvzOV3TmZP7/zQU/RP
TuUvTmMRp/M3Z/APZ7KXm796lv7H2QwJIcxhDOeyGOexOOeznptrZoEuYbeQ
JbmIpbiYpbmEZbiUZbmM5bic5bmCFbiSFbmKlbiasVzD3t6prPN0Fa5lVa5j
Na5ndW5gDW5kspuaepOuxXzW5mbW4Zbo/8Kt0W9hAePcXDfbom23nfW5gw24
kw25i/HczQj3MIGFbMS9TOQ+NuZ+NuEBNuVB9vFOkj6km/Ewm/MIW/AoW/IY
W/E4U9y01id0G55kW55iO55me55hB56N/n43N8w53dHuPDvxAjvzIrvwErvy
MrvxCv8D5fZ/dg==
       "]], Line3DBox[CompressedData["
1:eJwV0GVTEFEUgOGL2IVdY+H4K+zuAGxsTAywu1sBwUL9I2J3B6Fid3eggq3P
fjjzvHNnz96djU9JT0qLCSEUm7ymIbRpFcI+tuV+tuMBtudBduAhduRh9mkd
Qid9RHfmUXbhMXblcXbjCXbnSfa100Of0j15mr14hr15Nnovz0XP8jyb28k3
F3Q/ZxfZn5c4gJc5kFeYwHwmsoBJLOQgFnEwr3IIr3Eor3MYi6P3u2e4vqFH
8CaTeYsjeZujeIejeTf6Fjtj9D09lvc5jg84ng+ZwkecwMdsYafAPNETnT3l
JD7jZD7nFL7gVL5kKl9xGl9zOt9wBt9yJt8xje+Zzg/RP3LPLP1Rz+YnzuFn
zmUJ5/EL5/Nr9D/tLNDf9EKWchHLuJjfuYQ/uJQ/2dJOofmllzn7zeX8wxX8
y5X8x1UMzUJYzRiuYTmuZSzXsTzXswI3sCI3shIT3LNJV9abWYVbWJUZrMZM
VmcWazDRzlZdU2czjjmsxW2sze2swx2sy3g7Raae3umsPnexAXPZkLvZiHvY
mHvZhP8BHFaK8A==
       "]], Line3DBox[CompressedData["
1:eJwNzdVSFmAUhtHP61BUEBU7sBC7O366RLHAALvjPuxuMVAREbu7sFuxuzFm
XAd71nPyzo7OK4oU1gghVLpaUSEsiQmhJpcyistYm8tZhytYlysZzUhsCKt0
jF7NelzDWK5lfa5jA65nQybZbNBxeiMbcRMbczObcAubciubMdlmm26ut7MF
i9mSO9iKO9mauxjP3WzDErblHrbjXrbnPnZgKRO4nx2Z4leZTtQH2Inl7MyD
7MIKduUhdmOqzWHdXR9hDx5lTx5jLx5nb55gH6bZnNR99Sn242n25xkO4FkO
5DkO4nkO5gUO4UUO5SUO42UO5xVGeJVJTPfrmk7W15nCG0xlJdN4k+m8xQxm
2NzWmfoOs3iX2bzHHN7nCD5gLjNtHuqR+hFH8THz+ISj+ZRj+Ixj+ZzjWMXx
fMF8vmQBX3ECX3Mi33ASs/x6qyfrdyzkexbxA6fwI6fyE6cx2+aznq6/cAa/
cia/cRa/czZ/cA5zbH7qufoX57Ga8/mbC/iHC/mXi/iPi/kfESOO6w==
       "]], Line3DBox[CompressedData["
1:eJwV0lV7D2Acx+FnejqmDQsxtanp7mamDRuGE96C7u7unraZmG6mTTevA/f/
4Lnuz8n3ek5+cVnz0uZGhRCKvAWxIfyND2E+/3EhQ0IIixjFxSzGJSzOpZyS
GEIJvUyX5HKW4gqW5kqW4SpGczWn2pTVa3Q5rmV5rmMFrmdFbmAlbuQ0m8p6
k67CzazKLazGrYzhNlbndtbgDtbkTtbiLtbmbtbhHtblXtbjPmb6K1bv1/V5
gA14kA15iHE8zHgeYZZNgj6qE3mMjXicjXmCTXiSTZnD6TZJ+pRuxtNszjNs
wbNsyXNsxfNM5gWm8CJbM5dtmMe2vMR2zGd7XuYMf6XqK7oDr7Ijr7ETC9iZ
19mFNzjTpqu+qbvxFrvzNnvwDnvyLnvxHrNteuv7ug8fsC8fsh8fsT8fcwCf
cCCfchALOZjPOITPOZQvOIwvOZyvOMtfI/RrPZJvOIpvmcYijuY7pvM9Z9uM
0R/0WH7kOH7ieH7mBH7hRH7lHJtJ+puezO/M4I/I/fNn5Kb5K3Kn/B25If7h
fwW4fMY=
       "]], Line3DBox[CompressedData["
1:eJwVzeVWVVEYhtGFjd0NiqBidwe28NdLwMDiHNLC7sZWVGzs7sDWS/AS7E5s
nefHHvMZa4x3f0mZ0QmRuBDCE9+zhBAyk0N4yol8zkl8wcl8ySl8xSy+5vSU
EKbqN3oa38be+I4z+J4z+YHZ/Bh7t4noTzrKz8zhF+byK/P4jfmsiP3DpkB/
14X8wVn8ydn8xTn8zbn8w3n8yyL+43yGxBAWMI4LWYmLWJmLWYXZbi3RVfVS
VuMyVudy1uAKxnMlazJis0rX0qtZm2tYh2tZl+tYj+tZn1GbDbqB3siGLGYj
bmJjbmYTbmFTbmUzbmNzbmcL7mBL7mQr7mJrljCBOW7t1ol6D9twL9uylEnc
x3bcz2Tm2hzQKfog2/MQO/AwO/IIU1nGTsyzOao762PswuPsyhPsxpPszlPs
wdPsyTPsxbPszXPsw/Psywvsx4vsz3y3LukB+jIH8goH8SoH8xqH8DqHssDm
hh6mb3I4bzGN5RzB2xzJOxzFQpu7erS+xzG8z7F8wHF8yPF8xHQ+Zgb/AwbM
gIs=
       "]]}, {Line3DBox[CompressedData["
1:eJwN0CFIA0AAhtGTBcPCwtQJC6ITBwoOXBBcGGgQXBC2sCAoaBAUHCJoWBA0
LAgaFgwGg8GwYDAsTDAYDIaFBYPBYFhYMCwsGOYLx/vg5+C46d1K8WgkhHDs
tOIhxCdCeOEUO1zgN09nQ1jWPb3GATcZGQvhwralY3qfSZ4wzWvbuc7qK+Z5
ywIfWOYT99hihe+cca+qO7rGb9bZ45ztXg90g5FECE3GOG9700ndZppfzHLR
1tV53WeBQ5a5ZIuOe4dOsMIUq1yxZXRN51jnOu+5aivpht5hk4d844btTLf1
Jb94wy6Ltjvd148c8pnRyRC2ba86oT+Y4iczPLD96Jz+5Tr/WOKo//gHdDdC
Ug==
       "]], Line3DBox[CompressedData["
1:eJwN0C1IA2AUhtErLBgMA/8WFhQWFgwDDYKGgQbBBdEFg6CIQVB0iKBhQdCw
IGhYEDEMMYgsiBhEVAwGg8FgMBgWDAsLhgWDwRM+zgNvuXyDy5uzGx0RseU9
dkf09EU8cYAfHGKDO5mIUd3Sk/zlDBM9Efu2BZ3Uq0xzm1ke2fb0iD5knics
8NR2oef1NVf4wBLPba+6rD9YYYNVXtlauqZ/WWeiP+KON7akftFpvjPLL97b
RnRT59lmgdHrBg7bu/SKTrHEDMscs+V0RY+zyinWOGEr6rpe4h3X+cJp265+
1wf84jGbnLOd6ba+ZKQibtnFRduzTuk3ZvjJHNds33pc/3CKfyyy03/8Azqi
Q5o=
       "]], Line3DBox[CompressedData["
1:eJwN0CtIAwAUhtG7YDAsiO9gGLiwYDAsGBYMhgWDomFBUGFB8IGCoMEgaDAI
GhZEDEMMIgsihiHiAxQUFBYWDAsLBoPBsGAQPOFyPvjbTc2vTC4nImLN3XVG
dPdE3DPFOofY5MZgxIj+1mP85QTbuiJ2bDO6Qy9wgOvM8MC2rbN6n6M84jiP
bWe6oC9Z5C1XeWp70Vu6zj02WeKF7VuX9S8rbOuNqPLK1qGf9ABrzLDBG1tW
f+lRtjjORHfEo62gk7rIfq4yzWfblh7We8yxxDxfbWU9rSucY5VLfLc96U1d
4y4bPOQXp+wnuqXPmeiLuGaSs7YH3a/fmOYHh7lo+9Q5/cM8/zjNdv/4B/r1
Ri4=
       "]], 
      Line3DBox[{26, 127, 228, 329, 6264, 430, 531, 632, 6365, 733, 834, 935, 
       6466, 1036, 1137, 1238, 6567, 1339, 1440, 1541, 6668, 1642, 1743, 1844,
        6769, 1945, 2046, 2147, 6870, 2248, 2349, 2450, 6971, 2551, 2652, 
       2753, 7072, 2854, 2955, 3056, 7173, 3157, 3258, 3359, 7274, 3460, 3561,
        3662, 7375, 3763, 3864, 3965, 7476, 4066, 4167, 4268, 7577, 4369, 
       4470, 4571, 7678, 4672, 4773, 4874, 4975}], Line3DBox[CompressedData["
1:eJwN0C1IA0AAhuFzYcGwMHXKwsAfJigoiCyILAwxDFkQXDAILiwITlwQNCwI
GgyChgWDYcFgWDAYFgQXFgyGhQWDwWBYWDAYFsQnHM8LHwfHTZeOtisjIYRj
53UshEQihDZn2OMSv3g6F8KaHuhNDrnN6HgIF7Y9HdcHTPGEC7yxneuMvmaO
dyzwgbt8YpkvrPKNs+7VdE9f8Yt1Djhva+ihbjI6GUKLcS7aOjqlu1zgJzNc
tvV1Tv+ywMiEN3DVFtNlnWSVada4blvRVzrLOvNscMNW1E1dYosVdrhlO9Nd
fclP3rLPHdu9/tWPjEyF8MwY921tndTvTPODKzy0feus/mGefyxy1H/8A4rR
QaE=
       "]], Line3DBox[CompressedData["
1:eJwN0CFIA1AYhdEnCwuGhakTFoYoGBYMIgsiC0MMQwYKGgyChgVhAxcEDQZB
w4KgYUHBMMGgsKBgmGCYsGAwLCwYDAuGBYNhYUFPeJwPbvl5UzvltdJICGHf
a8VDSEyE8MZpdjnHHg9nQljUP3qFQ64zOhbCqW1bx/UeUzxgmhe2E53R58zx
igVe2+70ln5kka+s8Nb2ro91l1X2WOOD7UfX9ZANRhMhNPlki+u2TrHDNL/4
Ysvovs5xwAIj427ggj2mizrJCmd5zCXbvK7qLGvMs85l26Zu6F02WWabq7Yj
3dFn/OIl+9yw3eiBvmdkMoRnxrhja+mk/uAsPznPku1bZ/Uv8/zjJkf9xz9w
dUTt
       "]], Line3DBox[CompressedData["
1:eJwN0CtIAwAUhtErLBgMA+cjLEwwLBgMCwaDYcGwMETQYBA1GERFFgQNC4IG
g6BhQcEwwaCwoGCYIPgEBQ0LCwbDgmHBYFgweMLlfPC3O7SwNrXaFREb7rE3
YrA/4onDbHKULW4NR4zrHz3JP06zOxWxa5vXKb3CDDc5wkPbjh7TB8zzmEWe
2M71nL7iMu9Y4pntTZd1k/tsscJL24+u6j/W2D0QUee1LaVfdIYNjvCLt7Yx
3dZ5dlhkoi/i3jank3qZaZaY5bOtrHN6nxOssMBXW1XP6hqXWOc6320vels3
uMcvHrHNGfup7ugLJgYjbpjkou1Bp/UHs/xkjmu2bz2hf1lg+MMse/gPIkpG
fg==
       "]], 
      Line3DBox[{51, 152, 253, 354, 6289, 455, 556, 657, 6390, 758, 859, 960, 
       6491, 1061, 1162, 1263, 6592, 1364, 1465, 1566, 6693, 1667, 1768, 1869,
        6794, 1970, 2071, 2172, 6895, 2273, 2374, 2475, 6996, 2576, 2677, 
       2778, 7097, 2879, 2980, 3081, 7198, 3182, 3283, 3384, 7299, 3485, 3586,
        3687, 7400, 3788, 3889, 3990, 7501, 4091, 4192, 4293, 7602, 4394, 
       4495, 4596, 7703, 4697, 4798, 4899, 5000}], Line3DBox[CompressedData["
1:eJwN0C1IA0AAhuFbWFgwDJ0/YWEwwYEDDRMWFBYmGCZMEFwwKBoM/iwsCBoM
goYFQcOCwbBgMCwYDAsG0QWDwWAwGBYMCwuGhYFPOJ4XPg6OS20frh1EQghV
53U0hKnxEN44zS/Os8uTdAiLuq9XOOQ6Y2MhXNi2dELvM8VjZnltO9d5fcUi
b1nmPTf5yD0+s8Z3pt0701+6zi4b7HPG1tRD3WJsIoQ2E5y1dXRKfzLLH+Y5
Z+vpoh6wzGjCG7hgi+s9nWSNGZ5xyZbTdV1ggyU2uWyr6JbeZZtVdrhqO9Wf
+pI/vGGPG7Y7PdAPjE6G8MQ4d2wvOqk/mOE3czyy/eqC/mOJEf9Q4Qj/Aaxv
Qe8=
       "]], Line3DBox[CompressedData["
1:eJwV0C1MAkAAhuHTQCAY/EFncJM5A4FgwI2gGwE3A24ENwkGNg0EnASCmwaC
mwaCmwaCwUAwEAgGA8HgJsFgIBAMBIKBQDAQmI/h9rzbt91ut148y5dnQggV
52MhhNVYCF1uss8tDnm5EcKOHut9TnnI6GIIN7aijuky47xgkve2a53Wd8zy
kfl/bc/6WL+wxDdW2bR96prus84hG2zZxrqpp2wzuhxC5/8eW0x3dZw9Jjlg
x5bWI53lhHlGlryB2/Z5XdJrrDLBGndtKV3XGTaYY5N7toJu61N2WGGXB7Yr
3dO3HPCBIx7ZnvREtxhZCeGV8zyxves1/cUEv5niue1HZ/Qvc5z1DwXO8Q+a
U0VB
       "]], Line3DBox[CompressedData["
1:eJwV0CFIA1AUhtErBoPBMHWCQWSCYWHBsLBgWFgwDDQIGgQFDYKDGRYEDQZB
w4KgYcFgWDAYFgyGBQWFCQqGBYNhYcGwsGBYmMfwOB/8cMOb3y6tHoxERNlr
JSJmpyPeuMgvLrHL44WIZd3XKxxyneOTEee2HZ3UJaZ4xAyvbGc6py9Z4A3X
/rXd6S39wH0+scK67V2f6i9W2WWN97a+rushGxxPRjT/79iSuqVTbDPDDpu2
nO7pAgdc49hUxLNtSyf0PudYYZqvtlOd1VXmWWORb7a63tQN7rHJQ37YWvpE
t3nBDq/Z44b9Vg/0PcdmIh6Z4K7tRc/pT6b5zSzLth+d178sctQ/bHKCf1WF
R80=
       "]], 
      Line3DBox[{76, 177, 278, 379, 6314, 480, 581, 682, 6415, 783, 884, 985, 
       6516, 1086, 1187, 1288, 6617, 1389, 1490, 1591, 6718, 1692, 1793, 1894,
        6819, 1995, 2096, 2197, 6920, 2298, 2399, 2500, 7021, 2601, 2702, 
       2803, 7122, 2904, 3005, 3106, 7223, 3207, 3308, 3409, 7324, 3510, 3611,
        3712, 7425, 3813, 3914, 4015, 7526, 4116, 4217, 4318, 7627, 4419, 
       4520, 4621, 7728, 4722, 4823, 4924, 5025}], Line3DBox[CompressedData["
1:eJwV0C1Ig1EYhuFXMCwYBKcuGBQmKExQMCwsLCwsGEQWBBdEBA3DHzQsCBoM
goYFQYPBYFgwGBYMhgWDYYrBsGAwLCwYDAuGBS/Dx3XDcw58nKmN3ZWdgYjY
972OREyMRbxxhp9cZJfH6Yi87uklRjJilUM8t23qlN5jmkec55XtTOf0JYu8
ZYn3XOcjK3xmle+cdu9Uf+oau7xhj7O2uo7xiAaH2GSKc7aWTus259lhjgu2
H13UfZaYGPUPzNqSuqInWWWGp8zbsrqmC7zhMuss2sq6obfZ5CFb/2dsJ7qt
L9jhNX+4ZrvTff3ARCriiUlu2V70pP5ghl/M8sD2rQv6l8sc9CZlDvMPMI5B
Pg==
       "]], Line3DBox[CompressedData["
1:eJwV0CFIA0AAhtFbMCwsiE5dMAxcMCwYDAsLCwsLhgkLggsKgoYpioYFQcOC
oMEgaBhoEFwQNAw0CC4YDEMNhoUFw8KCwbBgGPgMx/vgv3BccnVrcTMSQthx
3sZCmJ4I4Z2z7HKefR7MhJDTA73AyHgIS4zx2LamE3qbKe5zjue2I53VZyzw
iiVe2m71in5khS+s8sb2oWu6y1P2WeedbaAbOjIZQpMxtvhgS+i2TrHDOfb4
bMvqH13gkCVG497AjD2uKzrJKtOsMWfL6FOdZ51FNliwlXVTb7DFPbb/79gO
dUefsMcL/nDZdq2H+p7RqRCeGOe67VUn9SfT/GKGu7Zvnde/LHLEf5Q5yj8i
tkSW
       "]], Line3DBox[CompressedData["
1:eJwN0CtIAwAUhtHrgsGw4GOKQXDIgsFgMBgWDAsLhoUFwYUFQcOEgQaDoMEg
aDAIGgYaBA2ChoEGwYGCggMXDAsGw8KCYcFgEE+4nA/+difL64VKX0RU3ftQ
xEQqosVpfnKOXe5MRSzoH73IxHDEEpM8sK3ocV1lhtuc5YltX2f1MfM8Z5Fn
tmtd1ves8JlbvLS19J7+5BG7rPHG9qOvdGI0os4kG7yzjeumzrDNWXb4aMvq
ns7zj0UOjEQ82co6pStMc4szfLHt6Xl9xBxrLPDNdqVLus41NrjJd1tT7+o2
D9nhKXtctl/oP33LgbGIB6a4anvVaf3BGX5xnhu2b53Tvyyw3z9KHOQ/20FH
Hg==
       "]]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJyUvHc81f///9+SVRKiSAlpqKwkhftL2SQjDUUatlBKMiqZCSF77733ftj7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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"Stock\"", TraditionalForm], 
    FormBox["\"Time\"", TraditionalForm], 
    FormBox["\"Option\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  ImageSize->{255., Automatic},
  Method->{"RotationControl" -> "Globe"},
  PlotLabel->FormBox["\"American Put\"", TraditionalForm],
  PlotRange->{{30., 130.}, {0.2, 10.}, {0., 50.000000000000085`}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5106870035670233`*^9, 3.5279642197717476`*^9, 
  3.5376685954373875`*^9, 3.541166711017417*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, {2}]],

Cell["\<\
A three dimensional plot of the  CUDA evaluated American put. In this case we \
utilize parallel programming over CPUs in addition to that provided by the \
GPU. \
\>", "PictureCaption",
 CellChangeTimes->{{3.5106848157035303`*^9, 3.51068491000953*^9}, {
  3.51068494410353*^9, 3.51068497426453*^9}, {3.51068508265453*^9, 
  3.51068509545553*^9}},
 CellID->243026665],

Cell["\<\
Michael Kelly
Wolfram Research
training@wolfram.com\
\>", "Subsubtitle",
 CellMargins->{{90, 20}, {2, 30}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellChangeTimes->{3.479485737971568*^9},
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Note", "Section",
 CellChangeTimes->{{3.5417742293323083`*^9, 3.5417742298003054`*^9}}],

Cell["\<\
In order to evaluate the contents of this notebook it is necessary to first \
Evaluate the Initialization cells by going to Evaluation > Evaluate \
Initialization Cells.\
\>", "Text",
 CellChangeTimes->{{3.539969176511142*^9, 3.5399691825744886`*^9}, {
   3.5399692640461483`*^9, 3.5399693974547787`*^9}, {3.5399728873403893`*^9, 
   3.5399729828598523`*^9}, {3.539973020700017*^9, 3.5399730768122263`*^9}, {
   3.539973116764511*^9, 3.539973150972468*^9}, 3.5417743635321293`*^9},
 FontSize->12],

Cell["\<\
Also to do most of the computations it will be necessary to have a CUDA GPU \
chip and CUDALink loaded in. Finally one needs to install in the notebook's \
directory the file CUDARandomVariate.cu and three curand header files which \
come as attachments.\
\>", "Text",
 CellChangeTimes->{{3.539969176511142*^9, 3.5399691825744886`*^9}, {
   3.5399692640461483`*^9, 3.5399693974547787`*^9}, {3.5399728873403893`*^9, 
   3.5399729828598523`*^9}, {3.539973020700017*^9, 3.5399730768122263`*^9}, {
   3.539973116764511*^9, 3.539973150972468*^9}, 3.5417743635321293`*^9},
 FontSize->12]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellChangeTimes->{3.479485737971568*^9},
 CellTags->"SlideShowHeader"],

Cell["Table of Contents", "LargeOverviewTitle"],

Cell[CellGroupData[{

Cell["CUDAFinancialDerivative", "Section",
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, {
   3.5274176909458656`*^9, 3.5274176934340076`*^9}}],

Cell["What is FinancialDerivative?", "Subsection",
 CellChangeTimes->{{3.495209008234375*^9, 3.49520915653125*^9}, 
   3.495209919765625*^9, 3.4952106014375*^9, {3.4952106824375*^9, 
   3.495210832234375*^9}, 3.514307848543872*^9, {3.514308058576482*^9, 
   3.514308065607885*^9}, {3.51430841745117*^9, 3.514308419642997*^9}, {
   3.5149152616687326`*^9, 3.514915280523456*^9}, {3.514915328702818*^9, 
   3.5149153375415287`*^9}, 3.514915444638068*^9, {3.527417783095136*^9, 
   3.5274177859502993`*^9}}],

Cell["CUDAFinancialDerivative", "Subsection",
 CellChangeTimes->{{3.5274179073942456`*^9, 3.5274179102574096`*^9}}],

Cell["Demonstration", "Subsection",
 CellChangeTimes->{{3.527418595167584*^9, 3.5274185965356627`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["CUDAFinancialDerivative and Parallelization", "Section"],

Cell["\<\
Plotting values using CUDAFinancialDerivative with variable inputs\
\>", "Subsection",
 CellMargins->{{65.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.5278234411518655`*^9, 3.5278234484232817`*^9}}],

Cell["\<\
Plotting Greeks using CUDAFinancialDerivative with variable inputs\
\>", "Subsection",
 CellMargins->{{65.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.527823414079317*^9, 3.5278234320393443`*^9}}],

Cell["\<\
Plotting the return of a call spread\
\>", "Subsection",
 CellMargins->{{65.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.5278233409491343`*^9, 3.52782335626101*^9}, {
  3.541264286543335*^9, 3.54126428732638*^9}}],

Cell["\<\
Writing the Black-Scholes formula in CUDA code\
\>", "Subsection",
 CellMargins->{{65.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.5412642938547535`*^9, 3.541264311310752*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Case Study: Finance\[LongDash]Code Generation\
\>", "Section",
 CellChangeTimes->{{3.5412643401424007`*^9, 3.541264342558539*^9}, {
  3.5412680934530783`*^9, 3.541268094941163*^9}, {3.5413511986574235`*^9, 
  3.5413512009335537`*^9}}],

Cell["The Black-Scholes Equation", "MoreExamplesSection",
 CellChangeTimes->{{3.5412695772989492`*^9, 3.541269577858981*^9}},
 FontColor->GrayLevel[0]],

Cell["Calculating the Greeks", "MoreExamplesSection",
 FontColor->GrayLevel[0]],

Cell["\<\
Generate Symbolic Code for Greeks\
\>", "MoreExamplesSection",
 CellChangeTimes->{{3.5087856686518016`*^9, 3.508785671496086*^9}, {
  3.5412695831382833`*^9, 3.541269583667313*^9}},
 FontColor->GrayLevel[0]],

Cell["Generate CUDA Code for Greeks", "MoreExamplesSection",
 CellChangeTimes->{{3.541269587362525*^9, 3.541269587842552*^9}},
 FontColor->GrayLevel[0]],

Cell[TextData[{
 "Load function using ",
 StyleBox["CUDAFunctionLoad",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 FontColor->GrayLevel[0]],

Cell[TextData[{
 "Compute using ",
 StyleBox["CUDAFunction",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5074707613125277`*^9, 3.507470763095252*^9}, {
  3.541264414574658*^9, 3.541264415710723*^9}},
 FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define New Options", "Section",
 CellChangeTimes->{{3.503732310771084*^9, 3.503732329329851*^9}, {
  3.5063648796898046`*^9, 3.5063648905180807`*^9}, {3.5063655134585533`*^9, 
  3.5063655199054065`*^9}, {3.506365555652142*^9, 3.506365565218912*^9}, {
  3.506366735174594*^9, 3.506366765761503*^9}, {3.5063676280968175`*^9, 
  3.506367632112494*^9}, {3.5082174374294577`*^9, 3.5082174394529734`*^9}, {
  3.5082175133952656`*^9, 3.5082175167948103`*^9}}],

Cell[CellGroupData[{

Cell["Binary Options ", "Subsection",
 CellChangeTimes->{{3.5082175839038324`*^9, 3.508217586847305*^9}, {
   3.50821773545848*^9, 3.5082177401539726`*^9}, 3.508815070938849*^9, 
   3.511012348856659*^9}],

Cell[TextData[{
 "Compute using ",
 StyleBox["CUDAFunction",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5074707613125277`*^9, 3.507470763095252*^9}, {
  3.541268240542491*^9, 3.5412682415175467`*^9}},
 FontColor->GrayLevel[0]],

Cell[TextData[{
 "Load function using ",
 StyleBox["CUDAFunctionLoad",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 FontColor->GrayLevel[0]]
}, Open  ]]
}, Open  ]],

Cell["CUDA Brownian Motion", "Section",
 CellChangeTimes->{{3.500080936034875*^9, 3.500080939722375*^9}, {
  3.537673916328058*^9, 3.537673917997225*^9}}],

Cell["Simulation of Stochastic Differential Equations", "Section",
 CellChangeTimes->{{3.5275665581855845`*^9, 3.527566572345394*^9}}],

Cell["The General Scheme", "Section",
 CellChangeTimes->{{3.5275679254247866`*^9, 3.5275679277089167`*^9}}],

Cell["Basic Option Pricing", "Section",
 CellChangeTimes->{{3.5275926477518225`*^9, 3.5275926499729495`*^9}}],

Cell["Performance", "Section",
 CellChangeTimes->{{3.5275931905128665`*^9, 3.527593191589928*^9}}],

Cell["\<\
Systems of SDEs\[LongDash]The Heston Model\
\>", "Section",
 CellChangeTimes->{{3.527850635803311*^9, 3.527850640135558*^9}, {
  3.541268398798543*^9, 3.5412684035818167`*^9}, {3.5412695137303133`*^9, 
  3.541269516462469*^9}}],

Cell["\<\
Stochastic Rate Models\[LongDash]The Hull-White Model\
\>", "Section",
 CellChangeTimes->{{3.5278907576155357`*^9, 3.527890765515976*^9}, {
  3.541268466078391*^9, 3.54126846780649*^9}, {3.5412685399186144`*^9, 
  3.5412685583536687`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["CUDAFinancialDerivative", "Section",
 CellChangeTimes->{
  3.483202458955147*^9, {3.514308340990994*^9, 3.514308352103572*^9}, {
   3.5274176909458656`*^9, 3.5274176934340076`*^9}}],

Cell[CellGroupData[{

Cell["What is FinancialDerivative?", "Subsection",
 CellChangeTimes->{{3.495209008234375*^9, 3.49520915653125*^9}, 
   3.495209919765625*^9, 3.4952106014375*^9, {3.4952106824375*^9, 
   3.495210832234375*^9}, 3.514307848543872*^9, {3.514308058576482*^9, 
   3.514308065607885*^9}, {3.51430841745117*^9, 3.514308419642997*^9}, {
   3.5149152616687326`*^9, 3.514915280523456*^9}, {3.514915328702818*^9, 
   3.5149153375415287`*^9}, 3.514915444638068*^9, {3.527417783095136*^9, 
   3.5274177859502993`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "A superfunction introduced in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 8 dedicated to pricing and calculating sensitivities of various options."
}], "Item",
 CellChangeTimes->{{3.5274178128548384`*^9, 3.527417836399185*^9}}],

Cell["\<\
Supports 95 styles of options, most with both American and European exercise \
style.\
\>", "Item",
 CellChangeTimes->{{3.5274178488718987`*^9, 3.5274178760404525`*^9}}],

Cell["\<\
The underlying model for all options supported by FinancialDerivative is the \
Black-Scholes-Merton model.\
\>", "Item",
 CellChangeTimes->{{3.527417880672717*^9, 3.5274179008568716`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["CUDAFinancialDerivative", "Subsection",
 CellChangeTimes->{{3.5274179073942456`*^9, 3.5274179102574096`*^9}}],

Cell[CellGroupData[{

Cell["\<\
A built-in CUDA-accelerated superfunction that mimics the behavior of \
FinancialDerivative for a limited set of option types.\
\>", "Item",
 CellChangeTimes->{{3.5274182148998337`*^9, 3.527418238820202*^9}, {
  3.541268603234236*^9, 3.5412686036632605`*^9}}],

Cell["\<\
In 8, only around a dozen option types are supported; internally, we \
currently support more than 50. The quick increase in support is largely due \
to the use of code generation techniques to be discussed later.\
\>", "Item",
 CellChangeTimes->{{3.5274183469443865`*^9, 3.5274184060337667`*^9}}],

Cell[TextData[{
 "CUDAFinancialDerivative demonstrates clearly the benefit of using CUDA \
within ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[LongDash]we maintain a very readable, high-level interface and easy \
integration with other ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions while attaining substantial performance gains from the use of \
CUDA."
}], "Item",
 CellChangeTimes->{{3.5274184371945486`*^9, 3.527418455611602*^9}, {
  3.527418487340417*^9, 3.527418571631238*^9}, {3.541268629343729*^9, 
  3.541268648543827*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Demonstration", "Subsection",
 CellChangeTimes->{{3.527418595167584*^9, 3.5274185965356627`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Here we can quickly compare performance for pricing a set of arithmetically \
averaged Asian options with and without CUDA.\
\>", "Item",
 CellChangeTimes->{{3.527418599189814*^9, 3.527418658757221*^9}, {
  3.5412686610565434`*^9, 3.5412686615835733`*^9}}],

Cell["Setup", "Item",
 CellChangeTimes->{{3.5274186597052755`*^9, 3.5274187019146895`*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numOptions", "=", "32"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"spots", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"35", ",", "45"}], "}"}], ",", "numOptions"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"strikes", "=", 
   RowBox[{"spots", "*", 
    RowBox[{"RandomReal", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.75", ",", "1.25"}], "}"}], ",", "numOptions"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expirations", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.5", ",", "2.0"}], "}"}], ",", "numOptions"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rates", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.06", ",", "0.12"}], "}"}], ",", "numOptions"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"vols", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.10", ",", "0.50"}], "}"}], ",", "numOptions"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5274186770652685`*^9, 3.5274187971101346`*^9}}],

Cell["Without CUDA (FinancialDerivative and ParallelMap)", "Item",
 CellChangeTimes->{{3.5274188091668243`*^9, 3.527418818919382*^9}, 
   3.5412686737272673`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ParallelMap", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FinancialDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "\"\<AsianArithmetic\>\"", ",", "\"\<European\>\"", ",", 
          "\"\<Call\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", 
           RowBox[{"strikes", "[", 
            RowBox[{"[", "#", "]"}], "]"}]}], ",", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", 
           RowBox[{"expirations", "[", 
            RowBox[{"[", "#", "]"}], "]"}]}], ",", 
          RowBox[{"\"\<AverageSoFar\>\"", "\[Rule]", 
           RowBox[{"spots", "[", 
            RowBox[{"[", "#", "]"}], "]"}]}], ",", 
          RowBox[{"\"\<Inception\>\"", "\[Rule]", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", 
           RowBox[{"spots", "[", 
            RowBox[{"[", "#", "]"}], "]"}]}], ",", 
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", 
           RowBox[{"rates", "[", 
            RowBox[{"[", "#", "]"}], "]"}]}], ",", 
          RowBox[{"\"\<Volatility\>\"", "\[Rule]", 
           RowBox[{"vols", "[", 
            RowBox[{"[", "#", "]"}], "]"}]}]}], "}"}]}], "]"}], "&"}], ",", 
     RowBox[{"Range", "[", "numOptions", "]"}]}], "\[IndentingNewLine]", 
    "]"}], ";"}], "//", "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.527418821277517*^9, 3.527418936968134*^9}, 
   3.527855729119206*^9, {3.527855760832781*^9, 3.527855771039909*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.0953486`8.236543541961789", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5279642802592077`*^9, {3.539743248923669*^9, 3.5397432601383104`*^9}}]
}, Closed]],

Cell["With CUDA (CUDAFinancialDerivative)", "Item",
 CellChangeTimes->{{3.527418962196577*^9, 3.527418968699949*^9}, 
   3.541268682031743*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CUDAFinancialDerivative", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<AsianArithmetic\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", "strikes"}], ",", 
       RowBox[{"\"\<Expiration\>\"", "\[Rule]", "expirations"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", "spots"}], ",", 
       RowBox[{"\"\<InterestRate\>\"", "\[Rule]", "rates"}], ",", 
       RowBox[{"\"\<Volatility\>\"", "\[Rule]", "vols"}]}], "}"}]}], "]"}], 
   ";"}], "//", "AbsoluteTiming"}]], "Input",
 CellChangeTimes->{{3.527418970594057*^9, 3.527419011568401*^9}, {
  3.527855731335692*^9, 3.527855772868269*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6770387`7.282158487463367", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.5279642805652246`*^9, 3.527964295903102*^9}, {
  3.5397432770192757`*^9, 3.5397432829596157`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["CUDA Financial Derivative and Parallelization", "Section"],

Cell["", "Text",
 CellChangeTimes->{{3.503228151346015*^9, 3.5032281572030277`*^9}},
 FontFamily->"Times New Roman",
 FontSize->8],

Cell[CellGroupData[{

Cell[TextData[{
 "Speed-up obtained using ",
 StyleBox["CUDALink",
  FontSlant->"Italic"]
}], "Subsection",
 CellMargins->{{66.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
   3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
   3.503314792621125*^9}, {3.5278234411518655`*^9, 3.5278234484232817`*^9}, {
   3.5408246539956884`*^9, 3.540824657960915*^9}, 3.541351253937586*^9}],

Cell[TextData[{
 StyleBox["The following shows the speedup obtained using ",
  FontFamily->"Georgia"],
 StyleBox["CUDALink",
  FontFamily->"Georgia",
  FontSlant->"Italic"],
 StyleBox[" compared to Compile, Mathematica, or FinancialDerivative (CPU). ",
  FontFamily->"Georgia"]
}], "MathCaption",
 CellMargins->{{65, 12}, {6, 34}},
 CellChangeTimes->{
  3.435513906503024*^9, {3.439663683411996*^9, 3.4396637076276307`*^9}, {
   3.4397408119503636`*^9, 3.439740816496538*^9}, {3.441727703707619*^9, 
   3.441727727802747*^9}, {3.451650706163927*^9, 3.4516507070383053`*^9}, {
   3.481284485808154*^9, 3.4812845148524265`*^9}, {3.4812854521231413`*^9, 
   3.4812854861832433`*^9}, 3.4812856331260223`*^9, {3.4812856655612392`*^9, 
   3.481285675685526*^9}, {3.481303689997296*^9, 3.481303722472939*^9}, {
   3.481456087628784*^9, 3.481456100455924*^9}, 3.504611177112706*^9, {
   3.5046112888711042`*^9, 3.5046113163688164`*^9}, {3.5046114197195916`*^9, 
   3.5046114760430303`*^9}, {3.504611935742608*^9, 3.504611941820656*^9}, 
   3.5046120249112825`*^9, 3.504612703857331*^9, {3.5046127356377673`*^9, 
   3.504612808432779*^9}, 3.5046329171904287`*^9, {3.504633499637619*^9, 
   3.504633528919244*^9}, 3.5046335625603*^9, 3.5046340231286945`*^9, 
   3.5046341153017497`*^9, 3.5046347243095446`*^9, 3.504634759106865*^9, 
   3.504635249566268*^9, 3.5046364613980284`*^9, {3.504636664724852*^9, 
   3.504636682818486*^9}, {3.504636963474331*^9, 3.504636980083706*^9}, {
   3.5408249399640446`*^9, 3.5408249424741883`*^9}, {3.541268786671728*^9, 
   3.5412687882728195`*^9}, 3.541269452114789*^9},
 FontFamily->"Calibri",
 FontColor->GrayLevel[0],
 CellTags->"Basic Operations"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogPlot", "[", 
  RowBox[{
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Tooltip", "[", 
       RowBox[{
        RowBox[{"Tooltip", "@", 
         RowBox[{"computeSpeedup", "[", 
          RowBox[{"#1", ",", "CUDATimes"}], "]"}]}], ",", "#2"}], "]"}], 
      "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "MTimes", ",", "CompileTimes", ",", "FinancialDerivativeTimes"}], 
        "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Mathematica\>\"", ",", "\"\<Compile\>\"", ",", 
         "\"\<FinancialDerivative\>\""}], "}"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Number of Options\>\"", ",", "\"\<Speed Up\>\""}], "}"}]}], 
   ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]], "Input",
 Evaluatable->False,
 CellChangeTimes->{{3.5024329377542796`*^9, 3.502432937834361*^9}, {
  3.5024330529745245`*^9, 3.5024331691469536`*^9}, {3.502433205322171*^9, 
  3.502433205473544*^9}, {3.502433332334861*^9, 3.502433483641452*^9}, {
  3.5024335751029716`*^9, 3.502433580886397*^9}, {3.502434039560259*^9, 
  3.5024340535432177`*^9}, {3.502434317351199*^9, 3.5024343225506177`*^9}, {
  3.5024346765720243`*^9, 3.5024346817548404`*^9}, {3.50243571573888*^9, 
  3.502435824615131*^9}, {3.5024593061290913`*^9, 3.502459309248351*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     TooltipBox[
      {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQY1SxxqVpq2bj/A6gDmV29x0PpY7OrDygXh79jn
kLHy/mGNZj4wv6HqiMNKF8lcrlYIn2HmSYfgQw5nAzcIQOS3n3MIt0w9uCBd
ECL/+qLDz1/n0p6xC4H5DlVXHN6/t3d6wgbhN3Bed+BLvp69vQ7CPzDjpsM5
tpz++iIIn0HjjsPje5/us3sJQ/Rvv+fgY16//bEelL/4gYOYjtaSm9UQ/oNX
Dx3iCvh1Qp1FIOYbPXY4e3GL2Fo+CF+h6olD0aPHQXphEP6Bg08dxDZdma+j
CuEncD53MGMzFn2UCOEzBL5wEL8pV7jADMJfMOOlg/ytb38uCUH4Dg9eOcy4
pnjpyWwI/4H6G4cWZePdrNeh9ue/dShgZvCTExOF2L/9nUOX17H13QYQ/oF/
7x12TqhUFIsSdQAAkwyBNg==
        "]]},
      "\"Mathematica\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Mathematica", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBGIQDQY1SxwYkEH1FgeGQAPm4Ld37MH8Hfscdiyfwv4l
6T2Y31B1xOEbz4WQjw/fQeRnnnQ4se7KQZ+ZXyHy28851JnZnzcJ/AGRf33R
QdnUWe/+4l9gvkPVFQfrxk1rq19A+A2c1x2YFLR+ca/+A+YfmHHTwbH41a3q
OAifQeOOg9+hhTP0Nv2H6N9+D+oeKH/xA4f0maeOLdJlAPvjwauHDq7JHN9a
njOC+Q1Gjx32my/o4l4L4StUPXGYWVPe56zGBOYfOPjU4VS40SnB6xD5BM7n
DvsmW28KdILIMwS+cOj5YCTM+RQiv2DGSwdu5rVVryZD+A4PXjmc158yb8YE
iPoH6m8cBCLi33G9gvAb8t86eOmn3Ntnzwyxf/s7B0tVx0LGSRD+gX/vHXhW
zlva/YHZAQCPFIm/
        "]]},
      "\"Compile\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "Compile", "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQAmIQDQEf7COijNYVKf3fD+bWLHFY2MQ9eeIKUQcwv3qL
w2/mOI5zV8Uh/B37HLbWxsQvEJcC8xuqjjhMrHgev1ASwmeYedIhYKEsd0uH
NER++zmHrv2eegZOMhD51xcdkjr+GLfeh/Adqq44rGUWXHbwIYTfwHndYeaa
lt9HI2TB/AMzbjp8jWud/jYZwmfQuOMQW97PaKUtB9G//Z7DRPuyNfM5oPzF
Dxy4edRZ+qMg/AevHjoc8X2UliwnDzHf6LFD/GU3+/q3EHmFqicO3SKWNbkO
EPkDB586HGKST/7JDOEncD53WPbl3o08ZwifIfCFw51tz1Q1JSD8BTNeOjxQ
tQho/Ay1/8Erh733FHgf1UHkH6i/cRALf9ljvAZqf/5bh7aEK8bTbkP4Ctvf
OQRmvWfhZVGA2P/vvcODm68EN8gpOAAA/fGIDA==
        "]]},
      "\"FinancialDerivative\"",
      TooltipStyle->"TextStyling"],
     Annotation[#, "FinancialDerivative", "Tooltip"]& ]}, {
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{2622., 2.7191000372887952`}}]},
      RowBox[{"{", 
        RowBox[{
         "2622", ",", 
          "15.1666666666666666666666666666666666655`5.191682621882566"}], 
        "}"}]],
     Annotation[#, {
      2622, 15.1666666666666666666666666666666666655`5.191682621882566}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{5243., 3.2525868822105126`}}]},
      RowBox[{"{", 
        RowBox[{
         "5243", ",", 
          "25.8571428571428571428571428571428571447`5.2698804790638345"}], 
        "}"}]],
     Annotation[#, {
      5243, 25.8571428571428571428571428571428571447`5.2698804790638345}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{7864., 3.8140425970679424`}}]},
      RowBox[{"{", 
        RowBox[{
         "7864", ",", 
          "45.33333333333333333333333333333333332949`5.209937071943841"}], 
        "}"}]],
     Annotation[#, {
      7864, 45.33333333333333333333333333333333332949`5.209937071943841}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{10485., 3.8149612925850147`}}]},
      RowBox[{"{", 
        RowBox[{
         "10485", ",", 
          "45.37499999999999999999999999999999999093`5.334884415857088"}], 
        "}"}]],
     Annotation[#, {
      10485, 45.37499999999999999999999999999999999093`5.334884415857088}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{13106., 4.172187048986035}}]},
      RowBox[{"{", 
        RowBox[{
         "13106", ",", 
          "64.85714285714285714285714285714285714728`5.27971468092579"}], 
        "}"}]],
     Annotation[#, {
      13106, 64.85714285714285714285714285714285714728`5.27971468092579}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{15727., 4.351199170878622}}]},
      RowBox[{"{", 
        RowBox[{
         "15727", ",", 
          "77.57142857142857142857142857142857143367`5.280796893552937"}], 
        "}"}]],
     Annotation[#, {
      15727, 77.57142857142857142857142857142857143367`5.280796893552937}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{18348., 4.507714849837378}}]},
      RowBox[{"{", 
        RowBox[{
         "18348", ",", 
          "90.71428571428571428571428571428571429198`5.281598450681455"}], 
        "}"}]],
     Annotation[#, {
      18348, 90.71428571428571428571428571428571429198`5.281598450681455}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{20969., 4.5067301131748385`}}]},
      RowBox[{"{", 
        RowBox[{
         "20969", ",", 
          "90.6250000000000000000000000000000000157`5.339585732365885"}], 
        "}"}]],
     Annotation[#, {
      20969, 90.6250000000000000000000000000000000157`5.339585732365885}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{23590., 4.623746571561027}}]},
      RowBox[{"{", 
        RowBox[{
         "23590", ",", 
          "101.87499999999999999999999999999999997945`5.340109473963729"}], 
        "}"}]],
     Annotation[#, {
      23590, 101.87499999999999999999999999999999997945`5.340109473963729}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{26211., 4.61181472870676}}]},
      RowBox[{"{", 
        RowBox[{
         "26211", ",", 
          "100.66666666666666666666666666666666665898`5.391211326493767"}], 
        "}"}]],
     Annotation[#, {
      26211, 100.66666666666666666666666666666666665898`5.391211326493767}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{28832., 4.822295664976738}}]},
      RowBox[{"{", 
        RowBox[{
         "28832", ",", 
          "124.25000000000000000000000000000000002163`5.340870363302108"}], 
        "}"}]],
     Annotation[#, {
      28832, 124.25000000000000000000000000000000002163`5.340870363302108}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{31453., 4.795790545596741}}]},
      RowBox[{"{", 
        RowBox[{
         "31453", ",", 
          "120.99999999999999999999999999999999999064`5.391929762525103"}], 
        "}"}]],
     Annotation[#, {
      31453, 120.99999999999999999999999999999999999064`5.391929762525103}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{34074., 4.870947423051822}}]},
      RowBox[{"{", 
        RowBox[{
         "34074", ",", 
          "130.44444444444444444444444444444444443464`5.392187575167066"}], 
        "}"}]],
     Annotation[#, {
      34074, 130.44444444444444444444444444444444443464`5.392187575167066}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{36695., 5.065754593317335}}]},
      RowBox[{"{", 
        RowBox[{
         "36695", ",", 
          "158.50000000000000000000000000000000002746`5.341620279596592"}], 
        "}"}]],
     Annotation[#, {
      36695, 158.50000000000000000000000000000000002746`5.341620279596592}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{39316., 5.0143321559775815`}}]},
      RowBox[{"{", 
        RowBox[{
         "39316", ",", 
          "150.5555555555555555555555555555555555443`5.392629147773365"}], 
        "}"}]],
     Annotation[#, {
      39316, 150.5555555555555555555555555555555555443`5.392629147773365}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{41937., 5.084161086234063}}]},
      RowBox[{"{", 
        RowBox[{
         "41937", ",", 
          "161.44444444444444444444444444444444443196`5.392822464559578"}], 
        "}"}]],
     Annotation[#, {
      41937, 161.44444444444444444444444444444444443196`5.392822464559578}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{44558., 5.0363030408448335`}}]},
      RowBox[{"{", 
        RowBox[{
         "44558", ",", 
          "153.9000000000000000000000000000000000037`5.4384489155163465"}], 
        "}"}]],
     Annotation[#, {
      44558, 153.9000000000000000000000000000000000037`5.4384489155163465}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{47179., 5.095588999976419}}]},
      RowBox[{"{", 
        RowBox[{
         "47179", ",", 
          "163.30000000000000000000000000000000000394`5.438610334745682"}], 
        "}"}]],
     Annotation[#, {
      47179, 163.30000000000000000000000000000000000394`5.438610334745682}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{49800., 5.053346412189305}}]},
      RowBox[{"{", 
        RowBox[{
         "49800", ",", 
          "156.54545454545454545454545454545454542823`5.479888983006022"}], 
        "}"}]],
     Annotation[#, {
      49800, 156.54545454545454545454545454545454542823`5.479888983006022}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{52421., 5.018382980887082}}]},
      RowBox[{"{", 
        RowBox[{
         "52421", ",", 
          "151.16666666666666666666666666666666669312`5.517579469017496"}], 
        "}"}]],
     Annotation[#, {
      52421, 151.16666666666666666666666666666666669312`5.517579469017496}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{55042., 5.152240069690059}}]},
      RowBox[{"{", 
        RowBox[{
         "55042", ",", 
          "172.81818181818181818181818181818181815275`5.4801486275276625"}], 
        "}"}]],
     Annotation[#, {
      55042, 172.81818181818181818181818181818181815275`5.4801486275276625}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{57663., 5.209982800480137}}]},
      RowBox[{"{", 
        RowBox[{
         "57663", ",", 
          "183.09090909090909090909090909090909092844`5.480288837269215"}], 
        "}"}]],
     Annotation[#, {
      57663, 183.09090909090909090909090909090909092844`5.480288837269215}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{60284., 5.2715999782093235`}}]},
      RowBox[{"{", 
        RowBox[{
         "60284", ",", 
          "194.72727272727272727272727272727272729347`5.48042983527465"}], 
        "}"}]],
     Annotation[#, {
      60284, 194.72727272727272727272727272727272729347`5.48042983527465}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{62905., 5.297407862165196}}]},
      RowBox[{"{", 
        RowBox[{
         "62905", ",", 
          "199.81818181818181818181818181818181814837`5.480486370818337"}], 
        "}"}]],
     Annotation[#, {
      62905, 199.81818181818181818181818181818181814837`5.480486370818337}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{65526., 5.337975047154196}}]},
      RowBox[{"{", 
        RowBox[{
         "65526", ",", 
          "208.09090909090909090909090909090909093117`5.480572355259251"}], 
        "}"}]],
     Annotation[#, {
      65526, 208.09090909090909090909090909090909093117`5.480572355259251}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{2622., 0.}}]},
      RowBox[{"{", 
        RowBox[{"2622", ",", "1.`4.918382968163738"}], "}"}]],
     Annotation[#, {2622, 1.`4.918382968163738}, "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{5243., 0.4519851237430572}}]},
      RowBox[{"{", 
        RowBox[{
         "5243", ",", 
          "1.57142857142857142857142857142857142851`5.072479933513251"}], 
        "}"}]],
     Annotation[#, {
      5243, 1.57142857142857142857142857142857142851`5.072479933513251}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{7864., 0.9808292530117262}}]},
      RowBox[{"{", 
        RowBox[{
         "7864", ",", 
          "2.6666666666666666666666666666666666665`5.0811102656614375"}], 
        "}"}]],
     Annotation[#, {
      7864, 2.6666666666666666666666666666666666665`5.0811102656614375}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{10485., 0.965080896043587}}]},
      RowBox[{"{", 
        RowBox[{
         "10485", ",", 
          "2.62499999999999999999999999999999999929`5.204172997270985"}], 
        "}"}]],
     Annotation[#, {
      10485, 2.62499999999999999999999999999999999929`5.204172997270985}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{13106., 1.3499267169490157`}}]},
      RowBox[{"{", 
        RowBox[{
         "13106", ",", 
          "3.85714285714285714285714285714285714341`5.1862446005750655"}], 
        "}"}]],
     Annotation[#, {
      13106, 3.85714285714285714285714285714285714341`5.1862446005750655}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{15727., 1.519825753744413}}]},
      RowBox[{"{", 
        RowBox[{
         "15727", ",", 
          "4.57142857142857142857142857142857142894`5.200445124751741"}], 
        "}"}]],
     Annotation[#, {
      15727, 4.57142857142857142857142857142857142894`5.200445124751741}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{18348., 1.6650077635889111`}}]},
      RowBox[{"{", 
        RowBox[{
         "18348", ",", 
          "5.28571428571428571428571428571428571447`5.211108801039139"}], 
        "}"}]],
     Annotation[#, {
      18348, 5.28571428571428571428571428571428571447`5.211108801039139}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{20969., 1.6817585740137264`}}]},
      RowBox[{"{", 
        RowBox[{
         "20969", ",", 
          "5.37500000000000000000000000000000000085`5.2702499799176685"}], 
        "}"}]],
     Annotation[#, {
      20969, 5.37500000000000000000000000000000000085`5.2702499799176685}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{23590., 1.791759469228055}}]},
      RowBox[{"{", 
        RowBox[{
         "23590", ",", 
          "5.99999999999999999999999999999999999887`5.277404910805408"}], 
        "}"}]],
     Annotation[#, {
      23590, 5.99999999999999999999999999999999999887`5.277404910805408}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{26211., 1.7730673362159026`}}]},
      RowBox[{"{", 
        RowBox[{
         "26211", ",", 
          "5.88888888888888888888888888888888888833`5.327388402985937"}], 
        "}"}]],
     Annotation[#, {
      26211, 5.88888888888888888888888888888888888833`5.327388402985937}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{28832., 1.9810014688665833`}}]},
      RowBox[{"{", 
        RowBox[{
         "28832", ",", 
          "7.25000000000000000000000000000000000132`5.288235758457089"}], 
        "}"}]],
     Annotation[#, {
      28832, 7.25000000000000000000000000000000000132`5.288235758457089}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{31453., 1.9616585060234524`}}]},
      RowBox[{"{", 
        RowBox[{
         "31453", ",", 
          "7.11111111111111111111111111111111111067`5.338361336746832"}], 
        "}"}]],
     Annotation[#, {
      31453, 7.11111111111111111111111111111111111067`5.338361336746832}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{34074., 2.0222831278398874`}}]},
      RowBox[{"{", 
        RowBox[{
         "34074", ",", 
          "7.555555555555555555555555555555555555`5.341522410417155"}], "}"}]],
     Annotation[#, {
      34074, 7.555555555555555555555555555555555555`5.341522410417155}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{36695., 2.2380465718564744`}}]},
      RowBox[{"{", 
        RowBox[{
         "36695", ",", 
          "9.3750000000000000000000000000000000016`5.300334871451647"}], 
        "}"}]],
     Annotation[#, {
      36695, 9.3750000000000000000000000000000000016`5.300334871451647}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{39316., 2.209494669928034}}]},
      RowBox[{"{", 
        RowBox[{
         "39316", ",", 
          "9.11111111111111111111111111111111111033`5.350276682946023"}], 
        "}"}]],
     Annotation[#, {
      39316, 9.11111111111111111111111111111111111033`5.350276682946023}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{41937., 2.268683541318364}}]},
      RowBox[{"{", 
        RowBox[{
         "41937", ",", 
          "9.666666666666666666666666666666666666`5.352752242462449"}], "}"}]],
     Annotation[#, {
      41937, 9.666666666666666666666666666666666666`5.352752242462449}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{44558., 2.2300144001592104`}}]},
      RowBox[{"{", 
        RowBox[{
         "44558", ",", 
          "9.30000000000000000000000000000000000033`5.396907437292837"}], 
        "}"}]],
     Annotation[#, {
      44558, 9.30000000000000000000000000000000000033`5.396907437292837}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{47179., 2.2823823856765264`}}]},
      RowBox[{"{", 
        RowBox[{
         "47179", ",", 
          "9.80000000000000000000000000000000000018`5.399064033649621"}], 
        "}"}]],
     Annotation[#, {
      47179, 9.80000000000000000000000000000000000018`5.399064033649621}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{49800., 2.236833715431265}}]},
      RowBox[{"{", 
        RowBox[{
         "49800", ",", 
          "9.3636363636363636363636363636363636346`5.438586771971003"}], 
        "}"}]],
     Annotation[#, {
      49800, 9.3636363636363636363636363636363636346`5.438586771971003}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{52421., 2.1972245773362196`}}]},
      RowBox[{"{", 
        RowBox[{
         "52421", ",", 
          "9.00000000000000000000000000000000000175`5.474685468931025"}], 
        "}"}]],
     Annotation[#, {
      52421, 9.00000000000000000000000000000000000175`5.474685468931025}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{55042., 2.320603598496724}}]},
      RowBox[{"{", 
        RowBox[{
         "55042", ",", 
          "10.18181818181818181818181818181818181634`5.4419673098330845"}], 
        "}"}]],
     Annotation[#, {
      55042, 10.18181818181818181818181818181818181634`5.4419673098330845}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{57663., 2.3642786619993856`}}]},
      RowBox[{"{", 
        RowBox[{
         "57663", ",", 
          "10.63636363636363636363636363636363636476`5.443630290700596"}], 
        "}"}]],
     Annotation[#, {
      57663, 10.63636363636363636363636363636363636476`5.443630290700596}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{60284., 2.406125771934886}}]},
      RowBox[{"{", 
        RowBox[{
         "60284", ",", 
          "11.09090909090909090909090909090909091038`5.445162588309963"}], 
        "}"}]],
     Annotation[#, {
      60284, 11.09090909090909090909090909090909091038`5.445162588309963}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{62905., 2.446291813660221}}]},
      RowBox[{"{", 
        RowBox[{
         "62905", ",", 
          "11.54545454545454545454545454545454545258`5.446579033157021"}], 
        "}"}]],
     Annotation[#, {
      62905, 11.54545454545454545454545454545454545258`5.446579033157021}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{65526., 2.492453855423383}}]},
      RowBox[{"{", 
        RowBox[{
         "65526", ",", 
          "12.09090909090909090909090909090909091038`5.448143547474136"}], 
        "}"}]],
     Annotation[#, {
      65526, 12.09090909090909090909090909090909091038`5.448143547474136}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{1., -1.9459101490553135`}}]},
      RowBox[{"{", 
        RowBox[{
         "1", ",", 
          "0.14285714285714285714285714285714285745`4.38326976646639"}], 
        "}"}]],
     Annotation[#, {
      1, 0.14285714285714285714285714285714285745`4.38326976646639}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{2622., 5.414617822244197}}]},
      RowBox[{"{", 
        RowBox[{
         "2622", ",", 
          "224.66666666666666666666666666666666664945`5.217484191677892"}], 
        "}"}]],
     Annotation[#, {
      2622, 224.66666666666666666666666666666666664945`5.217484191677892}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{5243., 5.9587937648184335`}}]},
      RowBox[{"{", 
        RowBox[{
         "5243", ",", 
          "387.14285714285714285714285714285714288281`5.285239405914845"}], 
        "}"}]],
     Annotation[#, {
      5243, 387.14285714285714285714285714285714288281`5.285239405914845}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{7864., 6.523072710056501}}]},
      RowBox[{"{", 
        RowBox[{
         "7864", ",", 
          "680.66666666666666666666666666666666661484`5.218775389235249"}], 
        "}"}]],
     Annotation[#, {
      7864, 680.66666666666666666666666666666666661484`5.218775389235249}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{10485., 6.525029657843462}}]},
      RowBox[{"{", 
        RowBox[{
         "10485", ",", 
          "681.99999999999999999999999999999999986233`5.343715371410968"}], 
        "}"}]],
     Annotation[#, {
      10485, 681.99999999999999999999999999999999986233`5.343715371410968}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{13106., 6.883316205676536}}]},
      RowBox[{"{", 
        RowBox[{
         "13106", ",", 
          "975.85714285714285714285714285714285720789`5.285914942332564"}], 
        "}"}]],
     Annotation[#, {
      13106, 975.85714285714285714285714285714285720789`5.285914942332564}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{15727., 7.064636920214875}}]},
      RowBox[{"{", 
        RowBox[{
         "15727", ",", 
          "1169.85714285714285714285714285714285722121`5.285988674842737"}], 
        "}"}]],
     Annotation[#, {
      15727, 1169.85714285714285714285714285714285722121`5.285988674842737}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{18348., 7.218281566894889}}]},
      RowBox[{"{", 
        RowBox[{
         "18348", ",", 
          "1364.14285714285714285714285714285714294858`5.286041505721157"}], 
        "}"}]],
     Annotation[#, {
      18348, 1364.14285714285714285714285714285714294858`5.286041505721157}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{20969., 7.22046527365539}}]},
      RowBox[{"{", 
        RowBox[{
         "20969", ",", 
          "1367.12500000000000000000000000000000023801`5.344034146646602"}], 
        "}"}]],
     Annotation[#, {
      20969, 1367.12500000000000000000000000000000023801`5.344034146646602}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{23590., 7.336692743275443}}]},
      RowBox[{"{", 
        RowBox[{
         "23590", ",", 
          "1535.6249999999999999999999999999999996901`5.344068979630592"}], 
        "}"}]],
     Annotation[#, {
      23590, 1535.6249999999999999999999999999999996901`5.344068979630592}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{26211., 7.347586028590503}}]},
      RowBox[{"{", 
        RowBox[{
         "26211", ",", 
          "1552.44444444444444444444444444444444432598`5.395224564136778"}], 
        "}"}]],
     Annotation[#, {
      26211, 1552.44444444444444444444444444444444432598`5.395224564136778}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{28832., 7.542213463193403}}]},
      RowBox[{"{", 
        RowBox[{
         "28832", ",", 
          "1886.00000000000000000000000000000000032876`5.3441214886724"}], 
        "}"}]],
     Annotation[#, {
      28832, 1886.00000000000000000000000000000000032876`5.3441214886724}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{31453., 7.508421606747917}}]},
      RowBox[{"{", 
        RowBox[{
         "31453", ",", 
          "1823.33333333333333333333333333333333319392`5.395266101074326"}], 
        "}"}]],
     Annotation[#, {
      31453, 1823.33333333333333333333333333333333319392`5.395266101074326}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{34074., 7.588436188586466}}]},
      RowBox[{"{", 
        RowBox[{
         "34074", ",", 
          "1975.22222222222222222222222222222222207122`5.395284407321126"}], 
        "}"}]],
     Annotation[#, {
      34074, 1975.22222222222222222222222222222222207122`5.395284407321126}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{36695., 7.779676063120352}}]},
      RowBox[{"{", 
        RowBox[{
         "36695", ",", 
          "2391.50000000000000000000000000000000041678`5.344170139195124"}], 
        "}"}]],
     Annotation[#, {
      36695, 2391.50000000000000000000000000000000041678`5.344170139195124}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{39316., 7.731930721948486}}]},
      RowBox[{"{", 
        RowBox[{
         "39316", ",", 
          "2279.99999999999999999999999999999999982581`5.395313784607206"}], 
        "}"}]],
     Annotation[#, {
      39316, 2279.99999999999999999999999999999999982581`5.395313784607206}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{41937., 7.812917653068449}}]},
      RowBox[{"{", 
        RowBox[{
         "41937", ",", 
          "2472.33333333333333333333333333333333314444`5.395328596616166"}], 
        "}"}]],
     Annotation[#, {
      41937, 2472.33333333333333333333333333333333314444`5.395328596616166}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{44558., 7.753881024139163}}]},
      RowBox[{"{", 
        RowBox[{
         "44558", ",", 
          "2330.60000000000000000000000000000000005546`5.44107540891464"}], 
        "}"}]],
     Annotation[#, {
      44558, 2330.60000000000000000000000000000000005546`5.44107540891464}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{47179., 7.815852535827764}}]},
      RowBox[{"{", 
        RowBox[{
         "47179", ",", 
          "2479.60000000000000000000000000000000005937`5.441086601759955"}], 
        "}"}]],
     Annotation[#, {
      47179, 2479.60000000000000000000000000000000005937`5.441086601759955}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{49800., 7.773594467360194}}]},
      RowBox[{"{", 
        RowBox[{
         "49800", ",", 
          "2376.99999999999999999999999999999999960143`5.482471730047811"}], 
        "}"}]],
     Annotation[#, {
      49800, 2376.99999999999999999999999999999999960143`5.482471730047811}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{52421., 7.737797978808402}}]},
      RowBox[{"{", 
        RowBox[{
         "52421", ",", 
          "2293.41666666666666666666666666666666706658`5.520253635051501"}], 
        "}"}]],
     Annotation[#, {
      52421, 2293.41666666666666666666666666666666706658`5.520253635051501}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{55042., 7.873909192210417}}]},
      RowBox[{"{", 
        RowBox[{
         "55042", ",", 
          "2627.81818181818181818181818181818181774132`5.482489161953958"}], 
        "}"}]],
     Annotation[#, {
      55042, 2627.81818181818181818181818181818181774132`5.482489161953958}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{57663., 7.9181653993053}}]},
      RowBox[{"{", 
        RowBox[{
         "57663", ",", 
          "2746.72727272727272727272727272727272756346`5.482496313943268"}], 
        "}"}]],
     Annotation[#, {
      57663, 2746.72727272727272727272727272727272756346`5.482496313943268}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{60284., 7.964440164411036}}]},
      RowBox[{"{", 
        RowBox[{
         "60284", ",", 
          "2876.8181818181818181818181818181818184867`5.482503461354895"}], 
        "}"}]],
     Annotation[#, {
      60284, 2876.8181818181818181818181818181818184867`5.482503461354895}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{62905., 8.007911829209805}}]},
      RowBox[{"{", 
        RowBox[{
         "62905", ",", 
          "3004.63636363636363636363636363636363585987`5.482509881204965"}], 
        "}"}]],
     Annotation[#, {
      62905, 3004.63636363636363636363636363636363585987`5.482509881204965}, 
      "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      {Opacity[0.], PointBox[{{65526., 8.059937057417244}}]},
      RowBox[{"{", 
        RowBox[{
         "65526", ",", 
          "3165.09090909090909090909090909090909124438`5.482517206369322"}], 
        "}"}]],
     Annotation[#, {
      65526, 3165.09090909090909090909090909090909124438`5.482517206369322}, 
      "Tooltip"]& ]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Number of Options\"", TraditionalForm], 
    FormBox["\"Speed Up\"", TraditionalForm]},
  AxesOrigin->{0., -1.9459101490553135`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  FrameTicks->{{{{-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0., 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {9.210340371976184, 
       FormBox[
        TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm]}, {0., 
       FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm]}, {9.210340371976184, 
       FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.35667494393873245`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782616`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {7.600902459542082, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.006367567650246, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.294049640102028, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.517193191416238, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.699514748210191, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.85366542803745, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {8.987196820661973, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {9.104979856318357, 
       FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}, {Automatic, Automatic}},
  GridLines->{None, None},
  ImageSize->{592., Automatic},
  Method->{},
  PlotRange->{{0., 65526.}, {-1.9459101490553135`, 8.059937057417244}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, {{-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0., 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {9.210340371976184, 
      FormBox[
       TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> SuperscriptBox], 
       TraditionalForm]}, {-1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.35667494393873245`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782616`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {7.600902459542082, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.006367567650246, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.294049640102028, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.517193191416238, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.699514748210191, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.85366542803745, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {8.987196820661973, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {9.104979856318357, 
      FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}}]], "Output",
 CellChangeTimes->{{3.5024329383421926`*^9, 3.5024329795849876`*^9}, {
   3.502433104009687*^9, 3.5024331401722083`*^9}, {3.502433201788832*^9, 
   3.5024332057303896`*^9}, 3.50243335719812*^9, {3.502433416860567*^9, 
   3.5024334346366405`*^9}, {3.5024334655235686`*^9, 3.5024334840731087`*^9}, 
   3.5024335274302425`*^9, {3.50243403256292*^9, 3.5024340752725677`*^9}, {
   3.502434293357114*^9, 3.5024343516747828`*^9}, 3.5024346016267633`*^9, {
   3.5024346771863055`*^9, 3.502434682139621*^9}, 3.502434845446673*^9, 
   3.5024351353162017`*^9, 3.502435241652316*^9, {3.5024360739059534`*^9, 
   3.5024360740631857`*^9}, 3.5024593097220025`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plotting values using CUDAFinancialDerivative with variable inputs\
\>", "Subsection",
 CellMargins->{{66.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.5278234411518655`*^9, 3.5278234484232817`*^9}}],

Cell["\<\
Here we can use CUDA estimation to study varying derivative instrument types \
along with their methods of calculation and graphing the results as stock \
prices vary.\
\>", "MathCaption",
 CellMargins->{{66.2, 3.}, {8., 12.}},
 CellChangeTimes->{
  3.435513906503024*^9, {3.439663683411996*^9, 3.4396637076276307`*^9}, {
   3.4397408119503636`*^9, 3.439740816496538*^9}, {3.441727703707619*^9, 
   3.441727727802747*^9}, {3.451650706163927*^9, 3.4516507070383053`*^9}, {
   3.481284485808154*^9, 3.4812845148524265`*^9}, {3.4812854521231413`*^9, 
   3.4812854861832433`*^9}, 3.4812856331260223`*^9, {3.4812856655612392`*^9, 
   3.481285675685526*^9}, {3.481303689997296*^9, 3.481303722472939*^9}, {
   3.481456087628784*^9, 3.481456100455924*^9}, 3.504611177112706*^9, {
   3.5046112888711042`*^9, 3.5046113163688164`*^9}, {3.5046114197195916`*^9, 
   3.5046114760430303`*^9}, {3.504611935742608*^9, 3.504611941820656*^9}, 
   3.5046120249112825`*^9, 3.504612703857331*^9, {3.5046127356377673`*^9, 
   3.504612808432779*^9}, 3.5046329171904287`*^9, {3.504633499637619*^9, 
   3.504633528919244*^9}, 3.5046335625603*^9, 3.5046340231286945`*^9, 
   3.5046341153017497`*^9, 3.5046347243095446`*^9, 3.504634759106865*^9, 
   3.504635249566268*^9, 3.5046364613980284`*^9, {3.504636664724852*^9, 
   3.504636682818486*^9}, {3.504636963474331*^9, 3.504636980083706*^9}, {
   3.539805643109412*^9, 3.539805721413891*^9}, {3.5398057831254206`*^9, 
   3.5398057969342103`*^9}},
 FontFamily->"Calibri",
 FontColor->GrayLevel[0],
 CellTags->"Basic Operations"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Quiet", "[", 
      RowBox[{"CUDAFinancialDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"instrument", ",", "type"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", " ", "K1"}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "T"}], ",", 
          RowBox[{"\"\<Barriers\>\"", "\[Rule]", "B"}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "\[Delta]"}], ",", 
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "r"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", " ", "\[Rule]", "\[Sigma]"}], ",", 
          " ", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", 
           RowBox[{"Range", "[", 
            RowBox[{"40.", ",", "160.", ",", "0.5"}], "]"}]}], ",", 
          RowBox[{"\"\<Rebate\>\"", " ", "\[Rule]", "Reb"}]}], "}"}], ",", 
        RowBox[{"Method", "\[Rule]", "method"}]}], "]"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"AxesLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<stock\>\"", ",", " ", "\"\<option price\>\""}], "}"}]}], 
     ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"ImagePadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"40", ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"25", ",", "25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "instrument", ",", "\"\<European\>\"", ",", "\"\<Instrument\>\""}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<European\>\"", ",", "\"\<American\>\"", ",", 
       "\"\<AsianArithmetic\>\"", ",", "\"\<AsianGeometric\>\"", ",", 
       "\"\<BarrierDownIn\>\"", ",", "\"\<BarrierDownOut\>\"", ",", 
       "\"\<BarrierUpIn\>\"", ",", "\"\<BarrierUpOut\>\"", ",", 
       "\"\<EuropeanLookbackFixed\>\"", ",", 
       "\"\<EuropeanLookbackFloating\>\""}], "}"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"type", ",", "\"\<Call\>\"", ",", "\"\<Call/Put\>\""}], "}"}], 
     ",", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Call\>\"", ",", "\"\<Put\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"method", ",", "Automatic", ",", "\"\<Method\>\""}], "}"}], ",",
      " ", 
     RowBox[{"{", 
      RowBox[{
      "Automatic", ",", "\"\<BlackScholes\>\"", ",", "\"\<Binomial\>\"", ",", 
       "\"\<MonteCarlo\>\""}], "}"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K1", ",", " ", "100.", ",", "\"\<strike price\>\""}], "}"}], 
     ",", "50.", ",", "150."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Delta]", ",", ".004", ",", "\"\<dividend yield\>\""}], "}"}],
      ",", " ", ".002", ",", " ", ".05"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", ".05", ",", "\"\<interest rate\>\""}], "}"}], ",", 
     ".02", ",", ".1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]", ",", ".3", ",", " ", "\"\<volatility\>\""}], "}"}], 
     ",", " ", ".2", ",", " ", ".5"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", ".1", ",", "\"\<time to maturity\>\""}], "}"}], ",", 
     " ", ".001", ",", "1."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"B", ",", " ", "100.", ",", "\"\<Barrier\>\""}], "}"}], ",", 
     "50.", ",", "150."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Reb", ",", " ", "3.", ",", "\"\<Rebate\>\""}], "}"}], ",", 
     "0.5", ",", "10."}], "}"}]}], "]"}]], "Input",
 CellMargins->{{66.2, 3.}, {8., 12.}},
 CellChangeTimes->{
  3.35696210375764*^9, {3.372880151390625*^9, 3.372880192140625*^9}, {
   3.372880484375*^9, 3.372880487078125*^9}, {3.372880548578125*^9, 
   3.372880569859375*^9}, {3.3728806570625*^9, 3.372880662640625*^9}, {
   3.37288081*^9, 3.372880820546875*^9}, {3.372882345109375*^9, 
   3.372882397953125*^9}, {3.372882737875*^9, 3.37288274690625*^9}, {
   3.372882818453125*^9, 3.37288282253125*^9}, {3.373080025046875*^9, 
   3.373080050578125*^9}, {3.373080368953125*^9, 3.373080369515625*^9}, {
   3.489861142296875*^9, 3.489861156109375*^9}, {3.489866782390625*^9, 
   3.489866812828125*^9}, {3.489866847421875*^9, 3.489866911984375*^9}, {
   3.489866981625*^9, 3.48986698953125*^9}, {3.489867047890625*^9, 
   3.48986713565625*^9}, {3.5042868587005544`*^9, 3.5042868770596046`*^9}, {
   3.5042870671224756`*^9, 3.504287107923809*^9}, {3.5042872276856594`*^9, 
   3.5042873277723837`*^9}, {3.5042878280739994`*^9, 3.50428791532299*^9}, {
   3.504287955066263*^9, 3.5042880176478424`*^9}, {3.50428844787245*^9, 
   3.5042885105050325`*^9}, {3.504288800946645*^9, 3.504288805745919*^9}, {
   3.504288994801732*^9, 3.504289120257908*^9}, {3.504289353286237*^9, 
   3.504289353765264*^9}, {3.504289546175269*^9, 3.504289550856537*^9}, {
   3.5042978123699903`*^9, 3.5042978501363087`*^9}, {3.5042978940583086`*^9, 
   3.5042978947603083`*^9}, {3.504298002116308*^9, 3.5042980441213083`*^9}, {
   3.5042981134953084`*^9, 3.5042981557913084`*^9}, 3.5042984410038567`*^9, 
   3.5042984850572615`*^9, {3.5044695373777657`*^9, 3.5044695450085287`*^9}, {
   3.504469593098337*^9, 3.5044695970317307`*^9}, {3.50446963153118*^9, 
   3.5044697336263885`*^9}, 3.504469904870511*^9, {3.5044706033423514`*^9, 
   3.5044706439564123`*^9}, {3.5049242926296635`*^9, 
   3.5049242956560683`*^9}, {3.54021984419971*^9, 3.540219844881749*^9}},
 CellID->637417305],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`B$$ = 100., $CellContext`instrument$$ = 
    "European", $CellContext`K1$$ = 100., $CellContext`method$$ = 
    Automatic, $CellContext`r$$ = 0.05, $CellContext`Reb$$ = 
    3., $CellContext`T$$ = 0.1, $CellContext`type$$ = 
    "Call", $CellContext`\[Delta]$$ = 0.004, $CellContext`\[Sigma]$$ = 0.3, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`instrument$$], "European", "Instrument"}, {
      "European", "American", "AsianArithmetic", "AsianGeometric", 
       "BarrierDownIn", "BarrierDownOut", "BarrierUpIn", "BarrierUpOut", 
       "EuropeanLookbackFixed", "EuropeanLookbackFloating"}}, {{
       Hold[$CellContext`type$$], "Call", "Call/Put"}, {"Call", "Put"}}, {{
       Hold[$CellContext`method$$], Automatic, "Method"}, {
      Automatic, "BlackScholes", "Binomial", "MonteCarlo"}}, {{
       Hold[$CellContext`K1$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`\[Delta]$$], 0.004, "dividend yield"}, 0.002, 
      0.05}, {{
       Hold[$CellContext`r$$], 0.05, "interest rate"}, 0.02, 0.1}, {{
       Hold[$CellContext`\[Sigma]$$], 0.3, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`T$$], 0.1, "time to maturity"}, 0.001, 1.}, {{
       Hold[$CellContext`B$$], 100., "Barrier"}, 50., 150.}, {{
       Hold[$CellContext`Reb$$], 3., "Rebate"}, 0.5, 10.}}, Typeset`size$$ = {
    400., {119., 123.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`instrument$113210$$ = 
    0, $CellContext`type$113211$$ = False, $CellContext`method$113212$$ = 
    0, $CellContext`K1$113213$$ = 0, $CellContext`\[Delta]$113214$$ = 
    0, $CellContext`r$113215$$ = 0, $CellContext`\[Sigma]$113216$$ = 
    0, $CellContext`T$113217$$ = 0, $CellContext`B$113218$$ = 
    0, $CellContext`Reb$113219$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`B$$ = 100., $CellContext`instrument$$ = 
        "European", $CellContext`K1$$ = 100., $CellContext`method$$ = 
        Automatic, $CellContext`r$$ = 0.05, $CellContext`Reb$$ = 
        3., $CellContext`T$$ = 0.1, $CellContext`type$$ = 
        "Call", $CellContext`\[Delta]$$ = 0.004, $CellContext`\[Sigma]$$ = 
        0.3}, "ControllerVariables" :> {
        Hold[$CellContext`instrument$$, $CellContext`instrument$113210$$, 0], 
        Hold[$CellContext`type$$, $CellContext`type$113211$$, False], 
        Hold[$CellContext`method$$, $CellContext`method$113212$$, 0], 
        Hold[$CellContext`K1$$, $CellContext`K1$113213$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$113214$$, 0], 
        Hold[$CellContext`r$$, $CellContext`r$113215$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$113216$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$113217$$, 0], 
        Hold[$CellContext`B$$, $CellContext`B$113218$$, 0], 
        Hold[$CellContext`Reb$$, $CellContext`Reb$113219$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ListPlot[
        Quiet[
         CUDALink`CUDAFinancialDerivative[{$CellContext`instrument$$, \
$CellContext`type$$}, {
          "StrikePrice" -> $CellContext`K1$$, 
           "Expiration" -> $CellContext`T$$, 
           "Barriers" -> $CellContext`B$$}, {
          "Dividend" -> $CellContext`\[Delta]$$, 
           "InterestRate" -> $CellContext`r$$, 
           "Volatility" -> $CellContext`\[Sigma]$$, "CurrentPrice" -> 
           Range[40., 160., 0.5], "Rebate" -> $CellContext`Reb$$}, 
          Method -> $CellContext`method$$]], Joined -> True, 
        AxesLabel -> {"stock", "option price"}, ImageSize -> 400, 
        ImagePadding -> {{40, 50}, {25, 25}}, PlotRange -> All], 
      "Specifications" :> {{{$CellContext`instrument$$, "European", 
          "Instrument"}, {
         "European", "American", "AsianArithmetic", "AsianGeometric", 
          "BarrierDownIn", "BarrierDownOut", "BarrierUpIn", "BarrierUpOut", 
          "EuropeanLookbackFixed", 
          "EuropeanLookbackFloating"}}, {{$CellContext`type$$, "Call", 
          "Call/Put"}, {
         "Call", "Put"}}, {{$CellContext`method$$, Automatic, "Method"}, {
         Automatic, "BlackScholes", "Binomial", 
          "MonteCarlo"}}, {{$CellContext`K1$$, 100., "strike price"}, 50., 
         150.}, {{$CellContext`\[Delta]$$, 0.004, "dividend yield"}, 0.002, 
         0.05}, {{$CellContext`r$$, 0.05, "interest rate"}, 0.02, 
         0.1}, {{$CellContext`\[Sigma]$$, 0.3, "volatility"}, 0.2, 
         0.5}, {{$CellContext`T$$, 0.1, "time to maturity"}, 0.001, 
         1.}, {{$CellContext`B$$, 100., "Barrier"}, 50., 
         150.}, {{$CellContext`Reb$$, 3., "Rebate"}, 0.5, 10.}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{798., {152., 159.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellMargins->{{66.2, 3.}, {8., 12.}},
 CellChangeTimes->{3.5279643444308777`*^9, 3.540219855970383*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plotting Greeks using CUDAFinancialDerivative with variable inputs\
\>", "Subsection",
 CellMargins->{{65.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.527823414079317*^9, 3.5278234320393443`*^9}}],

Cell[TextData[{
 "In the same manner as above we can also study the greeks of various \
derivatives using ",
 StyleBox["CUDAFinancialDerivative", "Input"],
 "."
}], "MathCaption",
 CellChangeTimes->{
  3.435513906503024*^9, {3.439663683411996*^9, 3.4396637076276307`*^9}, {
   3.4397408119503636`*^9, 3.439740816496538*^9}, {3.441727703707619*^9, 
   3.441727727802747*^9}, {3.451650706163927*^9, 3.4516507070383053`*^9}, {
   3.481284485808154*^9, 3.4812845148524265`*^9}, {3.4812854521231413`*^9, 
   3.4812854861832433`*^9}, 3.4812856331260223`*^9, {3.4812856655612392`*^9, 
   3.481285675685526*^9}, {3.481303689997296*^9, 3.481303722472939*^9}, {
   3.481456087628784*^9, 3.481456100455924*^9}, 3.504611177112706*^9, {
   3.5046112888711042`*^9, 3.5046113163688164`*^9}, {3.5046114197195916`*^9, 
   3.5046114760430303`*^9}, {3.504611935742608*^9, 3.504611941820656*^9}, 
   3.5046120249112825`*^9, 3.504612703857331*^9, {3.5046127356377673`*^9, 
   3.504612808432779*^9}, 3.5046329171904287`*^9, {3.504633499637619*^9, 
   3.504633528919244*^9}, 3.5046335625603*^9, 3.5046340231286945`*^9, 
   3.5046341153017497`*^9, 3.5046347243095446`*^9, 3.504634759106865*^9, 
   3.504635249566268*^9, 3.5046364613980284`*^9, {3.504636664724852*^9, 
   3.504636682818486*^9}, {3.504636963474331*^9, 3.504636980083706*^9}, {
   3.539805643109412*^9, 3.539805768725597*^9}, {3.5398099982115097`*^9, 
   3.539810007123019*^9}, 3.541269469042757*^9},
 FontFamily->"Calibri",
 FontColor->GrayLevel[0],
 CellTags->"Basic Operations"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Quiet", "[", 
      RowBox[{"CUDAFinancialDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"instrument", ",", "type"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", " ", "K1"}], ",", " ", 
          RowBox[{"\"\<Expiration\>\"", "\[Rule]", "T"}], ",", 
          RowBox[{"\"\<Barriers\>\"", "\[Rule]", "B"}]}], "}"}], ",", "  ", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"\"\<Dividend\>\"", "\[Rule]", "\[Delta]"}], ",", 
          RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "r"}], ",", " ", 
          RowBox[{"\"\<Volatility\>\"", " ", "\[Rule]", "\[Sigma]"}], ",", 
          " ", 
          RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", 
           RowBox[{"Range", "[", 
            RowBox[{"40.", ",", "160.", ",", "0.25"}], "]"}]}], ",", 
          RowBox[{"\"\<Rebate\>\"", " ", "\[Rule]", "Reb"}]}], "}"}], ",", 
        "greek", ",", 
        RowBox[{"Method", "\[Rule]", "method"}]}], "]"}], "]"}], ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"AxesLabel", "->", 
      RowBox[{"{", 
       RowBox[{"\"\<stock\>\"", ",", " ", "\"\<Greek\>\""}], "}"}]}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
     RowBox[{"ImagePadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"40", ",", "50"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"25", ",", "25"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "instrument", ",", "\"\<European\>\"", ",", "\"\<Instrument\>\""}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<European\>\"", ",", "\"\<American\>\"", ",", 
       "\"\<AsianArithmetic\>\"", ",", "\"\<AsianGeometric\>\"", ",", 
       "\"\<BarrierDownIn\>\"", ",", "\"\<BarrierDownOut\>\"", ",", 
       "\"\<BarrierUpIn\>\"", ",", "\"\<BarrierUpOut\>\"", ",", 
       "\"\<EuropeanLookbackFixed\>\"", ",", 
       "\"\<EuropeanLookbackFloating\>\""}], "}"}]}], "}"}], ",", " ", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"type", ",", "\"\<Call\>\"", ",", "\"\<Call/Put\>\""}], "}"}], 
     ",", " ", 
     RowBox[{"{", 
      RowBox[{"\"\<Call\>\"", ",", "\"\<Put\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"method", ",", "Automatic", ",", "\"\<Method\>\""}], "}"}], ",",
      " ", 
     RowBox[{"{", 
      RowBox[{
      "Automatic", ",", "\"\<BlackScholes\>\"", ",", "\"\<Binomial\>\"", ",", 
       "\"\<MonteCarlo\>\""}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"greek", ",", "\"\<Delta\>\"", ",", "\"\<Option Greeks\>\""}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Charm\>\"", ",", "\"\<Color\>\"", ",", "\"\<Delta\>\"", ",", 
       "\"\<Gamma\>\"", ",", "\"\<Rho\>\"", ",", "\"\<Speed\>\"", ",", 
       "\"\<Theta\>\"", ",", "\"\<Theta\>\"", ",", "\"\<Vanna\>\"", ",", 
       "\"\<Vega\>\"", ",", "\"\<Zomma\>\""}], "}"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"K1", ",", " ", "100.", ",", "\"\<strike price\>\""}], "}"}], 
     ",", "50.", ",", "150."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Delta]", ",", ".004", ",", "\"\<dividend yield\>\""}], "}"}],
      ",", " ", ".002", ",", " ", ".05"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", ".05", ",", "\"\<interest rate\>\""}], "}"}], ",", 
     ".02", ",", ".1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Sigma]", ",", ".3", ",", " ", "\"\<volatility\>\""}], "}"}], 
     ",", " ", ".2", ",", " ", ".5"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"T", ",", ".1", ",", "\"\<time to maturity\>\""}], "}"}], ",", 
     " ", ".001", ",", "1."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"B", ",", " ", "100.", ",", "\"\<Barrier\>\""}], "}"}], ",", 
     "50.", ",", "150."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Reb", ",", " ", "3.", ",", "\"\<Rebate\>\""}], "}"}], ",", 
     "0.5", ",", "10."}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.372880151390625*^9, 3.372880192140625*^9}, {
   3.372880484375*^9, 3.372880487078125*^9}, {3.372880548578125*^9, 
   3.372880569859375*^9}, {3.3728806570625*^9, 3.372880662640625*^9}, {
   3.37288081*^9, 3.372880820546875*^9}, {3.372882345109375*^9, 
   3.372882397953125*^9}, {3.372882737875*^9, 3.37288274690625*^9}, {
   3.372882818453125*^9, 3.37288282253125*^9}, {3.373080025046875*^9, 
   3.373080050578125*^9}, {3.373080368953125*^9, 3.373080369515625*^9}, {
   3.489861142296875*^9, 3.489861156109375*^9}, {3.489866782390625*^9, 
   3.489866812828125*^9}, {3.489866847421875*^9, 3.489866911984375*^9}, {
   3.489866981625*^9, 3.48986698953125*^9}, {3.489867047890625*^9, 
   3.48986713565625*^9}, {3.48986732721875*^9, 3.489867453515625*^9}, {
   3.5042870407719684`*^9, 3.5042870430981016`*^9}, {3.5042874725496645`*^9, 
   3.5042875013223104`*^9}, 3.5042883836427765`*^9, 3.504288558417773*^9, {
   3.5042886000951567`*^9, 3.5042886284737797`*^9}, {3.5042886720422716`*^9, 
   3.504288674615419*^9}, {3.50428875960528*^9, 3.5042887612593746`*^9}, {
   3.504288809404128*^9, 3.5042888161885166`*^9}, {3.504289156060956*^9, 
   3.504289174100988*^9}, {3.50428939443259*^9, 3.504289394830613*^9}, {
   3.504289485132778*^9, 3.504289490347076*^9}, {3.5042977661783714`*^9, 
   3.5042977698057337`*^9}, 3.5042982145393085`*^9, {3.504470738817898*^9, 
   3.5044707858015957`*^9}, {3.5402198785676756`*^9, 3.5402198793337193`*^9}},
 CellID->155820295],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`B$$ = 100., $CellContext`greek$$ = 
    "Delta", $CellContext`instrument$$ = "European", $CellContext`K1$$ = 
    100., $CellContext`method$$ = Automatic, $CellContext`r$$ = 
    0.05, $CellContext`Reb$$ = 3., $CellContext`T$$ = 
    0.1, $CellContext`type$$ = "Call", $CellContext`\[Delta]$$ = 
    0.004, $CellContext`\[Sigma]$$ = 0.3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`instrument$$], "European", "Instrument"}, {
      "European", "American", "AsianArithmetic", "AsianGeometric", 
       "BarrierDownIn", "BarrierDownOut", "BarrierUpIn", "BarrierUpOut", 
       "EuropeanLookbackFixed", "EuropeanLookbackFloating"}}, {{
       Hold[$CellContext`type$$], "Call", "Call/Put"}, {"Call", "Put"}}, {{
       Hold[$CellContext`method$$], Automatic, "Method"}, {
      Automatic, "BlackScholes", "Binomial", "MonteCarlo"}}, {{
       Hold[$CellContext`greek$$], "Delta", "Option Greeks"}, {
      "Charm", "Color", "Delta", "Gamma", "Rho", "Speed", "Theta", "Theta", 
       "Vanna", "Vega", "Zomma"}}, {{
       Hold[$CellContext`K1$$], 100., "strike price"}, 50., 150.}, {{
       Hold[$CellContext`\[Delta]$$], 0.004, "dividend yield"}, 0.002, 
      0.05}, {{
       Hold[$CellContext`r$$], 0.05, "interest rate"}, 0.02, 0.1}, {{
       Hold[$CellContext`\[Sigma]$$], 0.3, "volatility"}, 0.2, 0.5}, {{
       Hold[$CellContext`T$$], 0.1, "time to maturity"}, 0.001, 1.}, {{
       Hold[$CellContext`B$$], 100., "Barrier"}, 50., 150.}, {{
       Hold[$CellContext`Reb$$], 3., "Rebate"}, 0.5, 10.}}, Typeset`size$$ = {
    400., {119., 123.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`instrument$113515$$ = 
    0, $CellContext`type$113516$$ = False, $CellContext`method$113517$$ = 
    0, $CellContext`greek$113518$$ = 0, $CellContext`K1$113519$$ = 
    0, $CellContext`\[Delta]$113520$$ = 0, $CellContext`r$113521$$ = 
    0, $CellContext`\[Sigma]$113522$$ = 0, $CellContext`T$113523$$ = 
    0, $CellContext`B$113524$$ = 0, $CellContext`Reb$113525$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`B$$ = 100., $CellContext`greek$$ = 
        "Delta", $CellContext`instrument$$ = "European", $CellContext`K1$$ = 
        100., $CellContext`method$$ = Automatic, $CellContext`r$$ = 
        0.05, $CellContext`Reb$$ = 3., $CellContext`T$$ = 
        0.1, $CellContext`type$$ = "Call", $CellContext`\[Delta]$$ = 
        0.004, $CellContext`\[Sigma]$$ = 0.3}, "ControllerVariables" :> {
        Hold[$CellContext`instrument$$, $CellContext`instrument$113515$$, 0], 
        Hold[$CellContext`type$$, $CellContext`type$113516$$, False], 
        Hold[$CellContext`method$$, $CellContext`method$113517$$, 0], 
        Hold[$CellContext`greek$$, $CellContext`greek$113518$$, 0], 
        Hold[$CellContext`K1$$, $CellContext`K1$113519$$, 0], 
        Hold[$CellContext`\[Delta]$$, $CellContext`\[Delta]$113520$$, 0], 
        Hold[$CellContext`r$$, $CellContext`r$113521$$, 0], 
        Hold[$CellContext`\[Sigma]$$, $CellContext`\[Sigma]$113522$$, 0], 
        Hold[$CellContext`T$$, $CellContext`T$113523$$, 0], 
        Hold[$CellContext`B$$, $CellContext`B$113524$$, 0], 
        Hold[$CellContext`Reb$$, $CellContext`Reb$113525$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ListPlot[
        Quiet[
         CUDALink`CUDAFinancialDerivative[{$CellContext`instrument$$, \
$CellContext`type$$}, {
          "StrikePrice" -> $CellContext`K1$$, 
           "Expiration" -> $CellContext`T$$, 
           "Barriers" -> $CellContext`B$$}, {
          "Dividend" -> $CellContext`\[Delta]$$, 
           "InterestRate" -> $CellContext`r$$, 
           "Volatility" -> $CellContext`\[Sigma]$$, "CurrentPrice" -> 
           Range[40., 160., 0.25], 
           "Rebate" -> $CellContext`Reb$$}, $CellContext`greek$$, 
          Method -> $CellContext`method$$]], Joined -> True, 
        AxesLabel -> {"stock", "Greek"}, ImageSize -> 400, 
        ImagePadding -> {{40, 50}, {25, 25}}, PlotRange -> All], 
      "Specifications" :> {{{$CellContext`instrument$$, "European", 
          "Instrument"}, {
         "European", "American", "AsianArithmetic", "AsianGeometric", 
          "BarrierDownIn", "BarrierDownOut", "BarrierUpIn", "BarrierUpOut", 
          "EuropeanLookbackFixed", 
          "EuropeanLookbackFloating"}}, {{$CellContext`type$$, "Call", 
          "Call/Put"}, {
         "Call", "Put"}}, {{$CellContext`method$$, Automatic, "Method"}, {
         Automatic, "BlackScholes", "Binomial", 
          "MonteCarlo"}}, {{$CellContext`greek$$, "Delta", "Option Greeks"}, {
         "Charm", "Color", "Delta", "Gamma", "Rho", "Speed", "Theta", "Theta",
           "Vanna", "Vega", "Zomma"}}, {{$CellContext`K1$$, 100., 
          "strike price"}, 50., 
         150.}, {{$CellContext`\[Delta]$$, 0.004, "dividend yield"}, 0.002, 
         0.05}, {{$CellContext`r$$, 0.05, "interest rate"}, 0.02, 
         0.1}, {{$CellContext`\[Sigma]$$, 0.3, "volatility"}, 0.2, 
         0.5}, {{$CellContext`T$$, 0.1, "time to maturity"}, 0.001, 
         1.}, {{$CellContext`B$$, 100., "Barrier"}, 50., 
         150.}, {{$CellContext`Reb$$, 3., "Rebate"}, 0.5, 10.}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{798., {167., 174.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5279643536424046`*^9, 3.540219882088877*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot the return of a call spread", "Subsection",
 CellMargins->{{65.2, 3.}, {8., 12.}},
 CellChangeTimes->{{3.5023979742859488`*^9, 3.502397979747371*^9}, {
  3.5023981111320324`*^9, 3.502398113075268*^9}, {3.50331477157425*^9, 
  3.503314792621125*^9}, {3.5278233409491343`*^9, 3.52782335626101*^9}}],

Cell[TextData[{
 "We create the data and then feed an array of values directly into ",
 StyleBox["CUDAFinancialDerivative", "Input"]
}], "Text",
 CellChangeTimes->{{3.504636912943081*^9, 3.504636925677456*^9}, {
  3.539810042676053*^9, 3.539810079796176*^9}},
 FontFamily->"Calibri"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"price", ",", " ", "referencetime"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
        "referencetime", ",", " ", "0.01", ",", " ", "1", ",", " ", "0.05"}], 
        "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"price", ",", " ", "35", ",", " ", "65", ",", " ", "1"}], 
        "}"}]}], "]"}], ",", " ", "1"}], "]"}]}], ";"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.501336160352765*^9, 3.504298551109866*^9, {3.527856036330338*^9, 
   3.527856036744547*^9}},
 CellID->1041024209],

Cell[BoxData[{
 RowBox[{
  RowBox[{"currentPrices", "=", 
   RowBox[{"First", "/@", "data"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expiration", "=", 
   RowBox[{"Last", "/@", "data"}]}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{3.501336160352765*^9, 3.5042985511128664`*^9},
 CellID->286474932],

Cell[BoxData[
 RowBox[{"ListPlot3D", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"currentPrices", ",", " ", 
      RowBox[{"1", "-", "expiration"}], ",", 
      RowBox[{
       RowBox[{"CUDAFinancialDerivative", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<American\>\"", ",", "\"\<Call\>\""}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", " ", "45.0"}], ",", " ", 
           RowBox[{"\"\<Expiration\>\"", "\[Rule]", "expiration"}]}], "}"}], 
         ",", "  ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "0.1"}], ",", " ", 
           RowBox[{"\"\<Volatility\>\"", " ", "\[Rule]", " ", "1.0"}], ",", 
           " ", 
           RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "currentPrices"}], 
           ",", " ", 
           RowBox[{"\"\<Dividend\>\"", "\[Rule]", "0.05"}]}], "}"}]}], "]"}], 
       "-", 
       RowBox[{"CUDAFinancialDerivative", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\"\<American\>\"", ",", " ", "\"\<Call\>\""}], "}"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", "55.0"}], ",", " ", 
           RowBox[{"\"\<Expiration\>\"", "\[Rule]", "expiration"}]}], "}"}], 
         ",", "  ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<InterestRate\>\"", "\[Rule]", " ", "0.1"}], ",", " ", 
           RowBox[{"\"\<Volatility\>\"", " ", "\[Rule]", " ", "1.0"}], ",", 
           " ", 
           RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", " ", "currentPrices"}], 
           ",", " ", 
           RowBox[{"\"\<Dividend\>\"", "\[Rule]", "0.05"}]}], "}"}]}], 
        "]"}]}]}], "}"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<asset price\>\"", ",", " ", "\"\<maturity\>\"", ",", 
      "\"\<spread price\>\""}], "}"}]}]}], "]"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.501336160352765*^9, 3.504298551118867*^9, {3.52785601449088*^9, 
   3.52785602264002*^9}, {3.5399796328392096`*^9, 3.539979651767292*^9}, {
   3.539979717576056*^9, 3.5399797380242257`*^9}},
 CellID->132174553]
}, Open  ]],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxcnXkgVW3Xh2UmUyhCSJMyS2mQfczz3EClJFSSVCoiUYqiUiGVIgoNRGVo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   "], {{
     {EdgeForm[None], GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNm3kYVmO0xb/vO+d855UoJJGkmVSoDElljhCVsYQkU1EhU4NEJUqESJKS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         "]], Polygon3DBox[CompressedData["
1:eJw1nAn4VtP3xe97p/PKLJSUqcySUIZIKiKRylSZmjWYFT+Zh5SUjBGipMgQ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         "]], Polygon3DBox[CompressedData["
1:eJwt13m8znUaxvHHOTi2yla2MraxJGObSgvZd9lDBllHBlEq00JFZAwyCWXf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         "]]}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0s9PknEAx3GsNCpLzQy0X/oHmLe65ZpnrShAK6hMxH4MawEhgnPNORmt
S50K5x/gSbnpX+ClrW56bd5tzq1uvZ6tw5vXhzH2fJ8HBiZnY7mWUCi0qsBj
ynk5zhN6Y7eyTW/tkwzrnX2Kp5W3z7BdBfssz6lod7BTXXrv/Xl2q2RfYI/m
7IuMqGxH2at5u4+XVLEv84qq9lVe0y39ctBU8JmDVhjnN9a4xTXu8o8O7Ygb
HXRDN5hhnF+Z5yY/B6rNzf7gbR6wzA7X3uB17nCUr/VKn5zjJV/ooz3DrOr2
NDOq2VN8rhV7ks+0bD/lEy3Zaab0WB+8f8SHWrQnOK4FO8mEKnacD1S27zOm
kn2Pd1W073BMQ2o6f2fwXf52fyP8yTCb/O5ZfGFBDTvBLG9yiFEeeZ5/Pddt
7gWqbjeYZDX4nZjmvusPc539//9v/wCUQj9n
       "]]}, {
      Line3DBox[{1195, 1194, 1167, 1168, 2076, 1169, 1170, 1171, 2077, 1994, 
       1172, 1173, 1174, 2078, 1995, 1175, 1196, 1176, 2080, 1996, 1177, 1200,
        1178, 2082, 1202, 1179, 1204, 1180, 2083, 1206, 1181, 1208, 1182, 
       2085, 1210, 1183, 1212, 1184, 1214, 1185, 1997, 2079, 1186, 1217, 1187,
        2087, 1219, 1188, 1221, 1189, 2088, 1223, 1190, 1225, 1191, 2089, 
       1227, 1192, 1229, 1193, 2090, 1231, 1232, 1235, 1236, 2092, 1239, 1240,
        1243, 1244, 2095, 1998, 1247, 1250, 1251}], 
      Line3DBox[{1253, 1252, 1197, 1198, 2081, 1199, 1201, 1203, 1205, 2084, 
       1207, 1209, 1211, 1213, 2086, 1215, 1255, 1216, 2096, 1257, 1218, 1259,
        1220, 2098, 1261, 1222, 1263, 1224, 2099, 1265, 1226, 1267, 1228, 
       2101, 1269, 1230, 1271, 1233, 1273, 1234, 1999, 2091, 1237, 1276, 1238,
        2000, 2093, 1241, 1279, 1242, 2001, 2094, 1245, 1282, 1246, 2104, 
       1284, 1248, 1286, 1249, 2105, 1288, 1289, 1292, 1293, 2107, 1296, 1297,
        1300, 1301, 2110, 1304, 1305, 1308, 1309}], 
      Line3DBox[{1311, 1310, 1254, 1256, 2097, 1258, 1260, 1262, 1264, 2100, 
       1266, 1268, 1270, 1272, 2102, 1274, 1312, 1275, 1315, 2103, 1277, 1317,
        1278, 2113, 1319, 1280, 1321, 1281, 2114, 1323, 1283, 1325, 1285, 
       2116, 1327, 1287, 1329, 1290, 1331, 1291, 2002, 2106, 1294, 1334, 1295,
        2003, 2108, 1298, 1337, 1299, 2004, 2109, 1302, 1340, 1303, 2005, 
       2111, 1306, 1343, 1307, 2121, 1345, 1346, 1349, 1350, 2123, 1353, 1354,
        1357, 1358, 2126, 2006, 1361, 1364, 1365}], 
      Line3DBox[{1367, 1366, 1313, 1314, 2112, 1316, 1318, 1320, 1322, 2115, 
       1324, 1326, 1328, 1330, 2117, 1332, 1369, 1333, 2007, 2118, 1335, 1372,
        1336, 2008, 2119, 1338, 1375, 1339, 2009, 2120, 1341, 1378, 1342, 
       2131, 1380, 1344, 1382, 1347, 1384, 1348, 2010, 2122, 1351, 1387, 1352,
        2011, 2124, 1355, 1390, 1356, 2012, 2125, 1359, 1393, 1360, 2013, 
       2127, 1362, 1396, 1363, 2014, 2136, 1398, 1401, 1402, 2015, 2138, 1405,
        1408, 1409, 2141, 1412, 1413, 1416, 1417}], 
      Line3DBox[{1419, 1418, 1368, 1370, 2129, 1371, 1373, 1374, 1376, 2130, 
       1377, 1379, 1381, 1383, 2132, 1385, 1420, 1386, 1421, 2133, 1388, 1422,
        1389, 2016, 2134, 1391, 1423, 1392, 2017, 2135, 1394, 1424, 1395, 
       2018, 2128, 1397, 1425, 1399, 1426, 1400, 2019, 2137, 1403, 1427, 1404,
        2020, 2139, 1406, 1428, 1407, 2021, 2140, 1410, 1429, 1411, 2022, 
       2142, 1414, 1430, 1415, 2023, 2143, 1431, 1432, 1433, 2024, 2144, 1434,
        1435, 1436, 2025, 2145, 1437, 1438, 1439}], 
      Line3DBox[{1467, 1466, 1440, 807, 1441, 1442, 1443, 2146, 2026, 1444, 
       1445, 1446, 2147, 2027, 1447, 1468, 1448, 2148, 2028, 1449, 1472, 1450,
        2150, 1474, 1451, 1476, 1452, 2151, 1478, 1453, 1480, 1454, 2153, 
       1482, 1455, 1484, 1456, 1485, 1457, 846, 1458, 1488, 1459, 2155, 1490, 
       1460, 1492, 1461, 2156, 1494, 1462, 1496, 1463, 2157, 1498, 1464, 1500,
        1465, 2158, 1502, 1503, 1506, 1507, 2160, 1510, 1511, 1514, 1515, 
       2162, 1518, 1519, 1522, 1523}], 
      Line3DBox[{1525, 1524, 1469, 1470, 2149, 1471, 1473, 1475, 1477, 2152, 
       1479, 1481, 1483, 2154, 2029, 1486, 1527, 1487, 2163, 1529, 1489, 1531,
        1491, 2165, 1533, 1493, 1535, 1495, 2166, 1537, 1497, 1539, 1499, 
       2168, 1541, 1501, 1543, 1504, 1545, 1505, 2030, 2159, 1508, 1548, 1509,
        2031, 2161, 1512, 1551, 1513, 2170, 1553, 1516, 1555, 1517, 2171, 
       1557, 1520, 1559, 1521, 2172, 1561, 1562, 1565, 1566, 2174, 1569, 1570,
        1573, 1574, 2177, 2032, 1577, 1580, 1581}], 
      Line3DBox[{1583, 1582, 1526, 1528, 2164, 1530, 1532, 1534, 1536, 2167, 
       1538, 1540, 1542, 1544, 2169, 1546, 1584, 1547, 891, 1549, 1588, 1550, 
       2179, 1590, 1552, 1592, 1554, 2180, 1594, 1556, 1596, 1558, 2182, 1598,
        1560, 1600, 1563, 1602, 1564, 2033, 2173, 1567, 1605, 1568, 2034, 
       2175, 1571, 1608, 1572, 2035, 2176, 1575, 1611, 1576, 908, 1578, 1614, 
       1579, 2186, 1616, 1617, 1620, 1621, 2188, 1624, 1625, 1628, 1629, 2191,
        1632, 1633, 1636, 1637}], 
      Line3DBox[{1639, 1638, 1585, 1586, 2178, 1587, 1589, 1591, 1593, 2181, 
       1595, 1597, 1599, 1601, 2183, 1603, 1641, 1604, 2036, 2184, 1606, 1644,
        1607, 2037, 2185, 1609, 1647, 1610, 2194, 1649, 1612, 1651, 1613, 
       2196, 1653, 1615, 1655, 1618, 1657, 1619, 2038, 2187, 1622, 1660, 1623,
        2039, 2189, 1626, 1663, 1627, 2040, 2190, 1630, 1666, 1631, 2041, 
       2192, 1634, 1669, 1635, 2042, 2201, 1671, 1674, 1675, 2203, 1678, 1679,
        1682, 1683, 2206, 2043, 1686, 1689, 1690}], 
      Line3DBox[{1692, 1691, 1640, 1642, 2193, 1643, 1645, 1646, 1648, 2195, 
       1650, 1652, 1654, 1656, 2197, 1658, 1693, 1659, 1694, 2198, 1661, 1695,
        1662, 2044, 2199, 1664, 1696, 1665, 2045, 2200, 1667, 1697, 1668, 
       2208, 1698, 1670, 1699, 1672, 1700, 1673, 2046, 2202, 1676, 1701, 1677,
        2047, 2204, 1680, 1702, 1681, 2048, 2205, 1684, 1703, 1685, 2049, 
       2207, 1687, 1704, 1688, 2050, 2209, 1705, 1706, 1707, 2051, 2210, 1708,
        1709, 1710, 2211, 1711, 1712, 1713, 1714}], 
      Line3DBox[{1742, 1741, 1715, 2212, 2052, 1716, 1717, 1718, 2213, 2053, 
       1719, 1720, 1721, 2214, 2054, 1722, 1743, 1723, 2215, 2055, 1724, 1747,
        1725, 2217, 1749, 1726, 1751, 1727, 2218, 1752, 1728, 1754, 1729, 
       2219, 1756, 1730, 1758, 1731, 1759, 1732, 2221, 1761, 1733, 1763, 1734,
        2222, 1765, 1735, 1767, 1736, 2223, 1769, 1737, 1771, 1738, 2224, 
       1773, 1739, 1775, 1740, 2225, 1777, 1778, 1781, 1782, 2227, 1785, 1786,
        1789, 1790, 2228, 1793, 1794, 1797, 1798}], 
      Line3DBox[{1800, 1799, 1744, 1745, 2216, 1746, 1748, 1750, 1008, 1753, 
       1755, 1757, 2220, 2056, 1760, 1802, 1762, 2229, 1804, 1764, 1806, 1766,
        2231, 1808, 1768, 1810, 1770, 2232, 1812, 1772, 1814, 1774, 2234, 
       1816, 1776, 1818, 1779, 1820, 1780, 2057, 2226, 1783, 1823, 1784, 1044,
        1787, 1826, 1788, 2236, 1828, 1791, 1830, 1792, 2237, 1832, 1795, 
       1834, 1796, 2238, 1836, 1837, 1840, 1841, 2240, 1844, 1845, 1848, 1849,
        2243, 1852, 1853, 1856, 1857}], 
      Line3DBox[{1859, 1858, 1801, 1803, 2230, 1805, 1807, 1809, 1811, 2233, 
       1813, 1815, 1817, 1819, 2235, 1821, 1860, 1822, 2244, 2058, 1824, 1864,
        1825, 2246, 1866, 1827, 1868, 1829, 2247, 1870, 1831, 1872, 1833, 
       2249, 1874, 1835, 1876, 1838, 1878, 1839, 2059, 2239, 1842, 1881, 1843,
        2060, 2241, 1846, 1884, 1847, 2061, 2242, 1850, 1887, 1851, 2252, 
       1889, 1854, 1891, 1855, 2253, 1893, 1894, 1897, 1898, 2255, 1901, 1902,
        1905, 1906, 2258, 1909, 1910, 1913, 1914}], 
      Line3DBox[{1916, 1915, 1861, 1862, 2245, 1863, 1865, 1867, 1869, 2248, 
       1871, 1873, 1875, 1877, 2250, 1879, 1918, 1880, 2062, 2251, 1882, 1921,
        1883, 2261, 1923, 1885, 1925, 1886, 2262, 1927, 1888, 1929, 1890, 
       2264, 1931, 1892, 1933, 1895, 1935, 1896, 2063, 2254, 1899, 1938, 1900,
        2064, 2256, 1903, 1941, 1904, 2065, 2257, 1907, 1944, 1908, 2066, 
       2259, 1911, 1947, 1912, 2269, 1949, 1950, 1953, 1954, 2271, 1957, 1958,
        1961, 1962, 2274, 2067, 1965, 1968, 1969}], 
      Line3DBox[{1971, 1970, 1917, 1919, 2260, 1920, 1922, 1924, 1926, 2263, 
       1928, 1930, 1932, 1934, 2265, 1936, 1972, 1937, 1973, 2266, 1939, 1974,
        1940, 2068, 2267, 1942, 1975, 1943, 2069, 2268, 1945, 1976, 1946, 
       2276, 1977, 1948, 1978, 1951, 1979, 1952, 2070, 2270, 1955, 1980, 1956,
        2071, 2272, 1959, 1981, 1960, 2072, 2273, 1963, 1982, 1964, 2073, 
       2275, 1966, 1983, 1967, 2074, 2277, 1984, 1985, 1986, 2075, 2278, 1987,
        1988, 1989, 2279, 1990, 1991, 1992, 1993}]}, {
      Line3DBox[{622, 621, 638, 639, 2076, 668, 666, 2081, 694, 695, 2097, 
       724, 722, 2112, 750, 751, 2129, 780, 778, 806, 807, 836, 834, 2149, 
       862, 863, 2164, 892, 890, 2178, 918, 919, 2193, 948, 946, 974, 2212, 
       975, 1004, 1002, 2216, 1030, 1031, 2230, 1060, 1058, 2245, 1086, 1087, 
       2260, 1116, 1114, 1142}], 
      Line3DBox[{624, 623, 641, 2077, 644, 669, 672, 2084, 697, 700, 2100, 
       725, 728, 2115, 753, 756, 2130, 781, 784, 809, 2146, 812, 837, 840, 
       2152, 865, 868, 2167, 893, 896, 2181, 921, 924, 2195, 949, 952, 977, 
       2213, 980, 1005, 1008, 1033, 1036, 2233, 1061, 1064, 2248, 1089, 1092, 
       2263, 1117, 1120, 1144}], 
      Line3DBox[{625, 626, 643, 2078, 649, 671, 677, 2086, 699, 705, 2102, 
       727, 733, 2117, 755, 761, 2132, 783, 789, 811, 2147, 817, 839, 2154, 
       845, 867, 873, 2169, 895, 901, 2183, 923, 929, 2197, 951, 957, 979, 
       2214, 985, 1007, 2220, 1013, 1035, 1041, 2235, 1063, 1069, 2250, 1091, 
       1097, 2265, 1119, 1125, 1146}], 
      Line3DBox[{627, 640, 646, 2080, 667, 674, 2096, 696, 702, 723, 2103, 
       730, 752, 2118, 758, 779, 2133, 786, 808, 814, 2148, 835, 842, 2163, 
       864, 870, 891, 898, 920, 2184, 926, 947, 2198, 954, 976, 982, 2215, 
       1003, 1010, 2229, 1032, 1038, 2244, 1059, 1066, 1088, 2251, 1094, 1115,
        2266, 1122, 1143, 1148}], 
      Line3DBox[{628, 642, 648, 2082, 670, 676, 2098, 698, 704, 2113, 726, 
       732, 754, 2119, 760, 782, 2134, 788, 810, 816, 2150, 838, 844, 2165, 
       866, 872, 2179, 894, 900, 922, 2185, 928, 950, 2199, 956, 978, 984, 
       2217, 1006, 1012, 2231, 1034, 1040, 2246, 1062, 1068, 2261, 1090, 1096,
        1118, 2267, 1124, 1145, 1150}], 
      Line3DBox[{629, 645, 651, 2083, 673, 679, 2099, 701, 707, 2114, 729, 
       735, 757, 2120, 763, 785, 2135, 791, 813, 819, 2151, 841, 847, 2166, 
       869, 875, 2180, 897, 903, 2194, 925, 931, 953, 2200, 959, 981, 987, 
       2218, 1009, 1015, 2232, 1037, 1043, 2247, 1065, 1071, 2262, 1093, 1099,
        1121, 2268, 1127, 1147, 1152}], 
      Line3DBox[{630, 647, 653, 2085, 675, 681, 2101, 703, 709, 2116, 731, 
       737, 2131, 759, 765, 787, 2128, 793, 815, 821, 2153, 843, 849, 2168, 
       871, 877, 2182, 899, 905, 2196, 927, 933, 2208, 955, 961, 983, 989, 
       2219, 1011, 1017, 2234, 1039, 1045, 2249, 1067, 1073, 2264, 1095, 1101,
        2276, 1123, 1129, 1149, 1154}], 
      Line3DBox[{16, 47, 1184, 78, 1233, 109, 1290, 140, 1347, 171, 1399, 202,
        233, 1456, 264, 1504, 295, 1563, 326, 1618, 357, 1672, 388, 419, 1731,
        450, 1779, 481, 1838, 512, 1895, 543, 1951, 574, 605}], 
      Line3DBox[{631, 650, 655, 678, 2079, 683, 706, 2091, 711, 734, 2106, 
       739, 762, 2122, 767, 790, 2137, 795, 818, 823, 846, 851, 874, 2159, 
       879, 902, 2173, 907, 930, 2187, 935, 958, 2202, 963, 986, 991, 2221, 
       1014, 1019, 1042, 2226, 1047, 1070, 2239, 1075, 1098, 2254, 1103, 1126,
        2270, 1131, 1151, 1156}], 
      Line3DBox[{632, 652, 657, 2087, 680, 685, 708, 2093, 713, 736, 2108, 
       741, 764, 2124, 769, 792, 2139, 797, 820, 825, 2155, 848, 853, 876, 
       2161, 881, 904, 2175, 909, 932, 2189, 937, 960, 2204, 965, 988, 993, 
       2222, 1016, 1021, 1044, 1049, 1072, 2241, 1077, 1100, 2256, 1105, 1128,
        2272, 1133, 1153, 1158}], 
      Line3DBox[{633, 654, 659, 2088, 682, 687, 710, 2094, 715, 738, 2109, 
       743, 766, 2125, 771, 794, 2140, 799, 822, 827, 2156, 850, 855, 2170, 
       878, 883, 906, 2176, 911, 934, 2190, 939, 962, 2205, 967, 990, 995, 
       2223, 1018, 1023, 2236, 1046, 1051, 1074, 2242, 1079, 1102, 2257, 1107,
        1130, 2273, 1135, 1155, 1160}], 
      Line3DBox[{634, 656, 660, 2089, 684, 688, 2104, 712, 716, 740, 2111, 
       744, 768, 2127, 772, 796, 2142, 800, 824, 828, 2157, 852, 856, 2171, 
       880, 884, 908, 912, 936, 2192, 940, 964, 2207, 968, 992, 996, 2224, 
       1020, 1024, 2237, 1048, 1052, 2252, 1076, 1080, 1104, 2259, 1108, 1132,
        2275, 1136, 1157, 1161}], 
      Line3DBox[{635, 658, 662, 2090, 686, 690, 2105, 714, 718, 2121, 742, 
       746, 770, 2136, 774, 798, 2143, 802, 826, 830, 2158, 854, 858, 2172, 
       882, 886, 2186, 910, 914, 938, 2201, 942, 966, 2209, 970, 994, 998, 
       2225, 1022, 1026, 2238, 1050, 1054, 2253, 1078, 1082, 2269, 1106, 1110,
        1134, 2277, 1138, 1159, 1163}], 
      Line3DBox[{636, 661, 663, 2092, 689, 691, 2107, 717, 719, 2123, 745, 
       747, 773, 2138, 775, 801, 2144, 803, 829, 831, 2160, 857, 859, 2174, 
       885, 887, 2188, 913, 915, 2203, 941, 943, 969, 2210, 971, 997, 999, 
       2227, 1025, 1027, 2240, 1053, 1055, 2255, 1081, 1083, 2271, 1109, 1111,
        1137, 2278, 1139, 1162, 1164}], 
      Line3DBox[{637, 664, 665, 692, 2095, 693, 2110, 720, 721, 748, 2126, 
       749, 2141, 776, 777, 804, 2145, 805, 832, 833, 2162, 860, 861, 888, 
       2177, 889, 2191, 916, 917, 944, 2206, 945, 2211, 972, 973, 1000, 1001, 
       2228, 1028, 1029, 2243, 1056, 1057, 2258, 1084, 1085, 1112, 2274, 1113,
        2279, 1140, 1141, 1165, 1166}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJwUW3c4lf8blkohSjTIN6RCRYWGwpNImlYliiKkYUtGhEqyMrL3zMheyXhs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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"asset price\"", TraditionalForm], 
    FormBox["\"maturity\"", TraditionalForm], 
    FormBox["\"spread price\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  Method->{"RotationControl" -> "Globe"},
  PlotRange->{{35., 65.}, {0.039999999999999925`, 0.99}, {0., 
   9.874262704878193}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5279644023781924`*^9, 3.539743442503741*^9, {3.5399797472937555`*^9, 
   3.53997975751134*^9}}],

Cell["", "Text",
 CellChangeTimes->{{3.503228151346015*^9, 3.5032281572030277`*^9}},
 FontFamily->"Times New Roman",
 FontSize->8]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Writing the Black\[Dash]Scholes Formula in CUDA Code\
\>", "Section"],

Cell[TextData[{
 StyleBox["The Black",
  FontFamily->"Georgia"],
 "\[Dash]",
 StyleBox["Scholes equation can be implemented using ",
  FontFamily->"Georgia"],
 StyleBox["CUDALink",
  FontFamily->"Georgia",
  FontSlant->"Italic"],
 StyleBox[" with the following simple kernel.",
  FontFamily->"Georgia"]
}], "MathCaption",
 CellChangeTimes->{
  3.435513906503024*^9, {3.439663683411996*^9, 3.4396637076276307`*^9}, {
   3.4397408119503636`*^9, 3.439740816496538*^9}, {3.441727703707619*^9, 
   3.441727727802747*^9}, {3.451650706163927*^9, 3.4516507070383053`*^9}, {
   3.481284485808154*^9, 3.4812845148524265`*^9}, {3.4812854521231413`*^9, 
   3.4812854861832433`*^9}, 3.4812856331260223`*^9, {3.4812856655612392`*^9, 
   3.481285675685526*^9}, {3.481303689997296*^9, 3.481303722472939*^9}, {
   3.481456087628784*^9, 3.481456100455924*^9}, 3.504611177112706*^9, {
   3.5046112888711042`*^9, 3.5046113163688164`*^9}, {3.5046114197195916`*^9, 
   3.5046114760430303`*^9}, {3.504611935742608*^9, 3.504611941820656*^9}, 
   3.5046120249112825`*^9, 3.504612703857331*^9, {3.5046127356377673`*^9, 
   3.504612808432779*^9}, 3.5046329171904287`*^9, {3.504633499637619*^9, 
   3.504633528919244*^9}, 3.5046335625603*^9, 3.5046340231286945`*^9, 
   3.5046341153017497`*^9, 3.5046347243095446`*^9, 3.504634759106865*^9, 
   3.504635249566268*^9, 3.5046364613980284`*^9, {3.504636664724852*^9, 
   3.504636682818486*^9}, 3.504636963474331*^9, {3.527856119810442*^9, 
   3.527856125544129*^9}, {3.5412689376963663`*^9, 3.541268942640649*^9}, 
   3.5412689779366674`*^9, 3.5412694020179234`*^9, {3.541269789284074*^9, 
   3.5412697911971836`*^9}},
 FontFamily->"Calibri",
 FontColor->GrayLevel[0],
 CellTags->"Basic Operations"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "code", "=", 
   "\"\<\n#define N(x)       (erf((x)/sqrt(2.0))/2+0.5)\n__global__ void \
blackScholes(Real_t * call, Real_t * S, Real_t * X, Real_t * T, Real_t * r, \
Real_t * q, Real_t * sigma, mint length) {\n\tint ii = threadIdx.x + \
blockIdx.x*blockDim.x;\n\tif (ii < length) {\n\t\tReal_t d1 = \
(log(S[ii]/X[ii])+(r[ii]-q[ii]+(pow(sigma[ii],(Real_t)2.0)/2)*T[ii]))/(sigma[\
ii]*sqrt(T[ii]));\n\t\tReal_t d2 = d1 - sigma[ii]*sqrt(T[ii]);\n\t\tcall[ii] \
= S[ii]*exp(-q[ii]*T[ii])*N(d1) - X[ii]*exp(-r[ii]*T[ii])*N(d2);\n\t}\n\
}\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.507470727144957*^9, 3.5074707288720317`*^9}, {
  3.508786188045736*^9, 3.50878619258919*^9}, {3.5087862423481655`*^9, 
  3.508786297567687*^9}, {3.508786329731903*^9, 3.508786340680998*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bs", "=", 
  RowBox[{"CUDAFunctionLoad", "[", 
   RowBox[{"code", ",", "\"\<blackScholes\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "_Real", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", "_Integer"}], 
     "}"}], ",", "128", ",", 
    RowBox[{"\"\<Defines\>\"", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<mint\>\"", "\[Rule]", "\"\<int\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{3.5087863600259323`*^9, 3.508786453495278*^9}],

Cell[BoxData[
 RowBox[{"CUDAFunction", "[", 
  RowBox[{"\<\"<>\"\>", ",", "\<\"blackScholes\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "_Real", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
    "}"}]}], "]"}]], "Output",
 CellChangeTimes->{{3.508786455305459*^9, 3.508786481626091*^9}, 
   3.508872846670089*^9, 3.5397440315444317`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bs", "[", 
  RowBox[{
   RowBox[{"{", "0.0", "}"}], ",", 
   RowBox[{"{", "35.0", "}"}], ",", 
   RowBox[{"{", "35.0", "}"}], ",", 
   RowBox[{"{", "1.0", "}"}], ",", 
   RowBox[{"{", "0.08", "}"}], ",", 
   RowBox[{"{", "0.02", "}"}], ",", 
   RowBox[{"{", "0.3", "}"}], ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.5278561422691803`*^9, 3.527856170548588*^9}, {
  3.539743989793044*^9, 3.5397440190887194`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "5.04897920146445`", "}"}], "}"}]], "Output",
 CellChangeTimes->{3.527991205669634*^9, 3.539743626167246*^9, 
  3.5397440345056014`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FinancialDerivative", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<European\>\"", ",", "\"\<Call\>\""}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", "35"}], ",", 
     RowBox[{"\"\<Expiration\>\"", "\[Rule]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", "35"}], ",", 
     RowBox[{"\"\<InterestRate\>\"", "\[Rule]", "0.08"}], ",", 
     RowBox[{"\"\<Dividend\>\"", "\[Rule]", "0.02"}], ",", 
     RowBox[{"\"\<Volatility\>\"", "\[Rule]", "0.30"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.527856178826023*^9, 3.527856206236251*^9}, {
  3.5397439202730675`*^9, 3.5397439338248425`*^9}}],

Cell[BoxData["5.0489792014644514`"], "Output",
 CellChangeTimes->{3.527991208589634*^9, 3.539743630068469*^9, 
  3.539743936274983*^9}]
}, Closed]],

Cell["The function can then be called with the following data.", "MathCaption",
 CellChangeTimes->{{3.5088714447587147`*^9, 3.5088714549667144`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"numberOfOptions", "=", "32"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"call", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", "numberOfOptions"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"spotPrices", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"25.0", ",", "35.0"}], "}"}], ",", "numberOfOptions"}], "]"}]}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"strikePrices", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"20.0", ",", "40.0"}], "}"}], ",", "numberOfOptions"}], "]"}]}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"expiration", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.1", ",", "10.0"}], "}"}], ",", "numberOfOptions"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"interest", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.03", ",", "0.07"}], "}"}], ",", "numberOfOptions"}], "]"}]}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"dividend", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.01", ",", "0.04"}], "}"}], ",", "numberOfOptions"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"volatility", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.10", ",", "0.50"}], "}"}], ",", "numberOfOptions"}], "]"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.508786516985626*^9, 3.5087865690238295`*^9}, 
   3.5087866055324802`*^9, {3.5087870039743204`*^9, 3.508787009515875*^9}},
 CellID->721040315],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bs", "[", 
  RowBox[{
  "call", ",", "spotPrices", ",", "strikePrices", ",", "expiration", ",", 
   "interest", ",", "dividend", ",", "volatility", ",", "numberOfOptions"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5087863896028895`*^9, 3.508786429747904*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "10.433661874215362`", ",", "7.531472473235872`", ",", 
    "0.8731507245065462`", ",", "9.371125721131937`", ",", 
    "2.7001397503045714`", ",", "4.788362756502675`", ",", 
    "9.822384218368798`", ",", "8.80257240950991`", ",", 
    "1.7421902241149787`", ",", "3.0883056354059164`", ",", 
    "4.794887223868085`", ",", "0.05321470530504483`", ",", 
    "4.88520675848218`", ",", "8.594148041624774`", ",", "9.573678958718139`",
     ",", "2.924297182910031`", ",", "3.365504734708844`", ",", 
    "9.032450282749037`", ",", "1.4112932567058085`", ",", 
    "17.206597405371294`", ",", "4.702317565848749`", ",", 
    "6.876117924158106`", ",", "9.773279158198614`", ",", 
    "8.570801227592943`", ",", "9.153175581809414`", ",", 
    "10.338001876967938`", ",", "6.769298021962108`", ",", 
    "9.94848124297163`", ",", "5.573709421753766`", ",", 
    "0.9910296128510144`", ",", "10.495012377789903`", ",", 
    "10.660099211047868`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.508786461167045*^9, 3.508786485356464*^9}, 
   3.5087865786137886`*^9, 3.5087866178247094`*^9, 3.508872852423664*^9, 
   3.5397436850866156`*^9, 3.5397440491574397`*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Automatic Code Generation in Finance", "Section",
 CellChangeTimes->{{3.5397493808173933`*^9, 3.5397493842885914`*^9}, {
  3.539893849715541*^9, 3.5398938636183367`*^9}}],

Cell[TextData[{
 "In the above examples we have either used the built-in ",
 StyleBox["CUDAFinancialDerivative", "Input"],
 " or directly written CUDA code to establish derivative functions. But in \
this section we show how it is possible to go directly from ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code, which is very close to the actual mathematical equations, and \
construct CUDA financial functions. This transformation can be done \
automatically by using the function ",
 StyleBox["generateCUDAKernel", "Input"],
 " to create CUDA code which is then wrapped in ",
 StyleBox["ToCCodeString", "Input"],
 " and acted upon by ",
 StyleBox["CUDAFunctionLoad", "Input"],
 " to create a ",
 StyleBox["CUDAFunction", "Input"],
 " object that utilizes the GPU. "
}], "MathCaption",
 CellChangeTimes->{{3.5088714447587147`*^9, 3.5088714549667144`*^9}, {
   3.539893889442814*^9, 3.5398941580521774`*^9}, {3.5398943020204115`*^9, 
   3.539894321380519*^9}, {3.5398943563725204`*^9, 3.5398944130767636`*^9}, {
   3.5398944979406176`*^9, 3.539894557669034*^9}, {3.5412690676327977`*^9, 
   3.541269071569023*^9}, {3.541269135059654*^9, 3.5412691391688895`*^9}, 
   3.541269301042148*^9}],

Cell[CellGroupData[{

Cell["The Black\[Dash]Scholes Equation", "MoreExamplesSection",
 CellChangeTimes->{{3.5412692349613686`*^9, 3.541269259781788*^9}, {
  3.541269835779733*^9, 3.5412698376638412`*^9}}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "S", ",", "sigma", ",", "r", ",", "q", ",", "T", ",", "x", ",", "X"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5087855576837063`*^9, 3.508785557902728*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   SubscriptBox["d", "1"], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"T", " ", 
      RowBox[{"(", 
       RowBox[{"r", "-", "q", "+", 
        FractionBox[
         SuperscriptBox["sigma", "2"], "2"]}], ")"}]}], "+", 
     RowBox[{"Log", "[", 
      FractionBox["S", "X"], "]"}]}], 
    RowBox[{
     SqrtBox["T"], " ", "sigma"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["d", "2"], "=", 
   RowBox[{
    SubscriptBox["d", "1"], "-", 
    RowBox[{"sigma", " ", 
     SqrtBox["T"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"BlackScholes", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"CDF", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}], ",", 
       SubscriptBox["d", "1"]}], "]"}], " ", "S", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "q"}], " ", "T"}]]}], "-", 
    RowBox[{
     RowBox[{"CDF", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}], ",", 
       SubscriptBox["d", "2"]}], "]"}], " ", "X", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "r"}], " ", "T"}]]}]}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{
  3.50347225528722*^9, {3.503502345899627*^9, 3.503502436079026*^9}, {
   3.503502749366938*^9, 3.503502788933317*^9}, {3.5063655317171507`*^9, 
   3.5063655443159533`*^9}, {3.5082699253828473`*^9, 3.508269962701579*^9}, {
   3.508269998659174*^9, 3.508270022151523*^9}, 3.5082919549774976`*^9, 
   3.50829207681568*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{"q", "+", "r"}], ")"}]}], " ", "T"}]], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"r", " ", "T"}]], " ", "S", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"Erf", "[", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "q"}], "+", "r", "+", 
             FractionBox[
              SuperscriptBox["sigma", "2"], "2"]}], ")"}], " ", "T"}], "+", 
          RowBox[{"Log", "[", 
           FractionBox["S", "X"], "]"}]}], 
         RowBox[{
          SqrtBox["2"], " ", "sigma", " ", 
          SqrtBox["T"]}]], "]"}]}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"q", " ", "T"}]], " ", "X", " ", 
     RowBox[{"Erfc", "[", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "q"}], "-", 
           RowBox[{"2", " ", "r"}], "+", 
           SuperscriptBox["sigma", "2"]}], ")"}], " ", "T"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Log", "[", 
          FractionBox["S", "X"], "]"}]}]}], 
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", "sigma", " ", 
        SqrtBox["T"]}]], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5087855074856863`*^9, 3.508785620321969*^9, 
  3.5087866556474915`*^9, 3.508872631290553*^9, 3.537670488037428*^9, 
  3.5377165436125197`*^9, 3.539744093188958*^9}]
}, Closed]],

Cell[TextData[{
 ButtonBox["FinancialDerivative",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/FinancialDerivative"],
 " computes the Black",
 "\[Dash]",
 "Scholes formula for the European call option with the following parameters."
}], "MathCaption",
 CellChangeTimes->{{3.5412693658738565`*^9, 3.541269390450262*^9}, {
  3.541269850179557*^9, 3.5412698523506813`*^9}}],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[GridBox[{
      {"\<\"\\!\\(\\*\\nStyleBox[\\\"S\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
\>", "\<\"\[DoubleLeftRightArrow]\"\>", "\<\"CurrentPrice\"\>"},
      {"\<\"\\!\\(\\*\\nStyleBox[\\\"X\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
\>", "\<\"\[DoubleLeftRightArrow]\"\>", "\<\"StrikePrice\"\>"},
      {"\<\"\[Sigma]\"\>", "\<\"\[DoubleLeftRightArrow]\"\>", "\<\"Volatility\
\"\>"},
      {"\<\"\\!\\(\\*\\nStyleBox[\\\"T\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
\>", "\<\"\[DoubleLeftRightArrow]\"\>", "\<\"Expiration\"\>"},
      {"\<\"\\!\\(\\*\\nStyleBox[\\\"r\\\",\\nFontSlant->\\\"Italic\\\"]\\)\"\
\>", "\<\"\[DoubleLeftRightArrow]\"\>", "\<\"InterestRate\"\>"}
     },
     AutoDelete->False,
     BaseStyle->{FontFamily -> "Verdana"},
     FrameStyle->GrayLevel[0.5],
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
          Hue[0.6, 0.15, 0.9], 
          GrayLevel[0.9]}}},
     GridBoxDividers->{
      "Columns" -> {True, False, False, True}, "Rows" -> {{True}}},
     GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{2}}}],
    "Grid"],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "DisplayFormula",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 ShowStringCharacters->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating the Greeks", "MoreExamplesSection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"greeks", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<Vanilla\>\"", "\[Rule]", 
      RowBox[{"HoldForm", "[", "BlackScholes", "]"}]}], ",", 
     RowBox[{"\"\<Delta\>\"", "\[Rule]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "S"], "BlackScholes"}], "]"}]}], ",", 
     RowBox[{"\"\<Vega\>\"", "\[Rule]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "sigma"], "BlackScholes"}], "]"}]}], ",", 
     RowBox[{"\"\<Theta\>\"", "\[Rule]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{"-", 
        RowBox[{
         SubscriptBox["\[PartialD]", "T"], "BlackScholes"}]}], "]"}]}], ",", 
     RowBox[{"\"\<Rho\>\"", "\[Rule]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", "r"], "BlackScholes"}], "]"}]}], ",", 
     RowBox[{"\"\<Gamma\>\"", "\[Rule]", 
      RowBox[{"HoldForm", "[", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"S", ",", "S"}]], "BlackScholes"}], "]"}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.508787469905909*^9, 3.5087874775536737`*^9}}],

Cell["This shows a table of how the Greeks are defined.", "MathCaption"],

Cell[BoxData[
 TagBox[
  FormBox[
   TagBox[GridBox[{
      {"\<\"Vanilla\"\>", 
       TagBox["BlackScholes",
        HoldForm]},
      {"\<\"Delta\"\>", 
       TagBox[
        FractionBox[
         RowBox[{"\[PartialD]", "BlackScholes"}], 
         RowBox[{"\[PartialD]", "S"}],
         MultilineFunction->None],
        HoldForm]},
      {"\<\"Vega\"\>", 
       TagBox[
        FractionBox[
         RowBox[{"\[PartialD]", "BlackScholes"}], 
         RowBox[{"\[PartialD]", "sigma"}],
         MultilineFunction->None],
        HoldForm]},
      {"\<\"Theta\"\>", 
       RowBox[{"-", 
        TagBox[
         FractionBox[
          RowBox[{"\[PartialD]", "BlackScholes"}], 
          RowBox[{"\[PartialD]", "T"}],
          MultilineFunction->None],
         HoldForm]}]},
      {"\<\"Rho\"\>", 
       TagBox[
        FractionBox[
         RowBox[{"\[PartialD]", "BlackScholes"}], 
         RowBox[{"\[PartialD]", "r"}],
         MultilineFunction->None],
        HoldForm]},
      {"\<\"Gamma\"\>", 
       TagBox[
        FractionBox[
         RowBox[{
          SuperscriptBox["\[PartialD]", "2"], "BlackScholes"}], 
         RowBox[{
          RowBox[{"\[PartialD]", "S"}], "\[ThinSpace]", 
          RowBox[{"\[PartialD]", "S"}]}],
         MultilineFunction->None],
        HoldForm]}
     },
     AutoDelete->False,
     BaseStyle->{FontFamily -> "Verdana"},
     FrameStyle->GrayLevel[0.5],
     GridBoxAlignment->{"Columns" -> {{Left}}},
     GridBoxBackground->{"Columns" -> {{None}}, "Rows" -> {{
          Hue[0.6, 0.15, 0.9], 
          GrayLevel[0.9]}}},
     GridBoxDividers->{
      "Columns" -> {True, False, False, True}, "Rows" -> {{True}}},
     GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
     GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
     GridBoxSpacings->{"Columns" -> {{1}}, "Rows" -> {{2}}}],
    "Grid"],
   TraditionalForm],
  TraditionalForm,
  Editable->True]], "DisplayFormula",
 CellChangeTimes->{{3.5087875048434024`*^9, 3.508787512760194*^9}},
 ShowStringCharacters->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Generate Symbolic Code for Greeks\
\>", "MoreExamplesSection",
 CellChangeTimes->{{3.5087856686518016`*^9, 3.508785671496086*^9}, {
  3.5412698857005887`*^9, 3.5412698862286186`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ReleaseHold", "[", 
    RowBox[{"g", "/.", "greeks"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", ",", "\"\<Delta\>\"", ",", "\"\<Greek\>\""}], "}"}], ",", 
     RowBox[{"First", "/@", "greeks"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.506366023813932*^9, 3.506366113129594*^9}, {
  3.506366143601096*^9, 3.506366201903139*^9}, {3.5063662362862954`*^9, 
  3.506366272372642*^9}, {3.506366665453165*^9, 3.5063666726038303`*^9}, {
  3.5082913488348894`*^9, 3.508291352262232*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`g$$ = "Delta", Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`g$$], "Delta", "Greek"}, {
      "Vanilla", "Delta", "Vega", "Theta", "Rho", "Gamma"}}}, 
    Typeset`size$$ = {156., {3., 11.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, $CellContext`g$4564$$ =
     0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`g$$ = "Delta"}, 
      "ControllerVariables" :> {
        Hold[$CellContext`g$$, $CellContext`g$4564$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ReleaseHold[
        ReplaceAll[$CellContext`g$$, $CellContext`greeks]], 
      "Specifications" :> {{{$CellContext`g$$, "Delta", "Greek"}, {
         "Vanilla", "Delta", "Vega", "Theta", "Rho", "Gamma"}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{209., {60., 67.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5087856754464808`*^9, 3.5087866645213785`*^9, 
  3.508787532192137*^9, 3.508872876353057*^9, 3.5376706076993933`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"ReplaceAll", "::", "reps"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"\[NoBreak]\\!\\({greeks}\\)\[NoBreak] is neither a list of \
replacement rules nor a valid dispatch table, and so cannot be used for \
replacing. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\
\\\", ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/ReplaceAll/reps\\\
\", ButtonNote -> \\\"ReplaceAll::reps\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5402200459672503`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generate CUDA Code for Greeks", "MoreExamplesSection",
 CellChangeTimes->{{3.541269893124013*^9, 3.54126989358804*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ToCCodeString", "[", 
    RowBox[{"generateCUDAKernel", "[", 
     RowBox[{"g", ",", 
      RowBox[{"ReleaseHold", "[", 
       RowBox[{"g", "/.", "greeks"}], "]"}]}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"g", ",", "\"\<Delta\>\"", ",", "\"\<Greek\>\""}], "}"}], ",", 
     RowBox[{"First", "/@", "greeks"}]}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`g$$ = "Theta", Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`g$$], "Delta", "Greek"}, {
      "Vanilla", "Delta", "Vega", "Theta", "Rho", "Gamma"}}}, 
    Typeset`size$$ = {1298., {680., 15.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True, $CellContext`g$4600$$ =
     0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`g$$ = "Delta"}, 
      "ControllerVariables" :> {
        Hold[$CellContext`g$$, $CellContext`g$4600$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> SymbolicC`ToCCodeString[
        $CellContext`generateCUDAKernel[$CellContext`g$$, 
         ReleaseHold[
          ReplaceAll[$CellContext`g$$, $CellContext`greeks]]]], 
      "Specifications" :> {{{$CellContext`g$$, "Delta", "Greek"}, {
         "Vanilla", "Delta", "Vega", "Theta", "Rho", "Gamma"}}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{1351., {397., 404.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5087856832222586`*^9, 3.5087866697709036`*^9, 
  3.508787538784796*^9, 3.5088728827326946`*^9, 3.537670639462569*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Load Function using ",
 StyleBox["CUDAFunctionLoad",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.541269904275651*^9, 3.5412699049966927`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"src", "=", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"ToCCodeString", "[", 
        RowBox[{"generateCUDAKernel", "[", 
         RowBox[{
          RowBox[{"First", "[", "#", "]"}], ",", 
          RowBox[{"ReleaseHold", "[", 
           RowBox[{"Last", "[", "#", "]"}], "]"}]}], "]"}], "]"}], "&"}], ",",
       "greeks"}], "]"}], "//", "StringJoin"}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"greekMethods", "=", 
  RowBox[{"First", "/@", "greeks"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Vanilla\"\>", ",", "\<\"Delta\"\>", ",", "\<\"Vega\"\>", 
   ",", "\<\"Theta\"\>", ",", "\<\"Rho\"\>", ",", "\<\"Gamma\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5087857292198577`*^9, 3.508786691091035*^9, 
  3.5088728938368053`*^9, 3.537670691830806*^9, 3.5377165784450026`*^9, 
  3.5397442891761675`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"europeanOption", "[", "#", "]"}], "=", 
     RowBox[{"CUDAFunctionLoad", "[", 
      RowBox[{"src", ",", "#", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "_Real", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", "_Integer"}], 
        "}"}], ",", "128", ",", 
       RowBox[{"\"\<Defines\>\"", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", "\[Rule]", "\"\<int\>\""}], "}"}]}]}], 
      "]"}]}], ")"}], "&"}], "/@", "greekMethods"}]], "Input",
 CellChangeTimes->{
  3.5079828197277193`*^9, {3.508785741992135*^9, 3.508785754852421*^9}, 
   3.5087860115640893`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"Vanilla\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"Delta\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"Vega\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"Theta\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"Rho\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"Gamma\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.50878576235017*^9, 3.5087867089788237`*^9, 
  3.508787573557273*^9, 3.508872900755497*^9, 3.537670756755297*^9, 
  3.537716587499908*^9, 3.5397443240771637`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute using ",
 StyleBox["CUDAFunction",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5074707613125277`*^9, 3.507470763095252*^9}, {
  3.541269925156845*^9, 3.5412699258438845`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"optN", " ", "=", " ", "32"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Svec", " ", "=", " ", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"20.0", ",", " ", "40.0"}], "}"}], ",", " ", "optN"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Xvec", " ", "=", " ", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"20.0", ",", " ", "40.0"}], "}"}], ",", " ", "optN"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tvec", " ", "=", " ", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.1", ",", " ", "10.0"}], "}"}], ",", " ", "optN"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rvec", " ", "=", " ", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.02", ",", " ", "0.1"}], "}"}], ",", " ", "optN"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qvec", " ", "=", " ", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.01", ",", " ", "0.06"}], "}"}], ",", " ", "optN"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sigmavec", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.1", ",", "0.4"}], "}"}], ",", "optN"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{3.508786060194952*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"call", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", " ", "optN"}], "]"}]}], ";"}]], "Input"],

Cell["Call one of the functions.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"europeanOption", "[", "\"\<Vanilla\>\"", "]"}], "[", 
  RowBox[{
  "call", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", "Qvec", 
   ",", "Sigmavec", ",", "optN"}], "]"}]], "Input",
 CellChangeTimes->{{3.5074707346653957`*^9, 3.5074707387687845`*^9}, 
   3.5087860870806403`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "1.6980140754761677`", ",", "17.35908756793244`", ",", 
    "4.735926213363075`", ",", "0.13570838510603458`", ",", 
    "4.910408387658594`", ",", "12.155163694897212`", ",", 
    "1.1015300216024162`", ",", "5.1561950910699075`", ",", 
    "8.429002968183152`", ",", "13.137930725599503`", ",", 
    "2.575363857910768`", ",", "10.14283001002491`", ",", 
    "12.956980340390071`", ",", "7.92374531101961`", ",", 
    "6.0073068845897275`", ",", "3.4272051743633973`", ",", 
    "9.670276620375278`", ",", "13.765423721281694`", ",", 
    "11.337153581633881`", ",", "5.79266355458021`", ",", 
    "8.639262865174349`", ",", "11.065692604031513`", ",", 
    "12.860749425869455`", ",", "9.621121889929762`", ",", 
    "4.107991985068837`", ",", "3.930189203737847`", ",", 
    "5.1480781059281355`", ",", "7.594296126090216`", ",", 
    "2.606255590444298`", ",", "7.909613394168977`", ",", 
    "13.040673171200249`", ",", "4.54174081835554`"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.508786740573983*^9, 3.5087875841703343`*^9, 3.508815970509797*^9, {
   3.5088729135847797`*^9, 3.5088729247868996`*^9}, 3.537670901162737*^9, 
   3.5377166000551634`*^9, 3.5397443628073792`*^9}]
}, Closed]],

Cell["Or use all methods.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Column", "[", 
       RowBox[{
        RowBox[{"{", "#", "}"}], "~", "Join", "~", 
        RowBox[{"First", "@", 
         RowBox[{
          RowBox[{"europeanOption", "[", "#", "]"}], "[", 
          RowBox[{
          "call", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", 
           "Qvec", ",", "Sigmavec", ",", "optN"}], "]"}]}]}], "]"}], " ", 
      "&"}], " ", "/@", " ", "greekMethods"}], "}"}], ",", " ", 
   RowBox[{"Frame", " ", "->", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5074707409449577`*^9, 3.508786760272953*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {"\<\"Vanilla\"\>"},
        {"1.6980140754761677`"},
        {"17.35908756793244`"},
        {"4.735926213363075`"},
        {"0.13570838510603458`"},
        {"4.910408387658594`"},
        {"12.155163694897212`"},
        {"1.1015300216024162`"},
        {"5.1561950910699075`"},
        {"8.429002968183152`"},
        {"13.137930725599503`"},
        {"2.575363857910768`"},
        {"10.14283001002491`"},
        {"12.956980340390071`"},
        {"7.92374531101961`"},
        {"6.0073068845897275`"},
        {"3.4272051743633973`"},
        {"9.670276620375278`"},
        {"13.765423721281694`"},
        {"11.337153581633881`"},
        {"5.79266355458021`"},
        {"8.639262865174349`"},
        {"11.065692604031513`"},
        {"12.860749425869455`"},
        {"9.621121889929762`"},
        {"4.107991985068837`"},
        {"3.930189203737847`"},
        {"5.1480781059281355`"},
        {"7.594296126090216`"},
        {"2.606255590444298`"},
        {"7.909613394168977`"},
        {"13.040673171200249`"},
        {"4.54174081835554`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"Delta\"\>"},
        {"0.25366733314576534`"},
        {"0.685263556351845`"},
        {"0.5368352801825889`"},
        {"0.08745579901427594`"},
        {"0.3779386178862525`"},
        {"0.5712250336771857`"},
        {"0.37880599634384243`"},
        {"0.5732893121770587`"},
        {"0.6382340832780794`"},
        {"0.8840821541386931`"},
        {"0.33499435770792724`"},
        {"0.732878794021736`"},
        {"0.6568841281667428`"},
        {"0.6105037410251839`"},
        {"0.4992219694648911`"},
        {"0.47738798920845976`"},
        {"0.7980807308345019`"},
        {"0.8140738095501285`"},
        {"0.6287158179937156`"},
        {"0.5448478252146174`"},
        {"0.5280949585787639`"},
        {"0.47441759426994`"},
        {"0.5366826014231783`"},
        {"0.5883134372406265`"},
        {"0.3477001173821489`"},
        {"0.5190041348910805`"},
        {"0.42121118215945796`"},
        {"0.4748692980268549`"},
        {"0.3670952506072025`"},
        {"0.5434076706497731`"},
        {"0.5400819703085281`"},
        {"0.6093141355546634`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"Vega\"\>"},
        {"16.46477941506525`"},
        {"20.734714323905187`"},
        {"16.152353501559155`"},
        {"4.496715394140002`"},
        {"18.55661984133012`"},
        {"23.930122222357607`"},
        {"9.345002955949727`"},
        {"17.257726783375585`"},
        {"18.623106382196777`"},
        {"7.054532794425362`"},
        {"21.957955170082208`"},
        {"18.260922772365355`"},
        {"15.7414157584697`"},
        {"21.471990391578412`"},
        {"22.688953838895287`"},
        {"16.378472425726244`"},
        {"4.072002639215411`"},
        {"8.8666442144549`"},
        {"20.36638329137748`"},
        {"16.395455703289137`"},
        {"14.495777627903605`"},
        {"23.85292944105486`"},
        {"17.327267684242464`"},
        {"11.746632962447697`"},
        {"28.408858683084457`"},
        {"14.237196986834736`"},
        {"19.33245779940122`"},
        {"26.883623425332004`"},
        {"22.307494526490032`"},
        {"17.31636310177415`"},
        {"13.490328503258738`"},
        {"14.788059122882725`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"Theta\"\>"},
        {
         RowBox[{"-", "0.21066407632341852`"}]},
        {
         RowBox[{"-", "0.3969307309359722`"}]},
        {
         RowBox[{"-", "1.0697573585792637`"}]},
        {
         RowBox[{"-", "0.23782888787686204`"}]},
        {
         RowBox[{"-", "0.03402882057468606`"}]},
        {
         RowBox[{"-", "0.16702801460155697`"}]},
        {
         RowBox[{"-", "0.39521614744785527`"}]},
        {
         RowBox[{"-", "0.1617010171901997`"}]},
        {
         RowBox[{"-", "0.5342370518216326`"}]},
        {
         RowBox[{"-", "0.9726721706693703`"}]},
        {
         RowBox[{"-", "0.12438602350924115`"}]},
        {
         RowBox[{"-", "0.7316656631282361`"}]},
        {
         RowBox[{"-", "0.29699888745836817`"}]},
        {
         RowBox[{"-", "1.0208033284919393`"}]},
        {
         RowBox[{"-", "0.2616935696919609`"}]},
        {
         RowBox[{"-", "0.7609041600263181`"}]},
        {
         RowBox[{"-", "0.6804085332087221`"}]},
        {
         RowBox[{"-", "0.1171539897111678`"}]},
        {
         RowBox[{"-", "0.2931549307292149`"}]},
        {
         RowBox[{"-", "0.3617574413694317`"}]},
        {
         RowBox[{"-", "0.11269979437968983`"}]},
        {
         RowBox[{"-", "0.019972528915701365`"}]},
        {"0.3551882731999505`"},
        {
         RowBox[{"-", "0.11410434453716861`"}]},
        {
         RowBox[{"-", "0.0037808579448756034`"}]},
        {
         RowBox[{"-", "1.2049185354675451`"}]},
        {
         RowBox[{"-", "0.24323366041603578`"}]},
        {
         RowBox[{"-", "0.07212861450028771`"}]},
        {
         RowBox[{"-", "0.1576419270610202`"}]},
        {
         RowBox[{"-", "0.12014295442526736`"}]},
        {"0.23177040509978536`"},
        {"0.20454666561367024`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"Rho\"\>"},
        {"30.909168322209215`"},
        {"68.77872086216632`"},
        {"27.946976512971666`"},
        {"2.2980279194071054`"},
        {"58.47866348883488`"},
        {"66.4710339354134`"},
        {"10.172594694795011`"},
        {"65.57148115971384`"},
        {"83.80975238596228`"},
        {"34.61131410173385`"},
        {"59.549656835309435`"},
        {"68.24887502776826`"},
        {"45.09956888335403`"},
        {"50.33779722488627`"},
        {"87.2995268794741`"},
        {"29.616877525523467`"},
        {"90.88925586421539`"},
        {"118.27215680536061`"},
        {"62.831697615346`"},
        {"34.1061311892523`"},
        {"43.858643324298505`"},
        {"60.60129203614115`"},
        {"60.68494452941946`"},
        {"43.41935025696082`"},
        {"68.62550562938237`"},
        {"21.63458120258882`"},
        {"46.15109968441964`"},
        {"91.11187253350825`"},
        {"63.21389865810671`"},
        {"48.58269373822825`"},
        {"72.64008064329785`"},
        {"72.39980772369795`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"Gamma\"\>"},
        {"0.01948689787065978`"},
        {"0.004716420993535606`"},
        {"0.024771481178741353`"},
        {"0.044893740904376374`"},
        {"0.009959406229203275`"},
        {"0.006747278896027607`"},
        {"0.07930291554074917`"},
        {"0.02080497682598986`"},
        {"0.012653166642925108`"},
        {"0.010735506338276312`"},
        {"0.021427996021187782`"},
        {"0.013995931606800651`"},
        {"0.007039841532554529`"},
        {"0.015774765113097642`"},
        {"0.015108541057228732`"},
        {"0.031152736143408896`"},
        {"0.006377493011073307`"},
        {"0.006254716424344595`"},
        {"0.00809641298560399`"},
        {"0.01604687900132347`"},
        {"0.006581653342316743`"},
        {"0.004699854352036303`"},
        {"0.004028835137416948`"},
        {"0.006125630095748252`"},
        {"0.013522839856485535`"},
        {"0.03137635858431584`"},
        {"0.012716988946005913`"},
        {"0.009942972376528397`"},
        {"0.02540911436751233`"},
        {"0.01059952223590556`"},
        {"0.0035274983783334176`"},
        {"0.02792560197539619`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.508786762765202*^9, 3.5087875912310405`*^9, 3.50881595503625*^9, 
   3.5088729290943303`*^9, {3.537670949883608*^9, 3.5376709944400635`*^9}, 
   3.537716606662824*^9, 3.539744378750291*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellChangeTimes->{3.479485737971568*^9},
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Define New Options", "Section",
 CellChangeTimes->{{3.503732310771084*^9, 3.503732329329851*^9}, {
  3.5063648796898046`*^9, 3.5063648905180807`*^9}, {3.5063655134585533`*^9, 
  3.5063655199054065`*^9}, {3.506365555652142*^9, 3.506365565218912*^9}, {
  3.506366735174594*^9, 3.506366765761503*^9}, {3.5063676280968175`*^9, 
  3.506367632112494*^9}, {3.5082174374294577`*^9, 3.5082174394529734`*^9}, {
  3.5082175133952656`*^9, 3.5082175167948103`*^9}}],

Cell[TextData[{
 "In the above example we showed how it is possible to use the functions ",
 StyleBox["generateCUDAKernel", "Input"],
 " and ",
 StyleBox["CUDAFunctionLoad", "Input"],
 " to create the well-known Black\[Dash]Scholes derivatives and their Greeks \
as CUDA functions that utilize the GPU. In this section we will show that the \
same method can be used to construct a ",
 StyleBox["CUDAFunction", "Input"],
 " for any derivative that admits a mathematical representation. Here we \
consider building the options for cash or nothing calls and puts, asset or \
nothing calls and puts, future calls and puts, and one touch calls and puts."
}], "MathCaption",
 CellChangeTimes->{{3.5088714447587147`*^9, 3.5088714549667144`*^9}, {
  3.539893889442814*^9, 3.5398941580521774`*^9}, {3.5398943020204115`*^9, 
  3.539894321380519*^9}, {3.5398943563725204`*^9, 3.5398944130767636`*^9}, {
  3.5398944979406176`*^9, 3.539894557669034*^9}, {3.5398945996054325`*^9, 
  3.539894795509638*^9}, {3.5398948263254004`*^9, 3.5398949409179544`*^9}, {
  3.53989497720803*^9, 3.5398950379585047`*^9}, {3.541269975460723*^9, 
  3.5412699773218293`*^9}, {3.541270009892692*^9, 3.541270031700939*^9}, {
  3.541270080788747*^9, 3.5412701046451116`*^9}}],

Cell[BoxData[
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "S", ",", "sigma", ",", "r", ",", "q", ",", "T", ",", "X", ",", 
   "cashOrNothingCall", ",", "cashOrNothingPut", ",", "assetOrNothingCall", 
   ",", "assetOrNothingPut"}], "]"}]], "Input",
 CellChangeTimes->{{3.5063683358837705`*^9, 3.506368349732935*^9}, {
  3.5082180671509037`*^9, 3.5082180784628615`*^9}, {3.508219279626172*^9, 
  3.50821928092212*^9}, {3.5082694875990734`*^9, 3.50826948827114*^9}, {
  3.5087885108850594`*^9, 3.508788511054059*^9}, {3.5087887038930593`*^9, 
  3.508788704453059*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Pg", " ", "408", " ", "in", " ", "Paul", " ", "Wilmott", " ", "on", " ", 
     "quantitative", " ", "finance"}], ",", 
    RowBox[{"Volume", " ", "2", " ", "By", " ", "Paul", " ", "Wilmott"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["d", "1"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", "X"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "q", "+", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "2"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", "X"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "q", "-", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "3"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", "X"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "q", "+", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "4"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", "X"}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "q", "-", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "5"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", "X"}], "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "+", "q", "-", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "6"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", "X"}], "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "+", "q", "+", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], " ", "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "7"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", 
         SuperscriptBox["X", "2"]}], "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "q", "-", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["d", "8"], "=", 
     FractionBox[
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"S", "/", 
         SuperscriptBox["X", "2"]}], "]"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "+", "q", "+", 
          RowBox[{
           SuperscriptBox["sigma", "2"], "/", "2"}]}], ")"}], " ", "T"}]}], 
      RowBox[{"sigma", " ", 
       RowBox[{"\[Sqrt]", "T"}]}]]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5082190106861577`*^9, 3.508219028915373*^9}, {
  3.508219269786927*^9, 3.5082194402192526`*^9}, {3.5082195984636106`*^9, 
  3.508219624060296*^9}, {3.5082204229601135`*^9, 3.5082204399724855`*^9}, {
  3.5087884442840595`*^9, 3.508788459568059*^9}, {3.508788493030059*^9, 
  3.508788493686059*^9}, {3.508788712795059*^9, 3.508788744236059*^9}}],

Cell[CellGroupData[{

Cell["Binary Options ", "Subsection",
 CellChangeTimes->{{3.5082175839038324`*^9, 3.508217586847305*^9}, {
   3.50821773545848*^9, 3.5082177401539726`*^9}, 3.508815070938849*^9, 
   3.511012348856659*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binaryOpts", "=", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cashOrNothingCall", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "r"}], " ", "T"}], "]"}], "*", 
       RowBox[{"CDF", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "1"}], "]"}], ",", 
         SubscriptBox["d", "2"]}], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"cashOrNothingPut", "\[Rule]", " ", 
      RowBox[{
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "r"}], " ", "T"}], "]"}], "*", 
       RowBox[{"CDF", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "1"}], "]"}], ",", 
         RowBox[{"-", " ", 
          SubscriptBox["d", "2"]}]}], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"assetOrNothingCall", "\[Rule]", " ", 
      RowBox[{"S", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "q"}], " ", "T"}], "]"}], "*", 
       RowBox[{"CDF", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "1"}], "]"}], ",", 
         RowBox[{"-", " ", 
          SubscriptBox["d", "1"]}]}], "]"}]}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"assetOrNothingPut", "\[Rule]", " ", 
      RowBox[{"S", " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "q"}], " ", "T"}], "]"}], "*", 
       RowBox[{"CDF", "[", 
        RowBox[{
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", "1"}], "]"}], ",", 
         RowBox[{"-", " ", 
          SubscriptBox["d", "1"]}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
    "}"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.5082175895720186`*^9, 3.508217592264505*^9}, {
   3.508217782881199*^9, 3.5082177834974337`*^9}, {3.508217821536004*^9, 
   3.508217953308642*^9}, 3.5082182946586633`*^9, {3.508269477708084*^9, 
   3.508269478485162*^9}, {3.5082754922280807`*^9, 3.5082754986300807`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"cashOrNothingCall", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "r"}], " ", "T"}]], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"Erf", "[", 
        FractionBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "q"}], "+", "r", "-", 
             FractionBox[
              SuperscriptBox["sigma", "2"], "2"]}], ")"}], " ", "T"}], "+", 
          RowBox[{"Log", "[", 
           FractionBox["S", "X"], "]"}]}], 
         RowBox[{
          SqrtBox["2"], " ", "sigma", " ", 
          SqrtBox["T"]}]], "]"}]}], ")"}]}]}], ",", 
   RowBox[{"cashOrNothingPut", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "r"}], " ", "T"}]], " ", 
     RowBox[{"Erfc", "[", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "q"}], "+", "r", "-", 
           FractionBox[
            SuperscriptBox["sigma", "2"], "2"]}], ")"}], " ", "T"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["S", "X"], "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "sigma", " ", 
        SqrtBox["T"]}]], "]"}]}]}], ",", 
   RowBox[{"assetOrNothingCall", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "q"}], " ", "T"}]], " ", "S", " ", 
     RowBox[{"Erfc", "[", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "q"}], "+", "r", "+", 
           FractionBox[
            SuperscriptBox["sigma", "2"], "2"]}], ")"}], " ", "T"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["S", "X"], "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "sigma", " ", 
        SqrtBox["T"]}]], "]"}]}]}], ",", 
   RowBox[{"assetOrNothingPut", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "q"}], " ", "T"}]], " ", "S", " ", 
     RowBox[{"Erfc", "[", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "q"}], "+", "r", "+", 
           FractionBox[
            SuperscriptBox["sigma", "2"], "2"]}], ")"}], " ", "T"}], "+", 
        RowBox[{"Log", "[", 
         FractionBox["S", "X"], "]"}]}], 
       RowBox[{
        SqrtBox["2"], " ", "sigma", " ", 
        SqrtBox["T"]}]], "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5082182948969536`*^9, 3.5082755003200808`*^9, 
  3.508788261091059*^9, 3.508788523995059*^9, 3.508788768823059*^9, 
  3.508872942983719*^9, 3.537671028830502*^9, 3.5397444199986506`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Load Function using ",
 StyleBox["CUDAFunctionLoad",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.541270123797207*^9, 3.541270124533249*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binarysrc", "=", 
  RowBox[{"ToCCodeString", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"generateCUDAKernel", "[", 
      RowBox[{
       RowBox[{"ToString", "[", 
        RowBox[{"First", "[", "#", "]"}], "]"}], ",", 
       RowBox[{"Last", "[", "#", "]"}]}], "]"}], "&"}], "/@", "binaryOpts"}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.5082175381481695`*^9, 3.508217569043887*^9}, 
   3.5082178475272365`*^9, {3.508217961858775*^9, 3.5082179976892524`*^9}, {
   3.5082182146829357`*^9, 3.5082182184096413`*^9}, {3.5082182779841948`*^9, 
   3.5082182788719244`*^9}, {3.5088150811268673`*^9, 3.5088150920239573`*^9}}],

Cell[BoxData["\<\"__device__ Real_t cashOrNothingCall_compute(Real_t S, \
Real_t X, Real_t T, Real_t r, Real_t q, Real_t sigma)\\n{\\nreturn (Real_t) \
0.5 * exp(-1 * r * T) * (1 + erf(pow(2, (Real_t) -0.5) * pow(sigma, -1) * \
pow(T, (Real_t) -0.5) * ((-1 * q + r + (Real_t) -0.5 * pow(sigma, 2)) * T + \
log(S * pow(X, -1)))));\\n}\\n__global__ void cashOrNothingCall(Real_t* call, \
Real_t* S, Real_t* X, Real_t* T, Real_t* r, Real_t* q, Real_t* sigma, mint \
length)\\n{\\nint index = threadIdx.x + blockIdx.x * blockDim.x;\\nif( index \
< length)\\n{\\ncall[index] = cashOrNothingCall_compute(S[index], X[index], \
T[index], r[index], q[index], sigma[index]);\\n}\\n}\\n__device__ Real_t \
cashOrNothingPut_compute(Real_t S, Real_t X, Real_t T, Real_t r, Real_t q, \
Real_t sigma)\\n{\\nreturn (Real_t) 0.5 * exp(-1 * r * T) * erfc(pow(2, \
(Real_t) -0.5) * pow(sigma, -1) * pow(T, (Real_t) -0.5) * ((-1 * q + r + \
(Real_t) -0.5 * pow(sigma, 2)) * T + log(S * pow(X, -1))));\\n}\\n__global__ \
void cashOrNothingPut(Real_t* call, Real_t* S, Real_t* X, Real_t* T, Real_t* \
r, Real_t* q, Real_t* sigma, mint length)\\n{\\nint index = threadIdx.x + \
blockIdx.x * blockDim.x;\\nif( index < length)\\n{\\ncall[index] = \
cashOrNothingPut_compute(S[index], X[index], T[index], r[index], q[index], \
sigma[index]);\\n}\\n}\\n__device__ Real_t assetOrNothingCall_compute(Real_t \
S, Real_t X, Real_t T, Real_t r, Real_t q, Real_t sigma)\\n{\\nreturn \
(Real_t) 0.5 * exp(-1 * q * T) * S * erfc(pow(2, (Real_t) -0.5) * pow(sigma, \
-1) * pow(T, (Real_t) -0.5) * ((-1 * q + r + (Real_t) 0.5 * pow(sigma, 2)) * \
T + log(S * pow(X, -1))));\\n}\\n__global__ void assetOrNothingCall(Real_t* \
call, Real_t* S, Real_t* X, Real_t* T, Real_t* r, Real_t* q, Real_t* sigma, \
mint length)\\n{\\nint index = threadIdx.x + blockIdx.x * blockDim.x;\\nif( \
index < length)\\n{\\ncall[index] = assetOrNothingCall_compute(S[index], \
X[index], T[index], r[index], q[index], sigma[index]);\\n}\\n}\\n__device__ \
Real_t assetOrNothingPut_compute(Real_t S, Real_t X, Real_t T, Real_t r, \
Real_t q, Real_t sigma)\\n{\\nreturn (Real_t) 0.5 * exp(-1 * q * T) * S * \
erfc(pow(2, (Real_t) -0.5) * pow(sigma, -1) * pow(T, (Real_t) -0.5) * ((-1 * \
q + r + (Real_t) 0.5 * pow(sigma, 2)) * T + log(S * pow(X, \
-1))));\\n}\\n__global__ void assetOrNothingPut(Real_t* call, Real_t* S, \
Real_t* X, Real_t* T, Real_t* r, Real_t* q, Real_t* sigma, mint \
length)\\n{\\nint index = threadIdx.x + blockIdx.x * blockDim.x;\\nif( index \
< length)\\n{\\ncall[index] = assetOrNothingPut_compute(S[index], X[index], \
T[index], r[index], q[index], sigma[index]);\\n}\\n}\\n\"\>"], "Output",
 CellChangeTimes->{3.5082755219840803`*^9, 3.508788266462059*^9, 
  3.508788529870059*^9, 3.5087887747080593`*^9, 3.5088150964514*^9, 
  3.5088729482722483`*^9, 3.537671083247943*^9, 3.539744431998337*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"binaryMethods", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ToString", "[", 
     RowBox[{"First", "[", "#", "]"}], "]"}], "&"}], " ", "/@", 
   "binaryOpts"}]}]], "Input",
 CellChangeTimes->{{3.50881536567832*^9, 3.5088153771304655`*^9}, {
  3.508815520524803*^9, 3.5088155259163423`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cashOrNothingCall\"\>", ",", "\<\"cashOrNothingPut\"\>", 
   ",", "\<\"assetOrNothingCall\"\>", ",", "\<\"assetOrNothingPut\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.5087857292198577`*^9, 3.508786691091035*^9, 
  3.508815379030655*^9, 3.508815530216772*^9, 3.5088729530097218`*^9, 
  3.5376710973983583`*^9, 3.5397444536065726`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"binaryOption", "[", "#", "]"}], "=", 
     RowBox[{"CUDAFunctionLoad", "[", 
      RowBox[{"binarysrc", ",", "#", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "_Real", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", "_Integer"}], 
        "}"}], ",", "128", ",", 
       RowBox[{"\"\<Defines\>\"", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", "\[Rule]", "\"\<int\>\""}], "}"}]}]}], 
      "]"}]}], ")"}], "&"}], "/@", "binaryMethods"}]], "Input",
 CellChangeTimes->{
  3.5079828197277193`*^9, {3.508785741992135*^9, 3.508785754852421*^9}, 
   3.5087860115640893`*^9, 3.508815421352887*^9, {3.508815544069157*^9, 
   3.5088155586426144`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"cashOrNothingCall\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"cashOrNothingPut\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"assetOrNothingCall\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"assetOrNothingPut\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5088156309078407`*^9, 3.508872957847205*^9, 
  3.537671106782296*^9, 3.539744459550913*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute using ",
 StyleBox["CUDAFunction",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5074707613125277`*^9, 3.507470763095252*^9}, {
  3.5412701452064314`*^9, 3.5412701460524797`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"call", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", " ", "optN"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"put", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", " ", "optN"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.508815775268275*^9, 3.508815779882736*^9}}],

Cell["Call some of the functions.", "MathCaption",
 CellChangeTimes->{{3.508815888889636*^9, 3.5088158894996967`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "@", 
  RowBox[{
   RowBox[{"binaryOption", "[", "\"\<cashOrNothingCall\>\"", "]"}], "[", 
   RowBox[{
   "call", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", "Qvec", 
    ",", "Sigmavec", ",", "optN"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5074707346653957`*^9, 3.5074707387687845`*^9}, 
   3.5087860870806403`*^9, 3.508815793369085*^9, 3.5088158724559927`*^9, {
   3.5088161617229166`*^9, 3.5088161641351576`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.08864629563830007`", ",", "0.2827137812476383`", ",", 
   "0.24362625258114287`", ",", "0.07169243564725511`", ",", 
   "0.188803534084008`", ",", "0.2902475624191559`", ",", 
   "0.31439340244551905`", ",", "0.3395083070160717`", ",", 
   "0.26616302162303346`", ",", "0.75759217375477`", ",", 
   "0.20404857701309514`", ",", "0.412424944845247`", ",", 
   "0.3529913561605859`", ",", "0.2644055350615887`", ",", 
   "0.3193483020442193`", ",", "0.2714523220018497`", ",", 
   "0.49873915006327413`", ",", "0.6592940599879228`", ",", 
   "0.2950522943597738`", ",", "0.22235296764616905`", ",", 
   "0.17227724932621666`", ",", "0.1723466910602496`", ",", 
   "0.32425483701111923`", ",", "0.2049720975219199`", ",", 
   "0.22795161000456055`", ",", "0.31385271822667427`", ",", 
   "0.1988188088473968`", ",", "0.28098837714357994`", ",", 
   "0.22829865267174984`", ",", "0.30377509065339214`", ",", 
   "0.28503808827226534`", ",", "0.5777668903910146`"}], "}"}]], "Output",
 CellChangeTimes->{3.5088159918949356`*^9, 3.508816166333378*^9, 
  3.5088729662330437`*^9, 3.5376711284814663`*^9, 3.539744479385047*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "@", 
  RowBox[{
   RowBox[{"binaryOption", "[", "\"\<assetOrNothingPut\>\"", "]"}], "[", 
   RowBox[{
   "put", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", "Qvec", 
    ",", "Sigmavec", ",", "optN"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5074707346653957`*^9, 3.5074707387687845`*^9}, 
   3.5087860870806403`*^9, 3.508815793369085*^9, 3.5088158724559927`*^9, {
   3.5088159160803547`*^9, 3.508815919686715*^9}, {3.5088161698527293`*^9, 
   3.5088161721139555`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "9.802110570505874`", ",", "4.842768099260347`", ",", "9.103596970821847`", 
   ",", "25.513916029482097`", ",", "5.500516068945876`", ",", 
   "6.9529480176796605`", ",", "11.917442722090012`", ",", 
   "4.662606137237732`", ",", "4.355688382098407`", ",", 
   "2.7874551478896272`", ",", "9.193748834480687`", ",", 
   "5.282128182417725`", ",", "4.79115250775147`", ",", "8.450398315426492`", 
   ",", "6.961995897381426`", ",", "10.026974209887893`", ",", 
   "0.6951391266243423`", ",", "1.5710434467746288`", ",", 
   "5.378757765817137`", ",", "6.17387115796002`", ",", "3.4622525347618733`",
    ",", "6.311654572378198`", ",", "3.8154628142323683`", ",", 
   "2.5239440264073214`", ",", "12.206513947566084`", ",", 
   "10.382806324955103`", ",", "7.460470695903724`", ",", 
   "7.6939615815743005`", ",", "9.089927077249666`", ",", 
   "5.525387452609283`", ",", "2.559059848616706`", ",", 
   "4.517563464839859`"}], "}"}]], "Output",
 CellChangeTimes->{3.5088159990246487`*^9, 3.50881617365411*^9, 
  3.5088729687402945`*^9, 3.537671131441762*^9, 3.5397444822952137`*^9}]
}, Closed]],

Cell["Or use all methods.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Column", "[", 
       RowBox[{
        RowBox[{"{", "#", "}"}], "~", "Join", "~", 
        RowBox[{"First", "@", 
         RowBox[{
          RowBox[{"binaryOption", "[", "#", "]"}], "[", 
          RowBox[{
          "call", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", 
           "Qvec", ",", "Sigmavec", ",", "optN"}], "]"}]}]}], "]"}], " ", 
      "&"}], " ", "/@", " ", "binaryMethods"}], "}"}], ",", " ", 
   RowBox[{"Frame", " ", "->", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5074707409449577`*^9, 3.508786760272953*^9, {3.50881580302005*^9, 
   3.508815827870535*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {"\<\"cashOrNothingCall\"\>"},
        {"0.08864629563830007`"},
        {"0.2827137812476383`"},
        {"0.24362625258114287`"},
        {"0.07169243564725511`"},
        {"0.188803534084008`"},
        {"0.2902475624191559`"},
        {"0.31439340244551905`"},
        {"0.3395083070160717`"},
        {"0.26616302162303346`"},
        {"0.75759217375477`"},
        {"0.20404857701309514`"},
        {"0.412424944845247`"},
        {"0.3529913561605859`"},
        {"0.2644055350615887`"},
        {"0.3193483020442193`"},
        {"0.2714523220018497`"},
        {"0.49873915006327413`"},
        {"0.6592940599879228`"},
        {"0.2950522943597738`"},
        {"0.22235296764616905`"},
        {"0.17227724932621666`"},
        {"0.1723466910602496`"},
        {"0.32425483701111923`"},
        {"0.2049720975219199`"},
        {"0.22795161000456055`"},
        {"0.31385271822667427`"},
        {"0.1988188088473968`"},
        {"0.28098837714357994`"},
        {"0.22829865267174984`"},
        {"0.30377509065339214`"},
        {"0.28503808827226534`"},
        {"0.5777668903910146`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"cashOrNothingPut\"\>"},
        {"0.5441352279229524`"},
        {"0.3150696165318455`"},
        {"0.5151056014986253`"},
        {"0.89257783265803`"},
        {"0.29265775589359977`"},
        {"0.435908807424067`"},
        {"0.6268728397297788`"},
        {"0.3470107476708011`"},
        {"0.19534256462009472`"},
        {"0.1363948135416724`"},
        {"0.4146847587748165`"},
        {"0.28572215236579385`"},
        {"0.34304604540195405`"},
        {"0.41116556049613956`"},
        {"0.25133523305519195`"},
        {"0.5028379984931407`"},
        {"0.028154992285616645`"},
        {"0.07858052487301921`"},
        {"0.3855866588223441`"},
        {"0.6021618585697892`"},
        {"0.27839335900351275`"},
        {"0.4429968916398005`"},
        {"0.3765449649103926`"},
        {"0.20962357252729583`"},
        {"0.5996031171338211`"},
        {"0.5223862535281308`"},
        {"0.3994904643849957`"},
        {"0.36162049958929016`"},
        {"0.41121209855275853`"},
        {"0.38914548711365526`"},
        {"0.15490887847424403`"},
        {"0.23620841369589138`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"assetOrNothingCall\"\>"},
        {"9.802110570505874`"},
        {"4.842768099260347`"},
        {"9.103596970821847`"},
        {"25.513916029482097`"},
        {"5.500516068945876`"},
        {"6.9529480176796605`"},
        {"11.917442722090012`"},
        {"4.662606137237732`"},
        {"4.355688382098407`"},
        {"2.7874551478896272`"},
        {"9.193748834480687`"},
        {"5.282128182417725`"},
        {"4.79115250775147`"},
        {"8.450398315426492`"},
        {"6.961995897381426`"},
        {"10.026974209887893`"},
        {"0.6951391266243423`"},
        {"1.5710434467746288`"},
        {"5.378757765817137`"},
        {"6.17387115796002`"},
        {"3.4622525347618733`"},
        {"6.311654572378198`"},
        {"3.8154628142323683`"},
        {"2.5239440264073214`"},
        {"12.206513947566084`"},
        {"10.382806324955103`"},
        {"7.460470695903724`"},
        {"7.6939615815743005`"},
        {"9.089927077249666`"},
        {"5.525387452609283`"},
        {"2.559059848616706`"},
        {"4.517563464839859`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"assetOrNothingPut\"\>"},
        {"9.802110570505874`"},
        {"4.842768099260347`"},
        {"9.103596970821847`"},
        {"25.513916029482097`"},
        {"5.500516068945876`"},
        {"6.9529480176796605`"},
        {"11.917442722090012`"},
        {"4.662606137237732`"},
        {"4.355688382098407`"},
        {"2.7874551478896272`"},
        {"9.193748834480687`"},
        {"5.282128182417725`"},
        {"4.79115250775147`"},
        {"8.450398315426492`"},
        {"6.961995897381426`"},
        {"10.026974209887893`"},
        {"0.6951391266243423`"},
        {"1.5710434467746288`"},
        {"5.378757765817137`"},
        {"6.17387115796002`"},
        {"3.4622525347618733`"},
        {"6.311654572378198`"},
        {"3.8154628142323683`"},
        {"2.5239440264073214`"},
        {"12.206513947566084`"},
        {"10.382806324955103`"},
        {"7.460470695903724`"},
        {"7.6939615815743005`"},
        {"9.089927077249666`"},
        {"5.525387452609283`"},
        {"2.559059848616706`"},
        {"4.517563464839859`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.508816180537798*^9, 3.5088729797253933`*^9, 
  3.537671158549473*^9, 3.539744491626747*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Future Options", "Subsection",
 CellChangeTimes->{{3.5082175839038324`*^9, 3.508217586847305*^9}, {
  3.50821773545848*^9, 3.5082177401539726`*^9}, {3.5082186682316017`*^9, 
  3.5082186707834578`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"futuresrc", "=", 
  RowBox[{"ToCCodeString", "[", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"generateCUDAKernel", "[", 
      RowBox[{"\"\<FutureCall\>\"", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"S", " ", "*", " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"r", "+", "q"}], ")"}]}], "*", " ", "T"}], "]"}], "*", 
         RowBox[{"CDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", " ", 
           SubscriptBox["d", "1"]}], "]"}]}], " ", "-", " ", 
        RowBox[{"X", " ", "*", " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "r"}], "*", " ", "T"}], "]"}], "*", 
         RowBox[{"CDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", " ", 
           SubscriptBox["d", "2"]}], "]"}]}]}]}], " ", "\[IndentingNewLine]", 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"generateCUDAKernel", "[", 
      RowBox[{"\"\<FuturePut\>\"", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"X", " ", "*", " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "r"}], "*", " ", "T"}], "]"}], "*", 
         RowBox[{"CDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", " ", 
           RowBox[{"-", 
            SubscriptBox["d", "2"]}]}], "]"}]}], " ", "-", " ", 
        RowBox[{"S", " ", "*", " ", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"r", "+", "q"}], ")"}]}], "*", " ", "T"}], "]"}], "*", 
         RowBox[{"CDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", " ", 
           RowBox[{"-", 
            SubscriptBox["d", "1"]}]}], "]"}]}]}]}], " ", 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.5082197024900656`*^9, 3.5082198569178705`*^9}, {
  3.5082199075643463`*^9, 3.5082199087880263`*^9}, {3.5082202731106095`*^9, 
  3.508220390890523*^9}, {3.5082756032910805`*^9, 3.5082756368100805`*^9}, {
  3.5088162856023035`*^9, 3.5088162899447374`*^9}}],

Cell[BoxData["\<\"__device__ Real_t FutureCall_compute(Real_t S, Real_t X, \
Real_t T, Real_t r, Real_t q, Real_t sigma)\\n{\\nreturn (Real_t) -0.5 * \
exp(-1 * r * T) * X * erfc(-1 * pow(2, (Real_t) -0.5) * pow(sigma, -1) * \
pow(T, (Real_t) -0.5) * ((-1 * q + r + (Real_t) -0.5 * pow(sigma, 2)) * T + \
log(S * pow(X, -1)))) + (Real_t) 0.5 * exp((-1 * q + -1 * r) * T) * S * \
erfc(-1 * pow(2, (Real_t) -0.5) * pow(sigma, -1) * pow(T, (Real_t) -0.5) * \
((-1 * q + r + (Real_t) 0.5 * pow(sigma, 2)) * T + log(S * pow(X, -1))));\\n}\
\\n__global__ void FutureCall(Real_t* call, Real_t* S, Real_t* X, Real_t* T, \
Real_t* r, Real_t* q, Real_t* sigma, mint length)\\n{\\nint index = \
threadIdx.x + blockIdx.x * blockDim.x;\\nif( index < \
length)\\n{\\ncall[index] = FutureCall_compute(S[index], X[index], T[index], \
r[index], q[index], sigma[index]);\\n}\\n}\\n__device__ Real_t \
FuturePut_compute(Real_t S, Real_t X, Real_t T, Real_t r, Real_t q, Real_t \
sigma)\\n{\\nreturn (Real_t) 0.5 * exp(-1 * r * T) * X * erfc(pow(2, (Real_t) \
-0.5) * pow(sigma, -1) * pow(T, (Real_t) -0.5) * ((-1 * q + r + (Real_t) -0.5 \
* pow(sigma, 2)) * T + log(S * pow(X, -1)))) + (Real_t) -0.5 * exp((-1 * q + \
-1 * r) * T) * S * erfc(pow(2, (Real_t) -0.5) * pow(sigma, -1) * pow(T, \
(Real_t) -0.5) * ((-1 * q + r + (Real_t) 0.5 * pow(sigma, 2)) * T + log(S * \
pow(X, -1))));\\n}\\n__global__ void FuturePut(Real_t* call, Real_t* S, \
Real_t* X, Real_t* T, Real_t* r, Real_t* q, Real_t* sigma, mint \
length)\\n{\\nint index = threadIdx.x + blockIdx.x * blockDim.x;\\nif( index \
< length)\\n{\\ncall[index] = FuturePut_compute(S[index], X[index], T[index], \
r[index], q[index], sigma[index]);\\n}\\n}\\n\"\>"], "Output",
 CellChangeTimes->{{3.5082203588453465`*^9, 3.508220391216707*^9}, 
   3.508275710120081*^9, 3.508788303236059*^9, 3.5087885781610594`*^9, 
   3.508788791211059*^9, 3.508816292642007*^9, 3.508872987787199*^9, 
   3.5376712025298705`*^9, 3.5397445089907403`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Load Function using ",
 StyleBox["CUDAFunctionLoad",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5412701574771338`*^9, 3.5412701580531664`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"futureMethods", "=", 
   RowBox[{"{", 
    RowBox[{"\"\<FutureCall\>\"", ",", "\"\<FuturePut\>\""}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.50881536567832*^9, 3.5088153771304655`*^9}, {
  3.508815520524803*^9, 3.5088155259163423`*^9}, {3.508816385800322*^9, 
  3.508816414405182*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"futureOption", "[", "#", "]"}], "=", 
     RowBox[{"CUDAFunctionLoad", "[", 
      RowBox[{"futuresrc", ",", "#", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "_Real", "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", "_Integer"}], 
        "}"}], ",", "128", ",", 
       RowBox[{"\"\<Defines\>\"", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", "\[Rule]", "\"\<int\>\""}], "}"}]}]}], 
      "]"}]}], ")"}], "&"}], "/@", "futureMethods"}]], "Input",
 CellChangeTimes->{
  3.5079828197277193`*^9, {3.508785741992135*^9, 3.508785754852421*^9}, 
   3.5087860115640893`*^9, 3.508815421352887*^9, {3.508815544069157*^9, 
   3.5088155586426144`*^9}, {3.5088164321419554`*^9, 3.5088164424239836`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"FutureCall\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"CUDAFunction", "[", 
    RowBox[{"\<\"<>\"\>", ",", "\<\"FuturePut\"\>", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "_Real", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
      "}"}]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.508816459673709*^9, 3.5088729989743176`*^9, 
  3.5376712156921864`*^9, 3.5397445226935244`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute using ",
 StyleBox["CUDAFunction",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5074707613125277`*^9, 3.507470763095252*^9}, {
  3.5412701754141593`*^9, 3.5412701766292286`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"call", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", " ", "optN"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"put", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", " ", "optN"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.508815775268275*^9, 3.508815779882736*^9}}],

Cell["Call some of the functions.", "MathCaption",
 CellChangeTimes->{{3.508815888889636*^9, 3.5088158894996967`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"First", "@", 
  RowBox[{
   RowBox[{"futureOption", "[", "\"\<FutureCall\>\"", "]"}], "[", 
   RowBox[{
   "call", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", "Qvec", 
    ",", "Sigmavec", ",", "optN"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5074707346653957`*^9, 3.5074707387687845`*^9}, 
   3.5087860870806403`*^9, 3.508815793369085*^9, 3.5088158724559927`*^9, {
   3.5088161617229166`*^9, 3.5088161641351576`*^9}, {3.5088164790636473`*^9, 
   3.5088165006488056`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.20027619585821158`"}], ",", "6.827289541157393`", ",", 
   "1.7826005739695954`", ",", "0.042969268909468006`", ",", 
   RowBox[{"-", "0.8156241072894859`"}], ",", "6.300390105047143`", ",", 
   "0.6120237667885849`", ",", "1.35145848391389`", ",", 
   RowBox[{"-", "0.9447634389506275`"}], ",", "9.776476482201927`", ",", 
   RowBox[{"-", "0.9677588218898892`"}], ",", "3.6725053122810896`", ",", 
   "6.318830637602983`", ",", "2.2672730314285037`", ",", 
   RowBox[{"-", "1.6659195540203047`"}], ",", "0.8244028819343021`", ",", 
   RowBox[{"-", "1.445984916860784`"}], ",", "6.035249241116119`", ",", 
   "5.156401206406697`", ",", "3.8549695329672455`", ",", 
   "1.2501919794425844`", ",", "4.309817277397818`", ",", 
   "7.004110737214938`", ",", "1.131251260962146`", ",", "2.019764258900738`",
    ",", "1.7843109443085285`", ",", "0.3563978110079088`", ",", 
   "1.3884566777695702`", ",", 
   RowBox[{"-", "0.9323124762107429`"}], ",", "3.136300146766331`", ",", 
   "1.4628091142394286`", ",", "1.2822600188334001`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5088165400927496`*^9, {3.5088165857123113`*^9, 3.5088166068584256`*^9}, {
   3.508873009676388*^9, 3.5088730460490246`*^9}, 3.5376712268643036`*^9, 
   3.5397445306469793`*^9}]
}, Closed]],

Cell["Or use all methods.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Column", "[", 
       RowBox[{
        RowBox[{"{", "#", "}"}], "~", "Join", "~", 
        RowBox[{"First", "@", 
         RowBox[{
          RowBox[{"futureOption", "[", "#", "]"}], "[", 
          RowBox[{
          "put", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", 
           "Qvec", ",", "Sigmavec", ",", "optN"}], "]"}]}]}], "]"}], " ", 
      "&"}], " ", "/@", " ", "futureMethods"}], "}"}], ",", " ", 
   RowBox[{"Frame", " ", "->", " ", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.5074707409449577`*^9, 3.508786760272953*^9, {3.50881580302005*^9, 
   3.508815827870535*^9}, {3.508816515902331*^9, 3.5088165205917997`*^9}, {
   3.508816552138954*^9, 3.508816552858026*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TagBox[GridBox[{
        {"\<\"FutureCall\"\>"},
        {
         RowBox[{"-", "0.20027619585821158`"}]},
        {"6.827289541157393`"},
        {"1.7826005739695954`"},
        {"0.042969268909468006`"},
        {
         RowBox[{"-", "0.8156241072894859`"}]},
        {"6.300390105047143`"},
        {"0.6120237667885849`"},
        {"1.35145848391389`"},
        {
         RowBox[{"-", "0.9447634389506275`"}]},
        {"9.776476482201927`"},
        {
         RowBox[{"-", "0.9677588218898892`"}]},
        {"3.6725053122810896`"},
        {"6.318830637602983`"},
        {"2.2672730314285037`"},
        {
         RowBox[{"-", "1.6659195540203047`"}]},
        {"0.8244028819343021`"},
        {
         RowBox[{"-", "1.445984916860784`"}]},
        {"6.035249241116119`"},
        {"5.156401206406697`"},
        {"3.8549695329672455`"},
        {"1.2501919794425844`"},
        {"4.309817277397818`"},
        {"7.004110737214938`"},
        {"1.131251260962146`"},
        {"2.019764258900738`"},
        {"1.7843109443085285`"},
        {"0.3563978110079088`"},
        {"1.3884566777695702`"},
        {
         RowBox[{"-", "0.9323124762107429`"}]},
        {"3.136300146766331`"},
        {"1.4628091142394286`"},
        {"1.2822600188334001`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"], 
     TagBox[GridBox[{
        {"\<\"FuturePut\"\>"},
        {"15.105573456029301`"},
        {"6.940412867307822`"},
        {"8.960661613801163`"},
        {"6.023240559219416`"},
        {"6.857060844623458`"},
        {"8.805391312918443`"},
        {"3.2040725690147336`"},
        {"3.9341583996867135`"},
        {"4.579228405678382`"},
        {"0.8513448158701453`"},
        {"7.9637305411782915`"},
        {"4.1355999987093295`"},
        {"5.296666868281872`"},
        {"9.08195452153534`"},
        {"5.365603373064976`"},
        {"7.248853646051709`"},
        {"0.4142495530851435`"},
        {"0.7150053517296543`"},
        {"6.815097455612174`"},
        {"9.125258812005526`"},
        {"6.215366605295535`"},
        {"12.817761618447028`"},
        {"5.122335072199189`"},
        {"3.945813438069903`"},
        {"10.945606204627964`"},
        {"6.5861994199327745`"},
        {"9.160926134223272`"},
        {"7.629359618966944`"},
        {"7.173131375056505`"},
        {"5.951530710322252`"},
        {"3.0219604154319315`"},
        {"1.6294371959210658`"}
       },
       GridBoxAlignment->{"Columns" -> {{Left}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
      "Column"]}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.5088165575224924`*^9, 3.5088166155372934`*^9, 3.508873053362756*^9, 
   3.537671234017019*^9, {3.5397445377553854`*^9, 3.5397445400755186`*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["One Touch Options", "Subsection",
 CellChangeTimes->{{3.5082175839038324`*^9, 3.508217586847305*^9}, {
  3.50821773545848*^9, 3.5082177401539726`*^9}, {3.5082186682316017`*^9, 
  3.508218676959476*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"onetouchsrc", "=", 
  RowBox[{"ToCCodeString", "[", "\[IndentingNewLine]", 
   RowBox[{"generateCUDAKernel", "[", 
    RowBox[{"\"\<OneTouchCall\>\"", ",", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"S", "<", "X"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"X", "/", "S"}], " ", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "q"}], " ", "T"}], "]"}]}], ")"}], 
          FractionBox[
           RowBox[{"2", " ", "*", " ", "r"}], 
           SuperscriptBox["sigma", "2"]]], "*", " ", 
         RowBox[{"CDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", 
           SubscriptBox["d", "5"]}], "]"}]}], " ", "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"S", " ", 
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "q"}], " ", "T"}], "]"}], "/", "X"}]}], ")"}], "*", 
         RowBox[{"CDF", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", "1"}], "]"}], ",", 
           SubscriptBox["d", "1"]}], "]"}]}]}], ",", "\[IndentingNewLine]", 
       "1"}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.5082197024900656`*^9, 3.5082198569178705`*^9}, {
   3.5082199075643463`*^9, 3.5082199087880263`*^9}, 3.508220281005444*^9, {
   3.5087889007119894`*^9, 3.508788910902008*^9}, {3.508792786901579*^9, 
   3.5087927956604548`*^9}, {3.5087939499888763`*^9, 
   3.5087939610529823`*^9}, {3.5088121751722918`*^9, 
   3.5088121821279874`*^9}, {3.5088711686187143`*^9, 3.508871172799714*^9}, {
   3.5088725645528803`*^9, 3.508872565613986*^9}, {3.508872599596384*^9, 
   3.508872602029627*^9}, {3.50887279467589*^9, 3.5088727977932014`*^9}, {
   3.5088734580222178`*^9, 3.5088734602184377`*^9}, {3.50887350814423*^9, 
   3.5088735157969947`*^9}, 3.5088735848979044`*^9, {3.5089459288905725`*^9, 
   3.5089459325319366`*^9}, {3.508945967249408*^9, 3.5089459740540886`*^9}}],

Cell[BoxData["\<\"__device__ Real_t OneTouchCall_compute(Real_t S, Real_t X, \
Real_t T, Real_t r, Real_t q, Real_t sigma)\\n{\\nreturn S < X ? (Real_t) 0.5 \
* pow(exp(-1 * q * T) * pow(S, -1) * X, 2 * r * pow(sigma, -2)) * erfc(-1 * \
pow(2, (Real_t) -0.5) * pow(sigma, -1) * pow(T, (Real_t) -0.5) * (-1 * (q + r \
+ (Real_t) -0.5 * pow(sigma, 2)) * T + log(S * pow(X, -1)))) + (Real_t) 0.5 * \
exp(-1 * q * T) * S * pow(X, -1) * erfc(-1 * pow(2, (Real_t) -0.5) * \
pow(sigma, -1) * pow(T, (Real_t) -0.5) * ((-1 * q + r + (Real_t) 0.5 * \
pow(sigma, 2)) * T + log(S * pow(X, -1)))) : 1;\\n}\\n__global__ void \
OneTouchCall(Real_t* call, Real_t* S, Real_t* X, Real_t* T, Real_t* r, \
Real_t* q, Real_t* sigma, mint length)\\n{\\nint index = threadIdx.x + \
blockIdx.x * blockDim.x;\\nif( index < length)\\n{\\ncall[index] = \
OneTouchCall_compute(S[index], X[index], T[index], r[index], q[index], \
sigma[index]);\\n}\\n}\\n\"\>"], "Output",
 CellChangeTimes->{3.508219909211871*^9, 3.508219951612913*^9, 
  3.508220015922023*^9, 3.508220281235922*^9, 3.5082758209680805`*^9, 
  3.508788839825901*^9, 3.5087889177846966`*^9, 3.5087928031212006`*^9, 
  3.508793969300807*^9, 3.5088711156397142`*^9, 3.5088711761667147`*^9, 
  3.5088717870281353`*^9, 3.5088726740378275`*^9, 3.5088728006094832`*^9, 
  3.50887308920434*^9, 3.5088734618155975`*^9, 3.5088735217355886`*^9, 
  3.5088736147648907`*^9, 3.5089458294316273`*^9, 3.508945935112194*^9, 
  3.5089459755662394`*^9, 3.5376712564372606`*^9, 3.5397446121416407`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Load function using ",
 StyleBox["CUDAFunctionLoad",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oneTouchOption", "=", 
  RowBox[{"CUDAFunctionLoad", "[", 
   RowBox[{"onetouchsrc", ",", "\"\<OneTouchCall\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "_Real", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"_Real", ",", "\"\<Input\>\""}], "}"}], ",", "_Integer"}], 
     "}"}], ",", "128", ",", 
    RowBox[{"\"\<Defines\>\"", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<mint\>\"", "\[Rule]", "\"\<int\>\""}], "}"}]}], ",", 
    RowBox[{"\"\<ShellOutputFunction\>\"", "->", "Print"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{
  3.5079828197277193`*^9, {3.508785741992135*^9, 3.508785754852421*^9}, 
   3.5087860115640893`*^9, 3.508815421352887*^9, {3.508815544069157*^9, 
   3.5088155586426144`*^9}, {3.5088164321419554`*^9, 
   3.5088164424239836`*^9}, {3.5088712948797145`*^9, 
   3.5088713509567146`*^9}, {3.5088716040077143`*^9, 3.508871604469714*^9}}],

Cell[BoxData["\<\"\\nC:\\\\Users\\\\wolfram\\\\AppData\\\\Roaming\\\\\
Mathematica\\\\ApplicationData\\\\CUDALink\\\\BuildFolder\\\\mkellyloanlap-\
10816\\\\Working-mkellyloanlap-10816-4912-7>call \\\"c:\\\\Program Files \
(x86)\\\\Microsoft Visual Studio 10.0\\\\VC\\\\vcvarsall.bat\\\" amd64 \
\\nSetting environment for using Microsoft Visual Studio 2010 x64 \
tools.\\nCUDAFunction-7476.cu\\nCUDAFunction-7476.cu\\ntmpxft_00001184_\
00000000-3_CUDAFunction-7476.cudafe1.gpu\\ntmpxft_00001184_00000000-10_\
CUDAFunction-7476.cudafe2.gpu\"\>"], "Print",
 CellChangeTimes->{3.5088716064397144`*^9, 3.5088726965220757`*^9, 
  3.5088728194933715`*^9, 3.5088731479792166`*^9, 3.50887353995041*^9, 
  3.508873666877101*^9, 3.5089458485745416`*^9, 3.5089459450201855`*^9, 
  3.5089459816478477`*^9, 3.5376712854491615`*^9, 3.539744625097381*^9}],

Cell[BoxData[
 RowBox[{"CUDAFunction", "[", 
  RowBox[{"\<\"<>\"\>", ",", "\<\"OneTouchCall\"\>", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "_Real", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"_Real", ",", "\<\"Input\"\>"}], "}"}], ",", "_Integer"}], 
    "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.508871561997714*^9, 3.508871606443714*^9, 
  3.5088726965260763`*^9, 3.508872819498372*^9, 3.5088731479832172`*^9, 
  3.5088735399554105`*^9, 3.5088736668811016`*^9, 3.5089458485785418`*^9, 
  3.508945945026186*^9, 3.5089459816528482`*^9, 3.5376712854531617`*^9, 
  3.539744625100382*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute using ",
 StyleBox["CUDAFunction",
  FontFamily->"Courier New",
  FontWeight->"Bold"]
}], "MoreExamplesSection",
 CellChangeTimes->{{3.5074707613125277`*^9, 3.507470763095252*^9}, {
  3.5413513407865534`*^9, 3.541351341697605*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"call", " ", "=", " ", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0.0", ",", " ", "optN"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.508815775268275*^9, 3.508815779882736*^9}, {
  3.5088713628287144`*^9, 3.5088713635517144`*^9}}],

Cell["Call the function.", "MathCaption",
 CellChangeTimes->{{3.508815888889636*^9, 3.5088158894996967`*^9}, {
  3.508872017292159*^9, 3.5088720249639263`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"oneTouchOption", "[", 
  RowBox[{
  "call", ",", "Svec", ",", "Xvec", ",", "Tvec", ",", "Rvec", ",", "Qvec", 
   ",", "Sigmavec", ",", "optN"}], "]"}]], "Input",
 CellChangeTimes->{{3.5074707346653957`*^9, 3.5074707387687845`*^9}, 
   3.5087860870806403`*^9, 3.508815793369085*^9, 3.5088158724559927`*^9, {
   3.5088161617229166`*^9, 3.5088161641351576`*^9}, {3.5088164790636473`*^9, 
   3.5088165006488056`*^9}, 3.5088715359667144`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
   "0.21262841129117097`", ",", "1.`", ",", "0.7415519946310687`", ",", 
    "0.11735692087139589`", ",", "0.35314099568176893`", ",", "1.`", ",", 
    "0.5486337186667064`", ",", "1.`", ",", "0.5740733686977331`", ",", "1.`",
     ",", "0.2875188997101922`", ",", "1.`", ",", "1.`", ",", 
    "0.8061494108311793`", ",", "0.4840654258465909`", ",", 
    "0.5857661067603237`", ",", "1.`", ",", "1.`", ",", "1.`", ",", 
    "0.9523877539591917`", ",", "0.667073751027059`", ",", 
    "0.7932013348560415`", ",", "1.`", ",", "1.`", ",", "0.5223332927049253`",
     ",", "0.7488700314607016`", ",", "0.43984814954148427`", ",", "1.`", ",",
     "0.3176853739018201`", ",", "1.`", ",", "1.`", ",", "1.`"}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.508945877970481*^9, 3.5376713017927957`*^9, 
  3.5397446489837475`*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellChangeTimes->{3.479485497714637*^9, 3.4794855352525177`*^9},
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["CUDA Brownian Motion", "Section"],

Cell[TextData[{
 StyleBox["In the above sections we examined the use of CUDA programming to \
describe Black",
  FontFamily->"Georgia"],
 "\[Dash]",
 StyleBox["Scholes type derivative models, but most other derivatives do not \
have explicit solutions and require Monte Carlo methods of simulation to \
determine the future paths of complex options. Because of the assumptions \
underlying many of these models, the simulations take the form of applying \
payoff functions to Brownian motion paths. Hence any basis to option pricing \
in CUDA requires very fast methods for determining Brownian paths. These are \
shown below.",
  FontFamily->"Georgia"]
}], "MathCaption",
 CellChangeTimes->{
  3.435513906503024*^9, {3.439663683411996*^9, 3.4396637076276307`*^9}, {
   3.4397408119503636`*^9, 3.439740816496538*^9}, {3.441727703707619*^9, 
   3.441727727802747*^9}, {3.451650706163927*^9, 3.4516507070383053`*^9}, {
   3.481284485808154*^9, 3.4812845148524265`*^9}, {3.4812854521231413`*^9, 
   3.4812854861832433`*^9}, 3.4812856331260223`*^9, {3.4812856655612392`*^9, 
   3.481285675685526*^9}, {3.481303689997296*^9, 3.481303722472939*^9}, {
   3.481456087628784*^9, 3.481456100455924*^9}, 3.504611177112706*^9, {
   3.5046112888711042`*^9, 3.5046113163688164`*^9}, {3.5046114197195916`*^9, 
   3.5046114760430303`*^9}, {3.504611935742608*^9, 3.504611941820656*^9}, 
   3.5046120249112825`*^9, 3.504612703857331*^9, {3.5046127356377673`*^9, 
   3.504612808432779*^9}, 3.5046329171904287`*^9, {3.504633499637619*^9, 
   3.504633528919244*^9}, 3.5046335625603*^9, 3.5046340231286945`*^9, 
   3.5046341153017497`*^9, 3.5046347243095446`*^9, 3.504634759106865*^9, 
   3.504635249566268*^9, 3.5046364613980284`*^9, {3.504636664724852*^9, 
   3.504636682818486*^9}, 3.504636963474331*^9, {3.527856119810442*^9, 
   3.527856125544129*^9}, {3.5397919392575965`*^9, 3.5397921590341673`*^9}, {
   3.5412702340535135`*^9, 3.541270265973339*^9}},
 FontFamily->"Calibri",
 FontColor->GrayLevel[0],
 CellTags->"Basic Operations"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"CUDAMemoryBrownianMotion", "[", 
    RowBox[{"1.0", ",", "10000"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Time\>\"", ",", "\"\<\!\(\*SubscriptBox[\(B\), \(t\)]\)\>\""}], 
     "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", "\"\<Stochastic CUDA Brownian Motion\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.4995302681695356`*^9, 3.499530317843502*^9}, {
   3.499530354698188*^9, 3.4995304108328004`*^9}, {3.5071327957849503`*^9, 
   3.507132805810953*^9}, {3.5071329304214125`*^9, 3.5071329516745377`*^9}, 
   3.507133187251217*^9, {3.5071334167872167`*^9, 3.5071334401772165`*^9}, 
   3.5071419225595646`*^9, {3.5402409135457764`*^9, 3.540240914161812*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxUvXlczc/7/x9CEkLIHkKIohCFB0JZ21QUSotKaF+0OO17nc451elkCUn2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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(B\\), \\(t\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{478.3999999999991, Automatic},
  PlotLabel->FormBox[
   "\"Stochastic CUDA Memory Brownian Motion\"", TraditionalForm],
  PlotRange->{{0., 10000.}, {-0.7674852688044215, 0.14276649256617202`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5071334296282167`*^9, 3.5071334408982162`*^9}, 
   3.5071415387191844`*^9, {3.5071419233066397`*^9, 3.507141932985607*^9}, 
   3.537671806906302*^9, {3.5397446826886754`*^9, 3.5397446841757603`*^9}, 
   3.5400515857916827`*^9, 3.540093838185382*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"CUDABrownianMotionPaths3", "[", 
    RowBox[{"1.2", ",", "1000", ",", "50"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Time\>\"", ",", "\"\<\!\(\*SubscriptBox[\(B\), \(t\)]\)\>\""}], 
     "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Stochastic CUDA Brownian Motion Paths\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4995302681695356`*^9, 3.499530317843502*^9}, {
   3.499530354698188*^9, 3.4995304108328004`*^9}, {3.507135418870242*^9, 
   3.5071354333216867`*^9}, {3.5071407602223425`*^9, 3.507140769484269*^9}, 
   3.5071411799153075`*^9, 3.50714143396671*^9, {3.5071415631416264`*^9, 
   3.5071415798012924`*^9}, {3.507996829015361*^9, 3.507996846027361*^9}, {
   3.508043880145357*^9, 3.508043882981641*^9}, {3.537674097886212*^9, 
   3.5376740983162546`*^9}, {3.540051874289184*^9, 3.5400518896980653`*^9}, 
   3.5400519350106573`*^9, {3.5400930807550592`*^9, 3.540093087715457*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzF/0x8eekLFnD6EIWUqWb95ChWhB0sLQXsq07zVTM9PUTEm2kCSV
slQSsk92SkJSCam+KmskypJfv+d77u95fv3T83rOPefec889557PZz4Ttu2w
cOzO4XCaenA4//v/v7+WJZz//4cLrqe3tNmduP4fKqGsu+3zJwszibmQTMrk
OHAziIfi+8jT9U9OxRCrgj/ybv+NjTziMTA+fLLg2aA8YjWUBZjlhzbtJ56I
3pmdVsrticTqUJ29ZYIwLJXWNQUJ6kKzKZ8iiDXwrUix9bZ/Ao2fhsrLbsub
j+4m1kLCOPks49dXafxMHF2UPnByShGxNm5/OTh0/6nbxLOx6fErH8Gom8Rz
4BexZKOdLuO5GKnzU26QcJd4HmZK5sfs7cP0dfA0LGVEqjEbr4uTTX2DzL4V
EM/HTuXO4pc+Z4n10BQ7JPdLyzniBTA+0vf85UDGC6G544/mcZMLxIswptRt
hufUHOLF+Pw+4QRn/XHif9BeOvll6QM2Xh+3xrh6TvNg8y1By/61/rODoomB
936SgX4+u/7bLwFQ2Dz1o7AtlPZvKZKtV69w/b2X5EvB2d7cb9a65aRvAPOW
V5LHh1NJboCTKs1t368fI/1l0KtO2Os3LYfky+AdFuu/6COL/3IEmmwyP/wq
i+TLoW3w/cSGm8ScFSidMlb2ZfxRkq+AYJbKLptEE5rfEH9mt5kof99KckPU
W7XqOwXsJLkRrKquvzhbRedLYASlOd2XHtxN/nKM4XQ1fNL6nVdIboxRNjYv
2lLOkXwlbPgDy5M6jpN8JXhOk05FRItJvgrG01+/eb1oD8lX4Tx/tPWMN2z9
qxHZNHLYVf2zJF+N9XNPH31VROM5Jig51/2304B0kpvA6o3kkrAzheRr4PO5
dJnmawHJ10DtWvgF1yGuJF8LA0Pl+LoCyj/BWiwUTnPs8JGR3BSlvpVHdBek
kdwUqw5/a9i8nOWzGdIbRz8ZV0j5DDNkvRl70/mKlMabQW/zpVYHC/v/WGGG
xOAH7Y9cWb6aQ9DsqFOxifYT5uDs0h6ZY+z63/4LzGFm19JjfubB/1hhjq9L
+h76/TmT4mOBfHm9svdSyg9YIKu2+PBXLWKBBZYfzG+cvv8E6VsguYzfM60f
018HbvzYRz3K4kh/HZR+dSq21AlJfx0EEq3XN+d4kP46nBq4Wj9tNasX62H6
0M9K2TGZ1r8erY8LVjsGU/0QrIfhuwHbFnScIv/X4+Co972Hn8on/Q14f9lP
e13/M6S/ATeSCzacWczisQGeP1wdsqrPk/4G7Pbdmm2qdY30LVFhXFkcM+IG
6Vti36zy0xbb7pC+JSJVXJ5euaMg/S55W7Lq0q3EnI3wvn629TX/FulvxLHC
nANqW26T/kaUXPaUmPuQfcVGlFZnOwYY0niOFTJfbQ20arxJ+lZ44Nmt0vs9
yQVWuKDI8ixOIHsKK4TWDO59aBgxZxM2B63UMUh6SPqbYNhWaFFVUEr6mxBx
d8EJp9tPSH8TDoxPV1JcJ+ZYI3RaXaPHq3LSt8YBv8jFap5PSd8aU/LlrVZT
H5O+NcbcdNK3tyfm2GDEt246FRllpG+DYYXjCtvjiAU2yH615OJCI6Zvg0Nl
DQUj5zwjfVustrM78fkPMWwxaYx0TFx4DenbwmC/9kbOzeekb4v1mSVjXquz
9dtBmvFOZ8hGNr8dCub4T1uUztZvhzOD1vuqhpN/CjuYfL+iV27A5t+MKynX
g0cFMf83o8/tScETPpNcsBlDB6zdnX2KWLEZYYWTR5/8l/m/BeXvPixI7UHz
YQtw/fk61T5MfwsKI8TFpmVMfwv2vLjncH9oBenz0NKHI2mNrfqP1Xho1Tea
c9Cc/AcPb488i1y66cV/zOPhU0Xo04Ssl2SfhwezO15XSl79x6k8ODgXnu7l
9prm4+HRmMagNm7tf1zLQ0oa586Z8zSesxWpaWUzum+l8WpboVc3yDFvNY3H
Vhx5ZJzavJDkvK2o6VnknrmP9AVboZhn5uuvwubfioxTO5ZN7Ums6Brfo63t
tz1x7VYc5O/nSdzJP842bHXyDvghZvNvQ03LgEEG8eQvtiHK/tfLfrbVNP82
yBuK7Yyv0XkQbEN4jm2ovz7tX+o2PHZw6ngyl/QV23BAdy53xD7i2m24eeq0
+sQhpM+xR99xd9c0HqPzpGaPxmPvvxxSZvG0h07HicDse3Q+ePb4pGKu63GE
WGCPU6NFoT76xKn22K2/nmsoZ+fNHtdKAkSOX8h+rT0smkODJ/mw8+eAiiIs
HNhI50HNAXvV64aOzmX+O0D6VFD3fQqtl+eAxCEvDq8fSf4KHLBUoiftsbOS
5nfA1/3Z7xVbSK5wQJpERWxST/tX64D+J6J/yqKJOY4YMHxf0j4B2VdzxGvZ
T9kFS5LDESnTDYalF5B9niNyV3xJfTeVnW9HHMs27LdJn/RTHdHZ/d35BX9Z
vjrixI7cI+tns/kdMU7n/WPzCrLHccKIic21ytOI1Zxg8lB/7G5dYjhh1LJ7
XpKTbP+dYDmaa/2tkPZL4IT8TZ4r1qURpzohkpuf3TuN8kPhhEyVQeOSQohr
nTBa3yNwYCPtL8cZ3CEp+oI2ln/OeJG9YZOLJtt/Z/hj+OuQXOa/M95U7j1T
vovtvzMOSEbNu+zM5neG/uFBg04fJVY4Q1ijFyvLZP47Y+HMoXHat5n/LkgO
8TMaZsD8d4FWq/5ciRLZhwsWVQZULLJg+e8CJW7r9hW27Py7YEZM/3BxNZvf
BdamZ136Hmb774IeH1UvvPxI8loXXDD8uaUuh9UfV3xyif8kfszi7wqP7OHP
dvYkhitO+J+8ojGF8pXnimnYMVlcyPx3xfK01oLz80ie6grbFeKNynuofihc
4fn99xK9vZTfta54Hql8JHtcHc3vhgDN1zN7DX1D87thYOWB7qJCYrhBfu54
P6UWYp4b+KXhBXvFZF/ghl0ti0IP2JH9VDeUjrgd+O0Qm98Nr4sLT2rLWf1z
w5ptlhZWmsQcd+gNMVT9OJRYzR11FfPK6/+y+ueOH6mVfrN12PzueHh3jLlO
IZvfHcYZ3NsXphGnuqPV5Hl960jaD4U7Sq7p7vYoIq51R7ew5j8OV+k8crbj
u0RlZsF1YrXtKP407UhyAtVLbMdBhWHl80y2/9txI9DePb6c3Y/b0R4906+Y
7UfqdvTAV/7YibRexXZYmGZxH9UT127H2VVK4Qkz2f57YKrluXPbGtj+e6Bz
v5f7DXWSwwP+bU5JVTeIeR7I3T9l3e0jxAIPzDRrm/SPVz3N74H86d+WzLzA
5vdA49e3ayOd2fwekA98oH9kBTHHEwZOm33rZ7D994Tx1M8GH9WY/56YYddr
Wcte2h+eJ+pPTbBpqGT3jyc6XYqzu2kz/z1xJdfhg/85Fv+u8b3a9K13s/h7
YmeWQmtNPJt/B55kp4/RHs3834E5S9dM5xWz87cDQfNtt+RuYPffDrz8U1Ka
lsTu3x345LQi8EE1ceoOXK+KS/SewObf0fX8OMJlbTa7/3bguJvL+iA9ssfh
w/JRg6rSaIonlw/J3wtPe16ieqHGR9w20+IbtqSvzYfRCuODFSpsfXwM/vTE
2ecszWfGR52nWb7AmZjH77p/8kNP5tF8fD52JJx8VT6InV8+EqU97HaZESfw
4Vu7zmR5NNvPLnu3l4ycwuzn8fHYtGph9hnWX/ChKhu3/P15kpfxEdTHfcbL
uWy/+Wg6cn9723g6Hy1d+vd9zBcHsv33ws7noSPzB9J4rheeBGyJP2nN8sEL
Dej9gu9L+6PthbX4OX3NW9YfeSFgX3j3NXVUH828UGtXJI6MZ/nihbn2ZzOT
1tJ+8r3w4Ze6aYEpi58X+NGfNTMuESd4wWTTxErNNFbPvDD47pCchibmvxda
R0+OSmDnQ+GF4+UFUzrXE5d5ob/xYGsvdp5rvWDWcdGv/R3tV4sXju74ddHT
guW/N0bpznn9fSaLvzde6VbphorJHzVvbF9mNK+zjNav7Y3yRWckjpdZffaG
UuWKK2J2/5t5o2Kzg0OpCtV3njf+bRQOEanQ/cn3xuAIkzzzSla/vWE79Mm5
bYFkP8EbU8ofrRuYye5zb4zwGjG4ZgHZy/PGzHyHuUULWT/rjQmj1yln/kNc
5o1tL3uoaJTTfLXe8HXv7PEkhbjFG6X/fhw5ifVbHB9cHSw5kmZB/RbXBzWK
0viLjqwf88GK5XuWTh5G/ba2DwZ+rXt09hJ73vHBLVMX9YUSGm/mg4KNsUs/
tRDzfDAm+FutQIeY74OGDyG6rVHEAh80zTcKsrtfQv77oHjptPrnL8h+qg+G
v/pTX2NN8+f5YJTzVY9q1o8ofKBmEzPFR5f2s8wHQ4sPV5vosH7TB9pHtW5G
ONP+tvhgdUFTtJWC9V++WHfhvO8xSzoPXF9YZpRYDXxN+a7mC/mKtmK/N3Se
tH3RsP4Id/ULlv++2OV9RTNoNuWXWdf4p3b/vi9rIP99YbV91l/dKpLzfbE1
2uP9s+kkF/jCKbz3JmsD4gRfyOK+jpvkT5zqi0cPNm5ofkqc54vz4pyhf76T
PYUvXL1P9MEW4jJf9F310cz2Hqv3vggYsaE1fwdxiy88TuSM2JDG8t8PD9IC
ZJeWEHP9ULn8iGDHKvY84IeMXdHqllLaH20/lKv902fpV9Yf+eHy24vjvgyk
/TTzg8X+jVm9frJ+zQ/5RbFuMTo0nu8H6wvHzrveZv2TH2beSlDhhtD4hC77
JUUJY7+w8++H4dKvfh13ifP8cHFhnw0frVh/54e6AgvPtI/s/Pvhq9jtljN7
3qv1g1APWgGjyH6LH471trE0aaT1cPwRxbW4dWQlMdcfflv1N3ztx/pRf1Re
iIvpN5VY2x/nLGZyP11n/ak/zH67FIX2JLmZP9zewWSBB+sX/TF2nlJT2HBi
vj9Ed3YLHxey/sEfA6ZeSN+7kM5bgj/63OLmLPnCnqf8cbvpZV7hSua/P3ad
Ouqa/4nlvz+i/x5Yt/0bO//+OD7A4bylJflb6497iakjCoWUby3+mPemYdD4
n5TvnAD4l3iMaj9A+cUNgLzMxzmrhuV/AG65u93bEEysHYDSi1UZg3Po/QYC
4BBROyDsDcv/AFQtrAzdWcrqXwDKftUYXXlA6+UHIKU+91+dIvb8EoCH8/fs
K7tJ8ycEIGjMkATdcbS+1ABUW275fpStPy8AT3Md5ne6Un1QBEBlurHv+QNU
P8oCYPdhekmfl+x5LwB5wuMfoq4x/wMwcV/3kfN/sfcHgQg13GL2/gWrf4Ho
qeLn2bcb68cDoe7Le6W3kFg7EFevzL9qWcbqfyBq17XYfvYnf8wCIdLZ1r+3
PYt/ILpdrQ5Pk1K8+YE4ru1UEjGH3X9d8h7+1vy7JE8IhOm5rUF/FrP7PxB3
9xVEbnZn918gOnkT+n6eSP2fIhDjhJvUrB4SlwUiPiDPYcZIqhe1gUjfnmrq
epbd/4Eo0uywTR3P8j8ILr9jJp9uJH1uEPbp/2p0DWP9WBBU6hdPEvuQXDsI
bV5lSVdWkT0EoSMxPb9SRvOZBSGyQBhxK+9f8j8IR1wmJR+/8pb8D4JuxMIn
6R9ILgjCwZP70jbtayT/g2B5YGWE7VPi1CAI6+ZxpQubyf8gvEd5Vsv7JvI/
CA6l65YdGEJcFgRFW/VEJSHp1wbBTmTrUONB+i1B6Hb3eaX67HfkfzA2h7it
X/WA5Nxg9Jw4USX3N7FaMLaLtMpKosi+djBmb5u2IbaT7CMYh89qbMspIrlZ
cNeJSMjd9JSYF4zp5fVOC8xoPn4wdLrJ7n/+SfYFwXiV1TLHMfI9+R+MigUH
x1+sJnlqMN6FDpjw15L5Hwz/z1PyRLY0vyIYDU+MdtheJHlZMM48UZ1QX07z
1wYjpztvk1zM/O8af+3GYJMwmo8TgnmiTw4jqml93BDgYervZY2krxaCmoMN
LysimP8hGPnpYbNpI8UTIUgtGnk/dizZNwuBq9fttVYnmf8hcPomEKhvI+aH
oGOd35rq5cSCEMSPs1B6UcjiH4LZMQPPKlWR/dQQCP+5dH3uH+K8ELinpv6a
N5JYEYKsol5p1Y/oPJWFYLCVjfx8DIt/CA4VeG+fpsX8D4H2174OU8+RnBOK
9dvHVM6wJXvcUHjNH1v925TkaqEwf9i21XY48z8Ull+lfecdJ0Yofvxb8MZk
EO2fWSim82vOxvyf/6GIcUl5NPME8z8UV97MyD46iPkfinSPo3f7e9P6EkLR
R3r3TMh0kqeGooLjHd09gsU/FPuu32nNukysCIXzVse4FwPZ+Q/Fmuf8aeqL
mf+heH+pbnWdL+1PSyjCV4vvTtlOzAnDp0HCzhI+5S83DO4lu3u1riFWC4Pi
qPWrsdnE2mEo/L2zqNKFxT8MDn0W1C7oTvOZhWH4SS3uajPmfxicY1+O6bjD
8j8Me8b6GCqNJxaEQSn45q1JQ1n/E4ZxyxJKakax59kw9J41aZrTfqpHeWHY
lvOsKjKR1b8wJLg3qG3pTfplYZgSsXycfRHzPwznmn59FmgQt4TBIE7uJRjL
4h+O5pXiyx5aLP7hSKjLX/bGnMU/HPsPFc6pb6f90g7HrZs6A0c8ZvkfDtkO
Z6GhG/O/a7wiXfNFOdnjhaOwuu6H6jQW/675Th9TW76G5X848oM9fxwXkTwh
HD+S5v3sPMviH44rxzkfmv8v/uH4WnLKZckeVv+6xnu4KhuOY/EPB6bcfdzb
g/kfjqNfLH5kvGLxD8ekfqF3Ntow/yMgnLKtddI/zP8IGBxvnzl+Oo1Xi0BL
QeK7jmySa0cg1FyQvnE7i38EVgbO3Wk/gdgsAtUXHkWvZvnEi8CV5t99b7J8
5keg/9MBukNLWf8bgZdOt2WyJxTvhAisUSw1vmnD+t8IlO9bOjVQxPrfCCh1
ftk2VELrU0Qg4oHowunN5E9ZBDq3H59bzOS1Eajd6PW9/y/Sb4nAko7bC0cm
sfcvAjwb0Fdz9yeSKwkw6eeQYSNtWT4IoPTG5NDX+cSqAuSncOzc+rD8EKB3
ULpa3GJav4YAHbiknZ1OrC1AzcyKE4em03x6Agwc+dp4CXtegACDli1JvH+A
7BkLYJUzQ3h2GrtPBbA4OsbwUQPpWwngr1T3RnCf9HkCWK8Yf3/mYWKXrvWf
Dar6zO5jvgBbx0769Jfdr4Fd/ixuSA39h9UfAb5cdEse0UYsFcC7l1y96Dar
xwJs6Tb7i0kLxS9JgHKvZRk2o9n9LMC8ue8OPY0keZYA4x8cCWv8SvufJ8Dg
VFPTdfo0vlCAlEMb5q+Yxeq3ADne6aMvryC+J0Bi4O4t7TeJywSYteD882/J
ZK9SAOclTZolYex8C3ChvLvd5kvETQKUnOm920+Z5bsAVQ+m563UIW4XQCXB
NS9dmexzhKj2WdfP/SuxkhAj/LSVDhrReK4QFmfzLBN6EKsKMfputHpBBasP
QrjumCD5xO5jDSGibacax4Sw+0KI9Yf65wb8ofzVE6K4LFj98l1iCHGsVSnh
3GW6P4yFmP4tN0O0nt0nQtTs6Xv/VgjZtxJi15zrTb9tSZ8nhPtqNQuVmyR3
ESJgepl9Sw0xXwi3SdG/sw+w+Avhd8nedNUsYoEQhYb6TZtPEUuFSBrSc9nA
iyz+QiyZbmRlZ0/+JAlx4W8fuz89WX0S4sTSs5dCA4izhNg59t6jV3HEeUK0
TXyXprWXxV+IlbbPKmOOsP6lyx/pomfFbP57XevLN9vexPqzMiHM3Q2KbhQR
Vwphev/A5NOaHyn+QngN/dbbXuUTxV+IzNIip8BuJG/p2j+l3/YnzxC3C7se
BvUW/1v+geIfifi3Q/OlOSRXisSby7NwZywxNxJVvk7mVcnEqpHQWz11ad9i
YrVIjOxZtOyG1WeKfyQGz1mc93VEC8U/EnXnT0UuKia5XiTmhg8RcA2/UPwj
MVC3aEBSALFxJD6N1zeaNYrYLBLiqQWOHWfInlUkzITD9xcvJOZFovfVoGy7
b8QukXg/sE5dlkj6/EjIDuVt6p5LHBgJg85eGwpqiAWROIV3Uc+9iKVd+uue
bKlLJ06IRH3LaKHDfeKkSNRc/pBqfow4NRIpR68JNzwhzupa/+aHbsZjifMi
8fnkhPVnbIkLI5G2+fTqlcOIFZEId1+e05JI678XiXEG00Km5BCXReLWW/6r
veHElZFYZT18wMb9tJ+1kZgwyE9R5UzxaIrEh6mJ71Qd6Ty0RCJDuitR9TLF
uz0Se+6eDdZoZvGPQmkGL+qyL4t/FK71KWk+qcfiH4Wep78nbypg8Y/CE8fJ
k9NLSF8tCq3Dr+3vP4r6aY0o7O7fcloYTawdhcfrZuosG0/nVy8KJg3O2RNf
sfyPguxxZ+NXJWLjKPD6uO01rmT5H4Vz5/UOj64ntorCoo6X4xRNxLwoFCea
juG9ovlcojD1st6IjGG0Pn4UYtVrBv3MJXlgFJq5J/8cEpNcEIXZPg1q3wYT
S6MwyFJ08+Yq2r+EKCTNFnfuDiZOikJ/03mfzR/T/qdGYbhKjtaPYOKsKNyb
7T3L+x+KV14U3rrrO8nHs/hHwV/V4Me5PBb/KDyfLl/ZL5z4XhR6N20JFxp9
pfh3rb+sh7bpcOLKKJwt0B8//yyNr42CH0dUcPUecVMUEp8fruAPb6X4R0F4
2njpnRHfKP5R0HfOGp3XQXKOCD0vxY39/Q/JlUT4enZ3RscpknNFuJ/x0LSb
A7GqCLqVcoVdPa1HTYRsw8k/9E4Sa4jQ8NIos+AQsbYInXc5GnFzSF9PhKZQ
V2uv+cQQYXv0ofdq2TTeWISnOst67mll+S+CwbpbKcpGxFYivFnDK5fPp/E8
ERwbfIb0aSR2ESHgxSLdEi2yzxehLsJY84YqcaAIMXdWWB6rpfECEXLWLo94
HUVyqQjTdU32Pg9uo/iLsLLizMwis+8UfxGG79MSb75KnCqC5rXPu2weEGeJ
0OvHEV+fC8R5Ikz+nHTDce4Pir8Ihv1ezBtvTawQYdy5wRsVbPw9Ea4ohOtj
3xCXiXDBdd5vLwfiShH489/UzPQjrhWhj9vClSuLab1NIrwri/zJWUDylq79
m72Gu0+TuL3LvsWLfB1XYo4YnF7r9Cc3EiuJca75orpmFjFXjORV7xwiM4lV
xRjjqa427RXNpyaGfVSH79fPxBpiRKX3Cqk+QqwtRtDwuDM6Z+h86YmxXemZ
dfEXFn8xEj/PfdcjgOTGYkh6XKm58ZPYTAzNfIc7wo/EVmK8U51y5GQZMU+M
tGCHowfG0XwuYujHmZzbFEvMF+Nj265czRs0PlCMRyfLDvgfJRaIUX3/Zfvw
m8RSMfwXNnx5H0acIMbOqQKB3J7sJYnhud1JT8uQxV+MiE/fBrVvI3mWGKo2
NfJt6aSfJ4autmSxzQbiQjG+jeWuqdIjVojh6LQy+dYk0r8nxu9/bJenaRGX
ifHS2CFX8o3GV4rRvGpktfgUca0YssZVRnm6tJ9NXf7e99vt+I3lvxi9HbIs
jE8Tt3f5v9B4i/5gss+R4HzArnm1zL6SBDaVT8WGTM6VwP5m3iUXNWJVCfas
rZjwl8VPTYIqjT/VDYnEGhI8Lt+UcF+H7GlL8CzF+EgKW4+eBPuK1K7VV7H4
S9B95FvB4k0s/hIc9e7kOXey+EvwwObTMe4emt9KgrO1RfPCHhHzutaXl/5e
zuQuEuhf0NudvJXFX4Jdt7FBR4k4UIL5lt0eHbAkFkiwYcjPxkoRsVSCTzsS
tvQbR/FNkCCgYeLT6goWfwlu3bWR5ScSp0rgkvgm0/M7rTdLgu/SyAOnhpA8
r8ue1ounDldY/CWY3a5s0HslyRUSGFz0GvXTiMVfAifzUYtUK2h8mQRW3Y5/
bMoieaUEGUddrWUNLP4SlNvkKB97yOIvgb/W6JC3ESz+EjSnzDIpfM7iL0FK
zKJTSt1InxONDOM37b5uJFeKxs0Gzok2M6qP3GhYuvkuXJxJ9Vc1GppBlbqz
y4jVotG2oWj4gnxijWiM+2LCvTuC1f9oaPR7+U0kItaLhtI50+97HIgRjWrX
hzfOR7P6H42y/IPbfX4Rm0VjzrHqYaFOtD6raGy6uvX73MPEvK75tNzdNTSJ
XaIRuk9zZ0cy6fOjMWjrg9qQc8SB0dhn/nJcLxcaL4jG+6KhioMFrP5Ho8GP
P9v9EnFCNAQVlwsX5hAnRSNda5vDj1KylxoNFc26aSXPibOiEf63Ov/iXBqf
Fw2/+dZ9/2gQF0bD1Dei9JorjVdEo/OB88nWenb/RyMtsFfWRHPW/0XjzefE
8w16rP+LxruZUbkWGtSP1Ebjyfu9IXqWrP+Lhs3ROYuUlrL+LxpOysif+4f1
/9Hw5PSbrHmVmCNFSs3cZoPerP+TIsT5qPGpR6z/kyL33WK7XxlkT1WKgR9+
+zl9pn5HTYq13XZZu36h9WlI8bzk84NBz1j/L8Ub1R/TXTKJ9aRweC5Xj7hF
DCmmrw7YoW5JbCzFuRMn7iceIvtmUgyfmcL1kdH8VlJMUro8qMdQYp4UJ85a
drsykthFCqMvKSN2sucjvhQj1L96mihTfxcohVnlpNZdxdQ/CqS4p9KQ1v8S
9YdSKRYrtUx2GE3jE7pYJWBQfBXJk6Tw3K0jvdWf5KlSZA5J71N+gORZUnz9
hElBI2j+PCm4dYND/PxofKEU8qCQWo1/iRVSZNw3OiN8S/r3pLC/9djf8yhx
mRTKA0YljFnEnv+kuN5g5zRYSlwrhf+KZss5KcRNUtTvDJnrZ036LVJoKaVY
vF1N3C5F8L83jixh/nBiECirKBu/n9ajFIOdMpXa3JfsfXgMhM+u1vwzhuSq
MagdZ/j6dSrJ1WJQPqjz54sK1v/HQOcOV62RQ+O1YxB/VntzLxeS68VAMUKZ
f3g+6SMG2nm33g7ZwZ7/YzB4xOe/QifSN4vB21mrhz3wIbaKwaqER2di/hDz
YtCPp5Rv6kDsEgOX9+5TM+R0HvgxuKLmq1LaQPEIjMHvT+Hc/Fg6X4IYzMme
cCPch1jaJdeP7+zXSpwQgw0ZL0v7sfOeFANV08svNAfSeU2NwZ2vZ6bbnGT9
fwwuDJ9zx/g+6/9jUHXgRbfCEOLCGCSbddosdmP9fww+uN89N2Mhy/8YjFx1
48AbV+KyGGjU6m5KekpcGQPeWq1F6s5UP2pjwLFOn+oaQNwUg5YnmTW+H4lb
usb7xBmJ7Fj9j4GJmSzk+ArW/8ei4Yzg95xfrP7H4tEb5Qqfe3Q/cGMxcN9c
h7fuxKqxWN5r+Oktd4jVYjFt8tWDU18Sa8QiYYxdVHcrdv/HIurC5G/1T9n9
H4vfM1/kTNnN7v9YfFp8sP+ENlb/Y7FK9rLX+uMkN4vFDb0Fi/4xYf1fLPpd
na2ax2X9Xyy6n3j47C6r3y6xuDMxedlMKev/Y6EyY376+wms/4vFBs/MCzfn
sv4vFp77goxUGUtjcShTJ1Ynk9X/WPT/FpoZuIfWlxSLbktMDNrNWf2PhfRE
/8WCI6z+x2KeeHiV31HivFhoPOSVP1UjLozFnOZWk5IlrP7HQrf6zWTNThb/
Lv93uRXL1rDnv1gMqoo5mBvJnv9iEVeR3BYay+IfC51/8wx+xrH4x2JR0kRd
5z4s/rFInLsq5UQIcXsspn4xm7dISvNxZCiueT32zR1iJRlyjMyOH68g5spQ
UhmV3DKO3f8y7CmtXvBPL3b/y6C7x+pLGDvvGjK84/Y6sSCL8kFbhtjJR9Ve
XmPvf2TwLOvP2anP6r8MZVP/WF3uxeq/DG/n3V8adp/Vfxk8stMcQuJZ/Zch
PUldU7SO8pknw4KTO14v5hG7yPDLfsHNhCks/2VwV1sQbMLehwTK8PdW1Axe
HLFABs1fQ68ZzWX5L4NPc3Cw8kGW/zJEDtN4cMWa1pckQ+vbwqu6biz/ZRjN
bz2ssY44SwanFbs1JENY/stw0OZmxBkjslcow9zjzUmLmVwhw5Xrjm+3drD3
PzI0Vfr1yVCw+18Gq1/TWoXrWP7LsNh8s9Y5Z/b8L8P4sD9n3q9iz/8yKKuV
KKmuJ26RIZF3LLDPWuJ2GWJUovRznMk+Rw4Od+mQpSks/nIkvr9nl/OKxV8O
k9IYYz8DFn85MivvnNvZnfTV5Hi6Z/TSvx3s/Z8cL1ofmSTz2f0vx9DBm72T
Gtn9L8eAnx7nXglZ/OUY1pzSMbuU4mEsh7mpT+zSfcRmclyz/HRm7iCKr5Uc
Y25NVOp+iMVfjm/PMmbkN7P4y1EVkrl2tCG7/7vWM+revz23sPovR+7ovzeU
WH8jkEPw0XhWG3vfI5Xjd+DieQWN7P2PHJqNz+UvGCd1+fPN8KEU7P2PHI+i
i8MH3yN7WXJUel6+ll/H7n85DoVmfflnJIu/HKm7Da8sWEuskONkxpR+ajfJ
/j05Xp7VFG3MIXmZHPGl06YemEJcKUe5TvIRZwl7/yvHg9k/CmbXsPe/cuyZ
9e5G91L2/leOh9vNhq5RJ3m7HI3jn9opxbD+Lw5PdA765FqTXCkOGUvEu3mJ
rP+Lg+dCi5WfVVn/FweNPv5Knw7Tfa4WhyWC4UnvNrH7Pw495uwyev2c3f9x
0PnQt69rLNnTi4OW7G6D8gCyhzhcPCF7fCGfxhvHIWtIYWZtI7v/4xCqflU5
WIPsW3XZtw722e3D3v/HYXen8+lbWtQ/uMRhku0Tw30m7P1fHHI+Zy9KfMfe
/8Xh1P2qQ1WDWP7H4dnf3Hl/2ftyaRx+flGEeD5i/V8c+rflqszMJHlSHDbf
K5LfSmP9XxyK5qtxCtj79aw43Ap/Jhh1ksU/Dqvrk/s8ryQujENm8d8xmQ9Y
/xeHx5d0B25j5/leHH43lAgqCml9ZXF4HXdu2IYHxJVxSHOPeaS4xN7/xqHM
6q7nHdY/N8XBevjY2WOUiVviUPo9wH7VBRb/OEQW1zxUu0rMice9VcJXp2eR
PaV4yGsvdZyyIn1uPE5pe03I3kqsGo+hpq+Gtxay/I9HSLX33+HzWf2Ph/+T
Wy+CIln9j0eEeJONcSTNpxePgZppblVPyX/Ew6VdlKIzm8W/S3/jwfRcDsXL
LB6tHaZxs3bQ7ylW8bgr6908I4d+L+HFI7RpWpFiPf1+5RIPo9ezhQ7D2O/N
8YhMyn4xxIg4MB61ifXPftez72/iMW1PsjzUl/Sl8ei+grOTu5X9Hh+PXU0D
cocup98Xk+JRVxbc88h1+j0yNR4XD4rikkvp+6SsLnmJVoTQkb5ny4vHk/3m
p9c/ou+dCuPxo69TD5mQfb8cj6L8k6OvdiO+Fw/dgYKDu9ew75nj8chMd+Jj
DnFlPHjTHifPzGff98bjysPKUqebpN8Uj5mi5IgHujR/SzwqMxY42c2h8e3x
iF4h6f5gCPv+dycGz/BYPrqCvtdS2om6G+0fUxTse8Cd2I05fToPkT3VnZAa
XPIRCtj38jvRYbBsRp0dfZ+gsRO2SmOeZD9l30vtxNrqEr0VprSfejsR7f/G
5uoD9vtvl7z2zME5svrr/wNFJ4+z
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lYzGvYx8datgxZyjoIEUlZQvgiCWHKVtkmLSot077XzDTVVFM6ISGZ
lIQk0SbLZCuhhUpIhkKIQijC23u5f+91veefc33O/Tz38nyf9TedCbtdzWx7
slis5l4s1v/++98/bUtZ//8fXBw6K6eK60//XRmpR9u0ixLTidnICtgGjaIo
4mFQ2Tk26pxBIrEapPrNfy2yGR6DtKKxW/+IU67/Yw7qnsk1tAelEk8Eu7bn
5htOp4k1UF93MnNZZBLxFATfezrja1EYsSYyTrXeiGoNIZ4O+cN54325LhRv
BpLMX+8pvRtAdm0IrKc8G1h2klgHqp/WsIb4ZxPPxpFSh6P9i/OIdTGAP8L4
RONlYj0MD+ypVSq6STwHBTl57lVFxcRzEbj0+dz3OoXE8yBOqHKfYXyCeD4q
B6m3mXESiPUhT33p+PfrWeIF8ItZ3NJ2O594IW7vTHi9YKOceBEuTBoXYwAm
PwN8GJE4eKwKw4tx4t238VPdGF4Cltnl1LO/LhIvxXrPkblD8xg7kCzzLfbs
zPnHAqC4peAYezozHssgMbqzMU2J8hMsw1LjeTCtv0T25bjdZC7lVlwg+3Lk
jtt7oiHrPNlXoGHh+XgkkD/BCmisNlR05J4juyHk/AFZqVkryG6I9E0/Nw7e
lEz2lfB+7nVmmVMm2VeCxV5Vv5DP1GOEjqGsmyk5V8huhAjllMOSIia/Vbii
/GCUXJPmk2AV7v83c9EwkYzsxjBTUZ0kic0guzGuu/Z9uOMQU/9qyIbVLrBJ
SiP7arikLPcrrD9E9jX4NGuRurFvyr/5JliDrt9x87NMTtH8W4tL5+KzPk1K
IPtaJHq11nw3F5LdBC6eR97ajLlAdhPcGdErMuUo038dMuwHJ3SNP0f2dTCX
+HMfhJwn+3ocTRzrPSf3JNnXw/7gwfi4/kVk34A9B54FHbqXRfYNCP++RG33
AGIWFz+v6+mFqF7/x+Cizc6FxXt5k9pzod2l9OOOqPQfy7m4Jnrx8dWtEupv
ivvRxvN6fn5A/U3BvpJTf4F/i/qb4kNTW2K6z13qb4oReX0etG+m9iwzqHyX
eeS1Mv3N8PFl1oCrdlXU3wxmmff6fVpPLDdDbzUTn+9J96j/RtTeqP1xJJLi
YSM8OSfELdfuUP+NsDm6KGBibyb/jej/uodWxwKyszZBI3mft1MV2bEJvUSj
VF5NZOrfhKp2m/efnpVR/01QT3bKeLyUmLUZzesPVw6cU0n9N+Pu3aunT02q
oP6bEezz81jBtXLqvxnuyjsubk5l+m/BlbBt9mYPb1D/Lejr7zXMQKuY+m/B
+3NWB97OZuJvgZ5K6mXXyUz9W5HF7nfMo4naYytmL+mzaqAJU/9W3ArJay08
RnrJtyI/8/KQEO596m+OWUlaCwYsJn8wR1LrA/Y9fWovMMebj4qEBydoPOTm
eOCY6hFbQPFYFsizloxblkd2WCDZZXTTxDFM/hZY+aNo88dN16i/BYbMq9uZ
G0v1siyh+ymM+7Ke8oUl1OvHxj75SXoILPFwRO+1e1Xk1N8SOi/6lTQmMvG3
Yc3blP1je92m/ttgfS/1tC2HxluwDR1ba9NeG5E+8u72laZ7RZakD2s7hq5Q
6zJPp/HFdhj8Z2WUP43mo2A7nrQ/DT85mJk/2zFriFS/fCDTfwd6NY/pZ7OG
mT87IB6eZdsZnEf9d8By5NZeF6xofct3QKD7RXnq1VjqvxO+CUHDVh/d/28/
wU5Iqv587TfgIO03O7G5ZsahnKF0Xsp3wvz+QKlqejT13wXvFo3LyjZC6r8L
2TdUr1ZfsKD4uzBx99ldiY/OUPxdaBruaRI0npjFwwvL7UerXel85vCQ/xdO
f9bIqB4eTLyvmbFMaP/i8YBvg0cebhZQfjwoVFLSFMnSfyzjod5ozPJoywOU
Lw/Hq3scfL7q+D9W8CAw6/twQLQz7Z9WsDUt9RdrkJ1jhY4X74fsE9B5Aisc
NXjVt3wCna88K6zYdqhx4ZBrFN8KLznO/utB+7/MCpXj5aemBlB7uRVKHljU
r/pRRPGtoFlauiM5lTlPd8PLWXUpy+Mqxd8N/fP7bE610P6P3Zg/S9y15w+d
V7zdWJY9ffQwJ+a82Y1nYxPO7F9L8WS7keS/d1bswQKKvxsrM0fcnTaL7g+K
3ShMTp2w9xUT3xoOHQHRky9Tf4417AoVY9fplVB8azS/MdQ/q7hF8a3xUWvN
/a6hZBdYY1maypQlXvcovjWMwzTtEjruU3xr+O+a0lLeTKywRs+NT+xtCu9S
fBu8aBhypSac7BwbpE67l3e+ie43sAEn+Zbu3HfM+Nug7/ovXuHbb1B8G+Rt
nxFYK6H7hMwG4qprZUVVNN5yG3Rcll9R4dF5rLBBm3FS5sYKGh+WLbJ2DUh/
NpvsHFvkNLnXbi+8TvFtEYW2cVvD6T7Es4XXONMJrYXM+Ntivd0QTsZMug/I
bFHpfdw6SC2d4ndzxLQ/fz6H/Zu/Cluo3dw7Y/vneJr/dmhvX1ZeUbWP5r8d
1L2veyyYeoDmvx1uDXgxx2LYfxTfDtsX7fm73ZvaC+xw7MBjt8cux/+xzA5P
TqdunDE/k9abHUR/Hp9uyb5E8e2Q8Oy/SsPO0xR/D0bo6jWvOZlM8feg/U91
7XPVM1T/Hpwq+qB6ewetB94emDitjtEcQnbBHhzr+N26JJPGT7YHvZ4KsfQO
zWf5HlQWBlxL+UHrRbEHvulJpQ93kX4se7wRR6cY7bhN42+P5gZVE7eOCopv
j4m/P2cP5T+k+PbIeZDptVhQRfHtYRra81DGkEqKb489d39piA5Se7k9LC02
nbcNrKb49jikOGY/79Ujiu+AI3O8T2Ysr6X4DnhvN2bCLltqDwe80NgassON
2vMc8Mlx8UWl5cQCB3xfMW/zHcMHFN8BYg1dgbiAmf8OWOlrqK+9vJziO8Cl
0HjTUk/Kl+UIVZVLL2eNpHgcRxR8215oqFdD8R3Be36n4YI32XmO4DZNnib5
Sf0FjvhuaXi/wYj8yxzRp7eAWzeE1qPcERoq828Hs+5Q/G5/t5LE39cy74e9
UAt7VXbAkuycvZhvVZN2MIkYe/E66FtevSf54+3F+ETDHS3+tB8I9iLt9I6F
2edoPcv2wnd/5hkrI6b+vQj++yMlYSpT/16Eji5LXqIgZjnBaP/F0L+TmfXv
BJU+vgPvLKf5ASfkrmjPfMUtpfhOsG1SUuxUonwETtA98mZ59UjKV+aEMW/S
Ir/1ZvZfJyhe5XrvuJhL8Z2wPW6aaEmPwxTfGfz9FuXex+g+zHFG6dDWRqch
tN7gjMzizFVlP+l9yHOGeWAIz28b8x5xxuZzVhy39/SekjlD9uZ+4TkvMcV3
hlx53IdtV2m9KZxxJfndDhuPfFp/LvgycYzhSFu6j3BcUOykVtFjInMfc0Gi
k+nvHR/oPs1zwcLvnUrW45n7oQvatzt13v1L9yeZC8pvHtHQe0b3A7kLnERv
3uWWVFN8F9ibViYdaHhM8V3h5eI8uXLkE4rvir53Hjb7qlB7uMK7tqKrhxrd
f3mu+NMba3QlDym+KxqNFldPG0ftZa7gDemIzkxk7juuKPnuPLWaTfchhSta
h+aYyiyZ+zcfS8QshUkm5cvmY9b8rLsvuHRf5/Ch3Va4nmdE90EdPrzvb1zD
PUzjAT4u/i160lx95R9z+diwvbyf6GgO5ctH5rMNLgfu0/2cz8e1ikWPi7qY
9wEf++yHtvUop/tfHB9mtzNMjqZQfBkfA03bX9cdp/bZfOx5NbG+y5Luf3I+
1p9pMGBxSK9KPtIXTLZw5FI+Cj6ujp/haeR8+R+38XEzc13oKiFzf3TD5tjH
LbWzyD/bDV1ZKd59Z1E+HDdssmUP/juO7DpucL4lmpkyieYP3MCdJ9855Qq9
p7huUDZZNIQznN5nPDfMa55UtEmF7ld8N3CmaUT1fUbzU+AG2S/TFf3ehlD9
bni62mB7nlUa1e+GpDLVXbW3LlL9briiHtRwQ0Lx5W74NGj3o1Nz6H5Z6Qap
+0jJpOYjVH+3v0tT59tMyKb63SBw9XPorKfzieUObYNd1ZceErO7ufnl7SHn
KR7HHSZ5ytc7l5LeOu4Y96JXj14zmfPRHY1NN1te+NB9kuuOLRV6Y7li+j7E
c0fJy6VbbsWeoPrdYV8hn1osOUr6u6OVL3X5LKR649xhWOteZX2M7vsyd9g+
vvrHq5zu99nuMA517lHz9yrV746OPQdyJ65j9HfHq4R+v3K1Mqh+d9RU98S5
T/T+aHOHlqmtmv1wYpYHsh76NJ4fQMz2gImoqVBeSfOd4wG/g4IgwRyaLzoe
qPW8mDDpAM0veGCn97zCPtWkB9cD8cfS6gbNZ/T3wLGfuTHtw85S/R64NGmn
hfklet8LPKDQDYgvGUTnf5wH/tQdGXmtH1O/B24n/tTMX0nxsj3QrFfiv+gT
857zgFnDyxCPHfR+qfTA5YYE8a57NH8VHsgp79e7TJ3Gp80D+27sm9Yxmqnf
E+ZrVTQLetL7n+2JieOLZkxvo/gcT6h05M1c38rMf09wL0lqtq5j3lueaP6V
cndgCb1/uJ7wlN47PTyXmOeJxJ5tXqohlB/fE8VzF3WlRNL6FnhCndfnvegU
+YvzxHzDHcF/+lD+Mk+8UY8/PsGA2md7ooaj6JgZx9TviWGX1ZdN1KH8Kj0R
u+agc79+FE/hicIDMatGRNB+2OaJrg0Oq605zPvbC9uXnLSV7aF4bC/0tV82
6mInvY85Xtg5vWZM/Snaf3W8wC3hCyb3ov0XXvicf3ChUm9irhe0ex60/KVF
zPNC+/07h3UtaX/me+F7XHThWNNHVL8XKkdM9f0QQ/Y4L7i1Phkstaij+r1w
/eKMw9qOtVS/F3y4TZu3dNH5IfdC7q/Hv+QD6fyo9ELwZ/18w1pihRewQlyg
HfOM6u+ub1SOhu/Kp1S/N5wuHJha/Zras72xMPu4z09/8s/xRuDAwtcFupSv
jjcGJKw8eIHJH97QG/PBoJlbQ/V743FpyyPNBsqf5w0fJ92PfE2Kx/cGR1l0
78+PBqrfG4JZV9av0qin+r1xI3/eySHDKF+ZN/Z3BVtVJz+n+r3Br2pZsI1N
LPfGsyf5Nrc9iCu9cYfj8zHtCLHCGx3ZDqPaB1C8Nm9o1U9dNfv4C6rfB26v
XtvNKSJm+yBv5p1vb+TMeeyD15OCjnC2Euv4IGNrmXTETGL4IL3HCUdxFtXH
9cHyOP+XwsWUP88HLRllG8v1yT/fB3+DwozuKb2k+n0wsOlQ39v7Kb84Hzxr
tPmpO4hY5oOcwJ0WwfbUP9sHXXL2yOdryC73wYwK4w7fVUz9PgjXfPlp4mGm
fh9EGvR5pR5HerT54FaPmY0+s2m+sXyhPTz/5aQ3xGxfBCy++N8Xa2rP8YVn
8Kt5c4cR6/jC2kRTfruJ6oMvEg6s7dW5mfTj+mJcyNrWJHuKz/NFfMS2+TPe
E/N98XK743yOHo2XwBdaQX6767VpPON8sXPbg5/n3Zn57wu/+4knR29j5r8v
Hp7VXXSphljuiw+tb2YFMvOr0hcX/ZROf24gVnTbzSUadw+S/zZfvOm7dNT4
JsqX5Yc3qb6jyr2J2X44cKp3x1c7pn4/HFI9XL3XgNHfD0+jNHqU9SA7/BC+
8E78xgmUD9cPmg7HT7h+ofXB80OLsH3l2RnEfD8IIyePWx9H7QV+WFz72WLq
DeI4P2T4+FvM92Luc36Y27/Itak/7SfZflC55vEkq4n5nugHJdkwiZj5/ljp
h0UlL15xT9B6VPjBIGuJdUId+W/zw/uMOVnRP8jO8kf9w/n70nUY/f3xvIST
s/sytef4Y/Xk3svyucQ6/hhks25YzSti+EP4tTTjYxqz/v2hEj3ecvxusvP8
weqn+2ZiElO/P57GCGfcDKPxE/gjzfHQGR0/0ivOH9xGmUu4Hs0XmT/0ph7P
VfRm1r8/MnkOUa3azPr3xw/n8t7nB5J+lf5oX/Ao6VMExVd059d4zLQilfaz
Nn+0rbr7J0vO1B8Ahy0/52mPp/bsAHS650wuu8ms/wBMG7feM+ENM/8DsKnH
rglnvcgfAhAVWGolkzH1B6CjZ6zgrT9TfwAU51z8c1WJ+QGIjgnLF72n9oIA
HEnJe/VtPnFct/+krGdqb0lvWTdr9Nj5eTjZswMwZtTrWzkjKR95AMyN//Nx
4xJXBmCBya+nL/2Z/T8AMx6v5Ezsyez/3fWcLfrIrmXmfyC8P9i2awxk9r9A
pN9Y6t+2lcaXEwizkeXVt2aQXScQzb3saznxzPoPxI/sX2EeqygeNxAN5s9X
GX5h6g9EUvbzO1YKyo8fiM6ustARTP6CQHzfNOrMWilxXCCaMkJPLgmnemWB
CB2+/bkmc75kB2JW/jzLD+k0n+SB8DM/d3WZJ8WrDETAymxRn3JG/0CI2ntO
eOPB6B+I1Jzm8KKdZGcFIefFqDNNf8gfOwgfS/IvXO4k5gRBa8Iv3fks5vwL
wlzNEPeyAOb8D4L3R+Gl6xGM/kHI+GV8x3ANjQcvCP2dzz94dIbRPwgaF75N
SHnE6B+ENe/SV94xZs7/INQKalizpjL6ByFds5Hz/jm917KDoDzqq22EPbP+
g+AocFeVs5n1HwT134GZvaKIFUEIyL6402sctW8LwqZi80OeHsz362CcbNjn
GWhB9xt2MJbMnGYqfcPUH4xDu3bmFh+ifHSCcemLm6sijKk/GMGJ7UbHbZj9
LxhJoYlVhSnMezUY83o7r2iYTfH5wVj6rkxvylPm94VgSLh2thJ15v0XjOkh
H4fqBpJdFgzDs6a2uovpvpYdDOuR18o/PGfet8FQe/GIPX0MjWdlMHY+XNow
i9lvFcH4rT7om3k95dvWzW9N41QrmPMvBGvcT7kY7Sd/7BDMsOuhVqxJdk4I
5qx9c/VCEPnXCcEn6TqxaxMxQjAxpMnq4lum/hBklugGv+Uw8z8Efyt6nP28
gtn/QsBRTBMuZzG/b4XgmHG2qHcZ5RcXAsEH1y5RA92fZSEYeym6YkJ/uo9m
hyBxea8+ybrM7xEh2MXNMpSxC6j+ECwKufxdtIvu74oQSJ4ubFmdS++xthAk
94uc7HKRvkeyBIg4v+bCzbX0vlMWQDI8Nv2xKr132ALsCfrvdIaY9FATwDao
titzPfM+FoA1d87U3HfUXlMAl5sV7d+UKB8dAQz9NmLWDcpHX4AxY+c/StOi
9wcEKEhsejK6mt4nxgL8nBobt+AG3ee5AlxzXlBoIaP3ibkAXS9bbnw9T/54
AgRdH3ZijSP1txcg/qhWoPk7ei/xBVB/4rO4cSXl4ytAlZ5NwpJRzO9TAtQ9
NHj1aDG9vyQCeJgYj1T7RvHiBMhcu/rX8TX0vSdRgN3TAuoyDZn3iQDv4gNr
NU5TPRkC2HRcW3X/NOWTLUCnmrqn3IzqKRDASTe88sAH5vcsATLUPb91Xab3
d6kAww4rc+ecoN9fKrvbX9/Rp2BZ6j+uEyDnKsvgdDO99xUCXJlsGT/nDL2f
mwUYeC7iYKHnQdJbgOQ9ewI/XyZ/HQLI7GzWrry4+vo//YVInPHJI02f/CkL
cUU+q+emH/ReZQvRN2mFCMPIv5oQTS2Wgx5sZb6XC5GwRev8iFx632sKYRlV
Jpx5hH4v0hEiZcKxQa7qAtJfiJY+7X7u7z1IfyEWXnw5zWQK/b5tLIRAMetK
exn9PQlXCJnmkAeLM+k9by5E4bW8A7Ic+p7CE2IOW7WrkU3f9+yFsHFoytsd
S7/H84WYe2ebBSsgifQXYrBtY+b9HvT9QiBEyND5oTFZ9F6XCGFckaq2eCV9
/4gTQmP2qvgJ++l7Q6IQX/XNm7Z30vySCZFuMf1SeQvNlwwhDNK3Dk5bQnpl
C7HAZvRpuyT6/lLQPT5eWsZi21zSXwixxrIx8jbyXyrEvepZ80fk0PyoFMJq
QYQJfym9f+uEcGgZ1P9NArGiW78PgqAJj2h/aBaicr9/6BdD2i/bhFDROT4i
5yvtNx1CqMZvtPP6v/u/CKPuSn4GX6f9TFkE42GF+XdLaT9ii/Bx/XlevgPt
X2oiBDwOSl18jtpzRPg5+E/lzOd0vmqK0NnZ8+jDNcx9UYSELjOVWzFk1xdh
6aRNU1bMYPZPEQ7FCu4IkikfYxEKlVZPOH2f4nFFkN6ZVh10luzmIozIvapr
uI55X4uQ37ZlmVY71WcvQkWcdFziN2a/FeFBQ+ryhSMonq8IT68VXXxswtw/
RIjY/27B72t0XktEKLkeU3NwDHMfEWGc/bFrGgZ030kUYcs8e7ULRsz7VAS1
9/GNxgPpvpQhQmCPA+l9S+h9lt09vj5LvvlsJnuBCHt/c0oNvZn3mwheqfUr
ypYRl4rw5NrAiiYl5j0nQtthsyFXJlB+dSKE596eqenM3O9FaNcwXbdQg+pt
FsHg5E33qpc0Hm0iLHs693gI817vECFNfUBqp4jRPxTcsGsPRflkVw5FniAo
OqOB+R4cigjzdyFdFXR+q4Xi4ZKgjMrdZOeEQlE1qfTKD5p/mqHYV8aTGugw
34tDkcHT7Dfcn1g/FJ2+bp6ZNcz3o1BI1OZ9CP1O89k4FNHnrB/MCqb7DjcU
gv3Ov1IWkd282z6Gc7OY+Z7NC8X9+DVLitQpvn0oWG6vHT13Unt+KC649p3n
b0jtfUOhdmRxKXcr8/t+KC5NmFVedoXql4RCX6Bv9LKQuY+FwvKg/sZvV2m+
JYbi+Lb3b4xKmfdZKPg/PIsy+pEeGaHIEuz+UVVH9uxQmNTbtrkOJS4IxYg5
SdOMh1F7eSjudAo/VsvIXhqK0K93bN6JmftcKJzTu0qn2NF5UxeKB0rCTg3m
PFGE4r23eUTUVBrf5lDEH2oLUxiSvS0UHa6Lb7VfoP2qIxSne17WeNBJ+wtL
DN4BXdHl2/R9XFmMiS5vHfe1Mvu/GPJVE8tG33b7d16oiVG5qfiPVkn8P+aI
EVuZ0i/Pnv4+QVOM9/V6PVbHJv5jnW7/HM/IYPtg0l+MuMH2K8Q7zP7ZIcbu
hHA75Rz6/cZYjFs3C1kJuvT7MFcM7tsLM+OS6PdOczEEaRunLfpDf4/FE+OI
Y+ML4Tf6+zB7MaDoVXNUlfLji6F5RGlxG5vOD18x+E8O3u5IofuQoDsf2SWR
tITON4kYRkKV8ltXmfNfjP5NG/Sac4kTxUg6PFHao4jGVyZG56DIsGQujWeG
GA2b9yweIifOFkOW/2OMSxNz/otR7qNS8M2M+XsaMR6kX9cq+Ez3uVIxihT3
20bG0/ytFONmssuAOG+av3VitBu/KTSYTetPIYbj+5b0qASan81i6N8Yd1x9
IfO9s3s8Fh48naBK7TvEOD+1oo/yCbKzwvDm7XSzoa7M+g/D++HpM2afZ97D
YTCanfknMo/2H7UwiOKnnWGF03udE4Zj473ei47QfqgZhrAFWVmxLsz3kjDY
uTZoDh5H7039MCSvHTpnjikxwuC6081W+Sn1Nw5DWv2cXpsSaf/jhsGh72bT
BYuIzcPQkH9l6q159B7lhWH/213aZaUKWv9hKOtMrwzkvqL1H4bP/tm9K1vI
7hsGq+OyR99eEwvC0HXHUrlLQO0lYbhhKfpSWEEcFwYT+zXhFpbEiWHYuiG5
yUalkfQPw3Z+8+ZZAWTPCMPdlAkmHieJs8OQl3r9aaEOfe8rCMPVwif7v4wm
uzwM6YtDVqzPIntpGNyO6rzl9W8i/cNQscW5KWoAcV0Yft06Zxf9mPoruvWa
IUkXTqJ8msPgu/d58ZeD1L4tDJHaeZrSLWTvCIMN/7XAmfWG9A/HoZEqg7K2
vib9w9Hn9hBDx/FkZ4dj5m9+SP/TxGrhUDVzLFnwlPxzwjFcW33npPnUXzMc
uUV3H/uyiXXCMX2c9rU6d2qvH46mKiXLVEfKB+Fwu3hsn0cT2Y3DsaFz8dFZ
FmTnhuP6+a/F1atJL/NwdOWnXNwylurnhcN0+QajuEfE9uHY2iy8e66O0T8c
P32SI6vayb9vOLIbbBLDOig/QTiaM1Qvsg9RfZJwlB4+8+EVl+xx4SjZWLav
jwb1TwzH5ev+6kcnE8u684uOu2kYQO0zwuG55/EztzPkLzsc7cv1fkwPJ3tB
OOad4OtuWkz95eFYX5L27Mdh4tJwdNwvnOVzk/KvDEeNo/7B6ZtpPOrCMaN3
yrvRPRn9w6HdrucX95PmT3M4yusOrLacQe3bwiHRv+e8eTn57+ge34HuKXnt
jP4RCDnk0/7yIKN/BKJ/bTXgfGD0j0Dpk5JN5+Pfkv4REIz0rxnJjBcnAmUf
Hv/WWkWsGYFL3/4rUBNRe50ILNHbFHJyFfnXj8C92dZPz38iRgQKp5vPLjtA
/Y0jUDNf9eofNJP+EUi709jyo4r8mUfge6BbfdUz6s+LgFmHxYPZh4jtI9D4
3/ODIZ7kjx8BYWdCQMlDYt8I/N435VGLmNE/Ah7PLw6dU0njJYnAsdJ+R6pt
mPUfAdHSfIfo4cz6j0D4EscPPSOJZREYOozv/MOI+mdEIPD5qq8zKoizI7BQ
+j2mwZLGvyACMRVffIV/KB95BF4ohnSONiEu7a6nFcbrXxBXRsC/xbRGqT/V
XxeBlFTHn+LeND6KCKiYn/6h5ErcHIGvP2V87QLitgg8c1+1fRX7HekfASPn
wNOWIrKzJBAeVjIO2Ub+lSVQWzT6c8NUsrMliDn+c7HFAUZ/CRbtjZIY5hBz
JOj9oGrQ2GxqrynB4aObWxeA4ulIoP9UV1RtRXZ9Cf7buLI0ZwPZIUFcUeQu
i3dkN5aAeyR6kVEb2bkSlA15JlCEk91cgrpRm/4rPvGe9JfA897rz2EbyG4v
wTibJz9NHjH6S+Aktw3+5Up6+0rgVag032wk5S+QoHTC7jCTk8z6l+DG3Ksp
KwaRPa7b3taefGkYcWK3v/qP0TvrKJ5MgoWzW1sWdZE9QwJO4aOcI5Mpv+xu
u8et6Q1NxAUS/BUkjYjt/ED6d7d3O/5ZbdpH0l+CgifxHk6vWkh/CYZZ+R+5
6kv2OgmuvTNwTllJdoUEVl8apy+rIP/NEthF6vV62Jv8t0lg6lE8vfYto78E
J9vrzAxzyM6KRO55+8jNk8i/ciTcxxZH//5NdnYkJh07Iiuzp3hqkXBSdrhc
aEPMicQF38dL1KdRe81ImOTv/QsJ2XUi8aK1vvjiYvKvH4lmoYv6aR2yIxJR
BUsrZjwgNo5Eb5k2v9WTmBuJgrH7dPT7fCL9I5H4bt/hJdfIHy8SNuwz9aub
qL19d/7Xuo7t/Ux2fiSqRNp7Lp+n/r6RaP/ea+J6DrEgEufZrwq/vCGWRCLT
Mk7vdxr9fzBxkSjvHLwkheHESHglTDsoUCKWdY+HNPzWsSPEGZHQUfkVGB5D
nB0J5RjrVceyiQsikVPJWWeQSiyPRH2qyrVstJL+kfDJPbpOy5nyr4zE/DUm
Y5yzGf0jMXPDcvWSItJbEYkfouK6W08Z/SOhMfrCiW8/idsi0VFeHNO6n7gj
EnE1fT4VVxGzouD6qaTxuhqjfxRqD23soe5N48mOQsHT1ynQJLtaFCYY7m+X
72D0j0Lmpxda3sx81oyCftXA9cUDyL9OFAYnutzrFBHrR+G53taiIQXUHlF4
n+5tE6xCbByFIbu1Xo09S8yNgqB5deflNupv3h1/+8Ic+/MUnxeFQWnWm73k
lJ99FMKCHNZdOsDoH4XkY0KdmnuM/lH45Kp277gV2QVR4GYNv/r9BfmTRKE1
nXViGTPf46KgUWV6fKMStU+Mgt/fdcezRxDLojA/M88jTJ38Z0Thcu1B95ts
0jM7Cpwuvs6XwYz+UehTfXXnxh6M/t3x51aoloYRl0bhTbuwJPkm9a+MQs4k
rSnfGsl/XRTkZ71yriyk9ooonEy71OfFWeLmbn+nk71H3yRui4Jqfvi8/9KJ
O7r9XdxW3/sG8/95RWOjdS9XFTGxcjT63/v7YXgmMTsaJoKQfHuNz6R/NLY0
z57GZuYvJxouu9e68GaTXTMat3UXm9/oILtONLY1Tl0d+ZdYPxr9bHXn/n1P
jO724icpSiJi42hMubws5OphYm40fna0T5vsQP7NozFjYryhawExLxrv0quH
J4UR20cj0udU0fcYYn40yjfU3y5MIfaNxuLfQYd6mxILouE7/Friu+nEkmjY
qIh0fpcx6z8aj0ffetnPheyJ0WjNuL558m1iWTScJI3B1zS+kP7RGHcudMmX
kcTZ0UjeUl6HCcQF0djfFRiq9IT6y6Nh9HNt/+XpxKXRcDe+WjykmeJXRiPk
3srhOb7EddF4Ou6si4Efo380hMKw+IIymi/N0WjW0DSeHUDcFg3Tp5/aFYaM
/t3+7X1XP9Jg9JfCVGPhzc+g+MpSuEzMUptzj9FfCuX+pqMGaROrSZFXNrVh
wUxGfyl+T04daTiXWFOKHPagzuhTjP5ScFoGS5cIGP2lqL162sxtM8WDFG81
7poFtRIbS3Ekt8fcsl/EXCmyGse4zclk9JfiiVXPvJFnaDx5UvxdNjDqexGx
vRRGj2cP6Sol5kvxVOvw3sytxL5SzC55aBxvSyyQYqvvIpvi38QSKV70C1of
l0kcJ4XdiOIxx4OIE6XY/2Hn4W23GP2lSPccOcWNT5whhc9s11+1X5n9Xwrd
RRn5t3uTvaDbX0CP3TU8Rn8pGgZ+tey/l9Ffijh28Hd2JXGlFM/KJjnq6BHX
STHVoeLETCdGfymSpq3o/6qS0V+KP16rdtQ8Y/SX4lFn3ISf14k7pNAc/uHt
xonkjxWD0JpFAYlaVJ9yDBSLlWKtnpKdHYO8Z+lnzKvIrhYD3cl7BD/SiDkx
0LZtMMrW+Er6x+B0h2Vp/ley68TgudWCdawdZNfv9q+Y9U3rEjFikNlHfPfE
XWpvHIMd3ncmfz1NzI3B+mE7lIROxOYx6CrZlRwnYPSPgcE+UclyffJn3x1/
5ZpFuUJifgxm9Wu8rzmR2DcG5T3Mg9sSGP1jsHvj+V/CZWSXxGDM9KMpjjXE
cTHoq72muBeXODEG2fqPtNMWEstisGX6sTEVn4kzYnCg3m6pnWk76R+DJTUP
NlQkEhfE4OO9l9YRO4nlMZjmcrws4Df1L41Bnbgw1VZBXBnTfZXSGpm2gNrX
xUDwqsmgehexIgbsDbErd28ibo7B0KR3WlcdiNticCHex83uIfnriPnf79dT
M1nErFi8CYpJ7Z3B6B8L1Q6Y2zPrgx2LzPnqkbmjGP1jEb//1aDbjxj9Y+G9
/PmFEnVizVg4yD8NOZ3D6B8L68DM5xMcGf1jobZy0iBvM0b/WLB+1RTLfjH6
x6L+Y5WoqI3RvzveYY+q3rGM/rFoMTjnOY6ZH7xYNJ9eecDFgNE/FkpTBkzf
kMHoH4vhY3jzTQ8z6z8WgbKMK59saHwEscjru7QxdDOxJBYV0saUPrrfSP9Y
5Gz8mhH0ljgxFi+8H/63qM930j8W9tUm39rOEmfEQhp+KtlmK3F2LKqmJ256
foq4oNtfj54Nz7uI5bGoXZvjPkGlg/SPBddi2DCH2B+kfyzkniMTxx8nrotF
ZIlen/e3iBWxYOdrf7DLof7NsTgSYDTA+y9xWywGrlu7YfaITtI/FgWXnzzJ
nEzM2ofY9Y6OCz8TK3dz2z3h9vU/Sf99+GItCTzhR6y2D9l/9IbfG/WL9N+H
wP4Wp7p8iTX3oUXt7sUA5S7Sfx/K0qf3Uc0gu/4+/JCubf38khj7cP5ArNGG
dV1L/wcq8dI9
     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlczF30xydLKlv2rI09IUkeIXwiJJ4WFVmb9l3TvtdU08xUM1P27Ena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     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczN8X/0f5JNmSkCVGhYRkT5FXRbInolJMq/amfa+pqZlppqmEZM+e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     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzF/UHxSFiEIUyhrCSIjIh0goWrSQZbRrnfa9ZpqWaZnqZ61sg1L2
FhJZRqKQtEjZs6Ws2ZJsb+/j3Pd53v7p+Tznnu2ec+8933vPaDn4WDr35HA4
rb04nP/9/++vfSHn//+h7fW8Ws7nE5f/QQUc7lT/jlApYWWEvQ7QmPAoibAq
7liHpr/fuZ/kqKGmYt3xhtKDhDWw1bFm9GCNk4Q18TUwPrgjdR/hMWgz2NRn
/8ZjhMdB1/1a3evf2YQnYIX6tp27Os4S1sZMPY3ynq6XCU/GieZr73WNSgnr
oCdHref44zLC07DdWj1/T/IVwlx0BhTZeL6/TngGpl78lF96roKwLszGKYUH
Lb1BeCZ0Lvbz77Bn+vRw9MD5s/282fhZkJlcVqkIY/JmI8/8BKpuM/ocvNvm
eiPkKqPrQzvpSFiON5M3F/EPFJal3iwiPA9ydhlm7xfmEzbALRS+PqPDxs+H
+ViLM+fHnSe8AJX9NsiF2RUQNgQ3ZW9CblY04YWoWVGwK7R3HMULcFq157H4
atY/ugC47u7v4jk5g+iLUOx+7O6humP/sGARuL2N7+/Mvkz0xah92SJc63eW
6IsxcZcO783fIqIboWvP1ru9XGm8wAg6NoeutHsz/iX4atto07f0KtGXwOnm
yla1zzeIvhQKRRyHU17VRF+K80duKz0wqyS6MTSudA7Of3Cb6MaIR43PyNW1
RF+Gadc81HxbGP8yVNr8tL046i7RTaBh4+U6yKyJ6Ca4cy4qN0D6gOjL0X+A
g+qAtY1EX44st/1uB01pPGcF8kWtT6XNjL4Cw55jX3wTYc5K9Blduj/a5B7R
V+LwnFNjb1Q0EN0Usz/WXOlXyOimWHTdctr0F4xuhtURllWjnzK6GcT7T7x6
pM/0r8Lt45PaFFcz/avQR+hiPLK6nuirMahq4LEzEwgLVuOud/SRFJ8aoptj
+uDRXRfMbv3DMIfAyMw74fZNGm+OgMn9ty6QXP+HZeYIEy7fOFtUQfwWWKpT
euNXEuO3wP4nxbq/xlB8BBZI8hyms7QfjZdZYNjeMzo9DpI8jiV0Ns3jrtYk
fbCEvYKhi4V+FfFbYs9JXoT1XbJXZglxQMJGx63MfivEiiPa5XxIH6yQYDtg
Ri8Vpt8KspyRBbyLl4jfCh92ZJwd3KOA+NdgxeBNi8p/ZhH/GnQceaI1aBFh
wRrw+2zfc6e/H/GvweBdH2e66B4gfmsUDeJkLCzMIX5rxBwsmvQihegCazit
nlZQaiP+t75k1uB8vjJq/8IZxG+DYddzy9QSTxG/DR4evK5c0FhC/DY4XX0g
2nU8rSeZDfRO9KsNGniO+G2hFnfCcttHWn+wxd/PzcHcFPJPYIsbFxt2aI0+
Qvy2KPRaFyblMH47aDm3r6wbUEj8dtilW3Tvc8Fp4reDXa/oeblbSZ7MDp/T
/kz7Vs3mby1KzbLfH1C/QPxrobZievP1Q2w/WAu7M15mxzbmEv9aKHsPEOVl
0H7CWYcOC64ocDrzfx0M85ommZwiewTrUO6kvv60D9O/DkuqvAbXj2H67fGU
+/5D6CuKL+xxMl+/57aGMuK3R35NuIX78ivEb493Fyx/u4ZcI/71yMy1c6kT
s/xdj5K9Fy104lj+rcfSXDeBhQ3tJ7L10IlZdKrfbBrP2YASx2OvvvajfMYG
NKhU16kHkHzBBsjEsS6e2oRlG1C2viQvUoGtn43oWirfK2Uvy9+NqHcZt/dQ
OVt/G3H2pu7RCfpM/0YUqjn6BzWz/N+E0IZd8UmLiI5NKLnV+1GWN2HBJszZ
Yd12MY7xbwJn1KDOXXps/+Oh7IXWyJsNtL9o8lA6qO+Qto20v4AH/psGnsMb
2g95PDTATi46iO2XPFiN+G/Ny1iiS3n46vlscfUmwjIeRumZ3eNr0fhmXneE
1e8uyn5C+jfjeZng6eLgp6R/M86HHHyaOLyZ9G9G0sU1+/ouekz6N0N927Vt
muMekf7N2Oi3SmxjROOlm/Eh/9SiVxeekf7NuNNLT/fAGKI3b8b9NNUzZX9I
H8cB7SbHDJwvk3xNB7yu39De34EwHLC2ZfTNnjlkL88B5dZ7PJWjSL7AAbnb
trUv7f2c9DtAfNDc71cjyZc5IObc3QfeU4m/2QGrlkw41JZL8jmO2OP78HVU
EfPfEdmRC3/Oq2f6HXGQl3YqJe8h6XfEM7Ghb90hwgJHuAlqx52bzObfEXVj
3k+odWTz7wiRy6gCIzXCzY5Yszj3XUUgzR/HCX0T0j9GKRFd0wkjggtuXCqi
fIATFDfNUHP5QecRzwnj71bYmlcSFjhh6PvG8tODCEudMCR/VYVqLZ03Mids
f5k22uo34WYnzJIEXpA3JvkcZzR/3fu4fCTxazpj8Tn1D4a9aTyckd16bfyw
3DrS74wegy59tE5l+e2MQO63jdy9tB6kzthapDrtZifT7wxJ4Pjfj7so35ud
ET9Bb33me6bfBS/MNzyu2UHyNV0wy6s9XNmO+e+C1atfO8vs6XzlueBBbc9f
C3Tvk34X1DmVXjxeT+OlLnAcvk7vagf5I3NB7Ysmf/v3TL8L3n15uddgH8WP
4wqTDI9hh4MpPzRdkT5/mdbXZZQPcMU459tZuwdSvvFcsV1R/mT/75TPAleE
19UeSakhutQV+aqytN+zX5B+V0hzdxcdkFB+NrvCIZo3Mnn1K9LvBnuR36gr
IwhrukGu59Z56uUtpN8ND7rchKumvyb9bohXb/h1NJCwwA2GESUmH++3kn43
lBsqDDma/Zb0u+FX8hr1ysOEm92ga3XcQTf3DenfAv3mlYtW2hG/5hZ8cT3x
Mnw4YWzBndVtY5STmP4tuHRJKa1agfgFW/BmklbLsfEkX7oFrdOmKQh3Mv1b
oDvJ6tMl/3ekfwtenPCx1uhFdI47XOYp1JbkEdZ0x/HJomdFb0k+3GFoOEsS
wMbz3FFc1akTG0xY4I5B3unv7hwi+VJ3nM6LOyhqIixzx+ZDKwubGt+Tfncc
vGz/4tITpt8DGnZ1w298byP9Ht31sUvCvUVMvwcqv+nOMQ9k+j1wfFqW7dwR
zH8PZJ1bNngiw1IPxPAW7ZBISZ7MAytuKXt4KhK92QNVihpyl1qIzvFEoukB
A58xzH9P/O7KOWUzg+yHJ2zGBiyZv4YwzxMrVDfUq3gw/z1x1LfwRNdHpt8T
Zo3LN8t2Mv2eEPbK00l5RvFs9kRf09fyVgoUT44XuiaGVbR1svzzwuwRC3qM
yiYML5jU9TWfgJek3wt7KhUXNhwmLPDC9Umzd3CGUr5LveDzbRfGmbL93wsD
Y4wD43cSbu6Wf9JIpqRL64HjjdPfzzpXutB60vSGf0JYmK0BW3/e2Pm83PWa
NdF53mh75qqRtZqtP2/U+CYfUZ3N1p83tjcYczUPM/3eUHY+b8Hpz/R7g1tw
devULOLn+OB64Vpv2VGia/pgXui6EvlQwvCBXavjNdkhspfnA6fU4manYnb+
+ODq4cyyyGHs/PGBWUfOltPFJF/mg37p3nOjqug8afZB5Yh1XcXn2fnHR/3r
E/dDNtB4ZT6OciT9Do9l88GH5aOhj7xWEebykf3izxnDb2x++JjybJLioCmE
zflInKk7tq6OzRcf46t37xdb0f7G50NLb9YfNVPCAj5Ca2evqpxD/qTzsSbb
dMvxv+w85+PzhwU+nFjyL5+PvIqnI1RPMP/4iJTL317wnnANH1ul6hWTOGy/
42PzRzPD/VMIt/ORam/+wzeIxd8XViZ695+3EFb2xbeHEoX/RlN+afpCfdIA
j8PqhLm+6Gd1PXxbFmH4Imn4XNPJtwib+0L16kJzk3GUjzxfZAwsnnavjTDf
F7ax9SMOHyV9Al+8F8fNM7dm/vvCc49HWcH/5ZMvtNqeBKk9J5zvC+Ob9Yt3
DWH55YuEr77DX19m/vvCrcujUK+U1Tu+KCwfM2ncOea/L7alTVj5yYz4OX5o
Ebblh0kIK/thl9b6nxfUWD76YaxBbfzW2yz+fnhUpV7weCqrz/zwaluEz5Io
Fn8/JI8ocn85h9Vrfrh3ev32LZsJ8/1gmjqnauNbVr/5Yeg61ZPbu6j+SPeD
Yq7HksYbVC9K/RD2cfij9kSi5/vBZJCPfLEj8cv8sLKgxX2jA9Fr/FB8aPsm
RRVW7/jBYpDEQbGO9Lf7oWePU0fVXVn94w9lvdWiZWE0Xtkf9+5lPNyoyupB
f5wfZpG+M5/oXH+ceb5ires6Or/hj8hGxy3aF6geMPdHXGOfkdPnsnrBH09c
60O9d1A9wPdH/33LuT3EVA8I/MEdVfN2VQb5m+6PlXUvKyL6s3rCHzs0nxlU
jiX5+f4Y/2hA583dpF/mjxE6zz8/ukv+1Pij4mdnRPByws3+4JkHbJYzJPnt
/vA8Ua53dgerfwKQFnnbZN5zskc5AMamZYvvzSOsGQD371tvyLlSfcUNwB0P
pXO3Z7HvjQBkOJTuvZB6h/wPQNSzVeru8vR9xAuA50jjy2fW0fcNPwCuqTN+
PehL3z+CANiYTZwawyecHgDLlqP+OnPpe0kagAPxyyTD2mXkfwAuTF/yc2ER
fW/KAnA3ZZndpRvF5H8AClxk94pX0X1ScwBkXV8fz8+k77/2APw8u3yf8yf6
PuQEouT5OR17LtmnHAgNnx2d1kZ0n6QZCLmro9TOqjP/A+FwTL9hTBfdJyEQ
Pb8Pej74G9HNA/F9z/d3gnrCvECc7jXe6oUtyeMHYlQ2St+B5kcQiHm3zvXT
dCZ6eiD6TipU/+hE8qWB6Dd+RtxPb6Lnd9PnbPhe3IfqVVkg3v6VNy3UIFwT
CJHh259uhaS/ORCPs/wEAQEU7/ZANEp6X+qdyOIfhFD73DBtOcLKQZg+O1mh
4QbFVzMIliHjZ55cT/Zyg2Aw/O8UtxvM/yDce2p0/sQmGm8ehLzN6t/fzWb+
ByE71+3uNxmN5wfhycGSk12TWP0eBPX3fbflniP704NwZIlOZcVd9j0RhNUj
+mqn8Skf84Ngq2brFWbC6vsgyPyjo8orSF5NEDI/qBWKI2m+moNgY9551fY8
5Vd7EFqfrBzleo3yhxOMuV8GXpmz/SL5Hww5k0zj6sGENYPxOXJoa/h9Gs8N
hsTI4+gEOcpHBCPwpaqxkWc5+R8M5cpJfWODKb94wSga2CekNYLykR8M3dlm
SQtOUz4KgrFc99h/t6+TvvRgJJwcPKU4kORLg2F24eOTLH3izw9G/aG9x0a1
U77KgpGhO3zDqnd0/1ATDMPdyZsWDKP70+ZgZF3YcUUrnPkfjBkRczaHlLH7
gxBoG3yYa7Oc4qscgov2dhNnLCe6Zgj6vcrUv9GL5p8bglXCyf5HF7HvoxD0
h02P6kiKh3kIPJWmnGkOYfEPwbX19SkfMojOD0HlVcVf4w6x+4MQfL1kYXg7
lPar9BAEXLvz5IUd1QfSEAz51ld6QZXOm/wQVG267lfuy76vQ9CZ+7bMbynh
mhCsXerT6jeHcHMI5O9M3jh0NOH2ELQMzZw8/i+rf0KxY1BezVV5Vv+EomGM
UxH3FfseC0XM6EtRFi10HnBDkei2PMs9h32fh+Jdp9miJB+2/4din+rwAVxn
tv+H4tDcmQ7fxxHmh+JmznvD0HvsPjcUTUeWaHnJKN/TQzE5nlu5z57t/6Ew
HCkvPHaH+PNDsVhb+KtlNMVDFooe/rOabnvR/lsTilZtJbN3S9n6D8X2pgF7
/OOJ3t5tr0uUX4aE7pc4Ydhl6q5zfxrtt8phOJv49vMQlg+aYbCdfu5rx366
D+N201fxDHYsZ+s/DJtuaBo7DSa6eRhEA5b3ue/J9v8wvNww1txpMunjh8Hy
z5LhcqZs/wvD94lrayquEH96GLwzuxpWGrD9Lwzc1Qeu1QoJ54dh7Qzp+ppG
Gi8Lw94JHtfyTpG8mjCEHGrU8X1GuLlbnt3Km252xN8ehssnlIOm3GLvC+HI
uc47kxRF61c5HKHrpnDbNtP61QzH6Y5hjanqdB/LDQf/Pi/7fS67bw3HHrXN
Whvj6P7RPBwVE97U7/YnOi8cmtK+zkoewoX//A/HGjOp5jNn6T8sCEeiddbC
b/t2/8Pp4eiclHYrtnfiPywNh/LtaQ9qVoSR/+HoajBxHLJ9O/kfDr2iK9rZ
vvQeVxMO0+9OvY+83U3+h6Pxz473vbTo/rU9HJ+LqiJsT9N9NScCR+/3rXLt
eYb8j8CCp8uVtB/RfbNmBDzPmV4WPCd+bgSkhud6mavQ+xEicFd3efSzK57/
7DWPQIji/BW9S+n9jheBaRHjZ+7Vp/cpfgQM3/zp6ZdI73OCCGz8afn51t7T
5H8E5rl88+2tQO9f0giMu7ZSUz3y+D+cH4FZWTs3j7hL71uyCLz3ya5SPEa4
JgJeOaM2CfuRvOYIHBxnoWwtIv3tEajr67A4bQV7D4xEDTf7750gGq8cidOf
NbzUR+75hzUjYWe8s/+ngr3kfyRa1S93De/YRv5Hwvx74uHm0lTyPxIX1k3h
TEzPI/8jkTnuOleyn+zjRyLp4dePsTfJH0EkmuQummucyyH/I+H0eLIG7wa9
F0gjcXPOwczW3TT/+ZHwOrLrSckruh+XRcJm7vq1mevofKqJhMoQN75qEr2v
NXfb67B/+1jReYp/JD7fH7e+7Qt7z41C+jrfEYOKBBT/KOTvjVLZHJVA/kdh
TsspjaGrc/9hbhTss5R2RD3Y+Q8jCg7VOW/Mwuh91jwKAsV9pvc7ppD/UeBn
WxfJZufR+o/C4f+MTi00Zu8LUWiVGmrLKZXS+o9CYoHiV4sztJ6kUbBz2n0p
zYXeK/KjsD7FTc/BntV/UdhavPx1j2W03mqi0DmyIcbeLp/8j4LyCY/S5IRA
8j8K+kOnLbln/h/FPxrurbqaxz2PUvyjIbvs6bPi7SnyPxoY37Eku/kE+R+N
eRui99SH0vpFNPSlFV9m/6X5MY/GG617lgYckseLxse70zJF++i9mh+N6Vpa
4o6vZyj+0VjpcLlx3TLKj/RouJVVtMlrFFL8o+GV0f5xfGkJ5X80kr7Fy/un
0fu1LBoT3xhbTEuj9+SabvtunY45eIPyuzkai+JW/3yseI3yPxqp53l5j50r
yX8B5scrV38rpfdtBQGy5F6HpW67SfMhwHDRvZw4uZp/WE2AQL63Uu6I2zQ/
AqhxW04NdCWsLcCudqsZho1VNF8CtMs9+f1J+dY/rC/Ar3Wj/fQdy2n+BPgv
co+fxnmyx0SAm+rTLXpuJHvNBTBdcuDZFA/y104AG2/9AYr25B9PgPjD0e2m
h0memwDKE/J8J88keXwBohuf9dY/S/MTIsC7nj1Om+wkewQCrDr5op+XlOwV
CzBK61J25geipwuw4eaBdb3mV//DGQI8wiZ9YRKNlwrACfxRe2YB+Z8ngNze
gqqZbcSfL8CgulZ+r480vkSA9RMmlF0uIvtkAtzwn35re23ZP1wpgFPVssWG
lhcpngI83c1prNpO7/1NAly37qj9ICHcLECH6GDrkZk0H63d9tg+dzt0nPoF
2gVwuJg8zt2D8qlTgOfHJ6scaCF9HCFcywrThL40fwpCaK8O6X2qlOZbWYjG
gifNqmVkv5oQefsuzrk6nvzTFGLitpF3hifT/GgLsb7W8qzHf5RPXCGOpjlP
GveT+h/0hfAbnV9VdJHiCyGuWP3On1xwh+IvxLxhCvEXgijfzLvpM7hG16YT
thMiYv3LdzZFtRR/IUb3LTUIXXOX4i9E+VS/LYG6dRR/IeKHLwx8mEv0ECGG
W6heUThPWCBEklHi0WN3myj+QoCjFaK8rYHiL0TlYbtFzb8aKf5C5Ltv6LV+
A2GpEHOmNTrpHSJ5eULIl1f00PxM+vOFaJMXbkq6XU/xF2Lujds9PjN9MiFk
HQUKNQ33Kf5CDIvfqTmQT/QaIZbLaf3OVyHcJMQ7+d36za9Jf7MQ3pOGioxW
PKL4C7HZcefjG+4PKf5ChH9wtA12fEDxF0L6eIyh0VbCnBg0Dg5z4FmR/Qox
6GdwsVgznbByDCwO2PQw+UDzoRaDTU1b4wfsIbpmDEz/MwpIu0fx045Bx0rV
c5G55D83BscWRYnf3CWsH4PP7kdy31QRRgxE417NiFUieSYx6J+0d24PPfLP
PAYjX83c1Psb6beLgcLc9rMv4+5R/GMwWfpz3cz+hN1i0KaZ73FpJ8njx+BN
R48/j64Sf0gMwm6WRM3yp3gIYlD7+0WAhQGLf7e/71ra7+winB6DgP2SBxaB
NF8ZMRhdcMvwSQ+iS2Owfvcsv8CbhPNisPF13pv3o8ie/Bh80XdxDjxI+kti
sMhW69qNFLJPFoNXH6Yu0nEnXBmDvgfWqpxeS/7XxGDslCqDtAWkvykG1Ypp
NmUxhJtjkPPpfKrTFxrfGoPX14pMLz2lfGiPAcdvzofzk5sp/jHoOeyodeDH
ZxR/EazHdHVaKT6h+IsQuMhxiJ7xU4q/COtmLmlvXkP8aiJw3xROnjCd+DVF
8HMadP7+BMLaIhTL1yw+ofec4i+CbYjn6J8lRNcXIWKHmsxFhegQQTKC86Kf
L8k3EWH2PvcRopbHFH8RTmoP0siyJX/suvXxunZ5zSb7eCLYrxiNhWvJfjcR
5iutWJidQeuJ302/cmpXwECanxAR8hfIFP4MpHgIRJh7cF7H3q0UL7EI4lF9
cvaEs/iLsGPM00PhP4ieIULJxR9GrpOIXyqCZaTd27PraD/KE+GILZac+E3n
Qb4IFwqE/dR/svUvwrCMGdxLmYRlIggN9io0DSV5lSIsmVnfNPod5UONCOVr
O5SN00h+kwgTaz9fl3tN/M0iVOf8UrSwIPtaRUj3+DHpsjnJaxfBp33V5a5F
JK9ThAd3ZkCti/ZTTixuzC/pEBfS/q4Qi7KW1bxHg65S/GOhstr/SPETOl/U
YpF6+LWy+mI6nzRj8X3T9trbGnQeacfi+FXH4sHjWb0Ui+36nFxZP6pv9GNx
aUmu1hJVqrcRi+DffPe1p6geMomFXJjK0pxvVB+bx+Kw9OVZnKT63S4W+xYu
2GA/iuotXizWrd+erNFI491iYRa1dgLPspjiH4vsRf/Jr8yn+ikkFoOTTf3D
99H3hSAWf179yG54ROelOBZGV3fMXPOLzsv0WDSZGRfPOkX1fEYs2tP/Hliw
KPLyv/jHgutcYjVNI+ofzotFZ4PyV7fXx//h/FgsmX7tjaon3e+UxOLN4wj3
nKGsHyUWr14PNwspJFwZi7p+sp1D+HT/UxOLFRH+9sdL6X6nqTs+Gbeas5pI
XnMsTL+IeJ/tiL+1277Bk8SPIum+qD0Wu57MVQy6QPI6Y9EW116lkEOYE4er
wjtBchKqvxXicPRA9vvNP8h+5TjclZx07z2B+m3U4hBZr/JYzZi+FzXjwG+9
Oq/kFtXz2nEYN0/DZcQB+v7gxqHa807byQ6yTz8O1ytboutd6XsbcbCMmN/8
0ITuH0ziwJ1iLXsTQf6axyFl99shL2yJbhcHt+ARxueqyV5eHB65PtA7M4D8
cYuDQw7/ef/xROfHwaT+cn8za+IPiYPOvJgvP5pYf00chv0yLHYrICyOA880
+1rvL3RfkB6HjnL1Z++m0f1iRhza2x8+6t1E94vSOJxxeVV914DuG/Li8F3p
wbFXtnQ/lx+HrD4p+t+qyZ+SOJRnpu9vLKP7B1m3v+buxxLUaHxlHLZXTvIq
byd7a+JwzvjqyhvORG+Kw+lztva9Ktj3Xfd8Z9XGPRxK/rfGoeWq7Yqzh4i/
PQ5nL7fdrfxO9yWdcVDunD3h5Cd2/xEPj8gtxf3HknyFeEz+6T3d9AG7D4kH
P+BJmfMqkq8WD5epV0aqdBDWjMc7VaX6PzGEtePhM2uhS0QPwtx4oOP02Eoj
yhf9eJyuPZey7eEhin88uMr1qrbudD9iEg+BlVR46J4DxT8emic/6XXmUf+d
XTz22HucXpZO39+8ePQ4V9NVK6Z8dYvHRG3vd5li6nfjx6PAbeZsq1f0PhAS
j1lzDUMCdxEWxOPzgG09+pWQveJ4iFYO+5shR9+T6fHQV573X6k2fW9mxKNu
zecRAQ9p/UnjUZj2IOYlW7958TDZWPEju4jyIT8eP2+rn9Wvp/kuiUdI4bra
RxdZ/OOxZt+KS6J9lH+V8dBbr3JwnAnlV008VLeniWcNp/xrisfJ1X2dJknZ
/V63/qhHmYdKCbfG47xk6DfVX+y+Lx6fjn9N4/cj/s54SH7utwmZw+5/E3B/
UIV2SjVhhQRo+afmc5+RfuUEaOyM3pBeT/fzagnI4HGfScDehxJQmSW/t+UI
Ye0ETC7WmKTzH91fchPQo/hhtcNiut/UT8CTIW2O+aWsvycBDwwMrpQFkXyT
BOicC749cyxh8wTMzy1PbAX5Y5eAqpI/f1QE5A8vAVaZulZyTjTeLQFxg1Jb
jNdQvvMTIJcc19nXkfI7JAFe4j6i419Yv3ECNgV8Nf6TRvETd9sf2FepLJDy
Pz0BU4/f5ZQ00HrKSMC64dxZh09RvKQJOHqt+Gv/TaQvLwEpBTpjX9TRes9P
QDRnQERZMe0nJQnI8Rygf+YL64dNwKgnv853ttL4ygQMO5E47s8Zdp+fgE9n
R6S13iB9Td36dZ5fm9/G7vcTcGTj/i6DR+RfawJagy9dUDBi9/0JiDjeVTfh
BfF3JsDVSxKAdHb/K0bczHEeo4YRVhCDs/farVnzSb6yGHpvArdMXUD+qYlx
YnnfvqGZhDXFGCdo1Cgup3zRFmPNqRfDxu6h+HDFsLpsOWLmYcoHfTE0VxgH
2c+k+2yI4Ra+IzM0h/LDpHu8/wa9xCLC5mKsUm++PoT1b9mJ4RRx8vorLRZ/
MfpPWdrLtpDm100M24C5bqVdLP5iXD9V7DfjIOV3iBh2JnffnxhIWCCGx8lZ
7+KGk3yxGHIT/hM19iB708WwvHXs0eildL+fIcajdluf1XfY+5QYX2OuVxqm
0vg8MfZ5L7792pnyMV+Mnkd79dC5Q7hEjIpnhwUrUlg/sxi30q5qP7YhXCnG
melTtQ1c2XuWGHuyEvZ/NWHrXwzVt+PX2txg/XRiNEfWCdUuEm4Vo/XIV551
O/nTLobRi4sfFZzIvk4xZqY+V3I/wPrbEyF8XOnwdDnFQyER+tsW7XofQv4q
J0KzzNnBWZP41RKxuV/iW2ET69dLxAyVGV6HdOk9RzsRTambUvrEET83ESYj
FTfudiV9+olo3dzq/vcHez9PxCA3rd9rLOj9xyQRSS2zzB6fILp5IrYisOy0
C7232CWCa3x1AUfI+iETMXBRxtn2T6TfLRGNxYoSORfSz0/ErcCBsboTiR6S
iEvWMy0b3Fj/YiLU7lZJNPfT/iJOROqS/rk67hSP9ESYnRvfNvMhxS8jEXsO
HbR0WkjzLU1EYXp17mcrFv9EdJxRn579gej53fJHZx64OpD0lSSif8LKA5Ge
rD8wEZ5rF+0P5VP+ViZijECl5AGXxT8RFpX3f/ho0fimRGQXKO7N/Mn6aRNx
v1KS93wNxa81EemjY8wSNrD33kSU2HyOymTvTZ2JKL6kN/XiO9b/m4Rnn7+r
+AeRvQpJ+DAv5f0HOdYPkISXM5bNLmS/H1BLwuMd7sN6OhLWTELnw8Q7tmdI
v3YShMZRylbaLP5JCMrMVEx2JXv1k6Dcb+77ndMoH5AE061PPVJYP6pJEibf
blPorCS6eRL2XHtXfmwdybdLgq3k6xn7Sex9LQl2Kd+U5zH5bkmo/qRjqmRM
/PwkeM+47TTtO73nhSSBX7gy2KWd9Z8kYVjd9Uh71p8kTsL0fYebAsHeI5MQ
YZX+qfI5vRdmdM9X4jkD01b2PtlN/9K1p18h9cvkJeGu5aVNBg9Yv04S2uf/
UF66nt4XS5JgqKi1XGUT699Jgnlwr6HVJwhXJiHg5O2W4X6snycJa2Ki1NK8
yJ6mJFzf4NV2bCjr70jCxHzLiy+MyZ7WJKyXnyk1qmD9LklYNXPKCc5swp1J
aHRarFPK+mE4yYgPs05rNSWskIyAE/29Fg+n9aWcjLJPKiODdlM81ZLhlNzq
7ydHdM1kmLotObMpgbB2MtZOnJ69ow/Zx02G7qTisfFeFC/9ZFQ/fyCwnsH2
/2RkpbR5fvtN/CbJ6G151uzOBvLHPBkFg5Yuu9xA8uySIf9si09IEVv/yXgw
cUfRISfCbslAUZTxR9bvzO+mb1s4daA90UOS0bNsozBxCOufToa9x6y0wZ9Z
/JMRW6+3dIOI5j89Gbu3DHzxZzzhjGTY9IgR1bB+QGkyEh61pLum0fzlJUOc
v7LdvoW91ybja0TatmlVtP5KkmHkqTvbtI2wLBm/rG5utWyi9VaZjCZp5+rs
vayfIxmn/vwZ1DGE6E3JaLkkdyBvC+snTkae1nZhvwLCrcnYJq/ZdfcN7V/t
3fEpqr88fDHtL53d8e1tuqytF8nnpMAtzkE04wztfwopGGMerC6to/WtnILy
PqUOBmDrPwWdc/V6RnBZv3QKDMtVEjOEtF9ppyCZs8xJsICd/ykIarxqL+9A
/PopWKY5dcZuJbIXKbj5Y+/onr1ovEkKog5/zenksfM/BX3TXHJ+JJI+uxQc
T35ufuE88fNSwPHaETznNs2nWwqalFSuVBTSeH4K3sypiPn8l+SHpGDofOXN
1k/Z+Z+CE0rP1BMbqH4Sp+CGkuWsU2up/kpPgUrG2Opb5az+T4Gmyv531mOo
PpSm4Jlg7I6E7VQ/5aXg3tG1qyXr2Ht1CqpXqkYvec3qvxR8X368YO4qqpdk
KbjtPPqJugLZV5mCgPkrzN70IvtqUiCvcef0c3t2/qdATltvgOgmO/9TsH7J
AvGWXjRfrd36ez+tqN7Jzv8U9Jx/sHemNa3fzhSIRbzghgy2/iWI74pxOKdE
60tBgqF3ssbnebDzX4L7MWmDqwpJnpoETlVWG+6+Yue/BDHPdmyRP8riL4Fe
bdaDmMvkH1eCaZd65Y3OJLq+BLIXP4wyQ4kfEhy52liVfoT2bxMJZmds6zCL
YP0UEujq39w39hTR7SSIsDeLvfaS4s2T4GhShs3xpzTerRvnND2ee5v1W0jg
vbhRPvIg4RAJolRfGEtH0/4g6LbvZojazv6ExRI4vlg6sKOe/E2XoG72qi/b
0ghnSMDPWTtvji/Jk0rQw3h2R84csi9PgvU/LilGX2b9ehK0+uXK+mfQ/lIi
waV43t8D7qx/VQJp+bU5FV5s/5fAdEHo7F886teskaDhzXDTBkvCTRLMjVPw
d7/P+oklULEel2vfh3CrBKsurLwWXkf7W7sE7n3sfrz+wc5/CWJ39wx0+MjW
fyrMOQk3bAJY/Z+Kkkfz9g90pe8j5VT0CLJ8MXcQrQe1brrp+ltmEbReNFNx
1tHSSMOA+iW0U7ErVfR1RQZ9X3NTEdfg9GP3U/q+1k/F5eVcC8Wb7P4nFafv
22WGDCBskopNY/6+/vSG3f+kYu1Rp/+MXAnbpWKuYPJQkRJhXiqWaH8MTK+n
7223VNgULxz26zp9v/BTMcnBM3qeEu1vIanoaz1WoTyTsCAVriVPAnPkKV/F
qVj8PnD0xkKSl56K8rN/ZnzsIH8zUrG3xCB5HOtnlKbi14epE7UHkb68VByU
7My6Kc/qv1Q0nS3uc/845UtJanf8f8z0zyQsS0WQ/XfBFCnlS2UqJtjo/s5d
S/GqSYWDbi/noTE0vikVowJkGy3usfovFavKbrZH6rL6LxUfDu9oS77M6r9U
WDnYjCh6zNZ/Kh52qtbGGrH+1zR0vftjq7SP8lMhDecPbpnDYf1Wyml4WBkU
fruK1odaGobFC4Yk/N/vhdLw5ClXHOJEWDsNM+U2mO1j9RM3DdMkA/6+uEVY
Pw1bRi3MdeOy+i8Ns+w2SwzSn1z+H40HqBU=
     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzN/3H1slS9mzJyGEsYfwolQSRtKCMq3am/a9pmmqmWZaLCn7UAgh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     "]]}, 
   {Hue[0.08640786499873876, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlczF/UxydEWRORfSJkT1myxEdCpShrRZn2VU37XtM0zUwzzYiIrMmW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     "]]}, 
   {Hue[0.3224758424985268, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlYzN/7/8ceQhGKVJYWhMpW3uJZaBMlRSk1JW1apnXam6Zlpmm1JWuD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     "]]}, 
   {Hue[0.5585438199983166, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3lczN/3/8iWPYRsSZLKFlHJ9oxQUdqQiCnRXtO+19TUzLRnS2jzRqWS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     "]]}, 
   {Hue[0.7946117974981064, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lczN33n0iyZw/R2FIKkyzxiLelVJaSIiWmRdqb9r2mZWpqpilLKkmj
UI+tUMk+FKqHCklIoqSIQgjh2+/lfP749Y/X27nnnnPuOfecO/eez1Q7T7Nd
/VgsVlt/Fuv//v3717WC9f//4DNIQzp+dQz9vyIazr69cuZdxvW/WAnFv9dm
WnekEh6DLb2hv2JTDxJWhstYM/3b+XuJXwU3v9QpzZ0nJczGzkKdkdKaQ4Sn
ITvJxmHtXmb8DHTIxcgsdAoIqyFCPXT1No2jhNUR4ZKjXadyjvBs7JimvCr7
CIO1oPq6yMvu4HnCc/F0+4dsd34hYQ44R0p6Nq5i7NNGaKTAvCc9h/SfD8Pz
AeX7R+8lrAO+yLO3+4OQxi9AT2fJ9qAsR8ILcW1W7NCPJxn7FqFwTY/6hw+n
CC9GVc6pgtPHGboulP5cPbuhJo7wErQ8+7Qk1TqK5C1FV3myZPHZPUT/By2H
74sL7dOIvgySLTsmyKYmE10Pbzlfiru3HiP6chgOVqj4sWQf4RWY8q3TLkeW
SeOBbcXJsjzZ9b+YD6QZLb7f/KSE6CsR8CHqkaSziOgrIZxiPSnQiln/VRhQ
lLUubx7Zx1+FUY+Vr1aX5RB9NXba6KnydzP8q1GgGuRQzGfWbw0SLJZu9rhD
4/lr0Hzu4RMH+TSi62NvWe/c768Yuj7u65hVeGcdILoBKl1jLz8/TvbwDRB6
W/Ou7yHG/2vxKnvslX61MqKvRY7p+ZYzxox9hvC3P5NyUESYb4hB/bdn2VuT
viwjJG4LOH5GRvPxjVD/et+99bIrRDeGc5fcUuOlt4hujJavYxau0Swn+jq8
sVHYk8cvI/o6bLx44fzMa3eIvh6hrjtGTnrK8K9HXXbF+rrBpUTfAL/BpRoB
zgx9A7ZLa4LYp64RfSNaJ65V1ui4QPSNYBc35Bv6E2aZYGv2gJcpw4qJboLW
7+mJjb2XiG6KwhuCN+plV/9imCL7RNTanzokn28K3yc28jEvSX+ZKdSeWu4/
VEXjWZvgqVS4edsoWl9swqzxqnMMxxCdvwklPFam+BTpI9uEauPC0x6aFG8s
Mximp9+MBekDM2QfS8pY8JKJJzO8sbgxY98k2v8yM4SY78zJLWD8uxmcjkll
q5j4xGZcWbJt7EG3y8S/GXr1Sfvu/Kb9LtsMa/uWxxGFB4nfHFyPjnjf5y5/
9wfMwVMdd/q/rHjiN8duk4Fq/5qfJH5zrPdX7WlJJXtZFtDX1/u6Zyz5Bxbo
Eqr2/xl2k/gtwK/O2rFXk/wts0Crz8yWhZNvEP8WPBB1fbJYRvGELdgfHqzc
JSJ7+VtwtNbW74siY/8WBHpYa6xdz8TvVgyUU6j6Wkf6YSs6Ssevbq2gfMzf
itkz+q/5U3GM+LfCamvkA71YJp9a4sbXsBleB7OJ3xJD+005vnx/Bsm3RG7L
Pt15Prl/55NZQjZQM6Vj0jnKJ9vQ1fBC+EargNZvG+ZuWKU6yOk8yd+GH685
sX+WnCX+bZAo3s/WZl0hfitUBahNHrviKPFbody1wWaOJ8NvhW8zT2k+WXqJ
+K2wVGvK9UqNMuK3xsVr89aP6bxF/NaYyG7cmrKXMN8aSSvtAm+UM/KtMXXO
vy/j3xUR/3YMea41rLmE9MF2eNiUTr8vuEn823HTydUt2fwa8W8Htyy9/zEF
0odlg+Q6xfqoFKLDBgUJ9xWf8xh+G4x9YuZZk3yD+G3gYLF80deoUuLfAX7C
WKUmu8vEvwM3XqfxR9kVE/8OTDkyZPy6nbS+sh2AuTR5oZ4n+W8nDsVtvu3Q
TPUJO1GcPPJsvesJ8t9O+LX25/im0P6Q7USn3n8ZdW3M/uWCs1xV3erXxb+Y
zQVLsDjzdR7tH3AxurZ90QhQvHO5mKgxbenNGCafctHiemXstoD8v1jKxUqv
zYXlrZRvZFwsCubICYSEm7h46vY+Tz2dqb+2yH6x/Hb3NNKPbYvN2qs47Tco
vmELkwk39xoIqH5zbXHnxKep+j9IX74tZivebo0NpXwltUXV8gw113QmX9ki
qmWd/o3ESpJvi1b9GSrtx+6RfDu43Xq7Pi3gPsm3A45qmZR9qSH5drg+91D/
r8FE59ohxGxuBp9HmG8Hy8rbBz/n3yX5dkhO8Ut5yHlA8u1QrsXyu1xRTfLt
cKjXJL2f8UOSb49C2YGP4wOIzrbHB8tmkf7bCpJvD6f2It0B3VRPuPbwmDHn
ndZ90p9vD7Hdzu1JTf+RfHv4jv257qclYZk9Qv9MDZ+Xwsi3R1vvCfENc9Kf
5YANde3bd1qQPmwHXM8fKyuLJQwHDPV2XLy6uY7kO+Ba2pEJYSlE5zug4LLP
QdESslfqgLbK2q2p04kuc8Al3Y+Th+XTejY5wOzDRS3rXNKPtQsajcvWjVtA
9rF3Ye/+x/89PkD+xC4Ujp85/N0Hyp/cXWAXcU9N2UD+5O/CKq8GQ5cM4pfu
QrFwwueksSRPtguz38pq5uox/t8FBxXZkul7GfmOCJho9ef0AsrfbEcYSA07
DqrfJvmOGLV+t+GPgZSvuY5o2Hgxt+o2c55xxEz/tR+M4okudcT0NYP+qXMi
LHOEnOKFJ+nJhJsccQriFVvqqT6wdmP4NL2qD6sp/7N340pUhuWKRqrv2I15
6cP524tpPHc3Ovc12n5vZurLbiy+tyU7bBTpK90N93aX7lfpZK9sNxQ6bZp6
9Mg/TbuRqnw4tLCH1oflhJYGvdW1U5j4c4LlipsHx35l4t8Jax/qj/5tRfxc
J9yaqDlQ/jON5zvhqNG0c60RTPw7wcJS5wX/FeN/JwyyD3uyy4HirckJ79Nm
di+5ysh3Rsfu++9tDZn954xngRUbnkwgeXCGS3TzllP2j0i+MziaIwy6BPUk
3xneuXoT5eyfknxnVHS7trxaR1jmjIVXV95sHfqM5Duj5Bw+Kc4jOssFV5V/
jdJ9/5jku2CBWPhLO+wJyXeBTuNxhbsphLkuUBw7xilszAuS74Ke+DEq10c2
kHwXvKoqnZhjTljmAoUaB+n2/Y0k3wXjubtUBh1pIvmu6D49J9Z31EuS74qe
pyN/pG4mOlyxWPNB//AthLmuKFEwUZ7aS/PxXVG80epn/IvnJN8VMlkO++Eo
0k/miozpBwMWDiT+JldEZavuPKTJyHdDdZ3R9h/fCbPd4Lp108CyEEa+G4ZI
dkaPWcrId0OXrKZpQDlhvhtudgaKvINekXw3mB7VDpbIE5a5YdbOcbPr5pN9
TW5Id/89hjebMMsdZbb7Vs3tpPFsdxwy1jsTy28m+e44qHO52jytheS749xS
xVf8ptck3x0u3id1ysoIS91hzI0/4jDgDcl3h4dqRMDnme0k3x1q2vwbmvLv
SL4HFr5z3vgwvY3ke+DOU5vzmkaE4YFVz21XVFi/JfkeaL0iHVJk0kHyPSAZ
b/uPkRvRpR5IurMvK1yD6DIP7GN1uT/mkLwmDxjpNM68LaHxLE/w1L1fRSym
8WxPtIW+FdUr0Hh4on1e2ajhvxn5njh2deuYfSqE+Z6omL9JbsNp0lfqidvH
el/r3SMs88SvyPjgDdaM/Z6Y4qfgrHmeMIuHwBQFi2E6JF+Jh+D7iwWPqxl9
eChauadBbPX+L+bw0BQyIFPtxAfSj4crbt3BsYWdf7EpD1m3I65+vkXjuTxs
e7fU/t9QGs/joVSBHZr3k+h8HkRxGbPuFpC8ZB4OO8b33pxC9kt5kIazVm6p
Jn0LeOi5Peibol0r2cdD943HYptI8n8ND8Yn9CMSBhO9iYdzbt93jrMkehcP
es5DNnzTIszywoa2qtkq/QgreWHnhFfjJHUUb2wvWO7+PX3NapqP4wXbofLb
Ko9TfMELI7O19kePI/1MvVA/o4QjF0/rz/XCh7Y0BcFtovO8oOabv8R+AuM/
L8hlvGl3/U30ZC/4V7TEPr1PWOoF6Y09y72lNF+BF856jdmRrkx0Wd98CS8U
vcqIXuMFofhSfvh0wk1eeKlhOfhmOOEuLwwrVLDReUH2sLxRvmauT1kqYSVv
bLqRc7uilzDbG6NXrGhXPUT8HG9U2U0ZGfaWsd8bu7qvd8rtJbqpNx5M8mDL
b2fi1RvHWofb+18mzPPGooc3av1bSX++Nx7vO+na0UT8yd5ICTS+pFjE2O+N
mLr0qScmMP73xkCLH6KsACa+vfHHTi1S4xHRa7zRv7ldprOCiXdvfPnpsuOx
DWO/N1TGJ/169powywcxe9/lFV4irOSDaXE1Ryz/IX3ZPgh+MixYbESY4wPt
snUfhtcz+cEHvkNc/r0cRXRTH2xbfefqqEeM/33w8UfsiWNrGf/7wDS99OG0
UUTn+6DozDGtZgNaz2QfvN5tdY8dyuQzH7QY/+rWsid/FPhgibnm6LYiost8
8Djyd5XgFsVrjQ8qjKvvn7Gh/Nnkgw333hTsNCfc5YO40P+czzP8LF98HuGh
sciS8b8v1mrrnzM7ycS/L0xSe2Yf+EGY44u570e83jWGyc++sI49nvXHgPK3
qS8q3xqOfDmeMNcXrdHFHdc2E+b5QvuqWnlaL+V/vi/WH55mmziO6Mm+ONX0
cNv5FKae+CLiZIme9waSX+ALLfc8hdGVhGW+6I2aM/VaDrP/fVH0dddyfiPR
m3xRvqlxbPRDZv/7InjA6F+zfYnO8sPIquvXq7+RPUp+6JekvCfzFo1n+6Gu
pVTP7Aphjh/y526T/rOJ1gt+0NKaHz3cnuimfjgQKae0IIipV364tjPryrCP
hHl+aK5T2yYZRZjvh5yVPaPtCmm+ZD9obrNunXifsNQP0xJ7Uy5tYva/HxIu
5vYvPsjUNz8c9e9SfLuIiX8/xBhXexglMPvfD7P2Hd59w5joXX4Y6srT8qhl
8r8/JhhuVB1kSflWyR+/VuQrnNSm/Mz2R9U55Q85Y5j87w9vu4TEaR+Z+uSP
i84rPdWaiW7qj73tx1t/vKZ8z/VHZ7X5f9x2ovP8ETxdxKt8QnS+P5yN7x0e
2cPkf3/4GNSv2f+dsNQfjbnuLTpZxF/gj+uVrUrdZwnL/CE7e2LP4k80vsYf
cb80hy1qIXqTP0qXtmZeEBK9yx/5H6qj7m4kzAqAXpxndtw2Gq8UgJkLp0kG
vyL72AG4KcpxncVl7A+A4taNg1/bED8CMLotq2QWw28agOaxz5Zsm8/YHwDh
lk/D386k+XgBsHqWN33dcML8AMwy8ksce43yR3IAnPMmzx4yi8l/AYDnsgc8
JSb/BYAzI07VmKknsgDc71iWfvALk/8DkLr7tJrnesb/AVj1dkiDiRvFS1cA
3Dfof+8ewuT/QBinyN/WSaR4VArEmWyrRrVSZv8H4p+OqJggeWb/B8Jyybrx
I5ZSvCMQLybu2OI9gOimgRBYlnC4S5n4DwT7QHmvow8T/4Fo/OOhO5DZv/xA
fM1eJDn5i3ByIAJXPWt+b8Lkv0C0TdF/Nesms/8DUXcvbsrD88z+75v/Z3Z3
TDeT/wJxIXea/fvTxN8UiILaj97Rc4jeFQjbXcbyo5jzJisIio0OZpXTCCsF
YTbnoLpGHHMeDYJS4uUjJscpP3CCcMW/tvZUHpP/gnBqTnTzJV1m/wdB4den
2k+bGfuDoGbhHPxEjei8IHx74Wm0kjlP8INwzXZTTM8eJv8H4VkIK0HxM7P/
g/A8N6P9hSPRC4Lw6OyCN8azmfNPEIYqPQ07c4/Jf0HgqmutfGPH2B8E/Y0f
b3+bz9jfp39tvuUFB9KfFYxJsgXR+hOZ808whlWEv01kzkPsYPTb83b02CTG
/8Hg87ZYdf5k/B+M8apKL1b/IH1Mg5E+hntSxtjDDYbU8bu8eSrFIy8YNzVz
ZUoLic4PxpHjJpXffjL5Lxhd7QoKizsY+4PBKp5+dN45pv4FY9etj11PmPiU
BeNFcOeaJQLG/mCcHHBkYfBAxv5gTF8rsfG2Z+wPhqnSMPW7Vkz+D0GG4ke1
HyIm/kOgN+bLypLrtD7sEBQeH5C0QI3igROCG5tuxW0cTBghsAybHn14D9Uz
0xBULeXGTulPmBuCy6cqdg9Rod9LvBBM9Pnp+F8Z8/stBHv8vCWfouj3YnII
XAqP/dCfQ783pSG4y9f5k7CP7l8KQlC8NE2vZSv9XpWFIC1lPN/hEeGaEPCf
2hi8tKf5mkLwQ27pKHEE/T7sCoHGuTGGcm9oflYo3lvtdqvpod/HSqF43FB5
uz2cfl+zQ1GQLy79pUnzc0Ix8d+7HvlWpA9CcVc/NG5bJo03DYVmT7DHUC3C
3FBEZkd+195LmBcKQUR5iG4bzccPRZRu2KLjEwgnh+L4utk6AZ6EpaFQ0P4W
fegt/f4vCMWIY48bDn9l7tdCsXGHxiCtAUSvCcWiw2E1n0eRfk2hME8Wa/ab
T/N1hSLFXX6O6gIazwrDwM5Xx0W+hJXCcP7fdgu+H2F2GKR3WmUFr2i9OGGo
/vMkJk+B7g8Qhj3B/ebNO0nYNAw5SaIHV6/T+nPDwDaJWj+EQ3ReGNzMr19W
riX9+GFokVNd8keR1j85DNycc7Fmtsx9RhjaHL8563cy/g/DgTuXn2rU0X2J
LAwVssrMhgmEa8LwaINy/TtuFdkfBi+znIta84jeFYZDjfIpGv7M/V845mcP
rtG2pfscpXA8G7KitbSZ7mfY4Yh/x5O82kyYEw6L1QFThzP3RwjHoGEfDpc0
kz9Mw5GqdLs8yLqW7A/HmdOqidmOROeFQz286ml3KWF+OG4XxWfY6tF9UXI4
tMNSv3yaTVgajrI0wxsLV5C+BeHQ5Ey513KC5peF4/dH6+J1deSfmnD0U23p
0jtB/E3hUKy3yYw/SeO7wnHjnzuKX89TPLIiMELiYBoynLBSBBTXD0j+2cjE
fwSSfPYeH7SM/MmJwMY7L2+W5RMdEfhlP7PH35Lkm0agNTgzszyJuS+KwK7S
cUXLvMm/vAg4ZCnUqbSRf/kRqNz8sWtGO+P/CGx+N8DmylzKD9IIbP+3ZOGu
WyS/IAIxLifqc1SY+60IxN30TWu8RLgmApFHR9xSiSLcFNH3e/RFTaMF6dsV
ATUjNbOCtbQfWHwc+Wo9aespwop9ONe6QMxgJT7mJi97LUkl+cp8NNTKSU9O
pPnZfMwWXnptJU90dT4m/ZzxXO8as158rHrumH6snvKPLh9WPm/S6gOZ+zU+
8r6lfe4/muLbkI/t70YdnenL5BM+5sk55dYtJH5LPtJtDxxpZ+7XuHz4Z+ad
UNlM2ImPowlzxLkSWj8eH70Vu38Pm0P5N5CPPwUj6ieF0ng+HyZ3ClYv0aF8
LeSj+K6j0yMx4WQ+Rr+4mnrxMPGn8TF1yJLhf4YRXcrHKJRYZj2gepHXNz+7
/k/VT6oPBXz8CG/U+bKEcAkfh9cu0nj7jPhlfMxvUd5xaDHNX85HU0VGv9ep
RK/h40mvvkcpcx9Xz4eyc8iQ6yHMfWKf/kfF2RU5tD5tfEwcFOtp/p3J93ys
2JDEWhNP94E9fMSrthRbvSF+ViTeNcaYXlUmrBgJlT+jD81eR1gpEqc05CoP
M/ehypHwVFC9W/+M8X8kWszrk3e2UPyqR4LHbk1K0Cb/cSIxQjelRns58etG
InOFoop0AMUXIhGqtGH9HzHNZxiJMetEL+9lMPupT59Nngf2Z9P8lpHQuXT5
n39aaDw3Erkjs0y/iGi8UyRW+QbUcfyYfBsJu8yXG68nEz0wEk21L3xsI5j7
40jcUbMf3skhLIzEmdHLl95l6mlyJJxedSg4LiZ6Wt98t3wUXQ8SlkZiMJZ+
MKomnBeJlx9Fbf0ekL4FkdjXyJkx4A/NV9LHn3QhL1+Hqd+RWOQunjKmgOK/
PBKnT/+c2smmfFUTCf/TUbzpGYTrI9G7o2H/IQmT3yJRGj8nPHg44bZIrF+1
9cD8m0y+i0T+o8fih/6Ur3v61st25PyNrsz9exT+rLNe9VWF3pMUo3Aof8tJ
3aFMPYjC8tzLRwJuE1aOwiXTpg3lX5j7+igotauHa8yhfK4ehX7LRj0bIkf6
cKJgfWF874IhZJ9uFByKu+wzmPMEotA5rvxSPz1m/0fhV8K3xc3zSX/TKHxu
1aje8Zzmt4xCw4uiixtuMO8RUai4aF3Z1UHynKLgmh07tzaXMK+Pv6Fo7SI9
queBUVik/mvQhudkPz8KezckFhzJo/cgYRQmLEt4MXo3vb8l9+m7/3xCzCJ6
T0mLwoiLK1O2ZxFd2mevw+PAAHV6f8qLQtpYry/7mPeqgihcsKqsfXaIxpdE
Idqg1XFtFb03yaKAsE6VU8r0nloeBa07Rgnb19P7Tk0UdqSaODtMJnp9FHLy
8juuMO9NTVFYOHK3Wcgzeu9si0LKtVT7H3b0vtsVhcKI3DvfQqnfoScKXP3g
UGWTf8n/0ej+8UR74h96v1WMRleRYaSvP71vKUXDIzhWbHvsLPk/Gn7nFUce
fEHvc+xoZPU0tJ7VJ3nq0TjqI1VzZNH7LicaZTpZ1le+HyH/RwOP2zh3S93I
/9FQ/DFJ60zaqet//R8NwysTPOtT6T3ctI9/hsV7SzXZX2wZDZWDz5qneZX/
xdxonDHyWqOoRdgpGrz5LoVZc+h9nReNtBnCuiM/6T0+MBphrzNLMu/c/ov5
0Sgqq/H8eZawMBoNy7/L9bOt+YuTo+F5NvnPCb0Hf3FaNJas9tbv73/vL5ZG
wz3NaFzhCOpHyIvGgKLMQ81nKv/igmj8CDnvlzeWcEk0nu771Ok2l/SV9Y03
M90p7SR9y6NxN87vTYTPhb+4JhrLL83R95cnen00shfdOhj3lfRtisaghyn5
eVMr/uK2aAhPHsqKWn33L+6KxtDKc5H/PiD9eqKxjGWRe8vk+l/MioGKeG35
Ogmtr2IM9v4ZXT98BK2XUgyWte2/+6yYxivHYH3Sr6mjFamfgR2DmI6FgbsH
Er96DEY/jx5vuY76LzgxYHm9+PdAENmr24d3VRdPmETrgRiM3DmEn1BP+hrG
YMF/q9bcVaPxpjGYanJxeHQL6WMZA8lN8TfjErKfG4OONyerJscT3SkGd6Yp
3LuXxfg/BubPud2PMkvI/zHoYp1d8K7oMPk/BjM0VgkL51P/nLBPfizLOH5o
Cvm/T9/mzRkWqaG0/2MwQX+R5dyf1G8hjQEMDU4f+U79QnkxYK+y471wCCb/
x2Bi89imadUJ5P+++Y53vL34ivqNZDH4dSkkOUKe+mnKY+B0ds7p3GPUD1MT
A5lKTcGE8dTPUx8D8Wq1RulO6k9s6pNXcuvcwCLq92uLwT8nFPyDl+aR//vs
PWswcr096dMTg5aDQ3eOmkLrwRKA++lC56avFG+KApw9O+hijeJV8r8AT1me
1S941N+iLMB6OafEVw9ovdkCfCrYmr0i+A75X4BlEUuVN0SQPzkC+M951h1Y
SvGp24dfm+YrxpP/IMDoG4dT3/oSv6EA8090Cef6UXyYCtChzOLMuEjjLQWY
/H3Rw8Esij+uAHtM7smrLCXsJID66+Ifeyso/ngCpF0MX8e5RvMHCrDp08tk
o2iany/A12srjRyVqmj/C9A+TU8p9l/a38kCzJijelt68CHtfwEqfFt2Lv5O
+UAqgJrK99eix7W0/wWIGR6rW5BIuEAAyylc8TSjOvK/AMnLoqtr9R6R/wUw
n+gQ/rWUxpcL0Hpm35Kw34RrBMh77nXUKYHk1QsQ3jHzW3ki5acmAYYaflux
8DXp3ybAK9/vTdsXEL1LAJHp0+ohKffJ/wK8v6fwYZk+0VmxiPw+S3a6mbBi
LI50V+lr6VWT/2OhdbPrclEErYdyLJoP1Ats9pM/2bEQD1/wqfw7rad6LHov
X2Pn9pI/OLH4p+ukrGgPxYtuLGIMRKfDVzP9WrF4rORgZ9uf8pNhLDrOjVG/
PI34TWOx/wXXPf92Ovk/ti9/jMqqG5xF9T8WaZ87LD5ep3rmFIumu9zZFsOo
X5QXi0qHKd969KieBcbirdujr/7mTL9nLBbezVM3fEL1ShgLnyeZ0oxxVN+S
++z9/HuSXgTV37RYTB7WPnLYK6rf0lh8qd2w61wN9V/kxWJe2r45lwNofEEs
2gebs5dnEi6JRZT2wDWqjUx/SCymdgd/fmhJuLxP314D9VF11N9Y07deA8aO
Teyk+lwfiz2vBvXu4VM/VFMsXkx/ubBrMtXntti+31Pm95ZZHqf6H4vGjcca
Qo/R+vTEYnPBlPMeWUx/axxCnloWOC89Q/U/Dh0rkiY6+hK/UhyEC/Jm2I2i
fkzlOPS8zXiX+o76pdlxGHRo7K7yndTfpR4H29Kt7R9sqH+FEwfz3xqTE7uI
XzcOBpmrXdsXMv1dcXDS+/ljbibZaxiHdQuMudeP0njTOHiv215SsY/6Fy3j
oGgd5LnuLdnDjYMy3zFmwHLqX3SKg+mZtJyZLym/8uIgZmsXmdomkv/jcFx+
snB0A9MPG4fzHhmV0ROp/1TYZ//PCr+sMdSfmhyHqKwP3JxGoqfFYbnLvppX
IqbfJw7J/m/c/ErovJcXh4jrHxefuUTnsYI4fHGeteq0Pp0fS+IwKivC/ewv
ph80DglOodsCAun8VB6HtWdPDNy4muTV9K3fm1x39iPm/Ndn78yQXrdW8l9T
HMLqR4c3f8wj/8fhU+yB3sKhh8n/cbgbM2WK3uMU8n8cmvaUqt40sif/C6H7
zG34Qh0B+V8I5aKN99gVdF5UEiLwo5fclEVUj5SFCHV4lXpuKp3X2ELc1lh6
hjXwX9r/QiQ3OxrpWVC94gjRtdDAcaMj0XWFqPlVe8r56hHa/0JwVbMvJJ91
Iv8LUTZToTl5PdUzUyGuRSTHG57Kp/3fp4+T5tg1XlSvuEKserhS+/O9i5T/
heit+1asdZn04wmx3ian8bOY6mWgEJkjz9YLJ9B4vhDta5oFDr6Ub4RCmLxd
X3V4N+WnZCFWikdYTF1E+StNiNmF5zllT4guFUJvRqO56VY6/+QJ8V/M3o0d
odRfWiDE6vOnLTk51M9ZIsSzWfUXDZsLKf8L0VOWGraw/0nK/0KwprJPDbai
7wFqhCjxWuYdzY4m/wvBf9d9L+PftZT/hX3xWha94W4W5f8+/dxmv/NMOUP5
X4j68gbYKNJ5pkeIwf6cbuPjTP9zPA6Vquwa+JX2k2I8xNruPztLCCvFY5le
gtOAPZR/lONRP0AtUz0niPZ/PLrqeGz5e9QvrB6PtFMTxlRVedD+75vPbPyq
oDPkD914TDdrn+4WTOuDeKSm2P95cJfOP4bxmDF3t62tgM4vpvFQXm6gfamW
R/s/Hu6BvnWCxbTfufFY+yTAxOor5XuneBg4pdUNrKLvE3jxSFjjXvV4K31f
EhgPqeStfZZ6PPk/HnW6caL0YPo+QhgPOMl1p/6woP0fD5enmCkSUP5Ii8fd
qWOn3XxI+knjcXzom9WzBtF5Ki8e8iYeDjFnCBf0rZfW+MqvQvJ3STzWVDb4
CdMPkf/jwa0e/PJEDtlTHg+Fa67Fr67lkv/j0TLzyS1ZB9lTHw9jG7VpJkZU
/5r61vvdf7nafnHk/3ioTQVvy31az654NIau2fFMSLgnHqwhVo61BaQPKwGV
Jr8zBWcJKybARU7S1KJC5z2lBMjrfelM/0T90coJGHppr4LbTurPZieAI9+g
vdqA4k09AVXDhn8YWkj8nARsfZFvOsyG1kM3AYqpxo4L/6PfE+iTN8Jv44vX
NN6wb/4LI4q2vqJ+Z9ME1Jharj2XS/pbJuDUVZOXP/iUD7h9/H586x1rqR/b
KQFZpVsNupeTPF4CuoclLbzbQfknMAFnNlvcvMf0o/MTsFfeXmOD0QnyfwIO
TrnO4t2l/ZqcAMPJpqMjvu6h/Z8A39Xr5hrvoO+TpAmIizP5MCOf8nFeAk6s
bLp0Ovs05f8EtOy7JNysT/utJAHLXu+aOVuf8rEsAbF1Oy+96aZ+5vIE3Dgw
MfNpLfXz1yTgqsXEnxXvqV7WJ+DsK5uV/WLpfNKUgJWWde+m1hFuS4CV/4DJ
PsZ0f9CVgBKJ6hXZU+ov7UnAryz5LsVYqn8sEQ75uC+sTKH6qijC3dczXqj0
UjwqibBbKUDjl4z0VRZBddIu6eEQpl9bBKHxgasJRlTv1UUYIhp7wEyJ7js4
IkyJcPyaXkznI10RvPZkDH43gelvFsE4svPS1/50f2LYR/dJ+XIolOqjqQiz
53t6LjpH9liKYGZwL3B5LtOPLsICn45tZkr0fYlTHx408MytUub8J8Lpo8d9
bjbS90KBIjR81kyfOILqJV8E9xLJsvdMvhOKsJn3oCL4Ed1XJIvwbs4+5d/z
aD3SRHAJfr28I4m+T5KKoIZ8s4yLlB/z+nDRw+Os0eTvAhFMh65SfhQURv4X
IVla4Hltzxbyvwgzzts6d5dSfi7vG+80+fvojE3kfxHKNLt8D1+m81i9CLue
69yb+yaV/C9CZGHAvGcv6fzUJkLPAMd060KKly4RBgalPxh5gOKrR4SOfsLh
e8Yx35+IcWHWuSZFJ+JXFGPc9CmC4QHEryTGo4F7ZVZv6HyiLIZ86tjFfi5E
Z4txSnPQyzozild1MSoj144SXGPuf8RwT9+2WU6Ozqe6YnBSs9sd3ZnznxgG
zs9Wz1hF8WkoRu1va+9DhWSvqRjbOwyKxFcyaf+L0bNxmsmw4bQfuWJEPXtm
oziL7oucxBjetlg6dxT9fuWJsTfm8YKLh+k+IFCMtf0NnW0tme9DxBCpjf/u
JaT6LRRjYX/P8m/hND65T18DrxJ7U5ovTYywYdWNg4bS+UMqxoOvvge71lD+
yBNDqKuQEuRH+haI0W174GznIjp/lIjBHZFs33x0P/lfjIbp7D/jcsiecjGs
bw4OPVFD5/saMWTBWzfvtyZcL0aMKmu7y7sE8r8YThGzlmzcSvQ2MaZ5DfmZ
vJzWu0uMT5pnPXM/Ee4Ro8Btn8xrG/M9ZCLC901cFR5DdMVEHNL6ne2yhM7f
Som4lT5pqOtM2u/KiVhzIzJBOY5+L7AT4Twj8bKOCn1vop4I/u2yYU0naH9x
EmEwuFB1uAd9T6KbiAYrjUCVDxRvSMSCKn5WagbFl2EinrKb/CwFhE0TMTqv
eJZLF+ULy0Q8UZjcuIxN/ebcRLw9vWhizD46XzslomRkXpOdFtF5icgRqU04
eYrurwMTsUhHLnSENvP9RiKGVW7GNOb7LGEiNmvGTaofR+f35ET8GP4tRteA
9E1LhEfKsGfFWyhepYm4pl/qoP2Nzut5iQjWD8+Tz6V8VZCIwEG+pwWR9Hux
JBHqK7Wfvutkzv+JMBsceMv1EY0vT8SLyDfLx1TR/qxJROMHLZ2wucRfnwg2
/+2mBRNIv6ZEZHjcnPRzDeXXtkTEvX2k9VKVfr90JSJrq2jn9jk0X08iPJ84
ntGYwnx/IMHr7jUfJv9D4xUlOKWwJLjsM2ElCbzZkoXbXhK/sgTxht6js4JI
HluCNGn8p6W+hNUlCLoTJ1erQOvNkWDHyrwHG2Lovl1XAkvTU+cLDtF9OyTg
fFtQPcSB+A0l+GLkzuktJ3+b9slba2422YTeJywl2P10NS9zP83PleDt8lr9
9eMZ/0vQz790vvAErS9PgsO5uvbap0h+oASDLtyuOXOF+X5GAocwq2oDF3pP
EEpQsOj3rnWXmPdoCcxmbn74WZ5wmgTH7262aGXeV6QSNH7RrDWcR+8LeRIY
qpSt78hk+hUkOGg387J2C40vkWC+/KWvCobM+7UE9ZsezfUaR/OXS/Cg7li2
Qxbzni+B3wq3TP9u0rdegmNX3y9fwqJ4aJLgv4as+b0GtF5tEsyddOBKSiHh
LglWByy4taGaxvdI4OwcHNRPh+isJOT4ny1i5VO/gGISyocmVg9pJ6yUhGJJ
+dHcO7R+ykkoEGx9NiCS/MdOwvEuo2dIo/VWT8KSzJG8lniq55wk2K/Nr7ij
QfGqm4Tu31PiBSbM95JJUNy26GTOHtmK/wEjFJdk
     "]]}, 
   {Hue[0.030679774997896203`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzF/0HnsRki1bBqEIoQjRK1u2FmsbpmjROu17TdNMM1PTZg1hEIVS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     "]]}, 
   {Hue[0.266747752497686, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzF/0x8eePVuKMJaIkpGQbG8ikTKFFGFKJVpM+15TTTPTNiUkW4oQ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     "]]}, 
   {Hue[0.5028157299974758, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlYzF/0x8cekmTLUsaetciSLW+ksqVVizAp2mtatC8z1Swtk1DkSwxC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     "]]}, 
   {Hue[0.7388837074972656, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lczN/3x4dE9rJmz54kyRailySRJSRRatrTZtqnfWaamqVVWZJiSpKE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     "]]}, 
   {Hue[0.9749516849970554, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzO/3/0e27FlKlt5GeJctiYjCk7JlKSIRmUoqbdO+19RMzUxNi2hD
jCUVqewhNS1IQsqSPQqRpWSJLN9+1/vcn+v69Y/r0bnv+5xzn/uc+7xujbXz
WOugxOFwmrtzOP/v3/9+Whdw/v8faDnf86j/IqffK2PKOal5u3oqsQqsnjvk
qU87QjwML3u9Gz/Y6TCxOo4cuLVuypos4tF4NLHFLjO6gJiLXhU69ee6XSTW
hHLZLKnTwXPE41GBPZe9anKJ/0Xv6asqYh3OEmtjinjlFKtMZt8kFCT001ij
ur/kP56CQ5lzXGdfSCTWgTxsc95ZlVAar4tIkzWri2adJJ6OXPcPa0+dY/br
obrh1v5V35h8Bqp+HDhjqLafeCZSq3y8DiYzuT40v++/2SvxAvEsxHsothXb
K4hnY/S1umEeH08TGyC2I2fe82a2H3NQtHPipqC+KcRzkZtd07RNEUT2G+Kn
8d68N6kFxEZYZjOi4evEfOJ5+CPpE6o19TTxfNi9HLp+18W9xAuwsnDdmWtv
I2l9YK3DscaRvmn/yQXA6dHyp7mf5TR+IYrGxB3RNT5L8oVIt/XLXrL1OMkX
wW/f37T2KedIvgjxTq0DhyudIrkx9kzW0LHuQ/YJjPH+QNuJi1svktwEtkM3
mqmfPUNyE5y9c1JziD3zbzGEwY3P/mSTP4LFSCke/2fgjZMkX4JpJx/9Nk+l
9QRL8NWx0n3xFyZfCrdDYbK4WKZ/KQTnnu9N13Al/5fB/Ln9n5x+4SRfhs/m
yakNKqdIvhyHZrRVvKikeAuWI8j0bm6zdB/JTTFj7DTvKtejJDeFdeJxg++q
2SRfgU03jvZ2OplJ8hVwPWhRZKuZQvatROv94H4vVslI/0qMehremurCzvMq
XNyWt/RWehrNX4Wf868Y9wxn52M1engveV8K0ifo4vSMe30DdpHcDMrTrxz6
G8TiawbtJ/dcJ8xk+WCOMtPXSwIcU/9jmCM6TX9NSnsmjTeHwYqCUqfjkf+x
whxhH+4Ktd1FNH8Ngsauan5aJ/lPH9YgzT06WDQ5jOavwdFG7Z1KzTE0fw3O
zara7RSQQPatxU7DQVWR5Umkfy1yrz4KU1tI9gnWouDKhLBv3QNp/lqEVF4d
W3l4J823wKfPL2Y++XWG9Fvg+YKbW/XPUL0RWOCB+6iWxY7F/7HCApaaO+NQ
V07z18Hm0uE3f/5epfnrsPjL0Rz35yQXrENuGL/kxZ9LNH8dzjw2PKSWT/Hm
rEeHf0UcV4XOB9bjW9Pi9pdjDtL89eCGHB5zKS6J5q+HxHr9ncbf/rR/lkiz
GVLn3ZhM/lui49c7s23bZTTfEgVmYbs04+1oviWalLRMz3uJaf4G7P89VUlr
BuU3NkDFVfHyHyTS/A3wvLmxSHXDIZq/AUdiHxWdH8XqmxWMHj6d+8WG/IEV
LH8deBP0nc63wAqnckYlys7upvlWKJqTO2bAF3b+N8I8yVn98Gg639gIvRs9
3Lf+K6L5G1F/fXy91Ho3xa+Lvcp0IjQiyP5N2DT83q/7Mso3bEJAXnD+hf20
34JN6NZnY++O1kLSvwl6n2euuXSC1U9rfNPdHX3JkOILa1yPmvLl7xOqvwJr
aH/R2Zbcm8XfGh9H6Kz8XM7um8148PiP8Qd7pn8zdEafvtn5ieXzZoRe7V+v
PpXuG8VmfPHPXBc6meX3FghMll/Visqg+VsQbiaKDN3F8rGLzZtQt5/kii3w
am+Z8ZabTvNt0JL+bE70ePIHNvD/u/PZ/VJ2fmyg/fhvXpQxyRU2UK3P+mA4
jt03W6Hd24r7cxvdv9iK1bvaK/Ycp/wQbMV7dc2dnDNULxRbwamO6u4vs6T5
PMj77b/41o7OD5eHacEH9n2xpPoOHhymTFD+XkL1k8eDwMkmRRDC6jEPxeKN
2vK9dD/IefgzvPBn+UGq5woeuG7rnudtKv6PG3jY9vqw89yzZRR/W1x19w7/
WlRK+m1R3HQwe87Ia6S/S/469XqEbQXpt4Wg0PDiPM1y0m8Lq5/rS2YeovFy
W/TuZfWram016bfFlkdLsvg1laTfFn7iy4uWBtJ6HDvwdc9lntWn9bh2KNp3
foTxnauk3w5jU+P05v2+QvrtsKxhaHrQbrJXYIflm11rrebcJP122J56/YrN
CmKFHVxMXQXJeVWk3w7yOxHeK/XJPo49bJL/HZ2tT/Zx7dHkK0iwjmP+2+NM
W82kGXFkH88eDUvOB/7Jof0U2CM0zu3ESHfyR24P9117ysIzaLzCHp+DW+Zp
1RaRfntY9h2oatOb5JxtuP+rBn9s2P5vg9b1G8unDKLx2IaO82s2nnS9QPq3
od5oipdp/2OkfxsEZ3YPy86n8yPv4kvzCk9MpPtHsQ3avAXzOz3o/mnYhvk3
8z/O7c/uHwccCe6f/C35+H/juQ6INlXz+GVG+QsHnIsKtY5SpnrAc8DQ7jMy
HbJL6Xw7YMbH6/2bOkv+Y7kDHK9fNkmX0nyFA353i5adP0r9V4MD1Fwdh6U/
ovGc7ZgxPXD0xQZi7nbUq56J1/Ng98F28NKfvOpecYv0b0fChnWxa1xrSf92
9KitcDs1/z7p346Zyd3+mDQRK7bDdH3hLN+sh6R/O5pdv4WJvjwg/Y5QnXs5
wsSCmOsItTc/Jl7xoflwxNg3hZeuvL9H+h1RvGjSMZXDdaTfEZsH7PM0ySS5
3BHVK9t6ZXerJ/2OqOT/bDF+Qes1OGKGVUS7+3kaz3HCzPeXmge6EHOdoNJ0
Z/Igc7IXTrA2LMwp+sT0O2HW3uFT9kjJXoETbET7NMdqkT1yJyxxsvR4rkf7
o3BC+ktByzuvG6TfCeOsNG7+mlVD+p0RevnThAF+xFxnuLb86ah+RwxnFInt
Ug+w9XjOOD6nQ+O6guQCZyy1+VVlf+oO6XeGXf3r3eYgVjhjTv0Zc/0Td0m/
M7Raxju0fCV7OTsgPPbthVk42/8dKBukIay1o/3DDtj8VSy+qk3zeTsAwzlV
T42Z/zvwzqIwrVTxmPTvwJem767P5jwh/Tswc5/nnza3p6R/B1S2t2lu6kvM
ccH4kkc91kc2kH4X6B0Z++hhPMnhgrqgFN7qySTnuaB/8Rb9yp7PSb8LBn+4
vEE+7Rnpd8Gs9MXI+0nxU7gg56O+etkuFn8XxPdHfd5Tdv5csW9+ruWHchrP
dUVkwKWzu/QekX5XXAvhrx9uS/7xXDG2u94gfRtigSv8BjVeTyml8XJXXH35
7Cg2MP9d8cHJLWWGHtnb0DV+QnMrHMhejhvCZinFtWwh5rphl8i1RdfpBenv
4vXjjZ/9JDnPDRKHj9Wyo7S+wA0bVn8vfXaH9kvuhvrt0RXqe2i8wg3WK6It
Fh4kbnCDc5/fqybK2P6740UOj/OvO9t/d/zuqOBe30EMd1RUl5xXqSL7ee4o
jx2mtlyF5AJ3/DSq7ZixiuyVu4PbV8x/PoDkCndc2RxjKCpi/rtjAj8rqyyF
6fdAmnfLsB4XmP8eqNnxN/bdahoPD2zxvbRxxGkaz/PA1hFjrv68zPz3wIDF
1bfP5bL4e0D94Ytt3tZMvwc+eAmLdVcRN3hAc7nl2lfziDl8hPzMSKheTvNV
+Jj9VRb9zpLiy+Uju8NRWWMixVeXjzTNwwPe9ic5+Ggbdb1ozAqyx5yP3NqR
jb6rWbz48JmcvTZyIOnj8xE/SP/yWHbeBXyc3H1+nPAU7V8iH4mX2/aP570k
f/hQGy+tHCZr/I8L+HBWedQca9xE/vERWfhYfvsscQ0fI/RnO6atfkX+8rG7
/X3Zej/iVj6UU66fy3Kn8RxP7Mr+KDm8nFjFEyrnat+MMCb9XE8UnKrdH+1O
+nU94RFuk/SrhuTwRGWukuPuGGJzTyxwr2v1M6fxPE/sWzs670sdMd8TD23n
WOZnEAs8kTe3ZL6ulOYnemLR+bnjyyVkj9wT6ma5r3YZkv0Fnjg/6F6DUhjz
3xPa3b8LJnxi/nti9eCKuYtHvSH/PfFv2TWeXutr8t8Tr+XGxefkxBwvfPsT
bpEVwfz3wq3EnhGShaSP6wVH0+o5B+OJdb1wZIQg+cYeYnhhfn7U/kJbWs/c
C0r1UZXXC2k9nheGnLWp95hEzPfC0qZzw2PmM/+9MCtw2O1RN1n8vXD7vf4r
tRYWfy+ULo6qshhCXOCFjml5s1930niFF3ynbpjN0SJ5jRf6ZQ1dkriQ9DV4
QWC6MeLkApK3eqFg+RhP0/M0n+ONiYN1tn8MIlbxRs66MgtuOKsH3tB4Pr7a
W0Hzdb2hpu+c/pjFC96YZZWofOko+WPujTE79CakrmHx90ag5peG+T1pPN8b
lnrC/d12Egu8kacyzmnBDLI30RsFazNf6LXSfLk3ioyalpTPY/H3hlX3273/
2hArvPHHJ/i9vxbFu8YbJmMn7/Jc0Ez+e8PGa92Yk+9J3uqNs5tseOMziDk+
ODHzaemToxQ/FR8I0q/VKnWQPVwfBDhHjPW4zM6/DzJHGIXlu7D4++BKZt6P
dQYs/j7Q+Jx6s99CYp4Pjkwy7MENo/F8H/A/fNBfP5vWF/hgv1RTLWMl898H
n+xalTR+Mf994D9Z0bZJRvICHyjrJPQtvkz7p+iy74PdIq0GFn8fjLudvv3O
GeIGH6xQfl4y7i7Fs9UHe99s0LrUk9U/X1wtSnOymkD1VsUXww6pTerXSPWO
64tBYw1/ye7S/ajri/dVtT/Mh7P+yBe1wxaLMs3pfjX3hV77accfS0jO88Wk
+3V97dSoXvJ9Mbasv/zBbFpf4AvOw2lves6g8Ym++HVhxJKvq9l96gvehluX
Q6OIC3yhbDlcKrrN7ldfVF0f+iYunuQ1vri1oPjnuSzS1+ALVZHNy11jqR63
+sJHGPlDbxKN5/jhgGz4/tKNpF/FD401/Y9bTKf+h+uHuG/NC5vLqF/S9YNb
3iqu6nTqh+CHVL3A2hcTSW7uhwElxw7u0Wf9mh/2RS9ynNhJ/RrfDxU9m/qn
GlE/LfCDpUnK6XFDq8l/PzyqKHsQf/o6+e+H7t6Gw/LcSF7gh57pXxe1ca+Q
/34Y4Z0zrE9cBfnvh5L578rzT5O8wQ+mg2b7cfpXkv9+SH7UeOHAX2KOP2Zd
1Kv+Zz7Zo+IPy4+lyx803Cb//bFf9HtaZyj1k7r+8Ji/yvL1AxoPf+y7H5OZ
pkr+mfsjITSgpdae5vP8cTyij2Z9MDHfH5/6XfIsVmP9qz9ene55SahcRf77
w41z5lSTPvXLcn9UqNj+DPZj/vvD4UGAVfFekiv8scfGsX5HCflT449Ai7QR
N4bT/jX4Y8yYflX7cul7ptUf61QMzXcdJeYEoCC4dbxNLH1fqQTgmJdDyc63
ZeR/APYoc6SDl1wj/wMwor3W/oIlMQLw1Hzbh243ic0DMKt+5wn/obQ+LwCv
N3nobMwie/kBUP2ma3XJk/wVBMDe1/TKkTUUr8QA3H4SJfgxkvZLHoAqt0id
VAva/4IAzE2acu91NevvAzB9mGWB7nLaz5oA6MwYbvNqKskbAqAhze09wZO4
NQBv1nVTmjOf7OUEotfEPv4pufTepxKInw9/GGgPof3jBiI34sn62xr0/agb
iO32Ojkn5PR+hEAYdS6VxE2j82ceiJRJvY//6kXr8QLxSWg2/MxoWo8fiKHj
hyl3lpF/gkAkKMdOeLmI7E8MRM6NnCTrO5Rf8kAE5sYkKa2kfr0gEP+qV992
cCdWBOLNql6+x/tTvtYE4oiLtny2Nn2vNQRC9u2hnUUYcWsg3nGtk9rnUX5y
gnCutNT503nKX5UgTD4kPpw5kJgbBOvv/ncNn7P8D8I6hbVRZw2thyCUVRd7
CM6RveZBqNmw1LpnFfteCkJ++9DN+VOpPvKD8H7A6D6XN7PvpyCkTxX/Hn2Z
7E8Mgtr02ecnFrL6F4QBfQb/PT6I6lNBENaozE891Y993wThkL4scVQdcU0Q
fOI8xww8TPMbgqCz5fkjPKX1W7v8cVmeO2kDMScYipynNi3G1F+rBCNpavXP
RXrE3GBsKD2y5eJaqqe6wRjIC5y7gfmDYGhMblr6QMz8D8bKpk8HP29h38vB
wIoL/zQV0PnjByP+2YBJeZconwXBmHd2VD/HF5RvicGQXw6yMu1F7xvyYNik
vx6n+vcy+R+M7OsmfVx7nSf/g1Fzy31ghAb9/1FNMGKMlNwXaNF7YUMwhu2d
ciPU6gD5Hwze27fChFXO5H8IVDeMnG/Zl94TVULwRFWpvuMV1QNuCEbNTjbs
1UznWzcEM1cGLRq2hPIVXfOX9kG3sWSveQhW/zPMf1oevdfyQlBUtmzH4zqS
80OwdIjcP3oxe78Jgfk+/8+VesSJIXgY3lis+ayI/A+BSfni95mHyN+CEDx7
mW1S7cze40Ngez7jw8lY2p+aEFx4fHn7CAnlZ0MIzl8RHvBqpPxtDUEPb7/K
nL3s/T8UK5VuLEsdRv6phKJzROCegmdUv7ihsE7seWj/HapfuqE49Gm59jVb
dv5DEZn8re8zfTrP5qGounLz6cQZdP54oZhcVyoOnELnkx+KsGdvv3dOofMj
CMXvgEzPo9PY/R+KBRbSFeJHxPJQ2Dpp3rE/y85/KOJNk/3HsO8zRSiuG/S4
ucWUuCYUbQs4d+yT6Hw3hOLuvMvRluz7rDUUmU+cDm59yL4/w3BElTv4Bpf1
v2EYN963ZoaQ9b9hmLO2+5bdA6h/0A3D3uGmKp9/sveBMHy/M7QpQYV9/4Wh
c/7guhYv5n8YQj71WcKdyPwPQ/XWSi0r1h8JwlCi+3mmbjbL/zBM5EpLrxbS
fsrDMGao268VH0heEIbpSj8PHM5g+R+GR7+7OydYM//DEDhmxLPjwSz/w3A0
qlZbakrcGobGlfdET3az949wGEjGnBwZQOurhONnv7fT4v9QfLjhaG/7prbl
Aev/wnFU6mmxZSrr/8LhoPejGjeIzcNx5f2LKo8TtB4vHOevLTW7qEX7ww+H
fdXJB1M8WP8XDrs1/AlB3ek8JYYjOy6yOGEOe88KR5LqtdihrlR/C8JxYNoY
22+Z7P4Lxwd3oyXT7Kme14Sj/kGNC1/E7r9wiP/dO+VNFrv/uvTX7tn+z2xW
/wW4VT5F0e04sbIAfxUOWaEzyX8VAXx8Uw1PPSNWFyC+7f5x05nsvUiAuyX1
79cLaL62AAEXtPXX+rH7QoDv6/XNPVh+GAgg2jh9QCZY/RRg1q3lNnONyf9l
AozsSPq0sj/LJwE+f2+ffLOW6quVAHMvzPh8v4z1lwLcXpZ70lyL5E4CvJr2
Z/Y81p/yBVBs7lWkcpfsCRBAK3nxntI29n4rQKuj07tyF9ofiQAno37d3KlH
4xMFyHkRe+SEN3GaAG0VS6pUTlL/JxdgY79rBuZ7aH62ANLOuPmBLqS/QICy
a5cWG1nTeSgUIHCDgWYPVj8UAlyrW55wuReNrxTAsOJYVEJPktcIoOQ73T5n
Fu1HvQBbZ5wVd3cmexoE8Ppl3LixkuY3C1Ae9Vwy6ATtb6sA+/v/6vtjPsk7
BHih+iT8dhAxJwJ1TTsF816QPuUI7Oz99fJOLrFKBBz7394fVk+sHoFTQ2Th
isG0f9wIhNzvoazbn9bTjoD24ienTrjSeN0I8Pb5rvJk961BBK6GyOfnCVn8
I+Dnf6vWPpPmL4vAp3unend/w+7TCEzsttszfx/5b9Vlz9G7brvXE/MiMHjA
jcHdutF6ThEQ3DHLj7hAcn4EjExM0le0EQdE4GNS2KZFM1j/EQH1nrNOhiVS
PkoisKQsp780jOpjYgSc92nYva0nTotAwrYSLfU37L0xAh4n2h/5zKJ8yI6A
/vg4jcVbqR4VRCD1YXNjwSFavzAC5cbWWVZO7H2ya7+5ukr8j1QfKiPwyG3s
5an9af2aLn9TDgefbaX16iOgVrtOa+kw9p4Xgd2nzv5bH0HcHIHMUz+5X8fQ
93Nr1/6l8g89cCDuiMDypk7+qLfEnEh8XH171MkYYuVIlNycfPDuHGKVSPhF
zwiX/yFWj4TFZrGygS97H4iE7Jev8qR/iLUjYaOfv+H0XmLdSExZc7ZuxR6a
bxCJCX6/1trEkxyRkL/yezZ3KcmXRaJXscGUAaEkN4/Ed5V0o+p2kltFIrn3
nb8XtrH3lUgcsXk8tpW9vzhFYuTLET1yn7P3lkj87Zl+IegByQMi0alm5Bc7
mt4jBJF4qeZZpuhBLIlEuLzju98R9h4XicVJg4w+9iJOi4S2PTfjexp7n4iE
k8GjM9yfJM/u2q/O5Zv8D1M8CiKhjKBnHFviwkjcGqC87Wg7vTcouuRNd4O+
Z9L9WxmJgqwVMo0PNL4mEnVhFlezDpG8PhJWA/LDj3iy9+RIuCqFzP3cn85T
cyQGBogneI5m7x2RyA4efW5+GI3viETuytdhbcHs/hciYfXJgSvziJWFWMy9
W1h3g/XDQjTY7fx2wpDWUxfiXaxgbP5p9l4tRN7me8Izz2h9bSF+pvX5KzOl
8bpCTIw1DY12pv0xECJj7ZBjqc/Y+5kQp+t5GbIqFn8h3mu97v2xO3tPE0Kn
fV1k6zM6D1ZCHB5wf2qIMntfFCJMo2b5QCN6b3IS4viN2pmVSvS+xRfizq5e
Q82OkTxAiH3vpwdfb2LxF8K3YtoQXzV6L5MIMdBhYNXAFJqfKMQ/S0q7ay0h
eZoQ/DeZQV6viOVCTNf/FZF3jzhbiJM2ij22s1so/kK8qpLeOHHrHcVfCH3R
tBucb28p/kIM32npvHoYja8U4sVKw767RtH4GiEMYywKR7i9p/gL4Z4RG/5j
B41vEGKd1+zq5560XrMQD26OEAVIyJ5WIVQqLysZK9F6HV37W5Q9baoOMUeE
/guGjNdzIlYWwWLevEFLhtB6KiIkTn0jqAskVhfBvabs7ujJxFwRNJZeebHQ
kOZri+Bgbfdd/zexrghWgW2mDnFkr4EIN3c8tLYdRP5AhD83V038kPKR4i/C
5wn39ezufKL4i3Bv94SDATvp7xKtRDBw1R+yg9NG8RchMqfKxSGU5E4iLJi8
JdT5MTFfBB3PliHzTxIHdNkn1A/ePpZYIMJ0T/+cPm7EEhE2nO0R2OxPnCgC
58QX2YV1ZE+aCJoxRQZ79pG9chHUZq38981H8idbBMGV5yPN3T5Q/EVY+677
zDkhNL5QhM4Ezf6PPhErRPi27HiBZyetXynC+vc6kQkC0l8jgt32e2c9DYnr
RQjR0FLZ/ZK4QYQ89wtrP1cTN4u67tPsSQUatD+tIgy3UZ+6soS4QwTX60uv
bnnF/s4zCv1Mrko/dpJcOQpX8wc9sl74meIfhcykdwk11sTqUWj599x0YxBz
o3B4S+RqGRuvHQVtfu38XTdoPd0ojDza1nDmHrFBFOpW2x7ZzGmn+EchSNhx
0/E8zV/Wtb7j46K7a4nNo+CzacXkMQqabxWFpY38xjWzyH5eFH7mPZnjyuLp
FIVx9yRz/Pm0n/wobHng+PRQGIt/FDJedgtoi2Xxj4KxwshEuZPFPwoOKb33
V7P9SYzC9x65m7IHk/60KJg8Wv/82W2Sy6Nw4Kyy5q8PpC87Cvt+fL6+h8kL
onBXzGvRcKX5hVF4XSe173WHWBGFXpOPHsqPI38ro2D23eNn1hWS10Qh+a2H
StNN4vooxEnyVzbaEDdEwXNncj+jmyz+UcgbWj9beJTsaY3ClS+F0eFTSN4R
BZ2BQUvSckjOicbAHGE31wd0HpWjUZbwxcVOlVglGp1XLtbaOhOrRyPhzgif
26NoPW40HHaGLIkvJrl213o3NplMncniH41Dsw/xyz7QeINoFB++0DR4PMkR
jaR3JZb5z4iXRSO90yNgzk8W/y59M0auualP58UqGsEPy5sa20nOi0ZMasin
rUtJ7hSNowcP75moSsyPxmmbfLs7H2l8QDSMeZ3m9w2IBdGo0bt6xHYlsSQa
W0aFXM28QJwYjVs/dCcYfWDxj4aLmUX3d+nE8mgsTNlcMmQajc+ORvZsjVtb
hSQviIZ/Zx89KfO3MBr6aqMy1G7RfiiiMbz8lWVCM3FlNLzjb8ijtrP4R+Nz
hrZ00wBav77Lf73yVS0biRuicVKzWWx/nbg5Gqo5xTqCDPK/NRq1b7ZHubL9
6IjGsaqZVT7MP44YZdzizt9XSK4sxsVwubmTzleKvxjflv+7rn/nF4q/GPdG
qp7O2EXjuWK0Di6PnRpMcm0xPoZdbgyeSqwrRuKi59NH9SQ2EONm1QZzwW6W
/2KcbkxYqmJLvEyMceEhVc1raLy5GPuHHvwqnElsJUa3LdXHNEpoPE8MT87k
Huu1SO4khttgVbuxfYj5YkybE+ZcbU3jA8Q4eSC/nxmzRyCGUkbyJm9DkkvE
GHMy2PzODxZ/MbQ3Trrao404TYwhBxFTI6HxcjHShmb5NO5i8Rfj175ks9/O
JC8QY3pGzZMl8cSFYhhe4NskLCZWiLFc+vvv2RMs/8Wo0agwDNtH8hoxNr59
5vOykbhejMOeC95HLCb7G8TYZOztkjKGuFkM9Ue93PV7E7eK8c9okwkbmbxD
jOzvahVz1hFzJGgZrGpQm8ziL8GgFT2NVPuSXEWCK+PaT00/zuIvQeucXqv7
zSLmSrB+wSafVwUs/hJk+ZT8tuhO50dXgnt+v0ddGklsIMHm3FWy1nRiSHBL
0E/Qt5R4mQQiT7/shGnfKP4S3Byv7n46leRWEljOmppkUUTMkyDgxLFurvHE
ThJMuRuYeCqF5vMl8A71n5jTSvIACSJ27DQZO5bkAgn+GdO/WncDsUSCws37
l2XcJk7s4vKAHPO53yn+Emz758G3e9uI5RL83L31ZtQy4mwJLjfba3qdIC7o
8j9LXPfLmLhQgj+yk1firYkVEti1Z917uY64sms/BnvsNAwg/TUSdC/O1V3c
TvbXS6C0pqHDmfnbIMH4l/ZmvR+z+Hf5P/xUTWMgyVslmP3x9Bfdbyz+EiQf
vHUtbSvJOVIcHDHXT5XpU5bCdeJOXcfzLP5SzDGTT0mcz+IvRYL3g5wfHiz/
pbjyR3ke0oi1pbAXic94/CLWlWLR+8xHD8vZ/S+FcdLA/ZFZrP5LsTEi16XK
mtV/KYr3Vj2JNCU279Kfn6KfxeqflRS/ayaZv3zH+j8pPhfdKly/g+ROUpTl
mew8f5+YL4WX7qrgEzms/ksxq33p5q0bWP2XYrtWhe6sClb/pfg0Z1V9LMvH
RCnC5gl1k2LInzQpvmRdfs5dTfshl0K7+zfXTwUkz5bifKXIejyf5AVSDOvr
JnzzluW/FM81H067uoDkCin4Bks3nWH5VCmFT6iLts9Jlv9SiM10tHWTWP5L
YcgJPOzjw/JfikBToxO92kjeLMWjmh2RTZNY/ktRHVlep7qG1f8ue6znLVP7
wup/DIK1fAuNmoiVY+A+9cnbmOOs/4tBgMF1E20Tmq8eg/Zk01LBOJb/MXhz
pfdW87Es/jFYL1xePGUqi38MhnhlNAazemoQA+6KyQMMbhAjBtun9/IU67D6
H4P4DUluHk/Y/R+D727FE1IHsPs/BrHB32+ffsfqfwyuOXvebnvM7v8YCI8d
ruubyOp/DHr77NEbwfIlIAa/7TKUHHyJBTGYm/v1YHIVsSQGbWszRvjcZfkf
A6sj0vgrvsRpXfNH1Ra6lBLLY5D7Xt3thjtxdgwy7nK+iPYSF8Tg2NjPrntO
EBfGwPKk+3puGrEiBg9qvpd+ZuMrYzDgWcmPE2NY/sdg9rwLD0NdWf7HYMU3
95RxNSz/YxCeJDZO+1/+x+DM0fLbM1ex+MegdtXzaamnWf7HYPdlXY2loaz+
xyKJN+uXSSmr/7GoT3e1vtuP5X8sXnmYvVBm9496LBo1zMyaP7P4x0JzRXFv
Rz7Zox0LGzflYek9yX7dWKg89XIMyiY2iIV+6MzAix+JEQuTEEcvrwriZbFI
uDY9umwNq/+x+PNTV7XyFLFVLOK3hQcFJxDzYlHDU5SdERI7xSJv2ri5VSxe
/FgcMLc598ecOCAWZ7/q9OFksPjHYsEfE5eEZyz+sZhhxa3IGcXiH4sfuu9H
iHqw+MdinZ+3O78fjZfHInPRgkUr1xJnx0Jnn0VW4z3iglislD+bPIXZWxiL
QN25ThpPWPxjkZ8x9LY/s78yFm/6rTvu/YrFPxZ9HDuVrIOJ62PBV7s15csx
4oZYeN1/eP+YnO6P5lgc3BO44Xo5cWssvMt0AjuaiDtiYRcxemL/FmKODBXf
M/OTPxMry5DwfMEBhwfEKjJkl3QeOjOmg+Ivg9LwKalLgom5MugYnZqKczRe
W4Yi4zda6fYk15Wh116fQ9WriA1kcBtY7VTXmxgydHPXbzG9QLxMhrqf+ruz
xv+g+Mtw7Vv0uc1NxFZdPLqt/cQWYp4Mv1fNKvhkQ+wkQ5bzRENlJ1qPL0N7
lEX8Ew/iABlemMQ9/pFOLJBhR/744Gg3YokM0ea/B7Y9J38SZVjTM7b71iJ2
/8tQM2CmXHMeu/9lyJ9bPuT3PzQ/W4ZCxbkWDvO3QIYj9/o47pzP7n8ZXr47
rjtvNou/DP5lOnc9Uln8ZXCSvxgpK2fx79rvFQnKHayfqZchruWicx/WHzXI
UFuVUTN6Kp23ZhnWLokID/Rn978Mnu6DPqlVsvzv2p9NGz1fzmb3fxxO8d+X
yAqJleNQq7S3PN6Z9f9x6Khwkb7vYPkfh+NJD962nWX5H4eYQYtqb05k/V8c
NrzXVQxQY/1fHDJC30mMbrD+Pw5fZPdzeayfQByS3o6xSBERL4vDkJTkpz1j
aL55HK6um2fWS4/1/3FoUB71qq4/6//icN+Go/Pnf/1/HCa/rZ0j92D1Pw6q
lsFHDctZ/x+H8YFantq6rP+Pw8MjorbQLGJJHKr2bP135nXixDhoWH9OyC8l
Tuti3Qi/rP/lfxz8T7soj3xE8uw4DDt0w+mdEsv/OIi4ChRYkrwwDt2K7qv6
vGL3fxxsbANNeTbs/o+DINBsfMAI4po4nP/h/4/9ReL6Ln0HxNGd29j9H4ep
spzgVztZ/Y/DvHsDDH1NWf2PQ1vr6P1hzN+OOAy2bvR9W8zqfzwO7vB5F9TM
4h+PdTN2+4xVovOlEo+9ZikN51h/rN4l3/P+wNZjNJ4bj2FVIUaTfUiuHY8e
itPWWz6x+h+PvhvvuIsus/ofj4Z3M9Ur6ikfEI/B2eOaO3cTL4vH53drVp0v
ZPU/HqJ0ru/fMtb/x+Ph644lg1j/yovHjIGLe+/XZPU/Hiu+cEpPsf6dH48m
v5K0xd9Z/Y+HdmX7in081v/HI37hGQ95Fuv/45HybY94fT6r//FY4Lqw4/cE
lv/xeJK/eNtzVp/l8TDjOyfHhLH+Px4r+UW7PwSz/j8emambW0Imsvzv8v+f
w15bh7D+Px475vRQb9Zn+R+Pr1qlbV4O5F9N13ovwh94Lmb3fzymliz8u24h
i388KhJX7Hb7wuIfj/W+nlrKo1j+xyNktJFqBjuPHV3ywNGm6iYs/xPQ6GKk
3c7WU06AQaR76fsYdv8n4OVOx0M2g1j+JyClfZCSvSXr/xOQM3mg/5/9rP9L
wHTJtkE/aln/l4CDSfuSPrPvBYMEaI6Ylez3h33/JyDL+K69Zdf5/T/RyKSS

     "]]}, 
   {Hue[0.21101966249684523`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3k81N8X/6dNWkkLLaKSaKVFouUVQqJQSRFDWSKMfWeMMcZgKCqftGhR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     "]]}, 
   {Hue[0.44708763999663503`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3k41F/UV0mSSpu0SUU/Uv1UCq2fFJGKVKjE2ELE2HdmYQzGUqls1WhV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     "]]}, 
   {Hue[0.6831556174964248, 0.6, 0.6], LineBox[CompressedData["
1:eJxVunc81f///39ar0RDojSUJkUoKmndmjSUENpkZIRjb459znGMhqKpbaSk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     "]]}, 
   {Hue[0.9192235949962146, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnk01d8X92+zZt/yLc0Upfkm39CgN0pKSRJSijLLPM/XcLmua0iTZo2k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     "]]}, 
   {Hue[0.15529157249600445`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmHk81N/3xwcttNEuSRMt6iNpV6leaUMpolBkyL6OfeyDGWYsg1SkTbt2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     "]]}, 
   {Hue[0.39135954999579425`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlczN/3x8dWkSVrSciSki2yZH8JCSGEyDKltKCmfa9pmq2apkJkicmS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     "]]}, 
   {Hue[0.6274275274955841, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenlUzO8b9lh+JFt8Q7KNrYUie/ariBCSLUSjRWmd9mmfaVpmappKKISx
tIgyIioke7QYkVaJULYkpezvvMf9ec95+6dznXu/r2f7PM+Mt3G3sO/JYrFa
erFY//f/v7+2paz//w/jp7PFW38U3PgHVaDnHGl3axqD1WDa68HP4V9zCKvj
2iT1/TqLTxDWgMaekJxFXYcIj8bQ4yd0DQ7KKA4bMa7zf+gnnSI8ATkeiROb
Oy8QnoTwsp0+lSn5hLUQ/66re7PRbcI6yHz/veDl0PuEp8C6f+NqlSUKwnoo
yvl6hL/4MeFpCCtri43vYLAB5mjZqc8xZPAMeFeNkn20fkJ4JlYPrg0sO/GI
8CxMHlSiNdiA0Z8N8eLHdccjKwjPwTeHENOkA4z9XEhLplQtsGfymQdLt/OF
Dp5lhA0xShEdoIh+SHg+/np9XKg9kPG/ALahR78+bWb8L8TCiQNPT+lXSXgR
7szd6uE5/RnhxVg17OXnXmsZ+RKERdksD3nxlPBS1DgM6Ejez8gBtY65WrkT
a/5hPjAp2vw/1aP1JDeC4l2RMGXRc5Ibof9iDv/3a0ZujFf2eSE70UByY6RO
OfrjKp8waxnWXdaQ67kx9svwe822V/3DGfvlmK74tEOqzsiXw6jY/Ekk5wXJ
TeDxJTnohQdhvgnWPMk/9EZG+qwVcL66xUvtI2O/Au9O5mTPndpI8pXoc0SF
N8qAsV+JFtap82sVTHxTjHDLtKgvryO5KQpLEq++imHyX4VHN01sh0oY+SrE
9Ru5u+0CY78a16/86dUxs4rkq5Fem+hU2YMwaw0MIy9pDzOj8cBfg1a3RTzr
emZ8mMHM/9LGlnJGboZ5y1/dS/Vk+FmLpu9vzxsXEv/8tUgYntlXtIyxX4dr
XskWaTzin78Op81bFsz4xsjXo33i5RrPFBpP/PWQHh1w/ekcZnyZw2Rkgr1J
HenDHLc8z+t6+tJ44ZujMcTN8+RdwkXmSK0oKs28zPjfAIt8bptmD4qPDVgT
/jrF8Uw12W/A6FSB6pMc6kfRBnzfUqKiuYbkLAt89ZzjMTuWsbeAbJb96ol6
zHi0wKGf0/8uyGPsLfB5jTyR5cH0ZyNmfH28veoyybERE558e5PNYfqxEfdO
6OVoDmDsNyLm0E+f2SGM/SYkh4tztzD1YBO6rD7oJ7xl6t+EmuNpX84vIP2i
TdBSyZoSdpipfzMu1uBZ7W8m/80ICnI/qzuJ4XMz7t+Q/hXfpX4XbcbIvqzO
1iPMfN6Cg5LapqUmJWS/BaMdRxhp2heQ/RZcE9oFf9K5SfZboGF5K3lj7DWy
34pbrjrbhyyh9RFbUfesYmzbkUKy34oXfQoHPHl+mey34lie16b5d8gfyxJz
JydnOR24Q/aW6D+rJs7mB/njW+Ka9MrU7AFXyN4Slq6SF4usmPV5G24trJzv
2srE34Zlj9T6FTedIfttiKrpWDPt8kWy3waolDXr8bLIfjvk/aL0P68Wkv12
BAW+jHg6Zf+//YK/HXE/e2XX2l/4h4u2ozXp99Yz7zJpP9mB4HfT9It+0/6D
HXhcZvxp6BrC/B24UJfJ8p+eR/Y7YDZ5/AY903yyt8IxgXjO8OW5ZG8F3sp+
VfidRvZWSBg34FVlD8JFVii98Onz9D4ZZL8THXtr/uS6Hib7neA//5QhbI4g
+52oby+0ObYykerfiacu984F1KWT/S68Hua9M/viJbLfBY+bF4JqxpB//i60
qs5v0x2YTfF3YdNcC91FBjFkbw2uxK3e56kN2VvDMElr02c1Ptlbg8/P70oc
kE7xrWG+u/OG+tck6j8HKpOrdrL8k/7psznA04w9Kc9WkT8Ovn9NtRjudeKf
PoeDtkZcHJHFJf8c9MzZsCNSjcaXjIMnNf+dshYw442Dd/3CfwkTM/7hRg4i
R7XrHi88SfF3Q/o4xjDLlMYLezeMe8zc2LzxHI2H3ZBUzByuNoTsObsxM+qq
86kz2TS+duONWV7L98HHKf5uzMidLc4bKKf4u1Hl+abMY3Quxd+NzAUDR82a
Q/5YNjA98LG2qf95im+D+8Uza+LWUT6wwZhjTtdzJjHxbYD75klrd6RQfBuw
+wXqb51M5xuZDfYVc5oL1ej8U2SD0dmj7as30PhotMHs5PjVTwcmEn+2iL5u
Flw19iL13xbnzu5x7jk0nvpvizdzjBXLztN44diipUfyyqllNH75tvglHn9q
xKbzFN8WkRsHfx7SmUrxbcH2PnD1+fZjFN8Wl+qiw/PYCRTfDqn3M9evO035
su1QnOCyf0FlCNVvB4XsXo3dUB7Ft0OAW8KbT9fjqX47/Cr974EfjlD/7XDp
1DZxaDDxW2SHP1vbU69rEm60Q8HkXc7bzxJfLHts012jP76CxifbHqMSpfu3
fGP4t4eucy+HeYnEJ8ceVQ9it3+rJD749mC9XO0YEbKQ6reHedDUboH8INVv
j+XunTM/RWVR/faIru3U37z6CtW/B/ucb/fg6N2k+vcgfOQ+C7gRxh5U3lZs
mjpYTvXvQUqt35fCusvU/z3wRcfJz6xTFH8P6rxEmZ+3UbyiPRjudGP5z4sk
b9wDFaP3r2etI75YDtDcEZ+WsJHyYTsggO8tuBR3leI7ILO9sHzGWcqH44CP
TbmPHy+l8zffAXPiSsQ/TlN+MiWe8cxl/AlmvXOAsWORzmwWjZdGBxzbpW4y
7hGtdyxHLFrTkp7+gsYL2xF3GqsKH9yjfOEIs9orXe+f03rNccTy+rztecuZ
9d0RQ0u8f+zqR/zKlJidvXic5Q3i3xHqY/h+Q5/RftXoiGnRP/ecBu0nrL0o
j8zeO82EvgfYe8EZmd5a6xZG/O+F9zcrk+WONF45Snln5H9Dg5yp/r1YXm1b
37qc5qNsL9gXQ/adybOj+HtxrnEcxydqF8Xfi4V/JnwJHs7sH07YIKp5JFtL
6zvbCVnWKTdbh1A8OMGyV5VpxarNFN8J0tn5Vod30PrJd0Lt3cUDhnWJKL4T
0sZfubjUjFl/nMDZNLNhlw6N50YnXLvFT9XYxnz/OKPDZXX50SlpVL8zplUU
SjuOX6L6nZEd0nfClQu0f3CcMWHC3NyZA2k94zvDYuna0SfG5FB8Z1wMORjc
/o7Zb53xW39o9unZtN83OuNh65R5V+/co/gumFG97tjHW3T+YLtA85pqVf19
+h6BC34XzTmtfYowxwXJSZ2L0u/SeYHvgvjWnbr1I8m/zAXXNhvL2JIiiu+C
odELzY7+ovNBowueJed+DlHcoviucB0S+HKsK32/sV3RxCrRrJpB+cEVozbt
KShuLaX4ruBKkwYlrLpL8V0xt1Z/44wnNN5krvgyqeDD777MeckVDWv9Td+c
Zep3hWXYbZbFaqqX5aacPxXzpj1m6nfDbMfr3PgQJr4blh03ky8Jo3gcN5Qf
DOnc+f0BxXeDNF9qdSKF+iNzg0PWiO+sMyQvcoONbslycwuyb3RD19ajbeIs
5vzljg9xPPYKGX3Pst1xPvuYhsaK6xTfHeq2Uz8UB9F44LjDVNdh8gQ3mm98
dyie3azqThBTfHewu9sMxzhG0/x3x66iXbtfCI/Q/HfH4UF1Jx670H7D4qIw
wemjLIbGuxoXLNU/suZetN+zuai/PLZT007wT27AxcTYkrfF62n8got23cYR
0ZX7/snNufh4+PDJqoJImi9cXFaJGTfva/I/zOWi95H/aej5Uzw+F7MVHs/u
3T79D8dzwZ7dpRLLu0brGRfGx6zX1wym85ycC5unha2SLsq/iAvTKosVvQxo
PVNw0Tyg4D9rHq2vjVxwm6S3Gn6SfhsXMrvRXtMLb1P9HigWbJoSsvIe1e+B
/1RYg28fLqL1wAMN4WNmXAkkfQMPDFxj4tf+5BatDx4oMDuR9n4AYXMPXLK/
sNm/F2GOB27bTyvlCckf1wNVbsMkm3rcpfo90Ncrri1RUkz1e6CzqCXtGucB
1e+BK/1sT0vEpC/3QLVqelY8m/aDIg8EdfQriZLTfqTwwIDY47e4LVRvowek
PVOcX94m/TYP+Bh/H9G9nTDLE//7z2/q/GbCap44zLr5YEM59Y/tiVdT6uTt
z4k/A09gotXPkp5GVL8neDPmVgQspfOruSculp3z7WdM5wmOJwzqTgctVqPz
AdcT2Q8PmgxVS6Xx6wnHXl1DP9fRehXvCcWIwkGtcmY98cSN+QdWxQym+SH3
hEvzPNd3/Wg+FHlitXQ2y0J49R9WKPOzsC175sGsN554n2/k3/MBrTdtnghq
t1nzhVm/WF54dkVVUduH1h81L2gu235IPpWZj16YIv+zo6o3yQ288GaZj1H9
b/IHL6hmD/7zbD6tF+Ze4NROfpezi/Q5Xlg07NQFxy76HuN6ITnQ4ST7JM1v
vhdscge/NyijfOO9sGmw1SOdBxRf5gWWY52D2Vemfi/o6jeUmM4h/0Ve2P3x
hU/FL1ofFV5IenR6UmkI3Vc1emF1cSGkl0ne5gWRUF17/QvCLG/IDlVK9K3o
PkrNG2ez/UdP1SLM9obvw/Wlsjv0/WrgjQjn433zFMz3sjf2Hq8uhQl9H5t7
47CRuc3QUaTP8UbR6jetB3Poe5frjWvaQd8GJtF9GN8bwzuufPVYTutlvDde
LBkw4KQ1rZcyb/hM1U9hKYgvuTc+nl33qyiK+lnkjW/bN0/Yu5DGi8IbJo3T
Ff0KmPOGN1QmRjh2Pad+t3mj/vnpAG0WnV9YPmicdHe5fHgm1e+DT8271Jv0
aDyyfbAreqJNSvpRqt8HQXdWV+1OP031+6D7nIbW9wu0H5v74Nnx/JG/w+n7
mOODc6GdZ7zNiF+uD9wvTHjLq2T2Lx8YLVzXW2hN+0e8D+Id9J0yRjH1+4AV
c7rb5TqNL7kPVDasVXXoTfwV+UC9YGne+R/El8IHWr49o38z95ONPpjbIfjx
ZBD1v80HTuuXL9SMZ+4ffDFs7eyv2Tp036HmC638v+3v/Oi+hO2LqX+k+tv6
k9zAF6+l6WkmTcx9hy+ay9wmT2ghubkv+pTUr10rIczxxTW7kAiT6TReuL4Y
Mtto7eUrzP2KLwaPPB3fg0/jJ94X2Razw/S3Epb5Yq9xnNX8I6Qv94Ve0nCv
4ceY+xhf2Mx/vbX7EN0nKXyRtn7D1rN3KV6jL4pmHpKuekK4zRfPMja+fFrO
3H/54eBE64e3mPzU/JD2ov+kxcYUj+2H5T37G8cvpH4Z+MG0eEyVQTjNL/gh
/kOZ1shMwuZ+mBruGdQUQPocPwgbQpsdZ5VT/X64kDH/7fMLzPj3Q+aBh7kD
zhOO94PhzdwW6VrKR+aHPNmtZzE84lvuh0W202uCpjDz3w8qDkdSwz3Jv8IP
vJQ6Ec+dcKMfjG9vHNw7i+ZXmx/ipoWX/A1n7p95uH/Rbn3XMtJX46F6RsHD
QQ4Uj81DmrX3mmevaf4Z8HB9q/qR/tXFVD8PxxJezO2ZTdich1522QFnJzPr
Hw/+HzY7+bfS+ObyYFxt2JqQTpjPw689LtoTVtN4j+fh5XY3cb9aZvzz8G3L
BNcyB2b+87Cx4Ivvdztm/POQPyL9fGgUnd8UPDwYFPP63Wpm/PPwomB9ilov
Zv3j4eH8FfVGLdQPlj+2zpk85l4C5a/mj5mjtsbqNhBm+yNT0+HESR5hA390
fmwffZ85P8Ifkqvfp/gOp/3A3B+TfJ5lc94z50V/COd5PvILp35w/WHjXr+S
a8mcn/1xxF2vU9RG63u8P6TskI8b+pG+zB8rzgq0F46ieHJ/6J+1NXo1mDlf
+mO4huniElPyp/CHsZpk86PJJG/0h0vdxJXl94nvNn/l9+vqZQ+qmfeMACQd
KQ8+4knjTy0AuQKez6IPzHk4AL7sPvLBr6l/BgF4aNX4qSiF/CMAGx5nDL1k
S+PHPAB9bqmVr2gh/5wAeEtSffsy85kbgBbn+As21wjzAzBoydLccz9ovsQH
4N7l0aON5IRlAfhv9nan4OW03sgDMLbXjeUBuYSLApAzTT/wSz7NV0UAMjKH
Hn9zhJn/AfA01etzUkTjoS0ALGnPzqNi5v42ELodpoHXOXTfrBaIjYO28ycd
IswOxLclrt9i4ylfg0BYal3n9q9m9r9AlHeUvWDnkn/zQMjfW4xu8Ga+VwIx
9mpXwbS+xC83EC0pLaNbM+n7iB8I1m/7c7MrafzEB+LOl9iyN510npEFQm+S
5iBVa9qP5IG4OVb+bOo44rsoEBdH6nPcmPmjUMq9MhWrTZjvnUB4qh3tn3aa
4rcFIvLbsblXVtH+yQrCy6kKfnY75aMWhMI1rzIyXxNmB6Fau+LGrMu0/xgE
ocw22nWVNvlHEBYM7lWi95eweRAaK0ft82+k/Y4TBEmmdFHXPvpe4QYhQ8+s
4VQ0fV/wg1BfYOczecM+ql9pv6hoysHLdD6UBWFu6pLmkFX0fS0PwrMNiXeq
3eg+oigI/Gzu16OOdB+kCEL7+H2fTx4n+8YghB0e2/DzBcVrU+Y/pmJnTzv6
PmcFQ3v/yzd3Amk/VwtGteDBAGEq2bODcdDbLKj0GOVvEIwPp5OXvz6UR/UH
o/10R9RjY/p+Nw/GTKMeoq0H6T6LEwy2/HzVTkvijxuMUtHtah0W2fODkdW9
s8/ZV3R+iA/GPedzaUvL6fwiC8Ypzpmaq650fpEH45Vb+LFsYxofRcHo3WNH
eoUmw38wZHn7X73fT/O3MRiZdwZFtEYw8z8Yd7pMRSpCZv0Pwf88plZ/Hsvs
fyEYWxWeui2C2f9C0FZ5ZJX/UWb/D8H09P7vk27RfEAIdLzX35p3uJbqDwH7
fLf7xwB6L+OE4FiFZIjJYHqf44ZgdEXhzjPFzHtdCHre02ryXEPvdfEh0Bhk
MdSx30uqPwRzNbVUH/UkuTwET0Yu1ZXvIVwUgm3jjpaOXUdYEYLknOuBqvZk
3xgCvSf9bmXcekX1h2D5Upf3+a5NVH8oXuZ9UXcTklwtFMXTbdQyIgmzQ7Fg
pYZK1jDCBqG4OmWu4bwCiodQJHlE2HT1ofdFcyUOWPpB05HknFBMm3n404nN
hLmhOFZnFmz1/94jQ9HitdsuTEDvjfGhGLu2n19rNmFZKKwT9IM2iZj6Q1Fx
9/5mlyim/lDcvpSXp3qb/ClCsT7ftnnSepI3huKdTVLlzpMkbwvFn5BZztwe
xA+LD/Uup8jg+SRX4aMgMvNNL4ZPNT48Tpb47nQmrMGHqsbNV/PqyZ7Nx7DP
vJIMI8I6fAxoHjH3fgdhAz50z5yp2pdH9oZ8bJmsubDXb3o/BR/bcpLNjhpS
vaZ8XEnj/M/wKWFzPuK5Hr/GmVE9lnzYtwbc9khi+stHn/3OjypTiR9HPrhO
iX6qMuKXy8chdWfhCd7rf5jHxyTH8bkGOW+o/3wsfHrOadxfwiI+fBzW994s
IhzPR987Pyd5rSKczMfA1Qf25uSRPxkf0ww3mzi2UfwMPqq9A/+W6dP4k/Px
IOHLqL6FlG8eH0sVbJvT66m+ImW/rBoyZmqRfjEfMfOmGO5uY8YzH2u4eyMf
fSJ+qvlg/fo95m4qw6+yv/GpNb2CSd7Cx7v3kpd3XlF/2/iodCvIGPCK4nXz
cf9CTY3ffuZ9W4Db+p26bquILxUBtA72ufd3K81PNQHWN720NdlDcg0B7ozf
e/BoFe2/bAEeRHDyl66g7wUdAcY81f812oDZLwX4NcunbXQe7eeGArSYDDMr
H0gYAszlRKuM6EXnQVMB/HJ4PhpGzH4qgOSZ3H33PNpPLQXIyNORDPSm8wdH
gNJ5I8Y2vKPzmaMAIf2bVmrJmO9tAZao1aS9ktF7Kk8AvdHGPqnldP/MF+BW
Juu89gbSFwlwMnLKjXNezHlUgFljXpQeqyT/yQJcXzNT+r6R+T4XICzG//EB
VTqvZQig8vd/ss4lZC8XABML3nm9pPzzBDjnPfZdPHN+KhLgeF3cH1kurdfF
AlzzLd04kzmPKQSYVFyzbE0r9atagJTWTQ9fpjPnGwHGa6j1SvhA/WpR9tts
xIuxLZRPmwDne++dsf0+xe8WQK7FzU5+yKz/YVjW+5FgGpviqYTB+8buGnkQ
6auF4eHMhE+t6VS/RhgeT2gW52bR+YMdhoM9nlpYfKT9XycMaSPnWz53ovOD
QRhUbwaHDmqj90BDpX8TUf0aBfUPYeBMS1Vz0CL/pmHIGTbQf+te8m8ehorR
X97u7yL+LMOwarJmS8FA2v84YTi/ov9d/gHaPx2V/vvmGZu4Md/bYSjqUTA4
ZBntnzylP98yyyFFzPtRGFgblqgb5uwn/sPQ9qxlYef7oBv/+A/D/kL93sfa
SZ4chhsfD30eeYvun2Rh0D64949qM92/Z4TBQPz6yxI5nWfkYWiU9gyw2+f3
z19eGHi9LqznnIol/sNgIzyr9+4g3RcUh2HqEf32xE80HhVhaA/+nZtnTv6r
w8DWsJrOS2LeE8JwuZb/1ryL3i9bwvAj58ePh2/ofqMtDMXq+3YZqtL7X3cY
NHLTv8UfOfcPs4QIirqv5Sii92YVITb1Ub379yHdt6oJkW9qOoEXK/uHNYRw
XMa+fmsQxWcL8TqYm2i/nfqtI4TVjsS0yeuo3wZCbO7ZVXFrJY0PQyEMrneZ
uZow5ychOhbYvDjeTvWbChH821n+6RT5Mxei8H57Q00cnZ8shWBlfrC+nEz3
MRylf8OTQ5wc6T3SUYiPCk1X1h96/+MK4X2RNUbNj+6neUJwcoeF/m1Z9g/z
hTA9NTC/bA+9f4mEcDgbqhbgTfeh8UJUj3TRf/WH7m+Tlf6Ortt48xq978mU
/bLTs7oRSvelGUKo/yit/jaH3vPkQoy+bu3a0reQ+BeiQVyYuLGe3uuKhPjh
ff7pzyB6bytW9rfNMe2pHr0vKYRQTUqMsHU6S/wLoTNgYGP978PEvxIbbLke
84BP/AtR9CSk5F01jc82IWan3Rr7ro1wtxDXfV8Pduyg+cIKx4Lh7zysj9N8
VQlHDwfNxkXXmO+BcLSYeR8ftJS+TzTCsemQ/c6QfOb7IBxp45dFrk8nrBMO
8z/Hf+S00/pqEI59X5rTXk8huWE4uuvfqI+uYn4vEo4937f8TTxH89E0HPE7
Ut2HHY4j/sOReGPwr/s3kon/cBg0/u751pQwJxx7dU4Ifs6i+eYYjqW3vG43
ZdD5m6vMv+v6nf1T6X2EF44X6/Uc8gdQv/nh+E9bu8ZmD/2+QhSOu/qxbUN7
0HyJV8YLLbiR6H2S+Ff2a8rC3MhHzHt7OHxNOp4+SCa+M8KxaH7t+AFL6D5e
Ho5DT4dePPKN5lNeOJZ3anSml18n/sMx63L/jl/baLwVh6PB33Gi3wbCinA8
tUoMWzqV3m+rlf76CdYqptB7R2M42BEVnEUCms8t4SjIz6u+MIPeM9uU+fRb
1vu5kH4/0K3s7/dkE/deKTT/I7CkdevlsElUr0oETu6YYGPNod8rqEVAUz0/
ysOaxqtGBA6/b7p+4Djlz47AlKMrr77vpvp0ItDo+KfFuJLyN4iA1qxO32/h
9B5iGAFOjx2PMs/SewYicPP0zC8PN9H7h2kEhm0Z/4Ubc+cfNo9AiF5nwvn9
5M8yArWnKu9F6Zb9w5wIqI6Kja37oPiHHSMQKTTWVp1XSvM/AsVJFzPzFeU0
/yMwIfX2n9pMkvOV8e3Oxv/3luxFEfg+baw8LP4x8R8BPdbnrJOLK4j/CLz9
3bNSU15J/EfA3kN12uytz4j/CDgnRK/KTScsj4BaWHbvr7pPiP8IBAeM1mt6
Rf6LIuBX8y4vd9FT4j8CL5sTFj+vpHwUyn4OLuxRNpniVUfgUlPM//Tnkv/G
CCwo+/Z+VQ+St0Qgx0iy91wT+WuLgM5GtbfWvBriPwLSU0NvDjUifVYkDGQB
qtMyyZ9KJGQW/43M3U/5qkWiIvZdxRpbykcjEh2SkguaDtQPdiRCfybYDb5Z
TfxHKs870h7jgymeQSS+GU2altlE/g0jkTl/evSdLSRHJHJG8If4WBI2jUR5
VuooG5s64j8ST2PMt5c3PCf+I/H1gW7MauMG4j8SVaPffz+yqZ74j4Sb+6jX
h/sT5kaiJPCv5pUvhHmRSFDd+yhhGNnzIyGyLUpcVkdYFImX45tnve7xkvhX
+p/RcS3oA8mTI7HtecOcCc21xH8kWIerWxc2UL4Zyv5YnYraokf1yJX9+7Rg
7sQgwnlKuV36Ocs26ldRJEbG7rxzvJP4KI7E8rWT5k0+QvqKSHxY/XNzpR7F
q47EJ8Ovh31UqZ7GSDjMz7GU7yN5i1K/w7l01SOSt0ViS3nYjq9/CHdHYmjJ
pzpLbcqXFYW0LXWHh16i/qpEYdBKL253LOmrReFnekN7/grS14jCo543hj/Q
J312FIasEYee7kPxdaJQc1PVTP6a+mUQhVLBDechRxqJ/yh89+qxwronYUTh
2d2UpL66pG8ahcU6jXVVXwibK+M3/32dsJHhPwrVCwTDaoIpH04UHCpKWvV6
MPxHofGkTnpSGMm5UWhZMcB/eib540XhTMuNMHYGxedH4ZesuXP+S4Z/Zfzv
464GrCF/8VFor3beXM3wnays93/DLiTNIX1ZFEw/8esi9QhnKPUvzF0+ehzl
K4/CXbeEnR/vkr88Zb0Lw/hB2YSLoqAdGRi+r4D0i6MQdjW4u/025a+IgtbJ
Z1G3N1K+1VE4GdE7rbPhBfEfhZTpP53DZBS/JQqtL660ucQw/EfhQvW5pT3/
R/bdUfCY++Rmpc8r4l+EzUY6DtpTCauIMOnzChWZH41/NRE8b2gEmzSRvYYI
P0u/BGsvJcwWYVPkkue+Dk3Evwj+pcWzpTMJG4hwZui3CwEthA1FSH+ylTfC
/w3xL8JzzU7eYT3CpiJE+E9oG1jSTPyLMP5Brc7eGYQtRTC+MvGl89e3xL8I
PcaaTVrWh7CjCCH3Ngtzr5M/rgipLt9q/9NrIf5FeL/v4Dp/Lsn5InzsaH27
/SNhkQhPDWPWLXtEOF6EP4WBKeyN5D9ZhLZLlbMPH6B8ZCKoHx3jcn4RyTNE
4E5YcmhFOMnlyvzi5UfXDCWcp8y/IfbttfWkXyTCwfN356drUn7FImiWbdgx
cDFhhQjtxZfWWTURrhahSPTT8rcj2Tcq89FNd9qwgvJtEWFQT7/7ZfMIt4lg
ou/54tBQ0u8WoXvAIM4THcIsMfbl6J0Z/Zj0VcRIf2+98ls8YTUxVuyePlGb
yV9DjMENKuKGX2TPFsP93PrfZSC5jhiVwvaR2/RIbiBG3Y0brPInJDcU49jB
gOr8U++IfzG2WJ+6ePskYVMxpIPF7o+Z/pqLkRq4Szb/J8O/GF1nebuClhLm
iPFgbkRD0FaGfzEuCmw/lk8gOVeM/2yH+AzOpnp4YvyNOhXa+y/p88XoyRWH
8e1JXySGS/zj/Bm51O94MQxycw3/t4bySxYjf3FWwa6q98S/GM3dl4bsKCH9
DDEyr21yt/tM+nKlvbbdpslS0s8TY8LLsqjR/iQvEqPWJ3Py73qKXyxGzgSh
Y+99lJ9CjNX9fT6piEleLcYCaWPIqoOEG8W412K+0u4N4RYx2P2PWujaUz5t
Yhy+6JKT8Ifk3WJ8M5YGnRhPmBUN3pf7D3u6k75KNMJeycIO5pNcLRot02Vt
LDbloxGNrITLdb8CSM6Oxswl+4rtmf7pRCM85rKe9nyqzyAa07X3fdp8geo3
jEZkW/0Nw9CPxH803nbfPPTlZCvxH40vYv3vBTs+E//R0Dn9a3fXDpJbRuPX
Gtbr3ZYk50Rj0DSe0KWYsKNSv1f3Ytc80udGY8TnyuqPHZ+I/2iknqhaONWK
5Pxo6M8x1c8pI3tRNPQSX/XxHEk4Php9jq7wLl1FODkas59W9Fe3byP+o3E+
brXemCbCGdGw+iAQHI8iLI+GDf/myKaehPOicfmLUfDcWsqnKBr1P3s6ccKp
H8XR6L/ILGGULskV0aie/6aspJziV0fDwqi64G8r+WuMRvAx57ijdwm3RGOP
YGDrEHfCbdHK/caiwFBOuFtZz+CtKwLSCbNi4KmiPvbhM8IqMWAd2zU06zVh
tRgkfMp03mVDWCMGv95mquQlEmbHYLjBiuomvy/EfwwqLzUfnqHaTvzHIFp3
4JIkCckNY3BnjuaEw11kjxis5zWVLrYgbBqDl8vrf948yfAfg6QLfU3qCxj+
Y/B+jyBXI5v6w4mBrnRtW1cdYccYTBOe/Zk6nfrJjcHNh0bmkWMY/mOU31f+
i/NLCPNjMLuj/FHAedIXKevbMb7voYcfiP8YjHMSWqX5kX5yDLxdpD4hcyg/
WQwiV6loDrhBOCMGLuUzbvQUUb7yGLwed8r76hOyz4tBGWfWkEUHGf5jkLLL
qyDwGOkXx0DrkMVicxXyp4hB1o8skScjr45Bs+OIXadSCDfGYLHr8EtOBxj+
Y2Ct9cvSYDrDv7JfY9buKWPk3Ur5/j0e7EKGfwk+d1iemZvH8C/BnoFxPo+L
Gf4l+NnlX1lgSfxpSPBQenv3rgrCbAns1J0jfp9i+Jcgixc252UCw78E57Jy
/x7cT9hQgmsOFXlb1L4S/xLlepRToreesKkEvQOE2uWM3FyCgifqN06Xkb2l
BA+WfTILmk1yjgS16kVWr8+S3FGCP1FYPo1Dcq4E9aIUX/VgwjxlfRqzB163
IsyXYMWF6a0aqh3EvwQpx3919uxHOF6C50FxL5obyH+yBLPOLl24ZRVhmQTr
Sop9NBYQzpAgUPjToXUKYbkEnPe2pxrtmPkvwSQhL6VvP8JFEmg7JM0v1SJc
LIGZ+5O89CDCCglK5dNCzI0IV0tQqJtp8yCQmf8StC98uVw3mPrfIoFWmrtH
5GPCbRK8Ppk3P9WLcLcE8Z/PfdXrQ/mxYnFy0dWsIT8Y/mNxPMdqwsbnpK8W
C96Kw6WaxQz/sSgdvSHt+kWG/1hY+LP0dfkM/7EYeax5zvhLhA1iEW2m8yqh
gZn/sbATvYvPGszwH4t2k6iTvyYz/MciYnaoynRPhv9Y/JL61QvuELaMxeK0
rH4LfzP8x2K/rq3+md7El2MsIi9Nr49zIcyNxdjMh9GLUwjzYuE0d89E/lrC
/Fi8Xvn1UY9V5E8Ui+zzhwW5EsLxsdB8deXStYWEk2Nx8YnAYmMPwrJYLJoX
H3uxi+E/Fm0n4lRXiBn+YzFmX5XesiWknxeLFc9dUxyDSF6kzO96rU7VQsLF
sSj/lT426wBhRSzMsxyWlqsTro7FXO2KHfmJ1M/GWGjsCg2qLWf4j8WdML7W
qpWk3xaLkhc5K7n2hLtjsaSm/XoSi/JhSeF4xGRg6DjCKlJsWM3a5rqd9NWk
YB3aq8hg4mtIld/zDVu/xDL8S7EvoSjrxFyS60hh8bn06sNMhn8pdvZq6rBd
x/AvBd9y0HCjKNKHFKIda61tDxM2lWJa+Jkxeg8Im0uxyLQhUujIzH8pvs85
mHRgKcO/FClng/mcWmb+SzFJ767jxa+EuVK49HU/kXiFmf9SDDLWqjZewcx/
KTamXsxryyN9kTK/AplEOJPhXwrxR9Ea23KGfykuzRz77b9xNH5kUjx4t8Cq
dSnhDClkXRt7PTlLWC5F/dgxL9dnEc6T4kvL2x3ffhMukiJsVEbMtGWdxL8U
m057uBnxCCuk4GQqbvV2I1ytrGfMK9f32oQblfwlVjUgmXCLFDlutum9ogm3
SbEgVaf3pCHfiH8pSivGjHbPJzkrDlNmncv73kFYJQ66dhGjdH1JXy0Ov1aO
9Wg4TVgjDhMrfKcPGE6YHYevF97q9tcgrBMH3/ehK/acIX8GcdARmLK+XCRs
GIdn6ocUIf1IH3HI0xyvVmLTeeP/AGmUVzE=
     "]]}, 
   {Hue[0.8634955049953739, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3dUU0+wx2NHRQwKiNgQG2LDjmL5KipFUBSUokjoRUoo0ksSQhJKADv2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     "]]}, 
   {Hue[0.09956348249516367, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnc81e/7x09a2tLSUNpo0ZA0vKJBSsqIhr2ScezNOTjHcZxz0JA00EJR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     "]]}, 
   {Hue[0.3356314599949535, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzF/Uzx6JLJF97NkySEJ+PihCmKikwmjfTfte09RM00xNhUiSqSxR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     "]]}, 
   {Hue[0.5716994374947433, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenk81N/3/yS9U1SK0D4qpU3apcWzTSqVEFpoKEKWsWRfBjNjDCZpoVKN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     "]]}, 
   {Hue[0.8077674149945295, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlcTH/Ux8eekKyFZFQSQgip5KOobAmlJDUllTbTPu1T0zJb05AlW8Za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     "]]}, 
   {Hue[0.04383539249432289, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3lczN/3f2SJLCGEECUhiUpJ8rS+U2ihfRtFm6K9aZ9pnZmmRZLsJSUR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     "]]}, 
   {Hue[0.27990336999410914`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3k41F/Un3atpE0lzU+bNmlH24ckLUooKmkISZaxj33MmM2WtKCNfiqU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     "]]}, 
   {Hue[0.5159713474939025, 0.6, 0.6], LineBox[CompressedData["
1:eJxVu3lczdv3Px4ZGlwyVhRHRNeQuKQSPUWEm04qpUklGtA8j6fO6XQ6nQZD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     "]]}, 
   {Hue[0.7520393249936888, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lczN33z/L0VEgIRShrPCTLQ4jesoWikkpK075n2veaappmamYKoUh6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     "]]}, 
   {Hue[0.9881073024934821, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3k81N/3P6UohXbxVtOuXbs2nrRYKjuR0iBlN/adGcMsGKRN2qaVStJK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     "]]}, 
   {Hue[0.22417527999326836`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVWnk41F/URyVpk0rSNqqftA+ptH+iRfsUopImskUZ+84YMwzG0q59UkqS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     "]]}, 
   {Hue[0.4602432574930617, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczN8X/8ceiUKJouxJki3Z6mVPlhZb0jJtKm3Tvtc00zJT01TqU9kn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     "]]}, 
   {Hue[0.696311234992848, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzF/UT0RERpayjz2EsmarD4pQTCVSYdoXLdM+7VPT1Ew7WSrUVCSi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     "]]}, 
   {Hue[0.9323792124926413, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnk41F/0x6e0SCqJaNdOiyiVtL1bSJuESiWNJVth7GMfM2MMxtKuviXt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     "]]}, 
   {Hue[0.16844718999242758`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lczN8X/wehUgohS4SQtT4VIstLlrKnLIlIaVHJtO817TPNNEUofSxj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     "]]}, 
   {Hue[0.40451516749222094`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenlYzF/0f5YIIdn6ZGnIEpIie/KiKJJSaUcrLZZpn/ZZmmlqliKSbGNP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     "]]}, 
   {Hue[0.6405831449920072, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lczN33H8tDlsiefRCyloge61ukRRKFQplWU1qmfVXTTE0zLaOsIQyF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     "]]}, 
   {Hue[0.8766511224918005, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3lUzP/3/5AlESklW0ZCooUKIR4Vyd6GpDLtK037tJqWmaampmQplYTe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     "]]}, 
   {Hue[0.1127190999915868, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lYzN/7/5Olso6EeFsGoRJSqAhPpYSQFKnUtKfNtO81NS3TNCUh2aeQ
kISkbA2SsiZJyjK2ypJCSKHv/C7363NdP3+839fjep773Oc+93md1zn3vJrk
vNXSTV5OTq61r5zc//v/v38dS+T+/39YG+s5btuLqPJ/qAgL3y0K6T1CasfC
+7H1FWrXo4hVkH2kvHCw7D//WBXPthm6+MnvIH0cpo3YHFEbeoWYjc+93ZsP
5pUST4aJ3fjfFyMYXQ1T+VbjgxZdI56Gxiy76wEpl4jVYevluHXb7vPEmqj8
bba+Z28OsRbGcx7ZBxhmE8+CHCLqCu6eJtaGw5rT/hevHCWeg/Yf5usaM0qI
dVD9Yt2IS4/LiHVx/CuPY7b0OvFcxNw1EnhsKyeeh5FG3BUz5W4Sz8de17iN
peYVxHr45tz77Z3jbWJ9mOvZXfimeYvYAL6O50pvejK8AJfkz37Qu3iHeCH0
80PucuYybAhpRJdRn85K4kXY5tswoM9jCfFieEyUPL1gwsSzBOPu/R7mWnGc
GHBftaij5Nn2f8wD1osP6RyLOUn6UogyhRkqY8+QvhTa7tXPE25cIN0I3sr+
BmO+XibdCN1Sh5k/ZhLLGcOoavy78GwaD88Y9jn+40yNLpK+DBHGTrem3qL8
85YhZJ3cUOXjV0k3gXD95aoepxukm6C4aOVHVRVmfk1RHHg766Q/078phrOG
vvP5w8S/HF5N4t3zrlH8vOUoej0l/GBqAelmyN/4PfdO8h7SzcA+uuLgx6v7
SF8B/YPdPkYPA/+tZ94KqP25caNnyx5a3yvhYGlycZ3tQdJXQjHO4KnbRCfS
V6HW1WvSzhAe9b8KqmsWiE7y4kk3R0y1pvuiLD7p5ph9Mav4waLdpK/GwIZF
61PnZ1D/q+F1nDuj7+E80tegcniv7ZVppaSvQcWRJOWzgy6RvhYfuhY9hvc5
0tdiqd5a+29TiOUskNfVtK81p+QfwwKPipW7G8Vnqb0Fxt5ViIpeW/CPJRYw
vrfBsWJfIdmvg8XdMcNWGZSR/To0+G6/aj39JNmvQ2KM8xydEWfIfh0KM3ee
DRvKjN8S6mp/huaeO0/2lpjVmbfzihP541liUeYH3RHraT+RWMJH4bKVKGQf
2a+HysPYo2nlJ8h+ParGWnmb8Sh+3nq8dSge2XcVxSNZj5LtltllShfJ3gqS
lEW3f3y5SvZW2G1YeMRUl8bLs8Lxyx/YM6tPk70VumqW2Dy8eYHsrXG9J2xG
5SCaf1jDpMx1RMsTxr81TjveXh2w8DLZW2Nb+8t3ig+vk/0GCD2+TkqqqSD7
DXjdN3zDyMAbZL8Bg/yGTrncLiH7DZiwxq35RhuNT24jmvVWnDYQMvnbiGNL
jyuLIpn1sBEPtK7N/+7J+N8IHd3ioU0sZn3YQPnLuQUxadQfbKD4Ql8FGgfI
3gaNkzs9Vp0+RfY28Fti1OD/lMn/JiSJljYayFM+sQlPLAoibtTtIvtNkF4Y
ERcxW0T2m6A/V8Fa1MLk3xbBryeU132hfMMWc2Nz90Wb0nri2eLQKsm77oG0
PiS2aH+TeLDwf/NvhyyVC7lGGjRfsMOk+tHOjcX3yN4OEd79r80KI5bYIXd9
zoKza2vJ3h5mAWUpGZPqyd4e32q3H3xaVUf29ujcXz/XYuJjsrfHkcDg24Mf
NZD9ZpiPZ7Gv1BJjM2xerBg8eMBzst+MP38GPjVwaiL7zRgVZs8v4TL2Dpjw
zHDzyBVPyd4B07KMphuYk85zQJet7fx7uaRLHCDsP6JnUD9iOUcE6z/J64x+
RPaOuKSo2nr2ODN+R8TpzfVT2MKM3xGHPlx4cmgxxSvHQYxLesjCRGrP5mDM
8uO1vfHMfMj4qHta3SsaD4cDxcGaX1LHUDw8Dv7Oz7lU5079iznYu3C9XLrH
Q/LHQdvQss/DfYilHOSW7Zp1vrKK/Dsh9UNLZMeeavLvBJi2rTczo+cDTjhQ
WyBeLU/PB8cJ5X2SQg4qMM+HE/bOWfT1qZTWi9gJvNYDBpWetD4kTtA3sF3m
PJWeB6kTcgZtMilm0fMk5wzrRarOWuHUnu2MoqCSQz1+28m/M545Boea9Uv8
tz9znCE3r2D2/rPM8+EMwZEK3T2fY/7pYme0FY2vfOeZRf6dEfAi6WnxYBqf
1BkDx4x6NDuGWb8uWHVEc6+zTg75d4H2q+oFrTNSyb8L7As95n9YlU3xu4C1
8sP2z7Ex5N8Fz3a4yb92KiT/LpAMbwvU+LT/H0tcsCGKP5ndc+wfS11wefIm
xWd+ufR+c8Vye2VfFT16P7Jd0V1qf6JY9dA/hisMN9jnOh2n9x3HFQntAfez
dtB88FxhH1rfUmG7k/y7YkJbzo2sxiLy74qWJU/V+1nT+KSuKDJhKW3RYc4P
bggNnJ/InUjnAbYbtD5++vlAm97/cEPJw7J7Fr/oPMhxw1iRbmL2eNJ5brDV
6ytnUEnnM7Ebxm11nrJcg86DEjdcj2wcy+um86PUDff7/9Z/PYs5L7njcJtx
k48qnefY7qjNmL/mginj3x2u0y889DxD5zeOO16P+CK/wJTa89zxS8QZeKWM
zjtid3gKAu1T9Ok8KHGHRk9kROkYspe648Knvf85TmHOjx44KzK3rO4gne2B
ljd9a7WW0fkQHpCruVO44mgV+feAb9qEuRXXmfg9kMs9e3w6n85DYg/8Hr3/
auo6Go/EA2ZR56ziQum8LPVA0rPmOQMMmPOXJ14tmPurvI6Zf08YDmZdfppD
8wVPGLse0vxiQecvjkx/bupR3kPnU54n6vZ0lRt50njFnlD5NVB9XxmxxBN7
z1h92S1P8y31hFPepJ6OROa8vwWF/5l2usrReNlbYD+Tt3DoS9KxBSU7rrGG
qx4m/1vQOKxXtGftCfK/BT66ZfHyjofp+d+CfPOSSm07ej4lMjYqPqba/yD5
l/Wv0i/vrvVe8u8F9nLT044TxOTfCx+0ltit16P+4YWgVV+V9qzeTf698Pel
VXv7LhoPzwvKKn00L9zMp/i9YHK3afapvTSfEi8Mn36mZnEV5UvqhbJ7kf3z
ipn1542q5sr278k032xv7Bld2u6+mdYHvLEgNGinlS6tJ443ukUpYzNsKZ88
b8TNSkmqL6LnQ+yNOYsaNaomk73EG5ZzzpvxP9D6kHoDbubvqjuY+4cPTrZo
Kde/qSH/PnBvy8v1W0cMH9wuS7Rap/qA/Pvg1ZvvD6+8Jp3ngwDj3gm7Ft8n
/z4QmtgZF14lXeKD+pLqEv8Bd8m/D8zumOnyK6rJvy/yHQ8pz3rL+PfFiQ45
F8WeR+TfF+0JD+b+UCPm+OLAVs+Y8dNryb8vgpS3KLvsqSP/vqh7bflxZFI9
+ffFkl/vP/j5PyH/vthvk7BkVE4j+feD5o/EMNUnpLP9oKvTu35UEzH8oNb9
w3zVnKfk3w+Zng6zHZY3kX8/zLPK3j1vEbHYD35TJsx7ePwZ+fdDVVb1L9Vc
YqkffK//VnEY9ZL8b8Vqs5nO6cvInr0VCa+rzGY50viwFaoWvGsLD5HO2Yqj
oa3uE0Rkz9sKE/3q2YMGvCD/W7E3xp2T8I50yVZc+7tz3syXZC/dipkNmf2k
f4nluAg5lNyydjoxiwuLk6Zjp8U20Hi4qF3gsND6DbE2F/w5utzYFzTf4Mre
UEbGiQ8oPxZc7K/I36e4lskXFwfvaWore1C+uFxIfDL+PjCn9cTjYtnovSYh
e2n9ZMjs+6upFSpRezEXp1zN1RT20foo4qIgfaxpyxG6/0pk40s4PlxhD9nX
cBEz51TZrk5mvXGhrFY9OKX44T/u4OJrzbUXOcr3KH5/GF5+lC4/mvY3lj9u
Zy35tuoksx/7Y2d5XotSP3q+tf3BOTw08+wROs/CH0Vywke359L70sIfatNm
eYismf3KHw0ekTMrlpyl+P3R2HZscfwTZv/yx6g/xfofWVR/yPCHwa2/F96N
Y94n/lB5eyDZrZDep0X+2LxVrtZk6DmK3x/vfe0iDvan+3mNP5yzlUccUKL9
QOoPu/zBw9/kUDwd/gjgN/75q0nvE7kAnFg/sjBiOO0XrAAU3tnXszyA9nd2
ANa2zNxl7U7zpR2ALqHRwgNBzPspALfWjbU7qk7Ps0UAZiuOM+5IofxxAlDT
OPy2pQY9T9wAvE1gDQ6RZ56fABxI/1CXc43We0YANoiaTcJ06XkRB6D9xcXE
ZSrERQGYpnvtbJ8ttB4lAUi506w5fATZ1wTgWs2Ki0vO0fMvDUD388ltYi3i
jgB4rmNHvO+l9SAXiA9ckzsF8TReViDGlUX1Vs0hnR0I5VNVO5a60vrTDoSt
ivHhpUakIxCq5p8WKKSRvUUg5iZPN3/Tyqz/QGQtf5Q+8SIxNxCf7ELbWbk0
Hl4g1jj7HjuXS/OTEYjU+xYRRWUUnzgQzhFbhr8yoviKAlFhM/jtngfEkkDo
ZHulpvWl9jWBaBLHVtbpkS6VtZ/NWnRh8nOKPxBGyq9O6xxm9r8gpEy173U3
YZ7/IAw1snk5tJnas4Nwa3Rk88BlNP/aQbBvFGx7nUA6guBh+PHwq1hiiyCs
XGGgpvGT2a9k+imXqPou0rlBcMnuGPy9ifYrXhBqDbnPxi8kzghC3oD+Hou6
mf0sCE/elk1tG0P2RUEofZZ62XUVk/8g1GiUecUoMvkPwvuCZcu/6ZMuDcI9
26DeVyGPKf4gdIza5RXQTiwXDBV5y7Gb5Gn+WcEQ/xmjsdqU2f+CYb97cdAX
DepfOxgf4maOmCym9wGC8X6Hw8/Kb6RbBCO07+4EA3WaL04w6n4fjnh0keaD
G4w+czw9vtxn1n8wFgWYr+7tov4ygrHgoEvmlf+9T4JR+eyGfcdr0ouCcWzL
wvpjF5n8B2NG+fzm32DyH4yzCqNy01uY910wogqVnPp9Z9Z/MI5Ubxijt42J
PwRyr3/uMmTWKysEhhqdZ2+2EbNDcGrXTYOg98TaIcg/vmBIZiKtd4TgRqBF
nxVq9HxYhGBIP6MboxfS/ssJQdNeN/GtWbQ/c0PwbOdq8bDbtJ/wQjDAs+uY
ZyntvxkhMFibXOOzn1gcgp/hs854ZxAXhWDB3adfnZbQeUYSgsIz1/fUNdH+
VRMCtdU7lcVbqP4nDYF0kxk/U5HOVx0hePrX8W3QYeb+EYqW7tkhGEX7MSsU
c7a0+RWOpv2WHYr0wXc1P4fQeVQ7FJIFl/lhZhza/0OBCzbjTuq4UvyhqD0R
8aBzEd3nOKEQn3Z7veIy3de4ofB86/VcsI+pL4UiSzHmY0Vm0T/OCMXcW30n
3x1G9ytxKKp2YLVVE9W/ikIhN+jJtFe1dN6VhOI75qzz+0P1vJpQbNvubevw
lOo70lA0HAq7v7eS+u8IhSb/pHa+C92H5cIQVrpfXn0MjYcVhq+/PUd4vKJ6
FzsMhn1cJI7NdB/WDsPO+KX78xIoPoSBPbx91fwFe/+xRZjs/jnmMC/NlvIf
hrehgfrC2TyKPwwH+guenzCkeh0vDCH8OQ8ve1J9JyMMvfs7J+2Kpvu/OAzD
Z7XmH+qlekFRGJw7Hhd0at2i+MOwbVv39T2RxDVhUDvM7uffRO2lYRhTMtFC
v5n665CNf3LPub++zP07HN/eZ/yNcab6GSscXYbBPVuUqD7ADsdVo/LAISeL
Kf5wqOU5Fg2/ztQ7wxF0cX7sIwOaX4twvNxubWHvQfUJTjgMItgvZ5kQc8PB
eRbpe8+L6o28cGhWTRmetvcKxR+Oy1e4vmEDaPzicLAnHB5wpI6JPxxRxX4T
SoyoXiIJx4e6+oFHGqn/mnDoayst2B1I45eGg6V3esJ7PnFHOMqXLq9te8LU
PyJwc+aH+TtO0/hZEZg0t3uPxjmKlx2BX2P0T1uuoPWiHQFOd/3KHjNab4iA
cHb/wdlXyin+CIw6pjF1UDZTr4lALdQ2ZTXT+LkRKNR+zXFfdY3ij0DlKjUr
vkYlxR+Bqvh9VwwLSBdHAA+W/dzqR+MpikDH/gn+5U+ZerDMXwO3X6FCLsUf
gbcdX2t+2SZQ/BE4+PNSmf8wqp93RKDiJt/dbBrVZ+Qi4XM7eMbcmGMUf6Ts
vlx5UfkhxceOxNVHGlfNFah+qi3Th3p/fbGfqU/J9LqR9Zu/UrwWkaiOOxI0
JovWIycSabsuexuuJJ0bibDkl/BSYOKPhPcV49y6NcQZkYj39HaNPUDtxZGI
GJKWUJXN5D8S4tbYyd6cGoo/EvYvFl73DiWuicSQnR4nxvah+qY0EoadX97V
skjviMS5yw9zMuuI5aIQsju4zjWFmBUF01kC4cm0+xR/FBxGdnZg012KPwon
A25PeF1/h+KPwpvcNVv8FW5T/FFoPi3U456m9pwohFqOTV65jdpzo3CupElp
yyvqnxcFdrhub0Mg2WdEwcvii1NzCxN/FH4UHVJKy7xJ8UfB5JYtx0eTdEkU
fh5qE7WKaP3UROFgrq68pRGxNAqp+bcutcXR/HVEocBWPaFpJuly0fg7Zfq1
k4/o+WFFw8M06pRaIensaFx6fqOwfS0TfzSeXv/+OGMqjRfRuPde2HXKi+qb
FtH4ILo63+4/qsdyopG/O9fhyB2aX240StqnpizKInteNNJz7T7xjEjPiEZ3
zcMP0bHE4mgo5h9P1ehP9dmiaGz91Kbp35dYEo23A4wcypKJa6KR2u/rVK+9
Tyj+aDTrnZw97AvVbzuiIZi7PMtiAFM/jsHe1vZeaSPVc1kxWPYxf2TFbdLZ
MShfELd28dFGij8GCx/1PxF+lhgxCPv17OLgsy8o/hg8nD4k73EBMScGuUl3
zLK+UD2cK2vff/imN9XUPy8GPtUZIpYPjS8jBgqd01OjNEkXx8CuPbZe5z7V
o4ti4Hq4pM/yEeRfEgPH/cEvp2QT18TA1O399ZerKR5pDORn8Je0N1F/HTHQ
73e2MUXpGcUfi5YzKtunryR7VizyrKo2uX6l8bJjsTJwTuf1WCnFH4sH8ubH
zC+QPWJRNMFW6dlSYotYHGxqe+4+hfrjxGLPMVVF8UoaDzcW0pIlJTOOUH54
sXgRvXRHmwLVzzNi4R7H6vNfJlNPj0XbpsLRZp+Z/Mci8MfV8klCmi9JLNRm
7em9+4yJPxbGZfvl/K1oPNJYbPr9PGOeBeWjIxYLb2243XTnJcXPw9c9Wm6t
kyleRR5+SiNCEnYRs3jg6Px4V/2TWJWHKdNOffvZSPZsHj7c+3VzsyHp6jy4
v7kcdL6WWS88fCqdt+Ekj1ifh3MXDif0raLxgAer050fMp6RvRkP6tc6nyrO
Y9aTbDxjYofkFJBuw0Nx8P4flzeSfw4PjorF+e4PSffkIezkKZfTQ8kfl4ek
wdqfXBRo/sN4SOu61ag2hll/POi9kPPlTaB8CHjw6xj+zrCF2mfwsDt07VS7
ETSf2TxUvZ+R/+YMsz552OAgvzPWlvzl8xDyqfyqWxy1L+LB+O+kvHsXaHyl
PPQbG2Hds5Tik/CQ80djwvsoWl9VPBSu6dm44PwryicPnkXRvO8XSG/gYfrI
o+9r3pAu5aFzR25YdsDrf9zKQ+CY1heOyW8o37J8JH6Vlzd8+4+7eLhrVZg9
zIJYLg6fD9x1UHZ8R/mPw9vBzaOGfSFmxcHy0qr//ngRq8ZheXTRc/dWYnYc
pnSmFZ351UL5j8Pfb0OKV1sTa8vaZ7dYW4c0U/7jEHSroLo7lewRh0iOya3T
v0k3i4Ox/f334hhiizic1b/eofeJ2tvE4VJaU0ioaSvlPw7iI/M9Wo2IPeMQ
sqhlzsUpHyj/cYjqrjccpfOR8h+HVVfiNxcOJ+bFoXh3z4S6qW2U/zgMHVIc
13c5cUYc8sIaB+DaZ8p/HIx4M/tdMicWx6FQUBTQdyi1z4/DuN3Ls+acJC6K
Q1fDg5SAiZ8o/3HYU9Dcc+sM+ZfEoW3tUuPZU4mr4nB46a7Aws/ENXGYWuF6
8NRl4gbZeDQsw3Py31P+47DSTuXAi80Ub2scQtmi8wrbqH2HbH4W8Hq2q9F4
uuKgZvQRf3fQeOTicWHF5KeLQbpiPJrLl52paKf+WfFY6T6qxN2Y+leNh5N7
vYFpGTE7Hj6uh5emPCZWj0doYPa9nOnkXzseVT0NDtsPEuvHQ2/tO/1B4eQP
8XjyKXvPFVVis3go6CbVyBnT+CziwTb6paGiRmwTDxWfTff6OhJz4jH08rF1
OgOof894XKxL2PvJh8l/PEKs99484MTkPx4j5m+8flqR7HnxCJ+XaqJzh3RB
PFgzw00nJpOeIbPXdZJOUafxZcdD7pzd3B/M+hHH48i0RT6lD4jz45H+oun6
Yhfionh8W3PddDSPuFQ2n3NPJUjW0Pgk8cgY38Jzn0RcFQ/Ynh7hp0dcI5uv
4CqVFAXihnjctrT746jB5D8eedJYv2Z5Jv/xaNe6U/7mOj0PHfH4dGJdn9fp
9Dx2xUM4NDw2djM9X3J8pDg5rRn/kXn++ehJaXCurSCdxceNdM55/nliVT7A
Wl3j6kz7B5sPpfBXReVnyF6djyvLllsP5VN7bT5U7WfqxTH7hz4fj/eon99R
SDr48NvgYNq/L43PjI+8qCtDr0wituBj+a8PiZbZxDZ8XB2xbvaRFWTP4cNw
sWX+1rvEnnxEzmvpt6sPzQ+Xj6QRuzJDo2l+wvg4qKmyv+8R0nl86PTf1bTJ
huZLwEcEd6ONsIw4gw/JuSG3Xi4mzubDzUo9q2EK2Yv5uHv4TcFNZj3k8zHl
er/auVwm/3wYKJxamB3E5F8W7+iFc7gOtL4kfDxb/3vRAF1aX1V85PwUTBe5
E9fI9GmuGhHPiRv4OHHTcJGGDu0/Uj42S1/22v0gbuWjYsW9S5mW7ZR/Poqm
zhp5V0zcxcdYk/y2GdrEcglYuvJkd6A9sWIC5A7s85+6oIPyn4Dz55bMQh7p
qgm4stbMZGMp6ewErA1Rb804S6yegBkdK59bexFrJ8D72ZDFk9aSvX4CskS/
SyPdSEcCNPqoh82ZQmyWgA2VtcW+HdTeIgHJeTMf+QwitknAD+P5qhfDqD0n
ASG5zxfffU/smQB9XS2+yrYvlP8E5FZmByzJIT0sARGX2JciThPzEmD6rOTa
thpiQQJO7dhRPvgDcUYCJL9HFKdupf6yExCGpzlP00gXJ+Bk7+pljtak5yfA
wurbjod9vlL+E/CoyTH4cxPppQnIHGxw79BzYkkCIv/+fiYSUH9VCQg0yld+
9oPirUmAdPRb/9JFpDck4ILCUYXx2cTSBAzL+zNBfg9xawJufdF2O3CIuCMB
FTXlp/XHkL+uBCyvv2/8aSWxXCJKjDNdbU2IFRNh5RL9YOpaGj8rEZ8mngtz
W0Ssmgh1k93Vnf99o/wnYrjK5wuaj4nVE+EjFH8c0kjttROR573Z/PtY0vUT
MVS9aVVuFelIhI7D6lcNysRmiYh0GvNtymIaj0UieoME3dZHiW0SETWy7rvx
RmJOIkq/Hu7LukPsmYjOGLGbayiT/0QYuE1caNNCHJaIj0lKIzWVyB8vEQem
T0w8/Yh0QSK+jcrxuWFPekYikmx6VQx9iLMTsUxR/1D4QIpHLJu/4Wvj9bVI
z5fF2/U3bM8fJv+JqG6vKxkcS+1LE3G+zOiJ2wliSSJ+Tullv1hFXCWbX42Y
frouZF+TCDOX2uNBV4gbEtExuG1aTiu1lyZivrHC4TkTOyn/ibDUMDntEUDc
IbPnOnfNvU3tuxJxY/uTgn5s0uWSoBibofWOQ6yYBFhUjdU0I2Yl4UHhvg6V
AcSqSTAyXBi1r4yYnYRD77mnrDcRqydh8e6YR0oFxNpJcHt15dvmp8T6SbAd
LxrTtvw75T8J3ywDJQExxGYyztrUv3obsUUSqt84nPN2JLZJQmTxxCEbL1N/
nCScvZrlK3Qm9kzCpvr7vat6iblJ+Kw8u1/zauKwJAQvUfr59yDNB08WX+2b
Sw0GpAuSMHSPbv6+QeQvIwkzrm5m2bkQZydBrp51yGImsTgJN/VLp0RvIfv8
JEzoti0y20FclITjj+70Vm8jLk2Ct6FWSfdRYkkSuu4kmRq/JK5KQprftdKd
b4lrkmCi6K7VziJ/DUnYUfvUpC2UdGkSfvwOEVavJL01CWzlwubma0z+k1Ay
0P1B/13EXUl43idZ4el+Jv/JaAqaVpCwmcl/MpaMLvi4cir1x0qGzpGvMZKh
Pyj/ybiUs+Zq3CZidjIU0mNeLMsnVk+G4cjoR2ZSstdOxu79aQFDPYj1k9G/
6jzn+hom/8kYd1tv3PSNTP5l/irSdu6uovFYyPrrvrPC+SnlyyYZZfF1iwfZ
MflPRkfdXP1TXLL3TIbaSo29iUy+uMl4IW878ORGGl9YMsxGOCjHlZPOS4b/
w64DfZ+SLkiGnHz+hCkbf1L+k3E5Yynv7k3i7GQI7GdkZnoRi5Mx+GFMssp2
4vxkzL52Vf/4auKiZNx+cdPX4wVxaTK6H68u2iwiliTj3bLR6z6BuCoZB7ve
DZq/hLgmGfP0+46NNyVuSEbcq2E6SkHE0mSMUp3W+GkNcWsycj5NHVNVS/F0
yNrvwfjtn4i7kqF3NMc/YTK1lxPAOa3vjrJo0hUFmPrASW//QWKWAPdMHSKK
ZzP5F+CNeovRoVFM/gUo5E3bZiNg8i/A/epNds5MvrUFUNarjN+2gcm/AOlT
hplGpjD5F+BcM69+rxmTfwHenSiLYfdnnn8Bzjbs36NVTvm2kenzJm7IvkDr
gSNAcY+68/ZzxJ4CeM8o/0/TiJgrwNYwgXblGNo/wwTwlNecUpBF+z1PAJg/
aBjGYvZ/AUbzsnvn/GDe/wKoOyS9GcQlzhZA/Kk1tngCtRfL+jvT3JAXyLz/
BZh4XbftHvN+LxIge5pd9Vo98l8qwIetpT+GC4klAqht5mevKyauEmBL1jgN
VhKz/wvg5TxNQXSW+msQYPH7z5yqcGKpbD66Z/03KoTatwqgmf38o/Vu0jsE
OHi6PaSglXn/C1Ci1zL1FI95/6eAW1YoJ+Qy7/8UzApsOZ0+ijn/peBEnOb9
6WbEqinICFk31reAOf+lwGuY1rOEN3ReUU+B+dR088o7dB7VTkGBe7N9lgFz
/kvBgpVlDyy5xEjBBdejW836Mee/FNy9pbbh2Fuyt0jBpk69iFtJzPkvBZac
kiafb6RzZP1n27BdtEj3TMHgB9aSR4HUHzcFJXuT8pLqmfNfCjKDNma8q2DO
f7LxfCrja05jzn8pmLuJ88NDg8m/rP3Jd6lH+Mz9LwXv1i0veX6Ozu/iFHgn
HtsXfZ84PwVm5ZMqf58nLkqB4Z+7e2PeMPf/FKxo7t7RVsHc/1OwZnXO3k/1
pFel4JJ747C/ncQ1KZiapPPSXYe4IQVy96b/1FAilqZAq+/olcfHEbemQPhD
kFOWT/edjhTwA3uly4KIu1KwzG3srxd/iOWEKB5hZXpcl+4zikKk2j5uj2pm
7v9CXD/13zX5vsz9X4gJD/qcP1fF3P+FWLc3KzOzD/lXF+LSpPFu1VuZ+78Q
B5qn9xpPYe7/Qthn/TwYcIoYQhjzyj9+n0tsJmvf2jl3qYj8WwjBmjDj58oo
Yhsh/u5vqJ3pwNR/hHjR/1tiQwlz/xPC+11x9JfZpHOFuJf3NTvMmjhMCAP1
eb4PXOg+yRPiy3yL6jNKxAIhNGyPGy2LpPtqhhCJRrPWa28gPVuISXrTnef/
ofuvWAgzt8PN87ZR/S1f1t5g666KzVSfKxLi/rHp0zJsSS8VIjc2jPU5i3SJ
ECZdQ3JDlxJXCXH2UMGvWD1qXyPEzca398fdIW4QQmVX73/a+VTfkwqxZT/3
3nkN4lYhpg8f8TaWS+PrEKJP7aE1xqOZ+p8Qe/pl6R4tYup/qeDE6ZrsXEGs
mIp1ESPDB3SRP1Yq7pwxOHRnM/WvmoqLyUmDzmsx9b9U9Bjr3hn0H1P/S0Xt
ic/8sEKm/peK+TsfqgzKJNZPxe6vm5TZhZRPpGJi+LjX7T3EZqkwX5BUN8WS
1pdFKtiNvGmjHjH5l/m74WV3yY+Yk4rhehUtYh1iz1RY927e2DeTqf+koitc
dMi8h7n/p8Iq547Oo/fEvFSozU3duISpHwpSUbbb4eyvQdRfRiqElU3iRXHM
/T8VrUMejtW8QPGIU8EqjHLnC0nPT8WL4ow3Y8eTfVEqHvvqcHCQuDQV8mXH
XML3UHtJKlRXfJCc+k1clQrj5X7vXu8grknFpcUaS88tIn8NqajvDVjv4knr
XZqKmtmJVtsLKR+tqXh46a6XbTpxRyr0/ZeGJ7RT/rpSUaVUfaYyjMm/CC77
R8R25jP5F8FukIv/B29ilgjHO97Pl5vF1H9E6KcUGWtxg8m/CHlj1JN3eFJ7
dREmpe68Uq7E1H9EcP8+qXGkClP/FeEF7FMND1M8EKFzaexhdj3FaybC2v1q
WgMzmedfBOMlf1KOL2TyL4Je/cRxChFM/UcE5fXBHzMWMc+/CLcS1pnyoom5
ImQana8eoU4cJsKR2YNDF4Ywz79s/NwRE+PimfyL8Dt0qM6hHqb+I2s/YoGl
dBT5zxbBaGR4/xuqTP5FUHF3Ljg+kvrPF+HJ2S15OdNofopk7Ztn83Z6EpeK
wDFd69maT+0lIjSO3ODl/5n6qxLh7NKWAYVWTP5FqBvboLPCicm/CN1q9deu
xhNLRWgz237qbQVxq2w+OkxK1yoz9T8RAi9cmJukRNwlwo/Fr4qe21F7uTSc
StXRffaaWDENfWZvtc5j/LPS8N+4LQeWGZCumoakPrlag5j42WnQHWRwxseM
qf+lIfbYPaXQgcTaadihlyftmsfU/9JwjnW+XbWUqf+lYeztZ0pW65n6fxo+
f18eNKud2lukQf5b5SlTLVq/Nmm4dU5dPjWAmJOG4/a53UP9iD3T8GbBK80L
rcTcNARXxi0eb0DrMywN6XlGDcPHUv+8NJitK159J5faC2TjWWy48w2z/jPS
8HdDQWLPG9oPs9NwVb5vSecHYnEa7t7Yrlw+ldn/02DZ7fxuRwH9XlOUhtL+
jS9WqdDvVaVp0HrQ777l/36/TAPbfdhORxPiqjTkny3gerbR71E1adh/+H0f
Px/ihjSo3vHx3plBvw9K05A9x3WW6Tz6fbA1DQ0P9t+/Zcf83puGI2OCHFZf
pN+rutKgOCH7u9iG+pNLh8VPs0s3aun3a8V0cB5EzF8WQr93s9KhHbd3tfwf
+p5INR2wUU7cGErfQ7DTIbfefss9U/p7MPV0ZEz+PvqzG31Pop0OVnNUWe4K
+p5CPx1su6GdQ/ozf2+XDq630zzrR/T9iFk6eALubScj+h7IQta+6enkAa/p
7/dsZONNuLl97R/SObL+Ry5y4VXQ9xie6fA09zXzCmC+t0hHmPuKz6Z8+n0/
LB3S30Gzjy6j7xF46RBYrC6u9KXf+wXpkHh80rffR/YZ6Wi43Py87yCyz5b5
M1+hNbWSvocRy/pL1stcFk7fA+Wno8aN/9jZhb6nKpLNz/vmO+1H6fuVUlm8
O9pPvnrF/D1eOkpZRees59L3OFUy/Vjrsnvvme+ZZPkwuzWmvz+Np0E2vjdh
B+04zPcN6TD7uWFAmCFxq2z+L594vUqJ7Dtk44+cPl+zgeLtSof+55GxsV70
vYncNohnjNXvq0asuA1FVwSLhVyKhyXTteJc6lWZ/G+DRaTGoC1WzPdB2yDR
mrt9+JFDlP9tgO2+M/x3mZR/GZe23Ov6j74f098GztU1H6NG0/c6kNnzFzr2
2XWy/P8Arhy0EA==
     "]]}, 
   {Hue[0.34878707749138016`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenlczN/3/9iSPYQQJpIijD1ET1kqSyohJK1UWqZ92qdpm5lmaiK0WCKS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     "]]}, 
   {Hue[0.5848550549911664, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenk01N///6SSFqVdq2n31mJJJW0PJVGREIo09p2xj33sMxi0oQ2lIqlU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     "]]}, 
   {Hue[0.8209230324909598, 0.6, 0.6], LineBox[CompressedData["
1:eJxVu3tczNv3xz8UJSQkSSgluZZcTi7xUiRRci+lpnTVbbrfa2pmaqopISQk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     "]]}, 
   {Hue[0.05699100999074602, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzF/Uz54t2RLCZA1RiFLiI0llK0qpZEolUU37tE/N1MzUzFQiSYgs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     "]]}, 
   {Hue[0.2930589874905394, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenk01P/3/7SISlFJ2rWLkrKkjQeVFAkpWmhIshv72IeZYRiDqGiRJUkp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     "]]}, 
   {Hue[0.5291269649903256, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmndUU8/TxgFRsWPHHrEhNuzYH7GBFUEFK6EjvfcSkkASIIAd/VoQGyAI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     "]]}, 
   {Hue[0.765194942490119, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3lYzO33fzyWeEhlC8XYQ6rHksr2khCRqaS0aLRpb9r3mtaZmpnKluxT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     "]]}, 
   {Hue[0.0012629199899052423`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnk81N/3x0crbZQWfdombUpJUrTIq8XSJkURYpItKWPfGWMwM8bWRpsm
ISVZorQxpSRtU8nSIm2SNlHS/pvvo/P+49c/PZ6de865555z7/veM4139l7n
2oPFYrX2ZLH+9/e/P+3GrP//B0MPp3HKWg7TvytDv2nbkF4PCojVMDqx3Ct4
8YGKfzwUwnGTk9PaCok1cLOxf0X/siLi0Zh9y3HXoLBMYjYyQ+JN0qqY8ZrA
vVmbnracIJ4I5RseZ4oGFBNPxql+O4NN9Q4Sa8G2RcXUv3sPzWca7tw4vXDO
psMkn476E0V+vR8cIdbBu2+Vxcal+4h1wZkw6bu2xQ7SnwU1v/k6lV3uxHrY
58TbelN9N42fjffL+UKlo4w9fbQoBemE/EgnnoP7rUnCkkUHSH8uQt/aL7r4
fR+xAaSHlK0NfaTEhtgpt4qdYXWEeB6UDb/mVWgEk7358HIxvHZr71HiBdCu
PdH+evMZ4oXom7DBwv8Yw0YYksN6cGJHGfEiKF2vs/DbIiM2xhfXn63HN5UT
A9Iq1oZ8vQv/mAcEtnb9lKqVkHwxJt4fubHpDfnnLYa+sd1mgXkWyZcgsuvp
Ht/0bJIvwYFFxxOc2OdIvhQrE3tcsVxyiuRLsXXqpLyxF5j5LMOooQWnL+y+
RvJlyBMIlDT6ErNM8OvcOJavhJGboH/w955LxZUkN4Wxvk9aj0qyxzOF94C/
fxNnXSS5GdoT3yWbRDLxmcFxb4h/y77zJDeH0NswX3tFKsnNYTl5gfQwi8nH
cny9F3754Jpd/5i3HBz3s3rnDzD1swIn578eGeFJ9c1bAeV7Nt9rk46TfCXy
m3Zx5s05TfKVaN3x4Wy3DqO/CoYIbjiyeAvZX4WdTp6rTVfsJP+rYR0xY9mS
HvtJfzWQdMbkyDem/iygPNoqNb2CsW+Bm58/GMu9GP9r8Mr6ukA0nuqBtwY7
J9w1HzryKsktoeG+sNfUzCv/GJbA5Pm75w8k5lnCckG46uFv1/+xzBJVl/s3
JSVXkf5aTP/TuUejrZr016K6h8OJ+qKbpL8Wk1YMMMeVG6S/Foucu2u21d8l
/XXoer58fuw6yi/WQedhd+1Ylcukvw4JUzpMCgZTfLJ1cDl+alu+NtUTywo2
rpOXvBBSvcIKZb3bwqI/niR9K6SutjqYkUf1LrOC/pB+AbbNjL41HIM0x1SH
0fkDa1g0VretHEf2eNYYWHDCT3Mr498a3Hc6pgZTLpH+erhmJ39fnkb1iPWY
rrtnXWEtU4/rMbJVsOFYI7FsPfqe0yq4u4ipvw24dMH+wwI7qldsQHXbu3zO
NMb/BqzLWLDg8qAK0t+AVyqVB4tmM/vTBr4+31+7DyR7sIGNsf80iwZm/Wxg
2nE47WIgyWU2MLsq9VLOKCV9W7xy2Hqj8hLtb9hCUPZlX9h4KenbwvTCnlSv
LVRPMlt82fZ78FQ95nzdCNZs26acYq1/9YqN6LHJKEL0LJvqeSPaf/+2kngk
/2PZRvACim1aualU33awUx/5oSiI9h/sIJ/mVSIJFZG+Ha7u5xpEGuWQvh26
wkY7vRDnk7495i/andn0oIz820PtcefSC+erSN8eY54O4U3quEL69jg5ccaH
7zvPkr4DdlVGqU3td570HZDzo76P2berpO+AESvnrOsez+g7YJmKjaD1/i3S
34ThHs/ON366S/qb8CLn8Mf/+stJfxMabD4cyThELNsET1Gs9PnrGtJ3xPzj
B2zPJNB84Yhpvy3PTJKRnOeIa76QaQdWk74jzDk5BsOjrpG+EzQdK8Y2/JGR
vhPW1A1zbH7IxO+EbNaVjo5lN0jfCWzh93KHW8QsDrbVtKz2XUfxsDlQz60e
MZV/m+xxcLB+Q9EClfv/mMNB7YQN915m3iH7HJRZq2wTsWm8lIPhfqV9hlWQ
XMZB6Mdu3p2bZL+Zg+CjLR9vfqf1YG2G+thzyexNZJ+9GWdTL6xd+43xvxnb
ZBYLt5jTeM5m3N047WfaLrLH24zF5im9M0tpPaSb8YVr8uDGUCZfmxF11Gbw
FaXL5H8zcM7okaE6McsZP/qr649fWUn+nVFz6ffEk+oV5N8ZN4xU19WrnyP/
zrjyaVDl3D203jxnmJrd737EKyf/ztjepJR1ackZ8u+MNWZ+J9tzGP/OmBw4
OcTkBNUXawsmZ9S7mm28Tv63gFvaR2VXNON/C3RkZ1lWNVTfnC2QG0uEJuoX
yf8WWBt/6LtmIM1fugUVb2a4KBWQPdkW7FcaY7LmOdVP8xbUTagc8dqc5CwX
1K5wvHHMhNaX7YJs044hd0PukX8X8LQfe1xMYdbfBXfqeQvXVlC981xwxjh3
XqPZTfLvgru/zq4vGcXUuwtiKgc8Ew6i8c0ueGG3JU8sI2a54mD20Tz7dvLH
dkVb3fzylj+Mf1cIDnW0PC+tJf+u8DLwvuxWXkf+XfFl1v0o1Q0PyL8rth9r
mthnEenLXFF8zcP72VGqr2ZXvDRXPqXkTuNZbli2aPg5Cyeyx3aDsZHM0b43
Mdyw31n3456lDeTfDUrxN9ZdnllP/t0QPbSr349hNF7qhiHiDKOCCGKZG6YW
zoq7Yknc7Iatp44JPzZRPCx3/Fm22kp4m4nfHWOOzlAZzyU53HH8ebfw4Cfa
Txx3lIdWG5X0o/3Bc8cypwN/8w1JX+qOsSmzt83hULwyd2zVuPu5dyvJm91x
qudNwXo3krM84L22x4OwSCb/HnAo1HRTsiA5PFAxYW7B4gfM/vfAvYhdKhOZ
/PI8kFQZr3HQi/HvgS/NTcUtZcz+90CHxF46yJypPw+8b1nVaXSF5s/aitzh
97fkvSQ5eyvG3f9VJElg9v9WWO+8EvjoD9UrZyu0Nd5ES38w+38rhDM2PDL8
QPORbsWKUz63k+cx/rci0KfeftICqs/mrZhu5e9QM532C8sTSk8vTByUQ+cF
2xMfrxnVuz0jhif0eabqo7gXyL8nzufl+YS8JOZ5Yrzf8//WnL9E/j0xdEdq
gvMA2t8yT+hpxzriK53HzZ7YKVN5+OEa438b4kqz+1/dTvNlb8Ny6R6rIwuZ
74mCE3iHiz8x+28brpUq8c9203rztoGtusx6XTlT/9vQX/rRdN1Aqh/ZNgju
d2skz2Hyvw2rZt7W12X2M8sLlztyHi7ax9SfF742Oglm/GX8e+HvRZfdz4Yx
9ecFzrhz690dmfPfC15G1dMmS6g+pF7QX994RjeN2X9e+GTbUl6RyOx/L2Ss
/G9RYwdTf9sxd4u9SQSb8b8dY2ZPsm11o/xiOzjPY7/O6EvM2Q52782jTQyZ
79t2nLq9JutYJH0vpduRwrEP7dZk8r8dUxss20alMvnfjqXh8vNrKpnzfwee
r387L8OcOf93oFovZNgJe+Y+sAMOv9pPBRjRfYGzAx/lmiXcHDrveTtQXzbq
yRltsifdgWj1U2Lzo8SyHRie+zGtmU/10LwDVe/6nytMpXpneePQ3R23F3yn
eNje2JUVVnHhNMnhjVVs+4nD+PS95njD9Ovcpq4hzPp7I6vh09dQFvP99cb7
GadWbGf2h8wbx28P2F3Kpv3T7I26m/E9M7yY85+LsZZDaqq8yJ8aF6f2/H02
bRZ9T9lcPLLT8RniSuury0Wf2ZZzyk1oPuCiqOvTmwU7yJ8lFw2fdXYuVab1
5HAR7hO0wd2VmMvFcJ8Zy/m65J/HRZnRSMPtn8h/ChdzHxa2ZVWSPSkXuhf6
aPyop3gLuRgzVr5hfBRzn+Hi6wmZm3U96csV/nOfWa5Zxaw3Fx/+a+uO2UXf
73YuWg/IXntZ0PeV5YOvldo3tTbT/lXzwTzHkTZPUim/bB8MHa+p+juW5qvr
A9V8+YHwLcz54IPyHlWtKfqUP0sf2B84ca+PChO/Dw7NH7vmmoDGc30QGD7T
UmM1E78Psg99Lqk9Q+NTfNDwl6O5Qo/5nivst5+4tO0zcaEPzgStaQmqpfuH
zAdBh+ZkproRy32g5/rwRNgwiqfZB3+4MzvTn1I9tivi8a80PCmn+Fi+qMpM
PqnpTPpqvnCz3lvkMZDuG2xfXAwfff/+Vbqv6/rC5fkDt1yPlIp/8fui1aTc
xssjieL3hfS3oP+Lhs0Uvy/OHPbxuaGeRfH7gqO88nj3x/0Uvy/u94t8tXJS
GsXvi4Z5Q/VzLtP7W+oLp8iXXRnz6b5f6Ivgz8vyeanpFL/C3sQHPFmaGcXv
i+f1vJPnDHP/za/ZF8nxRrbT7eh91+6LoMoDYbtSmPeTH+xUAyNGnSRW80N6
8mLJ5qH5/5jth6fbjwx/GHHoH+v6Yczv9CXnp9B7H35IsTHu36UaQ/H7Qbb3
/pE4dT7F7wd/h6SJD2/ReK4f0JGo3dmPeY/7ofs09g+tJU7xg5+qmVO9hOYj
9cOT46MCQo/SfAr9UFP5NbQA1O+R+cF02oTDqXcz/rHcD5GPi57vb6T3arNC
X/t8KJKOUfx+YFdmNT0oT6L4/XF17r19Bt1xlH9/cPdWTO8htqT4/VF7jvsm
VC+T8u+PQp+/169+dqb69wfrd85rHy71uyz9UfRV3WfubXqvcfyhpXrVaq1q
CeXfH4bf15R686ifyPPHxPynzikvqL+R4o/goWMPBxow8fuDk/emt2wj9ZcK
FfOx7e/dZEvvVZk/riyeLDa+SPUg98eACNGp2U40n2Z/3F9ePdxhB82/XTHf
/KOR64J0KP4AXFxc0D7sHfXj1AKwcOOGFauP51H9B0A+I/ec/5Qoij8AmcEX
Rq2Xn6T4A9Cper3v4KH0vbAMQLqNS+sYGyHFH4BVy63tHr9KofgDoPvcTSZb
Sv1CXgASOwe8Vg0XU/wB4I02UDe12UD1H4DuzQHZq3muFH8A1KZir8tgqkdZ
AI5dVjqurJxD+Q8A61i2ygX9nZR/RTwXW5wXF0ko/gDMVU7ycC5m+rGBOLGp
6EGYKvVD1ALBWj7n3Isyqi92IA7s1GzfZkn1pBuIDgtva50pJEcg5o4v2D/P
nfq5loHocpI5jhRQv4ATiN15n16mt1K/kBuI9krbl/v30vx4Cnnp7sZDo2l/
pgSi/pTztv37qd8rDcRDK8lIQzem/gNRPjs/+qkr9YdlgZD9+bP6wVGyJw9E
r8rsnID7tL7NgSj5b7DevdnUL2sPxHx7VS0UUTysIKy6rz5tiT71h9SCkNHU
Wb/amfpz7CDoHipcOquL+iW6QXgxZ+GPhQIm/iBIsrznZu6gfpllEHKr+s+f
VkL9Ho5Cf/pf46vh1L/hBsHaq3ig4yemHxmEQx8WPxyynOQpQXB7vlrzZw/q
t0mDEJT3asd4b+rXFQYh755eMGsxsSwIc02T3OxyqN8jD4LZN97s3mfoPGkO
wuCoV72WXqL5tQfBZ0PU7uDHTP80GD1uP+06cIP01YIRdcG9+m0N2WcHw/6q
8LIslPR1g+F4ILFhUSDT7wrGnOID5c/X0HpaBkMt/ElilBHljxOMASpT1oU+
pPxxg9F8eQ3bZ1EQxR+M7qrT3Y//S6b4g/H+VDUn8swOij8YD48P+LVjCZ1f
hcE4cl13wkxl6k/JgvG9ePwvG0Mm/8Hgmv/tn61E9dgcjDteYebW88l/ezCe
LJjrenoRnZesEAyv1/+UoUz1pBaCiYanrw21pfmzQzDXYtkHldNUH7ohcFEu
tjMvYPIfgkuNXLlzBdWXZQh2L6yvb7lL5xknBIM2mmrWPCf73BB8ulR9uGA4
0y8OwW/7vrXfRpO9lBDEub9tnKVG/XNpCDIjq8PUrWk+hSHY6lf6w+A61aNM
Ia9am/QzjPqR8hDcv/NTNyWZ8tkcgrvCXsOOpJO8PQSLevfZUCkgOSsUdZe+
RxxoYfIfiubVteLHQurvskNRHXS3bdJVJv5QqMuWfKsyJjlCMfGDbGnDGaoX
y1BMHV0ijKujfi4nFO8nLAgeGEH9YW4oKkytFrLiSJ8Xim2Zd1bOnH+L4g/F
nO9p31ULayj+UIT3dk3SGUdcGAq91sMFpyU0XhaKjpx76pbaZE8eisr1Xvkz
h5O/ZoX9qA0zozk0n/ZQxGfnaU7tTfXMCgN708ya+5q0vmphOJP8rcSUdZbi
D8OeooilZum0PrphsOA8DdD6zPS7w9A1cEHGm9O03y3DYD1z4XCP17S/OWGY
07XycLA6MTcMyyv02HvTqR/LC8P8DnuTqvPUr05RzOfdf/l3CnZR/GHY+HjC
ltiWPIo/DAuPdcd71lG9ycKgrDww5tBdOl/lYej5sOmyzSk6T5vDMM/8s0z4
hs6D9jDc0jcZ97GZzhtWOIQGdWMHrKT6UAtHTPqktUUuFC87HDp3wk+U/KH8
6oZjY9XJez/dmP0fDv2+eqMn8+m8sgzHpSaWX2wZrQ8nHIcd5e+3DqL8ccPx
Tu/X9Lx9JOeFI/mG2ipZG/0ekBKOLpslVvlr7lH84eg1edzRmyNqKX6F/0Xh
VufVGyj+cPTrXFKa/P4hxR8Ot182Ne3qNL45HB+HaI7aNZPk7eHQaBBnzx5G
clYEPJWe/owOIn9qETCdkTGztfYOxR+BJfWT2eHOND/dCER9YC0+FX+f4o/A
+sH7G2e/JPuWERCwOAVTltZR/BGYMbFqpCczP24EUuPGPD9aRMxTsMGQWea1
9RS/wr/m8XW/91J80gh8G3yl7GI5yQsj8MnPqNPpJLEsAnFc/XppAsUjj8Ci
njxO3UHy36yQOxS5pqY1UvwRKPlws3/VySaKPxJDflngUPYTij8S1r31hB63
H1H8kfDqMUPWdfwxxR+JHWZ9Fj77RYxIhLfs6RV8gMZbRsJ1RGhd9wKaPycS
LYWtEYInNB9uJApbb10aLqb58iLB+jrkJ+svrUdKJAxWVxZHZZJcGol3+St3
pkY/oPgjYbphYmMji+SySMSEvLjTmsHkPxIV/0UOC7Zm4o/Es9AbL5euYvIf
CQ1pq3ddFTErCtXqLezUCFoftSg83nhHY3YCMTsKa94eC73iQPZ0oxT1GZv1
cwv5RxQEoU2zLiygerCMQlL18yCulOqJE4WGBYEXYnOJuVFwcF6pslbG5D8K
Uz7e8pz7R07xR8EoYve7xglM/FHofJ/2eVkWjS+MgrC9dk5bIa2HLAo805y8
7wXE8ihceqp6cJARzac5Cvd1vhVPVyL77VH4OCn7gf4iYhYPidqrMuyTaLwy
D/sieToNySRX4+F7x4deKSU0Hw0e4mrWhS/WIX9sHt6dnRZ5PJ/i0+LhyWtj
9cVpZE+Xh11/h/ffoUv6hjzYrp2fm82sL3h4e+vzr1nbqJ7NeZDYeTZPn0/1
Y8mDBn+lS+tYktvyYCjL1XTvJP8cHrK1+umJJTRfDx4apnzrmn+YvgdcHiI/
5xjqe9P5HMyDtCDTIfscfT95PLCDOE4lUXR+CnmQLfla65NG75MUHua/d6wI
TaX7RLrCvsBg/Pe7dF5LefjxW+3Qlyb6XuTyMG3RSLtIO3qfFPIw8NAP0wnF
9H0p42FMmLZD2zfm90QezLpmG1WPovdNNQ+eVVpi1Rr6Psh5KLtRNzPxLN0X
GnhYGJls4VzEnO88yF+MOvXEnb4HrYr5jTjvFFNO7412HhyP6/12OXD6H3fz
wJ3nm3ZgHP0+wYrGiHaPp+phxf9YORr7E0Z+/pNz9B+rRSNljedatYkR/1gj
GuX9/7Zci6Hfp9nR8I2ea9NbTPFqRcNw9t39GrEH/8l1o3FrsmZvzAn7x4bR
kL54e1Yp0pPyH42Dux46nb8WSPmPxujj9zad0aLfAy2jobz6h5u8hd7zttEQ
C0YMDR/HvC+iMf3JoaHPomg9PaLx/Zhy3TM1uk9xo9FiOHEOZwHdX4KjYVfX
86DeL+b31Wh8OawU77u1gPIfDd6WlzWiVbG0H6PRuETHUO8J+U+PhrlnmN3f
Vcz9LBpeSf3emvnR+yk3GrV/N0/XeU/5KIzGn27561fDyH9ZNNysujnV9czv
sdFIm9Z0+KYK/f5brVifq5XBa/bT91YeDZ3EoleH9tL3uCEaAttG473NVM/N
0ZgzxXuEGp/uN63ReNWr2ORzOf3e3q7Ij/HyH4436L7UHY113Hq9LmeSs/jg
Dyo5y15E32dlPqpHHR7fdwj9fq/Gx+hL3k6fC4g1+BBkFrKjRtD+ZvMh3dug
23COWIuPlPQ5WDuN9rcuH1rm5v1+fKXzy5APxwn7+3Ln0HkKPjz65Rb0CiM2
50OStkKtXxnzPeHD98DKcKkSsS0fFqkq3h159L3i8BExp6ITj+h75sFH3ag3
veLZzZR/PrwH9u34eJ/kwQp/r0adOTbmOeWfj+AXn/z62RIL+egV1vVg++8X
lH8+rvZ0ERnceEX556OfJ4vj10Ys5ePV9WuVaqGkn8sHd+q0oTueEhfyofw8
/8H0NuIyPl46j95a5v6S8s+H0hPrbt0omm81H+VPlrlNiKPxcj5Y30JW4xWN
b+Bjt/ThEs7Z15R/PsZw9g/SYb2h/PPRu0NVPCiYuF2xPrxo9tvrLZR/PsTa
opET9Vsp/zEwKmzxj1rxlvIfg2nSlFf/DWij/Megz2J+16QDxBoxOK4ZP2Cn
+TvKfwxmnp8yuyyK5Fox2H9IrulzkOS6CnvdjrYHO4kNY3Btvqjs+QsajxgU
X+2lUvf1PeU/BnNusVf8VCG2jIHTpZrDv0NI3zYG8XkTGsI/0Hw5MUgvCX6k
v5rsecTAlTcpNCuRmBuDAdNSzxtkUPzBMSj4E6fUbz4xLwZZ79RfTOxH+RTG
YMUV1QOLhtF6p8TgdmMGx12J6iE9Blvsx3/VDie5NAbnLvn4l1UR58Ygadae
nvcSiAtjsEE1cNaAw6RfFgOvPy6HJouY/McgW9ZvVYUS+a+OgUdspenMgcTy
GLhd4M/d+IzJfwyitIN+FWSTvFkx/ttBkcZbkrfGwPf90abm2RRfewyM17Vk
nR1I9dAdA6Gp8eq3MpKzBBi7cUzT1iiSKwswbtFtQe+dxGoCaNuP2fUil1hD
gB/i2qExYtJnC7DnYkveORBrCTCJP9nsizGxrgD/Ta25Mbec9A0FyIrVleRp
EUMA//OtDYEPaLy5AAtO77iTcZPq21IAK5/G9xnmNN5WgIzPj6qs7tN4jgCa
BzbPKzOi9fAQwMU057fHQNLnCrC7w7TboDdxsADT7d9pXBDReJ4AI3J+ZW/e
x+RfgD8pPkf6GdL4FAEcB/SKrcii9U0XIEL7XkdtPuVTKoDF0x+lG3SJcwU4
st7PceV6Zv8L4PVh7ym1LGb/C5Cgif8W/SWWCdCieVC79DjpVwtQ6fDxx32r
Z5R/AQY5yJ35Q+l8aBAgNFM469pekjf/T19lV5kHcasA0jlT8m/2IW4XQKyr
XxrJJf1uAcxj8vzdSun8ZMXCZsu6JRpWxMqxOGmwbE1mFp23arGYtzwl3KSK
uf/FIl8l+3bcAjqv2bF4+buu4IuEznutWNieP1Vi8JDs6caiwexIyWMezccw
Fieu1Pq6LHxK+Y9F18wfX/nWpG8eC/XJjUF9U4gtY7Hie6jR68Hk3zYW82+E
1Tgy7wNOLHqYd5vZLqL5eMRC1bld3fgJ6XNjUSEP0enfh+TBsRi0ijOM843u
j7xYnDLPuVVVSfdXYSxiXD0NAx8w9/FYqEyPNGMz9+f0WMifiB7UFVL/QBqL
vb67TSbp0Hs2NxYtN/f3KDrH9CticWDLjQFnrYjLYnElNiMiqYTupzLFfMQO
dzu86ftcHQu1HuKZ+qb0vZXHQrvUqm3AOeKGWOj13Cua0cz0N2Lx1cnZ7cUH
en+3KvyrPitJ76Tx7bGwTHCw5mtTfN2xqK21fi+KI31WHKoMc7W+5dB7VzkO
qmGdmWEezHs4DgdrtR7bPCHWiMMSudKY2Uz/hR2HvNVHLsTsu035j0NZ/2cx
fn/oPqIbB7et5zp8XYkN4zDv7ahn/wUz/98wDryhhs8/Z9L9xlyh3358Hd+C
6SfFwe7yivdTPWn9bOMgG7zvUttQ0ufEoUef+s+/jtJ9yCMOvY4NdFvykeTc
OJzQCLA2OkAcHAeNiSW5FhuZ+18cHrgVdc1YSv0RYRzWu0xWG3+I+jUpivgf
PB9//B7ZT49DYNTllJy1zO8Tivk7eW5umk+cq1ifI051Y0H3wcI4BOU3tE+0
o/tlWRwizuou++tI90eZQr+f297sTLJfHYckzyFPssrpPSGPQ781DvyqTbQe
DXF4Hzvyds9htP7NcSieOkS04Tr1J1rj0LRt2IYly5j3rsKf7tIDo2Poftat
8Bdrm+/5nZgVj4t6kiP2zPtJOR493zY6PFzKvP/iYa5koaNmSuM14pE9wEh7
2RSmPxKPtusf7xltYt5/8VDt/1A/TZv0dePBettZo7uM5IbxKGswHx14ieSI
h83Yg9UW24nN42Gy9cy4mcx72TIedxdv2rl3L7FtPOblb+rZHEH3V048Srwf
dMomk9wjHpe7k7mVXXQ+cOORFXePd1qP2f/xmGr8dNDvEGJePDa9nG3w9hGd
B8J4cIbtz+AbkjwlHqYLJctSf5G9dMX6NBwfVXyD1lcaj9Rpd+emlRLnxsP+
0hLH303Me11hr/H9u5e9Sb8sHu0JdUuMHtJ6yhT2B/PCY/xo/tXxOPPzbNbG
r7Sf5PFwG/tU0/w35bchHjku7/c2vWbyH48eNj2eLb1G+q0KnnYzIXECxdMe
j2tDpoZauzD7Px5fz8ovfjag/LGEyD2eUOb3mLn/C6H5VFXLsIZYTYgVbz/1
mrCbWEMI0ep5/ZLn0/nBFsLppJFB0wTKh5YQqgYrvFR70fx0hXjoMa+01JPO
I0MhZL9KNa/8ZvqnQjRfmBhwzIPOQ3MhKlS/HNJ8SnJLIVaN/Wv5dy/FbytE
qcq776WxZJ8jxNDAeRe/z2Te/0KonH7e5302rR9XCD1+4Nvzr0geLMT0sV1z
F26g9eAJYbqv9qJaE3P+C1HFWX5XMoPykyJEx8Zrg5JXEKcLMTJzyi/lbqY/
KcRqDZ8lmXqU31whts03m/FeRPVTKESb1iif4nzqX5QJkX6ofOzUIfR9kinW
99Cns3If6ndUC3EpdeSdqUdpvFwIDS/L1LAkqqcGIYarBNZ6JJO8WYi1rROs
PviQvVYhAoa3vbZYwvT7hLDuU/ZO1E32u4UoC+in/12P+ncsEepKgpdl3yNW
FuHkLK0l5ho0Xk2E2e8LPIcuJnsaIjwt0F9clE33F7YI5h87nzar0f1FS4QX
e5sD5nnQfUlXBPHDbTpqQSQ3FKEzrtfcdfuJofCn89Jx6h1icxHifsjXnIsk
fUsRegY97HHYh9hWhDO5ooT4SmKOCOxrTeG8Kub+J8Ipdh/NKY7EXBEm79uz
eEQhjQ8WYVlK7xI7X2KeCEN2pvneuUz+hYp4fg1fK6hg3n8i1LBdsy4eYe5/
Iuw2NLvq68Dc/0XwzM/8sCac/OWK0HI4fciQCLo/FoqwsFQv1qWTxpcp4v3j
+jyeue/JRHhzfstg3xxaz2oRqionhxuaklwuwsVj3zqbG5j7nwj3Xjpsmsfc
95pF4HjfXLtvGN23WkVoO7mjfi6PuF0EQ0UN1l2k+1a3CCsNb18w20P6LDG0
tJyrcgeQfWUxHHbkH6pII1YTI/LT5Z4VM+n9rCGG14nzJXlFpM8WY/vgO4YW
J8m+lhjKfeaW58qY+58YNw5fyL/jzNz/xPgZ6zZk7zWmfyzGe/RY3Tmauf+J
MdRlYWe6McktxfihPHa+1Xrm/S9GT2Gv0Pdt5I8jBqa5Xyt4TOwhhjDVrLgu
jubLFYNtanfQS538B4sxZ9O+PavkFB9PDI13/aNTX9N4oRglUqML9gUkTxFD
/N/aF8N3Un7SxeBdWeWw5jaxVIyy3p3v9HYz738xrnAia6yOMfd/MTJvzh7W
acTkXwznQS+Vjs1h3n9i1PxkHR71mLn/i8HxvVRTbsbkXzE//yUv1xrQ/BvE
OGf+c9n5b0z+xTj73pC7tYvibxXDTt81r+cL8t8uhnGe++Nlysz9X5Fvw+Ez
vQ4TsxKg3Jd9baAOk/8EtBrXzlk+mcl/An5Zbp69J5RYIwHCK1muifXE7ATo
/1w+80QV+dNKQMeNGwNbS6n+dRNQG1GcdCGV3muGCRjgs5F1ciLz/kvAxSdF
ux+PIDZPwJcPf/NUkmm8ZQI8x1uUj+1i3n8JcKzllFxPp/4FJwEn6lmbp0wg
9khAS6J/3PAyGs9VyMO6byarEQcngFPWZ471GGJeAuq6AjC0L/kTJkCSOEhl
zirilAT0uHQ5wmM82U9PQNuj3IExJ6n/IE1AjXT27FNaxLkK+4Gf9Yt1qP9Q
mICxvTclbCog/bIE/CmWrRpnRf5lCUiy8Et9sIH8VSegqfi0wYfFJJcnIMfU
LuzrHrLfkADDeU0rhvwhblbkp7/6ycytxK0JWCha23ZsAvlvT0CwXnHI3tPU
T+lOgNzktdmbyo+Ufwmq7pj331fxgfIvQavW+Nieu4nVJFi4+vWiqy+INSQ4
s5Ut4n8nfbYEalnO0bLTxFoS1N7SH7nG4xPlX4LzZiKDjqPEhhK8YM/dcc6N
GBIsqeA2mCwmNpfgy/Rdukp3iS0lWF5zdP0383bKvwQzjAdZbEr8TPmX4MGE
lO3Zzh2UfwmOn38/y96HmCtBv74/3tyMJw6WwLTSSNj/GzFPAsuV1y+P9v9C
+ZfgWsJuU41K4hQJGo/+uaqfT5wugZnz4qmic8RSCfpzys7rfSXOlUBr8tHM
az+ICyWYprQpze0YcZkEq44MG6GRQSxT2Mv+pFV9upPyr1i/79NOhbwhlkvQ
d7rh45m7iBskGPPor596M82/WYJKrsHQ31HErRIoG4wL38WsR7sEcj2RZehS
4m4JBkxv2/M6l9aTlQirz05KQ1KIlRNxsau146Y9sVoiOnc1zX5aS6yRCJNL
1WkVd4jZiSiRbFf+1kaslYiX7z5KhjkR6ybC6Unj/TFniA0TMaw5UHeAhBiJ
uNvtyn5kQGyeiB553KMrezP5T8SpDwvHhrgT2ybC9DVfQ/s0MScRnENZK9dt
J32PRCzUffYnjUfMTYSXsu/BRceJgxOBu2cCPUaQPi8R5uy7vj9f0P4QJsK2
9Mtvs1nEKYmwPKQx9mAbcXoiuv3spv9g0X6QJqL1W1xVz1Di3ESobXXopbSb
9kNhIuZ+7sUa94q4LBF90iI7jkeSf1kihkxZzhs2g7g6EdX2nXV2s2i8PBEW
6cNmhnUSNyjWu2OZsM9z8teciKSlbzMSJ5N+ayJqF/N1vA4StyfCfb/xSJO+
FH+3Ir9LF766KGX2fxIuTltY/cqdWDkJK3rds01xJlZT8LG3Cb2Lmf2fhNb9
RSEDvMg+OwklLSeylrKItZIQ/iHvyBs26esmofDzuhxxNrP/k7C1lL/wbR8m
/0kI+/RLnB/E5D8J9tp3HrosILZMwuKiswMaTjP7PwnFH2xMra2IOUngf61q
evyIyX8S1Fa1Dzr0jcl/EsYV7NazGEnnRXAS9tSPPTtRleS8JHBs8krKmXoU
JuHd9k+ZY0OJU5IgtB241ompr/QkrLktP+a9muxJkzDG0Hlwx3Li3CQceLt5
QR6LuDAJS/srF8SPIy5LwrkenXLZEbInS8Ktg8u2NfQmeXUSBgw+qhG0lOTy
JMw9Eaj7YgJxQxIyHm1Uf2VH69uchMCZj7+m9SRuTYJdBhY16zD5T0KXh5MG
N57k3Umovv/00UY9krOSMSvPWGoyltn/yWgcvfbps33M/k9Gyi/HKct9aLxG
MrKqGn8NuMjs/2QMczTZsbIPzV8rGd9aN5msOsbs/2T0vH5b+fVsZv8n49aY
YxFey5n8J2Pso/Xjbj76VPF/7TGpHA==
     "]]}, 
   {Hue[0.2373308974896915, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lUzH/Ux4f4iSzZs48t2SNLlvQmElKTJdlHKpVt2qd9ZpqZZqYpIYnI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(B\\), \\(t\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
   "\"Stochastic CUDA Brownian Motion Paths\"", TraditionalForm],
  PlotRange->{{0., 1000.}, {-2.6644370482517443`, 2.9739194564863345`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.507140771015422*^9, 3.5071409658138995`*^9, 3.5071411839467106`*^9, 
   3.5071414346577797`*^9, {3.5071415554138536`*^9, 3.507141580197332*^9}, 
   3.50714223298692*^9, 3.507143851768264*^9, {3.5079968419993606`*^9, 
   3.5079968471713605`*^9}, 3.5376740999504185`*^9, {3.5397446895010653`*^9, 
   3.5397446943333416`*^9}, {3.540051590933977*^9, 3.5400515982803974`*^9}, 
   3.5400518034621325`*^9, {3.5400518778453875`*^9, 3.5400518912851562`*^9}, 
   3.540051935679695*^9, {3.540093073791661*^9, 3.540093083511217*^9}, 
   3.540093438975548*^9, {3.5400937395467396`*^9, 3.540093769030426*^9}, 
   3.540093842740642*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"CUDABrownianMotionPaths6", "[", 
    RowBox[{"1.2", ",", "1000", ",", "50"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Time\>\"", ",", "\"\<\!\(\*SubscriptBox[\(B\), \(t\)]\)\>\""}], 
     "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", 
    "\"\<Stochastic CUDA Brownian Motion Paths\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4995302681695356`*^9, 3.499530317843502*^9}, {
   3.499530354698188*^9, 3.4995304108328004`*^9}, {3.507135418870242*^9, 
   3.5071354333216867`*^9}, {3.5071407602223425`*^9, 3.507140769484269*^9}, 
   3.5071411799153075`*^9, 3.50714143396671*^9, {3.5071415631416264`*^9, 
   3.5071415798012924`*^9}, {3.507996829015361*^9, 3.507996846027361*^9}, {
   3.508043880145357*^9, 3.508043882981641*^9}, {3.5106929520697966`*^9, 
   3.5106930045339327`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVenlYzN8X/yBkH2vZs2RPiUi2l6UUrVRUqimV0qJ9X2ampmZapqyFkGwJ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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lYjF/Yx4dCioRQ1lEhoUISwtcSlS1b6pdltFOY9ml/pmZqqmmxl6XG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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnk41O/3/+edt9ImpSRtU1TaR1ok5alU0mKUULxr7AoZ+84MhjF2bdpH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     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3dcze/7x4+dlSJkH4TsUMnKKyMpJUVCOO1dp33apzqdTqcpKz7JsZtU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     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlYjH3Ux8ejiIcaeyUae9ZGRLb62hMylcjaaCFSTZtK2z3VLNWUSMo+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     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3tYjFvUH0QhGZfDuA9C6CRHyOXwQwhhSFSK6caUaLpP9+k+1XRBCGFS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     "]]}, 
   {Hue[0.08640786499873876, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmHlczF/0/8f66WMdhIQMUaEy9mR72ZNkLCUig1JJNe3TPk3bNK0ISRgk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     "]]}, 
   {Hue[0.3224758424985268, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYzF/UH4QsPwYhy49BEaEpSbZ8bKlsYynZRyppnfZp/9bUNO0Lkn2y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     "]]}, 
   {Hue[0.5585438199983166, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYjOv7H9niWELoxMlwOmRtInQIH4QsMSkJqWnRXqZ92qd92geVOMlI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     "]]}, 
   {Hue[0.7946117974981064, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczF/0/4dC9uwhjFAkjJCQvJKlkkpEREbaVGra95qWmWZptSSEkRAq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     "]]}, 
   {Hue[0.030679774997896203`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczFv4x0eSKO7IcrvW4VqyZSQk28eWZBukhZZpUdky7dM+M23TaiyX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     "]]}, 
   {Hue[0.266747752497686, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3dUk9nzdxAL6qqxx7UFVEQUjaAS+2CFtUVFRQUJTUM19NAfeuhRQbHH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     "]]}, 
   {Hue[0.5028157299974758, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlUzO37+N8I2TIIeZCxRLJNeMh+SSpbjVQSako7adoX0bs9raNCIcaW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     "]]}, 
   {Hue[0.7388837074972656, 0.6, 0.6], LineBox[CompressedData["
1:eJxVunlczN3//z/2Luu4bKGLsWd9jz2yPLLGFYYWWWIklZSmjZGWV03L1MzU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     "]]}, 
   {Hue[0.9749516849970554, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczN/3+Ee2LDEIZR1LDOI9slWKEyEqhlIRGW2mSNOipv3VPtVUI0nW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     "]]}, 
   {Hue[0.21101966249684523`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzF3YxwchEiNbj62xl6VGtmT7ImTLyJZKppSy1bSa9l/7tI1syZZB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     "]]}, 
   {Hue[0.44708763999663503`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczN/3x8daWQeVZBsh6RONsiRLL9lCGCEJmVKpRKN9b6qpppoWe1RM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     "]]}, 
   {Hue[0.6831556174964248, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmHdczf/7/4+s7OxkdIxIVlYi42GWWUmL6Eh7aO91Tud0OqdOCZkZ2ckK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     "]]}, 
   {Hue[0.9192235949962146, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3lczPv3/yCEpHuzhDDckPUOumR/2kPIlpFtJAzCtE9pebdPe0iyD1lC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     "]]}, 
   {Hue[0.15529157249600445`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVWnlYjN37fywvZZ2shZcRKtnGniXd9qIYpZRSo4WSmEqrypO2adrGXpSG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     "]]}, 
   {Hue[0.39135954999579425`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lYzO/3/wchUoZQWSdrkUwU2eqoEKGJVEJNESXLtE/7q5mWaTUIkWUo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     "]]}, 
   {Hue[0.6274275274955841, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzOsb/wchjugoqa9tELKPPQlve8oyKSRhipgWTPu0T/tUU41s2Ycs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     "]]}, 
   {Hue[0.8634955049953739, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczPv3xz/2EI0l4lrmEkIxlsh+smaJiSSED0kbNUIlqU/7tBrqphBj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     "]]}, 
   {Hue[0.09956348249516367, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzN/3wCeF7GP9hDBIUmTsIRwh2aeIQZg2jdZpn9Lybp/28bGFPhp7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     "]]}, 
   {Hue[0.3356314599949535, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlcjOv//+/KkmMbe+gwZIljmWPN2ssehUFIxKCobG1q2u/2aR/Hln3s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     "]]}, 
   {Hue[0.5716994374947433, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzG3Ux0e27GNLlhjSUxEGSQjfrPGEEZJ9VJg2RptpUb/2aR97COOx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     "]]}, 
   {Hue[0.8077674149945295, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lczN/3x4dI9smafchHIQxRUTi2FsLYs+WttEgy7Xu9qbTXIFnLO2v2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     "]]}, 
   {Hue[0.04383539249432289, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lczN/3x99kKZKxlD6E0Yf0yTYRsh8SRRiyVFpGSpE07XveKhmtE0V9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     "]]}, 
   {Hue[0.27990336999410914`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXdUk8vz8B8rWC92sEYUxR5REeUCo1iwElQ0imAEVBDE0EP1oYcWgqg0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     "]]}, 
   {Hue[0.5159713474939025, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmndcje0fx287MjIi+zw8kn2sZDx8JSTrWMk+RsrsKNrlLtEeCGUehOyj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     "]]}, 
   {Hue[0.7520393249936888, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlYzF/0xz9Zk6VByD4SsjYUsh9bojCWMoqaIpLKpG3aP23T1Ew1IbLE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     "]]}, 
   {Hue[0.9881073024934821, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lcjN/3wB+EbBl79rGlrNNHJVKdIpLKUBKRKaVFy6RFe0+lfRt79rGW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     "]]}, 
   {Hue[0.22417527999326836`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmHlYzO/3/0eieFvmY81WEyH7WFqQHERlqVAULRNFm5pU2uvVMjXtoyxZ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     "]]}, 
   {Hue[0.4602432574930617, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lcjNv/wB974d47lojCyJZ9uirZP11FqTQkJamxpBBNC4ZST/ueiVzZ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     "]]}, 
   {Hue[0.696311234992848, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlYzG30/+dJyNog9Ngae1lDlP1NIXsUFcW0SqJp3+vTOlNNi+SRbIOQ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     "]]}, 
   {Hue[0.9323792124926413, 0.6, 0.6], LineBox[CompressedData["
1:eJxVW3lYTG/7P7JlH4RsGb6Wsg6RQrolbcjYUtkOlRZLo9K+nEo1rcaeXssg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     "]]}, 
   {Hue[0.16844718999242758`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlczN37/+e21n2HQdwhDOIO3cwtS6i8ssYdhoqQDIVWRuu0T/u0D0L2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     "]]}, 
   {Hue[0.40451516749222094`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlczOv7/8eW7IPQQTX20GGylYiXsmQf+3DQyBalpkWblnfbNK3GXo5l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     "]]}, 
   {Hue[0.6405831449920072, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlcjOsb/x8Uc6zZQxjkCGEQIstHtjhhqEi20aJJqWmf9qmmmqZtKBRh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     "]]}, 
   {Hue[0.8766511224918005, 0.6, 0.6], LineBox[CompressedData["
1:eJxVe3lYzO33/9uW7CNbCGNLCGOJkDpkiSwTWlQ0LTRFmhZUWt7te0boiSwj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     "]]}, 
   {Hue[0.1127190999915868, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lcjOv7xx+yRJaxZz1jLfsQKuslW45tEJJtirRiSpGKnhY17UOisk0o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     "]]}, 
   {Hue[0.34878707749138016`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlczO33/wdxxx1lT7ZB6CYkIYSXPXuIosWIFq1TSntNNdXMtMjeTTdj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     "]]}, 
   {Hue[0.5848550549911664, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lczN33wMeSJ9tj7INiJGTLRBiEIzwVYSikwlRoI9M+7Z/2aVqMLSNh
UCRkQgrJIMoSQ4uy1CBMloyEbPW735dz//g9/zyv9+uce5Z77j33fu5kpOu2
lZs6s1gsbRcW63////ufbh7r//8HrEMWZ6YJFFf/oj6w8pMPzWvZg8wGllv+
yOmp+5EHAGuS2RvZmEPIHGAZlvz+enwvsgGwmmbYvErcjX64wHIZ16mWnYls
BKzeoi+zynYgGwPLdNWhx/oZyGOA9fO43tpT2cgmAN02zNmw5jzyeGBa3N+3
vz+CPBGYNnX1UjcqNwWV4/vgasMCZB4wq7vNuKahbAaw/GLAy7jLyFNAs7qy
f8nra8hTQRiR1tCy/hayOXBvro94uZjyNGAu3+tx3+sO8nRQpR8aoxVWIM8A
jfOwhSe/3UfmA8vS48Plz2XIM0HzQ2M9fDeVzwJNJ04Tx4bKZ5P8DLkjqlXI
FsBaYc2O2kDlcwDSOeblfWk8c4G7rzQs+9x15HmgGmnQWqJXiAzAOtY9ajKv
6C8zAKovp/tn381H+Xxg6QngDgvrwxDm5h3wCbRHuSWwzBf0v/QmGuWEEzpn
Hx1xHOULgCkr+bJPcwrlC4AlXyabE3wW5QsBCnptG/MA/TELgVU9e/3bXXQ9
LAIw9zm8zRzrxywC1Q3f5D5exSj/D1ilP5zyx9P4CTs87hwWROtlBcxu1bsV
f66i3AqEZw+/nTy/FOXWIGxqHRYQdBfl1qCIjAvOzC1HuQ1wrYudCo7g/DI2
oNmhWXPwLpUvBhbfT+Z5GuvNLAZVpvDEaKPbKF8CClGniCGmWH9mCQjlg+Gx
xyOU24Ky1aBhwYBqlNuCYH6PoEE2j1G+FNhuXkvy3WpRvhQUi28YJtQ+Q/ky
UI+7VrrnyROULwNZdiVnw4PnKF8OzCm3qi9b61G+HDQHbq53ym1AuQA48R4B
dkrNXwYB8OriEjYtw/GMAAR2G7sfaEB/KgHopq3NuG2O/lgrQFD8j8uQW3U4
fgXI/os0yv2JzBD5uXMXnNahPRWRu149OmUTjW8lKC56S960YzywEtReB+xm
LKbxrgRmZeFZ167UP5F3SdSK59D87UCnEMx8ZIvzA4QDjOuj1lD/dsB7f+ph
gh+yyg7YX++liw2QWfagO9K76HoPGr898Gzj+nj54/wz9qAY+kkW6oT5quxB
NI97QbiZ1mcVsHyWZji1YP1gFXCPGDe3nsL4mFUgmi9zqoyk+a8CwaVjn/e8
o/O/GniqwpOmo2n+q0FWtr552BBkZjWo34wpHDTkBY5fDYKHytxYV2TWGhA9
Mc47+Qv9wRoQJrhnb8qj49eA7AtHHD8VWbUGdOsffWhLp/PnABDwI753P4wP
HEDX1+GF+PZTHO8Ayj9dXV3K6Pw7AKswxemKIa3fWuBlVoydm4n1grUgG3Xr
1T5P6n8tKC7LNrX5U/9rgS1yuv0oGPVZjtA28fzWrtV0/TmCaH95nugNrb8j
6LuXhOeb0PyJnJ1/7fJY1Gc5geBK98a4JDreCXjxKyuHlyIzTqAdc78tZyMd
7wSsbXLLw7l0/pxBHhq2oo8EGZxBN7KMs2rkKxzvDHxOz9MlA5FVzqCafPdz
pIiOXwfsg0e6rcqm49eB0P5TxU8+MrMOckbOa8yVUv/rgJP00Klv60scvx50
9/oV2zN0/HpgNQ9vS+pFx68H/lOL5rEKOn49iHyyfuoV0/WzATTcopHlYjp+
A7CelhQ3PKDzvwEcrMcJzCLp+A3QBtanVwdQ/0KQK7Y+n9AVmSsEkxU9fvep
p/aE4BFslxmUhSwUgti7esoaDo1PCKJFi470tERWCEH4WvdGbUT9CUHfZPX9
vjHIGiGoBJOG7bei/l2AM3626nlP6t8F+LumTa2m9sAFeN7Gqbb3cL0JXch+
Op5lG0H7kwsoi7JNjthjvgoXUMc8rVjwDtePygXgx43SsKOoryHjdxvtPzuE
rn9XUCZIbtvfxv3MdQVZ/G3Tg0/pfnYFdd+ojFXHkYVE/jV7e+eMGvTvCqyI
1pal1yrRvysI+F2HBtchq1xBtCYle+wA7PcaV9DMXLO48RQ9r90ABpqvMfTD
84LrBtxPxyu35OL5D27AigqyObUFzxehGzB7DMVhJ2+gfzdQPC5V7M3G+4DC
DVSvzS3+zLqJ/sn4ho7AH5fxPqAh/hZvdo3uQ+8HG4HJGr+wfe8l9L8RNCfb
Nex6tAcbAY4saCl8jPaEG4H1Zdlrc5uL6J+Mn++Vf3wYns8Kor99zgXLbDxv
Vf+zF1t5ch/a0xD2ihnNv432WJuAlRJxUHAH8+ESbjlQLPXB8xk2gUY7/3Xo
PBwv3AQKYaQsvJKex5tAWNK+ev19zEexCeCFQ2NVBp7nKjL+vWnHMxNkDZHX
xTTMykZmbQZF5s45d3bS+d8M3JUSv9sytAeETxwukYjx/iTcDIzx42WdfPG+
yBB+2XPvHf0r6H8zsELPfEwaS/PfDJobDcN7p2N+GuIvLu6Pv5jeP9yBSbQ0
ZfXA/LiEDS2HvYkuQf/uwG3+rl7QQfN3B4XN7qlz+9H6E32b9al+UmSFO2hi
t/Qb3Yr2Ve4g/HUzQr6N1t8dVN/C7lvsovcTD+AGGX+oOUHz9wDFSCcnnyC8
r4AHqErbGlvofAk9gFnstfidK70veYBwuWkKf9lD9E/spSxYelWPrn8PUBrd
tBmkQrnGA0Tpu3p7BSCzPEERbrfrSyWud64nCNa2s2dvVqN/T2Bscx/EW2I8
Qk8QXn9cNpZL71ueAK2DvtTtf4D+PUFTPYt1+hDaUxF57SDL9n6or/EErsmX
lQMX0Pu4FzBGqR+tbt9D/17ALQweeqo3zd8LIKxr5kMtrjehF2i2J1u4rsR6
MF6gONr8iZ+O90GFF5mPFzUNBXj/VBH7S07UpI/D9aEhnDuBo1HT+7U3wGZ7
haEA7+Ncb1BFLf8qv473W/AGzSXXBoMZtP7eoEifZXA/AOvLkPHFx0pTJ2H8
Cm9y//11r+QdxqvyBm743MfcHNTXEHuuhqoj8+n3wBZQcY3eeOy8gP63AMus
IKDJCfsBEPnMikKJ4Tn0vwWYhOtLrEyy0D/R14B+x9Et6J/wqJO515rx+01F
9Nct9J1+78TVv/63ABiPPZ3+Jv8vs7YCq71wrkp94S9zt4JqwNYCbvqlvwxb
ASb8Y1sy5epfFm4F4aTTcb/GXv/LDJE/6MLfNu7KX1aQ8Udmmn1PR/sqYj/t
7uf5ltQ/4Yd3J3U1zUD/PsCaP6j3xYp96J9w26HH12e5on/CvodlzTZHMX/C
TRdG2c7G/BjC3SxnX92Viv4Jf9IIxI8OoH8fYDacqtdaZqF/wumj06psjqH/
bcDaPfz6jlWJ6J8wM7ld2jYd/RNWBvRrkiZh/oTfBWyyXYb2GcLRab1OB6A9
xTaAOSHm5t1o/kQ++YDe2qU0f8LzFD/cOnLRv4h8H1t843bk/GW2CFhDXTJL
V2diPIR5CYeeHsN8eYSVE8ff+bES4yNc9vFb4fCdf+UCwqlZ8j3jDuB8Efsr
zl0/++LkXxYRed5UkwOuJ3D+RABif83eebj+ZER/uJ9+eS3uBwWR89Rbp7Yg
K4ncUlTuWnAa1xfh9d/+i+l+5i+rCZte4v+sxP6sEYGq3wabf3rietaJQDhP
bXKoK/0+9AXWVP+fq62R2b4g5C++qH2E/ZLrC5pnNpNdLmJ/5RH9tnl37svp
/iD60ScfFHvifhL4Alct3VMooeeFL6h6fNPbtwP3o4jIhUP2ZC2j34OEFzm/
ZXmjPxmx/zZj3T0D2k8IS8yOLHJHVhL9XhmxLzLp+eYLCi3v6c+v2P/UvsC+
mbThrhz7p4b417rpn8tHfzqSz3d7r+IAev/wA83jl9J35/E8ZvsB92qQ8ZBk
7BdcwkYVDLsFx/P8gO1RkXJuG+3PZPzqCKH8ObLAD9T7BlzQjMH+LiTj1zZN
qjhfhfmT8Rv9PF6No/cnPxA8C/6pzMT7lYzY0wvmeu9HVvgBOD7ZmXUSzxOl
H+heJC25FIT3KZUf8K5lrOhfiHI10V/huPinOd7nNH4gOjPbIrME/ev8gJW7
6tf4FtRn+YOwpqj7kLMYD9sfFCHj5//yR/9cIn/ybl6LEebD8wdu0/DN/M70
fka4h4P5GTeaPxn/I/NafjvWQ0i4dvjtltk4fyLCP5+smv4b5Yw/8LjOdzQD
MR+ZP+iGhcf9O4Sep0T/mkVn02i0r/QH1Z+OqjWL6PlG9H+Val3oeaom8QwP
qTb6ietF4w+sg/Ylz8ToT+cP0HOymjcQmRUACp9LJjMpswNAdqE0p8EB54sb
QM5Tno/5TGReAKhH7I6H6Th/EAACg49PZ93C+RIEgPJclOvSUfg9LgwA6KQq
/1WA39eiAGAPMH4hjqHvFWQ8xNdIs/G+LiPyWR0+Bz2RFSSem80jJKHIygDQ
P9xF1PITv+9UJP6RZsM0HShXk/FOv1JMfyBrSLxD8752scf7vy4AuJN27Og/
gn6/BgI7/PPzJ+Zojx0IwgUVVr7ByNxA0LrLRM05yLxA8JivXBi/iH6fBAJn
5DAjoz7IgkCQj96vyuqG+sJAUEbbODzsg9/TIuLPwW72iHL6fR0ImrN+Tdnv
MB4ZkevVXTqmR/MPBPVi/6cGbvi9ogwEXT9tIlB7KsIv/HJL/+D8qon+ricW
X++hXBMIqurJC6674H7QEfsxHKltAF3/QSCy3jxn3wSsLzsIBM5jbTdewPXI
DQJFp3HXYwNxffCCQHOr5z9cA2QIAuHw6Atbi/D+ISD6U71c5oTR/hcEDE/V
JaYD+5soiPS3fJ+QEuy3DBkf+cb7343Yb2TE/tyFYw7n431NEQSqXtcXQASy
kth/L061PEvvN0EApzyWdlmIcnUQcOfkvFh2gN73ib+znZSD+tP+FwTK+dtn
vPhC75/BIEiXBCduwf3FDgbWTctCi1y0xw0GzaYvhv/2QeYR+aUfZTH2uL+A
jE+qCHfh0/0fDMK2iw+OX0cWBgPP8EyXUW3IIiJ33rEv4h3OPxMMugs9t4mc
MR5ZMCi/awI3dsN+pCD6wpYB33No/wsG0dgrxkr6Paki+twb1j260v5H9Od+
dk1egPXUEM4q+nE2C/V1wcDuV7gry4LmLwZVSGBAQjrd/2LQ9Oi9oeoJ2uOK
Qdc1+758LO1/YoBBxTd2+yODGNhLC4NHN9H8iX6Rlfend+hfKAZR3pCA+u3o
XyQm83vOWvAvfe8kcq8zf6yqaP8Xg3BJi2I3D9ergshVJpK6nWhPKQb1xcaL
vmbIKiI/ZODdtBRZLQbmWaHhK0/a/8Wg/My9Wruern8S370/+591xv7ECgHF
6uq4k1ewH7FDyH499cd7NO4fbgiAbs2z3xtwf/FCgPu996V/3FEOIaDpfj7m
QjbKBSGgjqpp8G/F/SoMAd013r0nZuhPRPQLbpbfHE/fJwmb3ew/ZArqy0JA
0PNp4aYN2A8UxL9dvyR/2s+UIeCgl6Y/0Jb2PxLPgHc1bkJ8/1CT+L3XuFdZ
0f4XQu7rixd/TUB9HYnnoOvp/Un0/SgUlAviRfMUqM8m/HByyeWnKOeGAnf1
kpHuyRgfLxSYjj8huSfoe2Mo6GbN/dN5A7IgFKBmLG/8QZwfYSgIdvSHvQPR
vigU2HduJq00o++jxF/FHOHLGvQnCwX+gB66OQX0PSkUahc6bRJOw/chZSjo
H/jacWcnzT8UFJLpsQNKaP5E/q7fupwalGtCQXWVl3ewC/rThZL7qrvseD59
/wkD3jKFvzAYx7PDoNZw8yfzvuifGwayrB4Jnt5YD14YwEUv9/rD9L2TyDlT
7W+PQRYQe7OmHNB3ov0/DNhxcQYr6fuTKAwUnXdMyt1C3+fCgLG4NHrOM1r/
MFBqu++J7U77P5EX5kxYtADnU0nsvVDsv3GfvkcTfw+apm4V0v4fRu53Rpy+
q5E1YcB9eTV/3HMcryP2h8ritypo/cOhnDNMd3QC5ssOh9oRlmNfAs0/HLgT
JkV7jqTnXzjIN/moxvWh763h5P61z3FdOsYjCAedxUtlUxh9rwsHJifyJIvm
IwoH9ndjIfsLfb8j4+8P6C74RvMPB3FWe+MjC7SvCAfZ+w+3Ts+j6z8cNDGl
t/Sm0Pf0cNCfH3wtazbqq4n90e7+/+jo+ifxfJ8Y9tuOnv9Erv+q34qb9P05
AtgT9715Sd+b2RHA/fRFvyAL8+FGgG70YSvTCJTzCJ/Y0+5oStd/BDACufl5
Kc0/AgTSmD9d8+n9JwJU9WeUKW/p/ScClFfa7z6vpb8vEP2Bh+eN+0HzjwD9
D00mdiE0/wiQV15W5wbS9R8B2nL+f3sP0/dVYj9naUr/OmR1BDi88gozeU3X
fwRIVnJWMKl0/0eAUL0pZOYh+v4aCarPxYL63/i+zY4Eboa8RN7SiPlHgtyb
f3xaNDIvEjwm9f75q/Q15h8J/DSV57hJyIJI0DeTWS0OQBZGQttjJ/6K18ii
SFCK6yKrrtH39UgQM1ZmgSqMR0b0LQNrM2Jp/pGgftvz7VseXf+RwOi3CHuU
0fUfCYLOLfnDP+P8qUn807YzE8fh/GtIfg+t/pVtRn0dkX/b+tzqDJ6vrCgQ
KfRveTvS+08UqDTC4p676P0nCli2pndqbiDzooBtY3DAgov6EAXq3z5pFy7j
eSiIAmWypTJXn55/RG47ZI3VaHr+RYFm0Tq7sja8vzNRIHO5xHJ8Ss9/Yj+A
v2vvS/qeHAW6HYnh3lMwXiWRu8p8XYrp+Ud4dd2t69U4P2riL2DrTsNZ9P4X
BdxbUkl9Pd3/UVDuYOHwchD9/YQBQeCHK6a0H+kzoGqYdUB6DOeTzQDPMUz8
/A7OH4cB2TqfVKOjdH8woCmN+pH7B+2bEHv1y8rUY1DOYwASCt6UfcB68Blg
/R6yU2mAcmBA1zozdfs69GfNgLrbaHeP87SfEvmwZovbL5AdGOAcXTss+AHt
rwyY7HbT9ghC9mBAUuJhmnMJWcSAyNbXfHYU5icm8Q2tUz+nvxcxDMiL3ld3
aUCWMMCduXuFTRXuJxkD+tnF2WPo7zdyBmpL3R2f0f2oYEB7ZDqfJUN5DgNt
l+seGqxEVhL755pG3tFH/SIST9ut1rn0vFaR+Zv3qMriKfovJ/Pv3OmfIwq6
nhlgpzxzFHlh/rWkHk/JljBCuYYBhYfD+Qu0/2jJfP1jEmoxkJ53ZD7f9DQS
0N/f2kj+Fbrt3a7Q/h8NkhMnYvscQP/60SDiiJIaCun3UDQw/EeXYqwxH040
CCTfu/Lo9xg3Ghya7O5dnoT6JoSrSnu9VNDzIhrkO/IGm2pwPD8axPfWTzGI
xvmAaDB5+F9HsBzZOhpYHK3CJ5N+TxG5Cztj4nTsFw7RwF70foL3ddpfogFu
5Czz/fQG6x8NOTsS7X++QBZFQ5vr+64r295i/aNBXbOAU1SvxfpHQ+2j3g2G
/d9h/Ul8Tj0vvQ5DlkWDcINRv/Zd77H+0aBMtcj4xkZWRIPWw/5Kzz+onxMN
HjXJNu1DP2D9if/GZLkgA+VF0VC0qvLzWnP0r4oG1f79vyuTMb7yaChPilCv
HoxydTTw0jK7Xa1vwvpHA7f+vfp6E7KG5DN4ZWjlaxyvJfOnbLFWheB4HZm/
vMLkBNqv24j9NbtPjFmM88OKAeZOR+PxWGT9GJDke+lpt6E+OwYEZrwFrBhk
TgzwK48sPbYBmRsD+tpfa6d44/lgEgPWrVuDr66i50UMeHRLMZ1ZgcyPgaKt
K/ppYtAfxIC8bvqsoyfRnnUMOHxXGfROQX1BDMC2/VNLElHfIQa0PveXB3xA
FpJ4fKtG673H8R4x0Fa7vXyzGY4XEf9+5b8jluD6EccAb2eU+/J0ev7EgCow
JOFbPa4/CbE/PqX7lg/0PIoB0XD3gXuG0/0fA8r/PJZ1nKfnE4nX8JEstIzu
/xhQT9Il5abgfUNJ9EXJCs5T7I9FMaB5//Cx6Rl6f/mf3L6igd4/ymNA1//+
leX093s1iZdtM/QKH/VrY8j39c04l6P0fhMDrLVv+Iks3O9aUi/TIHPeQ/q9
Q9j7upepMX5ftcWArNe17x//o+dfLIjEQX59G5H1Y0Gzri87sB7Hs2OBOX7j
wBMH9M+JBbWFsFZ2nX4fxIJgXdSkrVto/yf2tHHDhN1o/yfy/ZOT7Ffh/YdP
+FuwMDKT/r1FLHBVcx69vYD2rYn/Vy0xS/KRBbGgFBq+D+hD+38sKOLz0/ed
of0/FvjOz49r8mj/jwV99qfjJ6Zi/USxULQ9MrKSResfC+K9ev1z3FHOEK45
c4vjjvWTEP0Xng4RpmhPFgvCy/sWJiXT+scCrJD/XPkC7SlIPGeuNlwrQM6J
Jfd/23DdamRlLMgDWj8GFeB6LIoFTu7SoWfZyCoyH78Tfw0NR/3yWFDZ5TeM
o+tRHQttuj4RjfTvEWpJvIcZKXxF1sSCdt2Gu1uHoT0tid/XxXnCU5TrSHzs
X7x9k1HeFgu1Qxo/dsxGZsWBpMl2xagdqK8fB+K57zyzNtP7YBwIqiwXx/TD
eDhxwC5JL/nApb/Xx4GDweyS/+j5aRIH8kd53c52wfnixUH5zrnzPOnv//w4
yEkoPOkwCe1DHOgfdzx0xZv2/zho6xkHJqF0/8eBcI/V8g/VdP8T/dp71n6D
sL8J48B6l+NteSHt/3GgvVHwYF4q7f9xoHO4E1t3BFlM4q1yfJH0G/slEweg
P3fChSZkSRxwNaI/rHPYX2VxwKnb3VG2G/u3nMzXnztOovvIijgo6lrv8XY+
ngc5JP6XRjWlVshKom9xu6LuPdorIiz4cqrTCpSryHhHdvYdPbRXHgd8vYYE
h0ba/4l87Gu7f+Uor42D2u1Xto2l55cmDtT/fQzpzELWkrmbeFg09T/a/+PA
I/N3s/gc5t8WB7KXx+aWFtH+Hw/awiAol2P++vGQ0zGoaPAWjJcdD8pVAy50
NUfmxANndFGm2yiMnxsPHqdej2n2QzaJBwc/afW9z3j+8cj4K9Ed/Vc1Y/2J
fMbHD53LkSEeim4kPjp27hPWPx6s3zTYcX6gXED0jzZXWTxHdogH2MLve6Hi
I9af+K9L+1xpj+M94oE5EtQl+CXKRfHQltoI6zth/OJ4UB3+OjbXkp7/8VA+
t7Sykd4PJCQedtWHGUEolxH7fWbc0vKQ5fEgaV/e03U06ivigcdsNk/qg5xD
5tPRLGOCHc6vkvhXvA/neSEXxYO8n+zJvKF4XqniQf/BXaGbL8rLib2r52qP
zkN76ngQms6ovzUFuTYexOm+13peRX0NsddctCiAT+sfD7X9t33Xn0nrT+az
r/uiSjFyG+FjXLdcI5wPVgKU/2s8YIIVyvUTQJt7xMpdiv7YCaDP3LFf4oDM
SQB5zY4pYx4gcxOANa0lZkI75mNC5F6vOH3OIfMSoEjp+aLTO4yXT/yV5U1M
64LjIQFq+WY3Ny7BeKyJv82/Gj+vRRaQ8Xe6K9duQHZIAJMb89tCryILiTxs
5+buQ3F/eBD/0xI+P/iB61FEuCzwdYcBrT/Jr7BnwYcouv8TQMHpMAoKx3gl
CcD31z4Nno1yWQJZr/43i75i/PIEEN7ts31HP9RXEP1Jj3n8pcg5CdAmNCwo
GIKsTACJ48dMMf1+LiL+akIm8Oro35ORfAps/Ct8UL+cyGHPwY69KFeTeFnN
ozbfxP5YmwCCC0M3/OxJ+38CcDu5BziaImsTgL3YdOpuPdr/E0A54u7yAbOx
/7YR+1e/HN2/jP79WiKYXPnw5GUdvf8ngriPyRbmC73/J4LstORHb/r3XhzC
TRcsnXfT85+Mz6gZe3Exyk0Iu8E+CyN6/08k9/X2CRXf8TznJwJzsnNw0Hv6
fpoIoFSb95UiWycCb9y9CYevIQsI91V1tFfj/cYhEUSiuUlhGvq+SPh0zwRT
+j7pkQi6Ky2fy/Xo9x+J99qQ+Xn36PcfiWeI74HSCvr+lgjyaxM1He/p918i
KAf9+vH2J/3+I/bHf1F6b0V9OZE3nU7z09C/N0sk9z/9fL1zOD4nETSybFGt
Af3+I/q8ns556SgvIv4c+8hs8uj7TSIIlKuXKuj3YXkiSN4+tlj0jr7nJAJ/
7fTvOytp/cn89bjYN+k8siYRykWKwwVZyFpSv10JRsvykHWJoF21ZA7rO61/
InD+MUhoOEG//yXgMEv7q3IzyvUlALqNPT7R+NkSyJFqvGr20PpLgPfedyzj
Rd8HJSCeZnzRzpDWXwKc0hblgTe0/hJgB03Yf78PxsOXgMJ/ycon++n3H7Hv
Y3mims6HtQTKj9d6zBpEv/8kUNsu2rI3FtlBAtaTE/nF3enfI0qg6PbhiKHP
kD2I/5wiw6/07x1FEhDMzD6aVIwsloDszwp18Ah6/yf5P9l1bfoiZAnhos+D
NYtwv8qI/36vtvl1xf0pJ/Hu5B+tXYJyhQQk/KKj43/R+58ETLYpYfkBlCtJ
Ph+DL92wwvFFhM9tOMZpoPc/wh6/TGpFtP9LgM8a8q3JG1ktAY/ig+v336f9
n8z/iIlTMozo+U/0zUPOnqXnjZbEL/1Wx5uBrCPzzx1bH1CD49vIfDUc08hf
4nhWEqi1g236ttDzPwlY+e7DpqXQ/p8EJuf9xj/tTPt/Esg3sVwGlNP+nwTW
Upf0vrZozyQJNJvjrtpIsd/ykqDN+v7T2Z9Rzif+xl7q1nwW5ZAERW8hr8Mb
+7d1EghHrU+3DUN9QRIotJ7129pQ7pAE2rNjV07cgvcLYRLU1q+8nuqL570H
kZ8332v5Gu8LoiQon/Z1U0wTspjwx+V1TRy8LzBJwHk3c0YaHS9JAv2MD6si
t+G/g5ElgahX1ZCoh6gvTwLoNyJSvwHtKUh+4g+jP2uRc0g+RUdDCpYiK5NA
dvfkRMVVHF+UBEzN07s1x9C+KglSWlvr3xgglyfBPY65qGwcsprIL8bWOYQh
1yZBr60Tr0XVImuSwF6cPcZu/GesfxJM/Ooy49AhZF0S2NZNnvM8A/XbkqCr
5Hxu6wv673ykIP4c8WNBHrK+FLgJfY8HdUZmSyHc+WjLitnIHCko/0n+NXgF
MlcK9h3+z31OIZtIodjpkfUpKudJQdc6Pm7bH8yfL4Ws3S3Gw+NQDlJwUNvI
gv3o/Y/o1+68kj6G3v+IvGD12xf+9P4nBbnJn/CFdagvlIKQM02zugblHlIo
Ot3h2DkC5SIpSDbl9H4oQxZLQbuk73+rbtP6SyFg5Q8zPRbOl0QK5pZnDPk9
W7D+UjB2jNhbk4gsl0KVKnf4nIFfsP6EI16r0s2Rc0h+pj87T5MgK6XQaD+j
mtuKXCQF521Ddk1qbMX6S2Hh7vY1MRlfsf6EWSVNTwXfsP5SMLijtIsfgfJa
KZyyzQseFYusIfITBWaTvJC1xH7Y7ikrqtC+jtSnucPRvgTlbVK4l8uqDspE
OSsZAizyPcKUyPrJ0HVK65rnlNlEfrGZr8tC5iTDwv5mSxYvR3vcZLi3w+x1
yT5kk2SY+HqF67gVyLxkMHhfm5HxHpmfDLttXg6Ey8iQDBvLFq18JEa2JuMD
f8/wAPQnSIbWsRvX3mxCuUMynN9TcXB7Ec6PMBmct66p6uWJcg8S/6thmybd
xfGiZLAfE3fKty+yOBm2jJXfMZmO+gzJz2xMD8MzyJJkiNMvau91G1lG/Fl8
HmU1EP3JkyEz1nvO71CUK5JhgLevYXM22s9Jhmc3Om2Jq6L1J/EnhPqV/KD1
J/7nfJHu2ISsSgZj797dZy7D8eXJkDLk/q7gSpSrSXxF/QZ5piPXEvnkuF/F
c5A1JL+yfW5ti3G8lth/m1vosg3j05H4y+x6vn1J60/i+b3DZNhbZFYKVNXW
PjmZhKyfAo2pmX0DOyGzUyDOZv0ZZymtfwpsbFK+GVyOzCXyjjuPqqchmxB7
k0b5LZiAzEsB81vVxvbJGC+fjPctmua6DxlSwNjsgsV0Q2TrFLA/et3OxwFZ
QOz966oYQO05pIBtjcGvhkSUC1PA2U996u5VZA9iv7ibgbQMWZQCC6sfpxp7
IotJvNopXyaL0B5D9JPnTHc3o/VPgWd/3DcWf6P1TwGDcVabTJ6jvjwFskTj
fJvNkBUpYFHfPD30Aq1/CmSyblU4a2n9U+BDa8e0WVrsH0UpcP7qYKuOOmRV
Ctxr75hX541cngJtylRWy1Xa/1Ngd2TllW2NtP+nwIDGpok8W9TXkHg+L4rZ
tR5ZS/KZ/cqtdDuyjuhPMZvtcx65jczHd/aZTZbIrFQo9fTYV+KFrJ8KWVL3
XfN7IbNT4fzJtlmNhcicVAgwLPfbORGZmwq9vigKnkVi/zRJhY1zbl8wvo3M
S4Vn68/L+UGoz0+FKidLn1FrkIH4n2H37t+ptP6pYHv38KQzN2j9U8EifL3H
PLpeHFIhfFTxJa+NON/CVDBuE0jMy5A9UqG4dcT8/t/p/k+FARW3NswC3L9i
ot/93e/9vZEZEo8832KwBbIkFRqFTzSjrtD6p0Lr5SejPtL+ICfjzzOzGvuj
voLMz4CjWVP1kXNSweDZEntRCOorib07WxZ7zUIuSoUP67ZMLv0HWZUK5vsu
n602oP2f2C/r9DN9MLKazCe3Iu97d8ynlth3q3g55hyyhszfqIVbM07Q/k/Y
4aPi4h66/1Nh4mHpG+Y33f+kHhltZq4JdP+ngXn86FF/6HrXT4Mty2933ijE
fNhpsFCyWzZwFjInDcKnvXggtUbmpsH5pQ2h7a+RTdKgV/7Fy3qNtP+ngW3e
ZWHcTdr/06B1g9Gjkedo/yf6D4M+OgTR/p8G96Z81CzwRhYQf2f5TSkddP+n
gXNahNVDZ1r/NOjqPbDxpT+tP5EPePS+2z1a/zRo9Jk+sE5O938alDa75o3W
Q2bSwP5R+mK9fsgSYm/Sty0mtP/I0mBAeO/5/v3p/k+DrIlHNvPS6f4n+i2T
f/BoP8wh+ufbfH9Po/VPA4Pmi/PZJ1BeRPL9vMbVLI+e/8SeZWTyLSGtfxoY
DyvIyqDrR50GcU+7rzsxEue3ltSDP6M9YB+yJg02dmFuBWuQtSTfi571loeQ
dSS+fZyJ7GjktjSYGN2cWGOOzNoO5gMvdh/yBVl/OwT0mRt9zeI71n87dD0+
3TBQg8zZDgv7Xpm+9D0yl8g/zp59UNaG9Sdy6/M3fbXIvO3wrKrf6CWTf2D9
t4PzdYflfm+RYTucby30s638Me//APVKjlo=
     "]]}, 
   {Hue[0.8209230324909598, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmHlcjO/3/2/Zso9s2WpsyVLGnv28hbI2ZWtlkGSJSWja79aZmiljT7wZ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     "]]}, 
   {Hue[0.05699100999074602, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lcTP/3x689a2PP+h17WTJChegtS9mnhKI0ZMkSg1QoXYWmvQiVbZIl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     "]]}, 
   {Hue[0.2930589874905394, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmXlYjP/3/297lhj7yDaytVgG7xTCyVYSRokkTElln4T2umtapn3slaWR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     "]]}, 
   {Hue[0.5291269649903256, 0.6, 0.6], LineBox[CompressedData["
1:eJxVmnlcjOv7+CfhZJ+sEc7Ysw8pObaLI2WJQRShsbSqjEolqad9Wo29bGfs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     "]]}, 
   {Hue[0.765194942490119, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lcTdv//7fwEXEdXEmmk2uIazjmzO8iknCuMVROmcp4mjSptubZMSfT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     "]]}, 
   {Hue[0.0012629199899052423`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lczN/3+F8SKmFslX3sWWJkq2zHnhQjW9kakVaa9ml/lahomZDKUmPP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     "]]}, 
   {Hue[0.2373308974896915, 0.6, 0.6], LineBox[CompressedData["
1:eJxVm3lcjdv3xx9zGTNnPtd0MydT5pUhhTiGqJROZWikQlKGpwGJkimFdAwR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"Time\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(B\\), \\(t\\)]\\)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotLabel->FormBox[
   "\"Stochastic CUDA Brownian Motion Paths\"", TraditionalForm],
  PlotRange->{{0., 1000.}, {-2.2549549760775784`, 3.8532706562731915`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.5106929723343263`*^9, 3.510693005360738*^9}, 
   3.5376719773233423`*^9, {3.5397446995186377`*^9, 3.5397447012777386`*^9}, 
   3.5400516068848896`*^9, 3.54009385704346*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"CUDAMemoryBrownianMotion", "[", 
    RowBox[{"1.0", ",", "10000000"}], "]"}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.507133642854658*^9, 3.507133664452818*^9}, {
  3.5073084546737137`*^9, 3.507308510214714*^9}, {3.507308583539714*^9, 
  3.507308635236714*^9}, {3.5073087017087135`*^9, 3.507308730443714*^9}, {
  3.507308935987714*^9, 3.507308940198714*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.1869999999999976`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.5071336521925917`*^9, 3.5071336658529577`*^9}, {
   3.507144841365958*^9, 3.507144851418112*^9}, {3.507145034844453*^9, 
   3.5071450525142193`*^9}, 3.5071452542813945`*^9, {3.5073077714204807`*^9, 
   3.507307775818921*^9}, {3.507308457452714*^9, 3.507308490158714*^9}, {
   3.5073086201797137`*^9, 3.507308642792714*^9}, {3.5073087069627137`*^9, 
   3.507308731325714*^9}, {3.507308944690714*^9, 3.5073089567747135`*^9}, 
   3.5376729516143723`*^9, 3.5397447162735963`*^9, 3.5400516232638264`*^9, 
   3.5400938636388373`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"CUDABrownianMotionPaths3", "[", 
    RowBox[{"1.", ",", "100000", ",", "100"}], "]"}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.507141378901204*^9, 3.5071413910164156`*^9}, {
   3.507144217306264*^9, 3.507144227405264*^9}, {3.507144387515685*^9, 
   3.5071444296393185`*^9}, 3.5071450878747554`*^9, 3.507145354565422*^9, {
   3.507307849658304*^9, 3.5073078547748156`*^9}, 3.50731086993232*^9, 
   3.5073114141837397`*^9, 3.5073114973330536`*^9, {3.508043897723115*^9, 
   3.5080438980541477`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5309999999999988`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.507144456557391*^9, 3.5071444765663924`*^9}, {
   3.507144541647911*^9, 3.5071445604117785`*^9}, 3.5071445984953938`*^9, 
   3.50714466433556*^9, 3.5071452710930758`*^9, 3.507145329210887*^9, {
   3.5071453638883543`*^9, 3.50714538955092*^9}, {3.5073078507894173`*^9, 
   3.507307860177356*^9}, 3.5073108710484314`*^9, 3.50731141568889*^9, 
   3.5073115020785284`*^9, 3.5376729199383717`*^9, 3.539744723662019*^9, 
   3.5400516284451227`*^9, 3.540093869423168*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"CUDABrownianMotionPaths4", "[", 
    RowBox[{"1.", ",", "100000", ",", "100"}], "]"}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.507141378901204*^9, 3.5071413910164156`*^9}, {
   3.507144217306264*^9, 3.507144227405264*^9}, {3.507144387515685*^9, 
   3.507144408681033*^9}, 3.5071450898109493`*^9, 3.507145357211686*^9, 
   3.507311508644185*^9, {3.508043900894432*^9, 3.5080439011624584`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5140000000000029`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.5071444572515993`*^9, 3.5071444801864777`*^9}, {
   3.5071445422430897`*^9, 3.5071445610128994`*^9}, 3.5071445991075163`*^9, 
   3.507144665378768*^9, 3.5071452864986157`*^9, {3.5071453442233877`*^9, 
   3.5071453817251377`*^9}, 3.50731082122645*^9, 3.5073115169920197`*^9, 
   3.537672923658372*^9, 3.5397447277832546`*^9, 3.540051639346746*^9, 
   3.54005195604086*^9, 3.540092894029379*^9, 3.5400938744314547`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"CUDABrownianMotionPaths6", "[", 
    RowBox[{"1.", ",", "1000", ",", "10000"}], "]"}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.507141378901204*^9, 3.5071413910164156`*^9}, {
   3.507144217306264*^9, 3.507144227405264*^9}, {3.507144387515685*^9, 
   3.507144408681033*^9}, 3.5071450898109493`*^9, 3.507145357211686*^9, {
   3.507310693545683*^9, 3.5073107317365017`*^9}, {3.50731077142747*^9, 
   3.507310808482176*^9}, 3.507311521746495*^9, {3.508043903543697*^9, 
   3.5080439038857307`*^9}, {3.510693023176052*^9, 3.510693048832019*^9}, 
   3.5106931065401907`*^9, {3.5106935611551332`*^9, 3.5106935639943333`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3119999999999976`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.510693026998077*^9, 3.5106930799698186`*^9, 
  3.5106931192386723`*^9, 3.510693570421533*^9, 3.537671899715582*^9, 
  3.537672936210372*^9, 3.5397447318884897`*^9, 3.5400516570837603`*^9, 
  3.540093877084606*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"paths", " ", "=", " ", 
     RowBox[{"CUDABrownianMotionPaths", "[", 
      RowBox[{"1.0", ",", " ", "1000", ",", " ", "10240"}], "]"}]}], ";"}], 
   ")"}], "//", "Timing"}]], "Input",
 CellChangeTimes->{{3.508003072339404*^9, 3.508003105030555*^9}, {
  3.5080031444468393`*^9, 3.508003193471262*^9}, {3.508013703209608*^9, 
  3.508013739912278*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3119999999999976`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{{3.508003091609014*^9, 3.50800320928918*^9}, 
   3.5080115047412987`*^9, 3.508011570189299*^9, {3.5080137127625637`*^9, 
   3.5080137422185087`*^9}, {3.5080336427980347`*^9, 3.508033657954035*^9}, {
   3.5081035783901615`*^9, 3.508103583282161*^9}, {3.508103653323161*^9, 
   3.50810365761121*^9}, {3.5081036925727053`*^9, 3.5081036975792065`*^9}, 
   3.5330641277267685`*^9, {3.537672324882641*^9, 3.5376723276303663`*^9}, 
   3.539744745597274*^9, 3.5400516686064196`*^9, 3.540093881110837*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"paths", " ", "=", " ", 
     RowBox[{"CUDABrownianMotionPaths1", "[", 
      RowBox[{"1.0", ",", " ", "1000", ",", " ", "10240"}], "]"}]}], ";"}], 
   ")"}], "//", "Timing"}]], "Input",
 CellChangeTimes->{{3.508003072339404*^9, 3.508003105030555*^9}, {
   3.5080031444468393`*^9, 3.508003193471262*^9}, {3.508013703209608*^9, 
   3.508013739912278*^9}, 3.5080437413114204`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.4369999999999976`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.5080437531674204`*^9, 3.5080438168700304`*^9, 
  3.5081036130761614`*^9, 3.5081037027877274`*^9, 3.533064131357769*^9, 
  3.5376723318019485`*^9, 3.5397447480224123`*^9, 3.540051675986842*^9, 
  3.5400938840210032`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"paths", "[", 
   RowBox[{"[", 
    RowBox[{";;", "50"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.5080032110108757`*^9, 3.508003215556324*^9}, {
  3.5080115848912992`*^9, 3.508011585213299*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mnlcjF8bxke2EEUk+9jLz5KIknRJUUSRpUVMe2mb9r1mmmapZmoolHUs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     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJw1m3lczN/3x7PWh5BsKTGWFFmSpay9EKWUKInEpF2pad9rtmqaakq0CZ8h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     "]]}, 
   {Hue[0.1421359549995791, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mXc81e/7x09pT0mlfaKhabQo1YtStAgZzUNm1rE355hnoqnxKdKgNBRJ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     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mXlczN/3x8cua7aUNdkSkRZC8SK0qiyR4mPatGfa95qWmaZmprJnDyVZ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     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mHdcze///zPelBkZkXFKlFHKzOyBohDJKFROaQ+d9q7TaZ1Op2GHUIjs
ZBXilBWhjMisrLJSZsn49bt9ns+vf9zuHtf1uq7n9Xg+n9d1aDr6WDm3V1JS
qu+gpPT///7fn0bjkj9edzyNM43pH/B5psnjdtcPEytjmElJB9mWXGJVJEr2
X9J0PUfcBzs62HoITp0gVoet64KQeO/TxIOwbf6nzG4up4gF+HHoZveGT4XE
WujdZ8b2o/7nibXR6jd1jl3xWeIRKPh7WeftkWJiXVSoOkZeWHyDeBTyr7rK
N/ZgHoPGNzGXb8y5RawPkZLXl3yjMmIDvM8auOOf4iaxIVqEfsJnXe4Qj8NR
819/7TdUEI9Ho03HLUX9WJ+Af15npwxPYZ6ICZ7KqvuDmCehwbqp8fsrXn8y
pr6UBxX2ZDaC+doub7o/5e9PwZCUyfpjm5inYkxOKMxv8v6mYcrpyVsNY24T
T0eq0X/h59TKiWfAsPf3ofZ9eP5MrH/7XPyoA7MxroaXyQzrK4kBE5Mis+cH
H/6PxYDN/alrOxs9In0W6g5pfHarpvHiWfj6tffxsmcPSJ8Nway6fes97pM+
G5avLl1Od75L+hzEW2crNvYgFs/B5Ssl3Q+O5/2YYOhx6a5NRnReYhPUlXQo
6ruU4zPFr7qq8GvlV0g3xVPVHptcf1wjfS722GSN/qNFLJ6LjU3iWckTef48
rC81uxTznfJBPA8BHp0XHJrH+WGGn4WhKUUtlE9iMzyb9HDm+85XSTfHzaF/
i6dlFJFujoDCazv/lnL+zcfjk5NWbjl2mfT5OF98s2RHLM9fgL9oMtQNKyF9
ASpW2lwfnFlA+kKMmH7XNXE31Yt4IfbX9dqlpsv1ZIF15vHKXRuOkG6Buw5p
8XXLub4WoUR+1m/auV2kL0LC4HNu+R8Pkr4Y+Qcce3z0PED6Ykyq3DFkUdNR
0i2RYvvN/3Y41ScsoV8bWT3+Nu/XEr1P5x9tH0SssIT7xKKbzdsUNH8JOo5d
mlseRfFiCQrH3UiLn87zl8A2bWqxpwb5p1iCMi3l3Ir2fP5WeGluOjbnONUD
rPDbPul5isU9mm8FT+mE7s9yKP8UVrjjsK7JehLn31K8MHlx/bsJ5SuWovdB
7dyEAZyvS3G/4041076U34qlGNpkpBk/n/N/Gd4mTFw89jx9D8vgqvbgV+k9
YvEyfDV4cmbTSWLFMjxQP9N70FOevxxPciVy08XEWI4kn17jDK7x/OU4JMiL
/f2H5y/H+UwdMxUV2o/SClw3LITwCNUPVmB6gN2WsdVUH+IVqLffpZ/4iFix
Aiqr4w9ubeF6t0ZfX6OQVRepvmCN/X17TJ7ry/VoDVFt1yNZcl7fGuEl57fi
Lp+fDVYm6b30iuP92yDv9ppl5isf03wbzMh0sk3NfUrzbbA7cmen7G/PaP5K
fDa1WHT/A+lYCW3B9FETC0kXr8SM52mS21k8fyUMK/42GUXy/FX4uPlxp+hh
T2j+KvTXj7Y260jjxatQUhgWfsC4iuavQueOu4eeD+LzXw0Vk25P1tzj/a/G
n0sRMxJM+fxXo/uWS0X2N+l8FKthqjnTxriJ+5Mthiasz3ZbSvkGW7Qsue3z
6g+fny3sS4sjf2gTK2xh8T78xJRzPN8OcwOKTR8eZP/s8GKl0rhevbif2uF9
QJ+d9xIoPxV2CK2M+H16LZ2vkj0w2STmVDjHb4/PO4Nwqiufnz0MXvUof9eN
dIU9jm+r3nWsy3OavwZPNkU11jpW0/w1mJnUq3V/2Quavwa/yg+qDb1N4xVr
MPLO7PAV60hXEuL2c6crxw1pvkCI0E/BG3WO1dD3hNCbaytf8ox0oRDDWne2
09hMuliIxgbx18+9a//HWUIUP7mVdWIC6Qoh3o/K3HlgJ+k1QvhLreZ8z35J
6zvAW23wVdt9xAIHTPl9S3Z19Cta3wHPTa8K25eQLnSA/Mscsz2zSRc7wDVr
/pOYjsRZDgiL849yufGa1ndAxov9t+4UENc4oO+sFfahP4mVHHHn7Q23CY/f
0PqOmPE+vLC+iXQ44l1VE6BHutARh09r/JZ7E4sd0S1bKWnJLhqf5YjoFneH
xnxe3xEx2tX3LTfz+o74Hn383qUcXn8tbtulVMnKeP21WKp5IWPLA2KsRWby
hUs9z9TR+muRrdW/NuoqsXgtbj7aZRsxvp7WX4u7RxLjrjeRrlgLyceCz0Jr
0mvWYol1btDIKaQrOeFjyfch334TC5ywf79PxrcDNB5OeJunFWwjeEfrO0Hr
HhZ6uRGLnVC65N2rpyd5fSdIikzyug8kXeEE9ZoBHXa38PpOWPt0q7BuNrGS
M65sSjWsPcjrO0OWH7lB4E0MZ+wwmVeR68XxO6P50Fbz9/58/s64/UsaFZ/D
/jtD2Uh5jMpDPn9nzF1dqhKjRuNrnPFgv0C6/uVbWt8F4d9aOipqiQUuMOnQ
PTo7ntd3QdcnvwtmO3D8Lvi497BJtDvtX+yCkHnvzskLSc9ywb/hHV86qr2n
9V0wsFgREfmX9BoXyP7VfvX/wvG7orQ1c9fMXGKBK87WJfh90KP5cIXjjOK/
J4J5fVd0KB612N2H13fFmPyMq7dm0v6zXNHTQ+vN/kRihSt0ux/Xn/KM43fF
qbrla8xLiZXcMM6tX2WlL+efG36PHuI0robmww2DZh+YkhnG5+8Gn957VP8F
c/654VlMfJ+WicRZbhgbmn+mz3fOPzdMNA2cnbORvlfjBsWMO++rF/P67rje
0Ji62oLXd8e2nOCi0Qs4/9yx0aEcUx9x/O5YUmf46M5Vzj93nHo/aOXNaXz+
7kg2fH4k6DefvzvKrph1KDhAXOOOecFNJsu78fl7wPtPsujRPT5/D+Qq/Z3e
KZv994Cgj9qi/P60f6EHtq63e/HLiFjsgZ1nZk37JOL4PWAcMPDy0N98/h5Y
eeaZvocr6TUeiG1aoefpz/nnCZ3Vo6wh5/g9MXPyJc8BO/n8PVGge+pa52pe
3xPnDxcffbyDz98TohsCv4vDuf480T6/TH1+X64/T4S/6f3oMPeDGk+szvnc
vn0Br+8FiffBXSXjuP684JA5UUW1iuP3grNze7W4OPbfC/vfXCi3V+H1vVAi
87Momsvxe+Fj1fVJje4cvxfmPe/kneTC/nvhVJ8JH/p24vW9cSHS8MioYj5/
b0izly9VGUb7hzceHzAu1gwg/4Te8FRfsubcHmKxN7Z7tYuMbc/xe2PMuVED
L5pz/N6YdfzS/rh1XH/ecJxW1TrwALHSOjR+0Ncv0iEWrEPPdx+0s1s5/nVo
53xi0/kA+r5wHT5WznNzZf/E63Bjd+2JdUkc/zp81XM1zLlD4xXr8M081Sr0
Jfe/ddg6QfnSlM8cvw8MgrZrqy3m/uODz/oRLw7e4P7vg/2yDtc3vKN+JvTB
3upxub7teX0f5AU3fLw8j9f3gcoFdft2e/n8fbDivaVnWTnXvw/S/7xefWcr
ry/Clw/7nl05T99XFeFjj9V+RoeIBSJs2H19aIsZzTcQYafpsurPe/h+FCGs
y9uyPYuILUXw9bvWu+wV35cijPx7p8rsC7FIBJ3KCy9T1/P+RZiir9c5IYf0
dBG2JpsZ/+nH96kIovp1q/WExHkixKVOy3UqoH6vEGGe+p1hswU0v0KEyMOD
xzlN43hF0Nhs+MtIQOMbRXhguSxsmB+/P3zRcN7Yrmst6aq+2DfF8M82Y2KB
L+5s3X09+Bytb+ALqweK0HeNNB++OGvxSLCN3zOWvri45L+oT9f5veKLyqvN
b7Rn0fdEvtiqtrBh0AD6ntgX/85O2f1ExPH7opvPhjeJ+dzPfdF99VCnWxqU
n3m+EAfqmATt5v7mi/jARbk2rZRfFb7ovT93o+sczndfbLY5tcXBhfRGX/z8
btzk3cD3vx92dU87NsiRdFU/5G3cdadsDeejH6LV8239HTl+P/Qb/WroPR/O
Tz8MLPctz7xPbOkH8X2nWevPcb/yw+HhPVX+jqb1RH4oro5+tjCU/ffD0867
Q/K4X6T7wfk/h7N6/Th+P2RfWXzDJZA4zw99LZT88xpoPYUfXJsPynbzfVbh
B82V5/MKt7P/fuhw7VFRUhjNb/RDRkePq64TOH5/7C+ePEUcT7qqPyL6e+n9
434p8MejI/u1LxfR+Rj4o+nguH3Trbg/+2OzVA3TzWm8pT/Suo+cfaAP90t/
lPTffjFEneP3x4LjXY7FvuL4/bH30QGTJWtJT/eHzvKwijO/OH5/WLdmpPfq
QnqeP27Evr5+hv1R+EO9cYWPgRXpFf7IVtKcO34Dvzf90XNIZcZKa+JGf4wp
P1ESM4jv3wA8b77QpG/M8QcgTK+vpsMCjj8AC2bMdVq9mnSDAJRm3/s1piPH
HwCPzAnzZPxesgyAIMrSZN997pcB6Ow1zbl6E7EoAI89MzbfPM/3RwBujDAQ
FTxn/wNwcahxn7uLuZ8HQP336op77zj+tvXFHneze3P+B6A8c9gc+8wPFH8A
rh3ytp6m+oniD0DANvtHlT1JbwzAuvbHj397zf0/EL83PPygp0m6aiDkDWp7
+iUTCwJR++jrxnZPPlL8gZh5ZsPzr4eIEQgv7WE3Lg0jtgzE3/LanuVWNF8Y
iDXvNsQt+kz7FQWiwn7Wzt0rSBcHQjNKeWadN+0nPRAL0p9ISvqQnhWI0oLt
X2K70ffzAtHwYskK4waKTxGIzGKbw7qCRoo/EJavdfbe7NNE8Qei6L0406Sa
9MZAnGrZ+PiMMelKQfCJKnNptSVdNQjZPj/V51wnFgRh7hv7tKmniQ2CsNjr
rvrzQ8QIwiD5uw1P59P3LIMwTkf6aP8p0oVBsNwR+6z95c8UfxBuPhsQ4pxO
LA5Cnx36kJ0kTg+C0fuI9MtqND8rCO+8u83+uYU4Lwj+o0d77NlKrAhC1+Yh
4XXzOP4gfMoeUHLxKHFNEJ5WKb/qYUj7awxCr2n5mVn3SFcKRuDHVceEI0lX
DYbe9OWhX75x/MHwqSzxV3Yi3SAYTftqEwwWfqH4g6Fv6Xf3XTHHH4zLsac/
3njJ8QdjpIay1+4YYlEweizUrT92jFgcDEmHygcBfg0UfzCUOgsfXK8nzgpG
YoH/TntT4rxgVP3pmZN5jM5LEYw/ysfifw0hvSIYC+dd9xAJOP+DsXTboITv
QcSNwSh0MTJuHkfjlUJgM9xx3bDnpKuG4Efv29NVp5MuCMGr7VYRwzNJNwiB
xYkFg16okY4QdKhpKtbqQGwZgmkrC36UT6D9CUMgeWg5xbyK5otCIPviuH2t
ErE4BE3fBqW4dSVOD4F464d7w/tQvmeFQMNa+/0Re87/EKw9vdy+uznnfwg8
NBOLY25z/YdgzYmA33oBNL4mBCb9Zx/4/Izrv239jQ7ypFHESqFYr3Ou2bYH
jVcNhcD2jk6OL9d/KF5YjSobZEBsEAqfwlHL+m4jRihOnPR7aPec2DIU/mMW
2z58x/UfCiwceNx7GrEoFDpDe95Rm0DriUMx0ld7jOQR6emhWH798ayZ3bn+
Q9H1b8/B4TXUP/JCMei/b6svOdB8RShi7+oPU+STXhGKUVpDXS0H0PyaUNwa
Ur9oHuuNoZih2Zz2wZzmK4Wh08oRw3U3cPxhGKIwuHvwC52vIAxRN+SyDcvY
/zBk1c07ut6a+18Yuo33j5dMI78tw+B23GT+jffsfxja5SwJ+2DH+R+Glu/m
L9e2cP6HYcr9F2cDub+kh+GwZd3hk15c/2Gw+Xv4w1DuX3lhmKDqo3etgus/
DPvjbt3y5PquCMM1/4gPZly/NWH4L6LDfWtH7n9huJXg/yhwLtd/OMqV19id
7sz1Hw694zt3eIm5/sNR63hh6kEV7n/hMHbJGDQin+JDOIwMBoSOUOf8D8fx
i1uKZj6m8xKGw29L2BB3rj9ROBQaRz5tLOT+Hw7hwJfPy33oPNPDkb9PSWlR
II3PCodlbwuXMkuu/3Bozgk+JrLm+g9Hlz8aitBhNL4iHBu/9qvrc4PzPxyT
xy2N+P2C/Q+Ho0rhJeWpnP8RSNg1OXTXab7/IlC/fpOmwJZ/D0Xgw2nXmJfL
+f0TgerObspF9/j3UQSK145yc3pA4y0jcGHf6QKP33z/R0Cyx2xvBK8nioBB
r5RUB64PcQRGjBy7TlWD8z8CgdPdQ37P4vyPwKfhEz81jOH6j8CiIUlf3hlz
/kfgS4FqxuBuHH8Eyv0Hvq0No/OqiUBW1jTB4GF0Xo0RyC47qfNpPo1XikRx
pPm1Ncmkq0ai1nj5Pf88YkEk5t9var//G7FB2/gpvdyv6LL/kRjYK6NXpgbn
fyTqYl5/WHWZ1hdGYojnbcdH/+d/JBaNDnI34fMQR8Jq0fPhxzpz/JHoX3l5
67Gz5FdWJDYe7xF/s5Djj8S6YW5RytyvFZHQnrrZ3WoT9/9IuGlkOhftYf8j
sWXxKN8thaQ3RkJL9q712Rbar1IUDCdonZmtRLpqFHqP0FrQrpjrPwqDy5wC
1EtJN4jCuHzfFCdj0hEFHffLT+sKOf4onJg1T3aE7zthFLp7qr20cOD6j8Kh
ktrIGylc/1FIPLMn5+Anqr/0KHzpLk9sGUn3a1YUmrZ/ULrWSnpeFFK0zwVk
6JGuiMKPGz363jrA9R+FKWr+T3L6k14TBfNtBzdq7CBujELz3O2Vj/cSK0Vj
5FPVHbm/iFWjMaul2M79ObEgGg/nDO9615nYIBpX88+lr1rJ9380BgR2/ax1
ldgyGoqLds7ph4iF0bB5kRqu3UL7E0Wj35fQlBu9SRdHY6Fczfi/5cTpbdx/
/IGp/l8p/mjkpD34b2IkcV401hW8PLF8CbEiGpXBxW6+OTS/IhoxBktbhQs4
/mhsOR2e8bKQ3z/ROBfipbdkCMcvhqJdvslOfr8oi9HP2+DZzHHcD8W49+BF
xNUNxOpiLKxMRH0HPh8xBg8y1I5aSLquGP6e+UMxgd9LYrTXMviSeYvYSAwr
q6D59aP5/Nq+L79kdL0HsZkYgqqHRWv8+T0lRlHmT9WpWcQ2YnR1X39md1c+
XzHkz/fEv+DxbmKo3P694OwWPm8xRmWtF6gY0PgQMSxddX/pufP5i7EgNqGr
4hKxVAxv+3f9D65nP8Qorp12tU6DzjtDjAMH1Irr7NiftviCFmq+LKXxuWKM
yNAyXe5DnNe2vw1/D/ROIS4QI0TN2y7aifNXjHGL/vtRcJe4VIw/S+feVNjS
9yvECFrbdO7CduIqMaSGm88WMteIERxzJWpXJ+J6MYZZSo7MGErcKMaZXdu7
/6qg7zeLcf7cEl3Vh+x/DFyObr119jSxcgwiri9vOWBJ81VjMGTcEd1fa4jV
Y1AWFyv6V0ssiIH48Pa92ZyvujFYcWTGvwNviA1iUJI63PagzjfyPwZjdvV5
G3eKGDG4szR/xxpdYrMY9D2c6zz0P2LLGJz4cDFXI4zYJgb7RZuH9cojFsZA
pWS+wfi3xG4xMO+fNk553nfyPwZfd14pHdabOCQG8/TX3RUuJxbH4EPRwzpN
ObE0BlZHjYePPEnfS4/BuSebtQf0Jz0jBr81j67e30p6Vgx0Khcad39FnBuD
82W9z/7h+XkxsBZe9+wXQlwQg7naYWNWXSBWxCCnU4Kd7SU6r9IYWDgVj5rA
4yva4leEd3n+j/2PAQQ7RnzsRHpNDOwbNgW18HnVt/l3dajgeir7H4OpnSfW
lVwmbo7BxYZK/8rdNF5JgkGpF9xX96D4lCUY3u9r6tyrpKtK8Cpiwa05waSr
SzDL/lNLv/XEAgn0x/jX7jMm1pVAo3ny+JZmmm8gweAm9bqi0ey/BH1W1QbG
Pab9QIKKL7YB60NpvpkEYQUWq2Z3+EH+S1BmW3l7kSmxjQSSN9tTy77ReKEE
ETl93/VfQLqbBPPXJmQcvE8skqD76+rMt7k/yX8JIm0D7WwWN5P/EljNt7KT
eBFLJbBYdulQ7yIany6Bw8NznVvXE2dIsDVosO4+PeIsCcz7TfWtcSDOlWBS
tW7jhlpaP0+CCR4qz8q+ExdI0OpZutr+B+1fIcEvFye9O16kl0oAx9s3dVeQ
XiHBn7GaUx5wvlZJULPqo53OT/ZfghbX+MNfxpNeL8H20peT10USN0owYk/i
8rxJxM0SzDn+zT9pILFSLIKemH+eX0PfU46F2sVPj0bMJl01FmHCilAfMfsf
i9O3YnftGcz+x2KyJENcFUTzdWPRMHFV4rBvXP+x6Fk+dOD0D8RGsfgc89v7
jxH7Hwv/hsTevtzPzGLxL+XHQpVzxJaxmHLK/pOzBdd/LPruLzPpuY3rPxYn
HNaaz1zC9R+LuelvV+nb03xRLGb/PvcyPJ04JBZd9Td2G2RKLI6Fy17XrJuL
aL40FnPWL9TZbMj1HwvJ9a2PrHyJM2Jx1WXEkY7nuP5j8cC+3qP6Ctd/LM6K
ovtOeMT1Hwsb9w0Bosl0XgWxGLfn6FPZdfY/FmciGj8cH8z+t+3P3KH/bTvi
ilhI683aG74iropFXPsV//p2o3yricWfbTUTbmsT18diXleP3fJlxI2xWPLM
3npAPXFzLF4P2mf7t4xYKQ5HD3c5tiSTWDkOfreCGjQyqB5U42DkanfbR4NY
PQ7+e708OuYTC+Jw0javFenEunH4FDxefVkrsUEcNLJF0ZNriI3iIJvmP9CC
5yMOATsEQXbRxGZxGHDjwmp1B2LLOPyDZaQgmNgmDp8tJ+qbPaf9CuMw/sZa
86QVxG5x6JOc+afxCbEoDkNz51VPEXL9x+G953WdaWeIxXG40uA38QnXrzQO
GQ3F1poP6LzT46A84H2U5DHXfxy0LEZl2LjQfrLa9i8o2FZzjDg3Do5my3O+
7yHOi8PhqOCNLWbEBXHYFL7VpKqSvqeIg+FkmWFeFXFpHL6+vlC6SovGV8Rh
WukUqUSNuCoOYSu0jpcWENfEwWmpZPIJHeL6ONxcUKE8gcc3xsFLY8D9j5PY
/zjka+u+P7ad/Y9H6YCbVqqNFK9yPHx9vccX6ZOuGo9yHUOf/2P1eLwxdBYL
OH8E8bhprLcqsh/7H4/3Y+9+1fxFukE8zjTG9+luTGzUphsLnj2WESMesiUH
TJd3IjaLx93m/udOveX+37a/ygfPzvD3bOIxzLFbQSOfpzAevdJ6Rdj/Zv/j
MavjZv+jh0gXxSP9gel00VfikHikuBW75Fq0kP/x+LpxiNabVmJpPDrnvX1u
n/2L/I9H5dFfSndNiTPa4h8+cPKqRcRZ8ZhTfD+zfHYr+R+Pi5ibZmVDnBeP
tcq9YsZ/Jy6IR7PZX5uZQ36T//HwFhlFqjwjLo2H1t7Jynoz/pD/8ajakLLn
y9i/5H88VIrid2WKiWviYWVomKzOen08Tvq3NqwwJW6Mx7dT6we97k/cHA9V
cbCZSy6xUgJM3r/T6lxJrJyALj0Gac5y/kf+J7S9D77pz3IjXT0BTW65HW27
EQsSECk4ozf7M+1XNwEuV7Y/+TeJ2CABwTvLg3R2Ehsl4M0cdeUuajQfCbhw
uvDEF19iswTY3v6W2/cmsWUCSiaN6lr7hdgmAQE/N67N+I9YmICzOi7uvafQ
990S4DxZdvHkGmJRAiZdrzazX0IckoD01h52S5/QeYsTcPzI9t0O00mXJqAx
R/Bj2yfS0xOQ9tHF02Ac6RkJWBQlVzqUTpyVgPJ+l/J9VxPnJmDC9CES0060
v7wEfPBJE9rfI70gARG7V3R74kO6oo19qrSH+ROXJuBTktUZ9RDiigTsDZHl
fp3G/iegV+SVHqHD2f8ETM1J8W3KYf8T8DTjjo+vNvnXmIBxGUYqx+rY/wT4
aj7L2bSPdKVEGG78IdcrIlZORE1Q+yzfx+x/ImZtLVNVnkWsnojAvotWmOUT
CxJxd9zjCdMP0/d1E+F1sSZ+LMdjkAijb6Y6r9WU8D//E+Ek2rV6YkdiJGLT
u3WfI3bS98wS8dTfKK1Ji9gyEdP7Xv7y8jb7n4gvd+46BEez/4lwtHxxfv1V
9j8REzJPZFsMY/8TodpeKugWx/63/Xb9nJSkyfkpToS+ddytiR3Y/0Tcc7mk
+zmQ/U/EtHWtPRXNxBmJOJQ4OnJLE3FWImaP7XF7niH7n4iAE0OGBbQQ57Xt
78+4ydsy2P9EtP8ZEDtvKrEiEQNP9capnsSlibBI7hfe/JK+X5GIYE/7C4eD
SK9KhCBtYto3zteaRGCF9g2tLjS+PhG/lJYtys2mftPYFm+466ZON4ibE+E7
MmHD0RJiJSmuBrQL7b2AWFmK4MvhSQ+LiFWlGDrzcVZaPrG6FHoZ0//bk0Us
kCJ8VVPj9yZiXSmqTixvb/qX+qOBFLbvjtyamEFsJIXbWAevI/E0HlKcUp+6
SLMr7d9MihzLF8divpFuKcWy6hkzq3OJbaRwXLtjikYhsVCKwpQ6t8U3id3a
9PEKy1kcn0iK70XGOsKvxCFSbK4uUDIZxvUvRZddGyuyLxJLpZgcZH96+xv2
Xwr55umyU+vZfynU1J/sburM9S/Fz9S4qqunSc+VQjPVVUk8ljhPCgPZmZrx
usQFUkT8O5s5Tpf9b+Os6Vpzz3L/l+LkJcXU0uvsvxTztR4eG8Dfr5LiwIZZ
kdPV2X8p/H59CD+wk/2XwjsrpTaZ87NRCutnZ0eO8CdulmJP3yUDl/F5KSVh
YP+eMVfr2f8khCs5FOuo0njVJGyodj/57CT7nwT11ltFTxaRLkjC9sGqVRf8
iHWTsHqGiuQm149BEl6vure/40Lu/0nQ6LLZ3LecdLR973AvWVUn0s2S4PjI
KMhPSGyZhPmTzr7PlxHbJCHNdYvN/lBiYdv+Jo4PcvhD33NLQr2qdPsPDa7/
JKwr2FMX25/rPwlrDiYdUuf1xUnYeMi6+lki+5+Ejr0OX7V0p/HpSQhU6buy
/jL3/yRcHb5m5tab7H8Svv3eYrw0les/CbYPUnYtm8D1n4SXm67FJHxk/5Ow
pzBXX53rW9HGGVkz009x/Seh+7fJN9bd5/s/Ce3+6v0UT+b+n4QuP1rtTcLY
/yQoXbVc/3QjcX0SfsQ1bOyiyfd/Esak5m8aWUl6cxLeBYZoGEn4/pehp9qK
Ed238f0vw20jVRUvW2JVGdyfPtpg85zvfxlshmqcT9Lm+18GxcijgS8Hcv+X
Ifvn28vaP7j/y3DZ6+mCWReJjWRo6thRbdZLvv9lMJgyaexULb7/ZfgtsD63
4QH7L8MW8069P6xk/2XIGdja/gT7J5Qh7KabZb4Z938Zxj+8p5+Uzf7LMDvP
oOjlV/ZfBmFD45rI29z/ZVhsN8INUu7/Miyb7lricZr9lyFvZqefGqbsf9v5
6HX/qnKH/Zfh9DAd/2z2N1cGq9G4et+B61+GBR+b6w2vsf8yTIxZOHfEAfZf
hiOd9ve+843rX4btDW5Nf8aw/zJk9JV3tCjm/i+D6WTlducd2H8ZjJvmx09r
5PqX4bVK0fpuo0hvlGF0j8CKHs7svwwl48rXbs8iVkoG3h2Zs0iX/U/G1wl1
oxbxeasmI3/DuV57XtD31ZMhE1t/9njE9Z+MYq/o49P5ftJNhpbt0h1m/N40
SMYBJd0eIyK4/pNh3q1n/pd6YiSj8bjQ3tuf6z8Z66o7RHTqx++/ZOh46k8c
UcX+JyPtqu/v4AvsfzKmr+r/SFPO/idje0l++Ht+b4qSIRZ9qCvewf637fdj
ouq5nvR9cTJuqeTF7g4mlibDJn7a8LPfiNOT8SUquSownjgjGZc/a+9bzfFl
JcNN+7KzvxNxbjJmzH89Te8K138yQgNWxozn91BBMhSm3e+NkfH7LxlnTOqX
HD/P9Z+MwXtjxHeH8vsvGdn3xqR35H5TlYyMHmaVh0sp/ppkjKlumDMomv1P
RlzNYZWE//M/GcdnV1mclLD/yWhq8e/6R4v9lyND//ucgV+4/8sRvLr1wOul
fP/Lofm5/todT7q/1eUoVT9t0X4tsUCO5yVfe6V25PtfDqF7tfPsR3z/yxHW
elG3YQPf/3JEiOYUXggnhhyp5W+Obc8iNpOjdcf1a46sW8qxQzivvE8osY0c
IQt/zJl8kFgoR5fwMqPqk8Rucjhb28lv8u83kRz9f35atnwX3/9y6J/+tMsg
h1gsx5w7VsvP8ntCKocisHzlEX7vpcvxctJiQWUg178cUUvsOmiXc/3L4Sb7
e9bGg/2XI7JrzwiVI/R+zZPj+0M768h5xAVyvJWVmHgPofevQo4JyseeCwNJ
L22LL/P5qjfviCvavve+S8X3UuIqOXxt/k6Y0srvfzmkKvvSdRL4/S/HQelY
jYCD3P/l0JnUx2LBBX7/y5E3b3LD0Qju/ymYlWZi77eY3/8pELdbKRML+f2f
gk8X9Xom1vL7PwWbld/ZXcnm938Kzhg4qHr0JNZNQWSPTjvf9iE2SEF6lMGH
e/x70igFktQIdaUYYqTAbWF08kE3fv+noEfSApvd6/n9n4Kci56rnowitklB
jHTXgMtF/P5PwTELvdOFf4ndUpC0tbj722k0XtSmz541ZrOUOCQFUs+Oyzw9
iMUpiG88f665gFiagmkVJQfOa5I/6SmYZ9VhlGcgcUYKNhqmWqTvJs5KwX3Z
aCsvJ+LcFJhUnPz8fCZxXpu+a2C3uffY/xScvRv851A79j8Fpww32JwpZP9T
0N+95e4x/n1VkYJuP6SHE1mvSoG9Ta2GuIz9T4HGy/2LtuiRXp+CE8a3ms/f
Z/9TkKXZsiJ8LOnNKQi4XBpw8jj//kuFe+Vtsx1l7H8qHKTurySraX+qqVj7
JG3MjznE6qloLHSMmF/D/qfi4b9OM7fvYv9TYXB3ZbAa57NBKr4K/3QZf4X9
T4Xnuk5reg7g33+paN91+B87FWKzVJjua3C89YT9T4WOYfuEeCv2PxVzGzdN
P6RK44Wp6Lblw8i330h3a5u/Pvj1tgT2PxXyZaOvzLvN/qeiU0/pg8Un2f9U
2FlGK73vTd+TpsLpkuudHczpqegRNC715VEan5GKscp7juTxeWalwq304AXn
c1z/bfGXflZt9x/Xfyo6tts5eNkr7v+pKF58Su0h56ciFd4jcKpjBv/+T8Ws
4clNE7ieKlJRZNGxm9IG9j8VXm4tK80b2f9UJD02fQF+79WnYsP6/cM+Xef+
n4q4d0P+M+D7rzkVr4bn3zz4ivt/GlrveX5sEfH9n4Yn4ZvFHuf5/ZeGnptG
Xbkxm99/aQjaOdJOwPefIA0HnN/1qJ3L77804O3S2qku/P8/abBZqOx/z4Tv
/zR0s7ix9Ehfvv/TEGvx4e7nv63G/w/l67pm
     "]]}, 
   {Hue[0.8503398874989481, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mndcze///0PIzk7CyUhlhSgjPYyUXaGh1Gk67dPedTqjTjtZibSMEGVH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     "]]}, 
   {Hue[0.08640786499873876, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mXdcze///0+yMisrK0eKyEhIZo8UQlRGUxwN7b33GZ06dU7DziwVZSej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     "]]}, 
   {Hue[0.3224758424985268, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mHlczF8Xx0dE9iRkH4QQUpYQfSIpWcrSIjTtSWna95pqqplpWsiSLWVJ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     "]]}, 
   {Hue[0.5585438199983166, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mXc81e/7x4+o0KIh7ZMGaWlr4FVJNEnJKE5khRx7cxznOIODFkrjpEFK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     "]]}, 
   {Hue[0.7946117974981064, 0.6, 0.6], LineBox[CompressedData["
1:eJw9e3lczN/3f/aUCFF8eCtZEhGFSHraW2lDJTXte6Z9r2mqaaaaKbxRloyd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     "]]}, 
   {Hue[0.030679774997896203`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnc81X/0x9HS1hCVilJRktKg5RUNmlJJRZEt2Xte7sXFdaOpJQ2iIt/2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     "]]}, 
   {Hue[0.266747752497686, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13lcjF3YB/BRofAkDxFZQhHakCXrrxJZC6UoNSWt1LTvNdPUNDNNU9la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     "]]}, 
   {Hue[0.5028157299974758, 0.6, 0.6], LineBox[CompressedData["
1:eJw1W3c81d8bJ0RL2lq6baTSsBp6a9KkMop0rSLKta993csduJe2hrqVvknD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     "]]}, 
   {Hue[0.7388837074972656, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3lcjN/3H9kKUYQsZYSUNfKhSL1bUIikaMO07zXte03bNNMypUKSDJEi
CaEojT1bWixJUtZky55s336vzvPzj9e7c889+33uvefOVAdfc2cpFovVOZDF
+r//+/916+VaBeve89+nR3+A3V/vskeK4pp+KA2jMgOTxqgCwnLIH+7/Il3x
IGEFVFnUHQx4u5+wIuRn6b71vFhKeDL81E/GbHRn+NngjTMeLqVYRlgFd9a4
nP9vxEnC0xEf4DuKtfYMYVXwuk0LR/2qIKyGV2olVQt1qgnPwuFxHdp+Z88S
noP4pQ9Nl75j5psH9bPDVLYkMvwaqE7MnFhbxchfgEqbAPe25sOEF0Ka682W
uBQS1sTo6x2VG64Xkn8WoVzNtnfQ1WzC/6G64oHouM1hwotRmFKmdfx+GeEl
+H5G9rq7CoO1YMcri7RYeYawNp4kqc/mnCgnvBT8+iLXIqWThJfhX1brjbFp
jHwdzE7ovbUp+zjh5WipGPpz6oRThHXRmPxm0J3bJYT1MG5USMX1BSfIHiB/
ffZPH8cj/ZgHfNIS3nmdeoro+vB9sf7deaPTRNeH+Oowh51qjP8MYD1wRu3K
gPNEN8ChmQs6rTYy/jbE3KbIiXmy5UQ3RPfLlR6PXjPxNMKQP9o/F2qR/3lG
SIicJV29/CjRVyB3Dq/MjMvotwL1Maot+41oPtZKFGrWFS2exvCvxGkNdbtb
XCb+q+C51fvhXhbpy1uFA7PNZ7ENzhHdGOK2vITrXWQvzxitV42fxhxl/GOC
Uofx3dsWUPx5Jki6bnxs2oksoq+Gdce7thtZe4i+Gio5xp/cmuyIvgYGjr2S
3GvW/f7nrUHvmegzZeWRFI+1WDvkm7GOy1biXwvVkkHCb97JxG+KHZvMVm70
oHjzTNE4bK/G6QHFxL8OKZfy7mrqEeatQ1tVVnFxRgbR10N/+qRPITIVRF+P
C7c4Kzgcwiwz9CY+WlPy9kQ/hhn25RVqTxIdpfFmmHk0cNa90yRfYoZa3cAp
LmpHiH8DYqPDVpaxjhH/BrjKGG3fvSKO+DdAo1b103qtncS/AYnsQZoWkkzi
N8fs20ovL5qR/jCHt91ErbNtlO88c2wYLE5vb6T6kpjDUGtnUlE16cfaiNE5
MwcNzUsh/o1o1LOrK969h/g3Yuj7GoeYraSvZCMeBUVttnh0kPgtsOetTqfz
MaN+f8MCvfm+r/9tPkD8FjgmyQ7/l7eL+C0wx07ulcqrHRQfS8gFOFtdGxBC
/JYYrWKwof0N+YNnic3WvdNmah0ifkvoGW8PzojNJ/mbsGHjeN5AF7IHm5Ae
tSdypHMe8W/CrmH3ph9r8yb+TVC5t758gxmj/2ZYNL+7bOJH9Y3NcNwxs8e7
gfHfZvzMfxY3YCKtD5LNuDyraMf7RWLit0KgcsMK0zrSD1YQ5pZ4WH3hUT5a
Qdvh3G8XMxovscLOaMtB+7XIPyxrOLup+qRrk39gjYBRko2y/4mI3xrJtQ3s
7wou/VhijU1DMp0KpJnviQ0OI+Z9dq4n8dvgtqq2VcMNJ+K3wZ/4YRGV0kz8
bXB+88Mp2ReZ9c4WF0rtpixuYPLXFs2h59c1sJl6scVdjyE31afTeiuxhXnE
b89ot/PEb4cd+28bW9VUEr8dzOvrBCrSNB/PDq+VzaW53UXEb4dy17BXJ1Yw
/Fugc/cnP8uc1ltsQUPnyY4rRxn+LfhtlWmSpHmO+LdgyonWldHLmfrZio7l
h660LmPivxV7XDROzFOk7wdvK9IudK1OOsnEbysmy7ldnSfDfG+24cSTxBnD
95F+2IYHBY2ceQOY/N0G5daQB8OOk36Sbfgkv/jf9AWM/hy42nFqWr7S94bN
QXVajPn6GyKaj4PcL5o+4zL39mMOB9+3/yocMJ6Zn4PApykThC6Ub2IOitIV
UobFnCV5HJxK67YUDyH72zk4bvAo/v3kGpJvD80JiqtSx10l+fZ4t2SMSvvt
KyTfHuoKcReiOy+TfHuk+s/3+JVJdJ49tHgmk7NSiS62xyTu8pxr9USX2ONC
cK1hhNRtkm8Pr4uNp6c9JTrLAWfS6+/IW94g+Q5w0/DOqX7CyHfApouPsO3Z
TZLvgEnn9ZeJJ10n+Q749+CvrJqY+MUOqFB8Ebs8gJHvgAd5ipXltRKS74C7
oWc8S4cw32dH3JlpzfVVIX+wHSEZFnm5duYlku8IW6HdLJ0dtF5zHFHeXL3y
Ws1pku+IKytLLJc7MPY74kHa8/Axy4hf4gitoe4PXVSJ3u6IeVIuY10MSB+W
E8JPoExa5RrJd0KlwpCm4suMfCfITtG8BHXyH8cJh68U2JoEkT94TjhupbAw
pe0OyXcC22TrU62RF0m+E37kynCnt1F9tTuhJbuw5b/fVB8sZ3xonJEczqf8
ZTtjnEmqnHsNU8/OOLFUx6Q0nPKJ44z41Qsbx1pQ/vKcMerLkfdNNbReip2x
VU9f3ugd7V8lzpB7PPlxwgNu/3rS7oyHsXKHZtzIoPXHBZe37E11WJ7Zj9ku
CMgfFXL/azqt5y6QWmI4epEr7W85LijwP5R8vZf2rzwXTFq0cuGH/2g9FrtA
u/q04tX3KbTeueAKT/foyfU0vt0Fjx8/NtF+x+w3XSGt5t4xrnUr2e+KDxVO
GTsTaD64oqhtQsyxiu1kvyum77vzbtfvfJLvCnf3KXz7LNoviV1h8/SDo1wZ
7cckrhipX2/4+6uE5LtifiNHceS0KyTfDXlHlSW2Zy6S/W6oUJOfwFt1iex3
Q7bZ5NuaAsIcN3B0tAd+yWD2U33jNfYPfSCi/Z7YDQYGwyZ5TyN7JW6YMczs
vsHvIpLvhpJ8hU+rxzP7a3d8r57yvEzJk+S74+bs8pH342g83KEQ4Bp105X2
Yxx3tA02VT/NJXk8d5xdoVpqPaiS5LujUnXKwsI/tD+UuKPXX2rFuYW0H2x3
x5bcz/Ov2Vwm+R64zDdQ9p9I/mB74N32v47NT8l/8AD3BnvZxejjJN8DxxS7
XxW20veL54GBit98NSfR/ljsge+ftDKl3a+RfA9kbb+ybfZ8xv8e6HI69+bh
R/I3yxNaM98Wz9nJ+N8Tua9CumdvJf3giRTlp4H3am6QfE+8/DG4alP1HZLv
2bdj+3JyUSTRxZ5YmHO/OGQm2SPxxAilIT7jPxNu98S20q/DW7Yz8r2w1/NY
Z60rY78Xfkasu34sqIbke2Gnu2bFuu/kD44XDp/gFuM4438vfBcfbmnq2E3y
vbCm5ZJ6aCp9zyVecNj6K/uYp5Dke+G5xbA1GoXkT5Y3hiQVnfGJLib53ggW
fDk79wfFG96InrOl1ZpH/uV4Y5ifn9t1O4onzxsXHB8/WzeMyT9vTJ/07LNz
chXZ30fnNQi1Isjedm9wa0+qH6u5QPJ9sMxdbr7GSjoPsH3AfsGuzquk8wB8
0GtcWyodRPwcH5Qlv2vJvMGch3ygtrxrhfAII98H6SsGjQ+TofqQ+EBssOl2
9GU677T7wG1I686iP8x51ReP900ac82D6GxfhBl1zc9RO0byfXG/PozTYkf1
xPHFvNEd1QaJzHnFF49eX9Et9CJ+sS8a9+/8dTGKke8L0Tc7v1Qrqo92X+xP
X6+Yt4Y5/3BxYm1A7qXbxC/HxU2/ayYW5lQ/bC5ax77WtcmkfNDgIjHwx8FB
zPoBLjz3G6XkGF3vx2Zc8KPnjIiaQpjDxQvveUbcD5TPXC5WXd9f9HDVXdKf
i9zMeEHppIZ+nMFFx0b5IzxNoou5cFhcv9Xjen0/LuNiAV+5Z8e4RrKPC3FC
V6zkEtHruTg47fcbh/uE27nYtd3249VRhLu5mJo9uPjKontkvx96Ix9JHdpP
88n54cPLrx9CZZrIfj+8uOa+Zfx3omv44Unqu+pnhkSHH7y+KiWpO9B8Zn5o
/CaqtK+l8Rw/7B7tmj/vN9nH9UPl1C/T33aQPjw/iIZ/lA28TOMz/NCT5fVL
J4rqW+yH/CkP6wZ7E3+ZHySjg5seFtwm+/3gbGxRbHHxJtnvB922rcfGfab1
oN0PZpu9rqmpEr3bD3qF321PnibM8kdM1ZEnyp5XyX5/fJphVnprJK1fbH8s
mjT99a+nFG8Nf/i+cZ34RIpZn/xxLn/SJKlgWt/M/Pv2m2c67zpTPnH8saNG
cUBgJeU71x8XFyXz2p5TPvL8MWqTvmvzbKrXDH9USJm8Z72h/BX7o/jbaKv3
4VTvZf54ZJqbXr+c5En8kW3XE3I+hPSr94du3g7WpABmvfWHi8OzshRL0rfb
HynuKsHXPzL3AwHw6cjcs1KD5MsFgH8j7uz9e7Q+sAMg06RtMbYjl+wPwG7W
ZJG4kPYDCMBVhZ0TVPdFkf0BuG4SITvrVxrZH4B3H0S6c07Q+YjbN1/6N75T
bXw/5gXg88cdd6OD9/fjjADI5uzxufYxqx+LA2BwLG7bI8vSflzWp19NoXGZ
Ae2/JQEo8Fi5+GoH7XfqA1BomGnfYUTnn/YA3JOtGFg3gfZX3QGYq6Oh7WvG
3CcFwqHqguFQVdr/ywWiYjF719ULtF9nB8LJUC7T1I3upzQCoZ0itf/iJzpP
IRB6E+TWTlCm/Z1ZIEzWfA04N5PGcwIxVc+tvEBCmBsIgzeL5+aXkDxeIC5H
nXiVs4j4MwIh51RWK/ak/a04EG+dOic7baX9b1kgOvI/Fq5cy5znA/GFtyTT
YhbpWx+IJXtzQuTjaP/dHoiWfM2iheZ3yf5ARHl++il9kParrCA8yOjeuHNY
HdkfhO72A8HsqgayPwjjouc8Ht9EWCMI7D9+Yc+z6sn+IIyc8OrRzmuNZH8Q
dnMbpFbOekD2B8FO5bqZ+ob7ZH8Qzuut2L/yLs3HC0JVr6eRbxDhjCD8Tubu
vyokLA5CNrsh1C7rHtkfBJG5zinbTMKSIFgNCJPzW/OQ7A8C37ap+rAH4fYg
OHO0BLOLmsj+IKzVnO//XzHxs4Jxd3uFcIkLyZMLhkN7sKrHE/IPOxhbtyvI
1yiRfRrBkMhu6Qk3JH4EY/EiRU+OI2N/MNjj1wtEi2k+TjAsznEutckRnRuM
LyvW3Ft+hzAvGI4+IU7BquTPjGCMjE5XYp8hujgY8ja7L4waxdgfDIW05xHq
rYz9wWiX3vj0eUML2R8MsUBq4d4jT8j+YOwfP57/cXgb2R+M7CFFldWWj8n+
EDx6eViUv5WwXAhGTH50cf1omo8dgqKupK0eJ1vJ/hBIvVomGzSLxiME6YHm
r+WCm8n+ELyaEBd08NYjsj8EddmzuEcZzO0bv3jpmJsi4ueF4FDqHcEiDdIv
IwRnn4YP4f0g/cUhMJNradqygHBZCHLLRFoDVWk+SQh692nM+ruG5qvv07+9
22r1HNK/PQTtJ9vW69cQ7g5BzZ0hOlO0SV9WKGreC716pQjLheLk+CNDDi2l
fGWHwuKFOdc9jfJHIxSD1il3Pj9HdITCcbZMhr8qxcMsFDNn9mzRvsnkfyjC
/wnmGIZSPnJDkTnt7ePf2kTnhaIjiG/KbqX5M0Ix5ePL4M2Dabw4FDE5YXed
9UheWSgGJ8wvTj5N+SEJRetT1ftpMkSvD4XGM7+YEcU0X3so0kpbrp69wOR/
KHY6fXa6eobks8LglTRS85Qf6S8XhvFJA/OfmBFmh2Go465bme5M/YdB//Mm
rYoHtJ4gDMH13qw7BwibhaGrrvHAsx+0nnDCML/wll4Pk8/cMFgs/jJaaQPZ
xwsDa9tjH7s6kpcRhu2Vp71fDyF7xGG4PXZEzYA9VB9lYTC5NTf9UzWdvyVh
ODt+W7EFCNeHIUmlatzeTMLtYZg4LkMcW0rn9+4wvBqvbbhsdi3ZH47Eixen
lp6n9VIuHJxRR9re3yQ6OxzZWV/l+fZ0P6MRjl+nJUF2JXRfgHAMm2y/kfua
sFk49saq5HGu0HhOOGIC/87gFdF83HBkLvn3b/A85v4kHGv59QemXrxF9ofj
+6IG3d03mfuUcOwrvT79TAjZUxaOCTGbrJ/mE10SjtwSxwdLlQjXh6PJZKlP
oCZjfzg8q5pmmO4jed3hGHm327ukjsazIrDmXtsEmak0Xi4CGift1i3ZxdwH
RWDqddHG119If40I+DX8vfnVkvyJCPydz0kw3U3YLALfezLqZw+jeHEisOB7
/uYBIso/bt98RqbzOabM+heBJOfa7k9TmPU/AnsUlNe9mMKsfxEQfVnlUixH
9LIIbEguGPnmFeWXJALbZys0/PnK2B+BuL3x4stjSH57BPIvsbpcpJjvXwT+
LZmY/OIC0VmROBAvNBiTTXS5SFjaX3m/tZXo7Ej8PVauo3Gfyf9ImLl/fNNV
SfIRiRNXJra1faXxZpEY/jDwgVots/5HoqRJ2KBvyNgfiYl33HRsGyi/eZFI
bZeJHCJL9ZARifg1xhq5fkz9R+Lkc/bCwT9ofSuLxPEx5dJV9whLInHq2Yv5
PQq0HtZHwtq46XLJTsLtkegosOF//Un11R2JmwMVv5xi1gNWFI7/V3cxyYOp
/yiINxe7u2xgvv9RkFFepRnIpfzQiMLyQwNef3Sh7yOisK31wZMDf5n4R0Fa
5M6yjWbiHwWlrk7dm5dofm4UnOZM1J5gRJgXhazqeRvn5dJ6lBGFdZH7cg6u
YuyPQmO5ftobXcb+KHxSjWGV3qbvkSQKduOf1FpICNdHIXdV3IAxbYTbo2Aw
RX8Agoi/Owp7lvrVb5QhOisaCzzPdDrL0vdHLhofVOqf2LIJs6Px6FLBuIr1
zPcvGkbKeXVZ84iOaCTqrbVJ47ST/dFQOr7vROAgonOikb4w1NGZTfzcaERM
r3r10oi+R7xoDFR/y2WZ0vcnIxqWEln7W8z+RRyN/WczVDSlaHxZNGxuDMnl
CwhLohGUyf9yL4jZ/0TDz1FKXs2T+f5HY2/oksoNuxj7o/FwUOngTZ8oP1gx
WFbrKiM9gvn+x6Ax9EySFJ/iwY7Be12/njfHCWvEwFIu0+5uE7P/iUHF/GXO
H8soX8xisHZVeEhcI+UXJwZd8vXjLzL7Q24MZvocWbQ+jqn/GOxeP9iGdZLq
LyMG7dX4tSqc8kkcg7iFGeqG16m+y2LwZmC89VIHZv2LgcflKSOeP6R8rI+B
1rPxtxOG0nraHoPSAbZlSZWUv90x+Gr2O/dSMWEWD5WOYc7dHrReS/NQZnp5
nbU1redyPCj+6nm7woqwIg97B79NUc0j/dg81LKfTLNk9odqPITWRlxaHEL2
aPDwZOPaY7n6tH5q8XDNYoauRhxh8DByyiWHFA2a35gH9k2/zFo/Wq/NeEh6
s3TvkN003oqH5TcPCQ4q0XgOD2de6tXtsyb93XiwyfFQ2+hLmMvDKOEVzRkP
6PsWyoNvh519wV/yH4+HmfoPDgz8VdWPBTwMwucNg4R035zR5w++/PCrFXRf
n8PDyonnrE0X0/25mAeXwy9PLKqj8UV9/orS6L1vRff5ZTy01Mq8XDqY5Ffw
UG1onjdoIukn4aH1tZ5K7AG6n6/lwVB2fNlnmQsUTx5WV+tKYTud15p5CG7M
iDhkSridh/kaMiHW5+l818lD1B73XbKh1E/t5kGtS88lZxqdJ3t4OFjctkXD
IIjiHwuh5PKx7tExFP9Y6O3JG7v+fQHFPxaXLS24ZbrVFP9YvBv4/MZ7ezr/
sWOhOOxB7/x4kq8Wi7dhoeucw4iuEYsIj5+Fc8VE14pFo/dP/oWu+Jr++Mci
6L1+fn5QGMU/FnPNdkk2Ref0081i8WzP6ZM+d6nfbhWL/f6ha/OT6H0JJxbd
X9Srr+hRv9ItFqm3S4a6GxDmxmKMXVXvqGbq14bGYveB+KK5lcz9ZSyGzjwc
bqR0qB8LYuEi4er1KtF7g4xYGFjMC1MYKOjHObEY+0/+7YCv+/qxOBb3bv4K
lBNRv6woFuFqnbl+/nQ+L4tFzdZDYtkCur+v6MPS0a+fxFF/Q9Knj03Nf4kf
6PxbGwuvQHtLHea8Wx+LHzkngi950/m5ORanZ3Zlbg1hzvexMEo5Ln/EiMZ3
xuLmD4HM5tM0vjsWO47dn3g0l3BPLIY4aHaoDmX6P3HYPCSha4IWyZeOA6u9
oNx2G52/5eIwpkowdPwIwopxqO71XeXbwNwPxGFElWTeeTnCanHwVfLj5x9j
4h+HBOHbKJM2ur/QisOVmPCBUd+Y/k4cTt+8kVPO9LOM4zDzl+LrbBXCZnG4
s5Ar2+BM/R6rOOirCBeOWE79JU4cRNGTrSdwqJ7d4jD3svTiouO0fnDjcHtV
q2bmY6b+4/B7SWZytROtH7w4NLAnfpM9QvMJ4lB6rqdyaD3VZ0YcNM3iLBMz
yV85cYhz2L8j9QTZK46Dw88Rnq3GhIvi0Hrlr73RFab+4xA178bjLUpUzxVx
mLgw/+ffFUx/Lg6/yll3xjH+rY3DBJ/FaU+Z9xn1cRh1crGcgRbVc3McfrrJ
5v+6T/XUHoe2qB+TLN+T/M44qCdP53/+Rf7qjoOldESyzCWavycOWkpml7bs
2kHxj0eTTZ3pM0e6f5KOx97tabODdJj6jwff4cLyos+UP4rxuD7jqPqJO6Qf
Ox6sjFM9Pz/T/GrxyLz479+gSMp/jXgYau812BwT0V8vWvEoi9k1+f4hek+D
eNzZ05Z5zZXq0Tgek0vmR9XJ0f2hWTx2lKz5Y2ZG99VW8Yg2vLtr6CjmfjEe
gxsF1XvkS6j+46HroFo5xITqlxuPuyylVRYrqN8U2kc/sn3Bu3/bqf7joe+x
63XQU1pPBH3z6/zTPT+V7v8y4rGsJrzU+gndJ+b02btsqavZDua+PR7JmQLB
9yWkX1E8ymNkXd0PEb0sHgry91uK3ajfURGPSWurmlXN6f5eEo9/t49H2wqp
n1QbD676rPId6rQ+1scjcDx3/6wuWn+a45FjfXhrtz29p2mPx4RBbXmrlzlT
/OOxVTQwNTyTR/GPh3Pt/d7zfpH9/D3x2PDb1tRnrE0/ZiXA/4BPueFtipd0
AqbJBm60LtvVT5dLwJ8h0zWebKL3TYoJuPVy+yPlBx79mJ2A4QZ/JtrWEl0t
ASe/8Euvu1F/UyMBF19PHbrsPd3naiVA8dCgrrPS5F/0yTf8aNjyke5njRNQ
OkPZ1rqM/GmWAHXTJnk55n2fVQJe+n669UBA/JwEtES8tNG4SvnjloCGFe5d
YRH03pCbgHy7WYmjjtB9b2gCshWk7g3+Sf1FXgLW+qY27+FT/1SQgGKtl4mO
zTQ+IwFqj+4e0n3NxD8BprNzd8mF032zOAFDsieKFi6m+/OiBCjN7n1251gt
xT8B3ILPe1t6qR9SkQBjJ+cn3R7M/XXf+AGqbRfK6b69NgGhw0LE3waQP+oT
sCE/zU7tG83XnIDZPw1L5hYw/bw+fWy02CPX0PjOBORc81c7UFLXj7sToHk5
9rGyAuGeBOj2rjs1+x/1V1iJGNl0+oJwKPUTpBOx8Zpdkr45jZdLxAw9BWfR
cupXKCbiYrXydsuNhNmJWHN7ekaaDM2nlohJLLUH05OZfkkiXCu9FO+vIKyV
iAzVeDPzDTQeiTCa0/xAczn1N4wT0bIu2+C5+BbFPxG9T72S5tylfoZVInpK
Nv3+fJzphyZiCrR+tmwg7JaIKJ9Vz67oUP+Emwg780N2ZefJf6GJ4Pze+VSt
nem/JCKlSP1DuSZhQSLya/eMGTqa/JGRiHcei15KuxDOSUSYvvM78y80nzgR
v8PiO9aC+oNFiahV8Hs1wYvysSwRXjMLR6+KovytSMQ0szmVI3ypny5JxPMF
j+fUdFO+1SZi6bIlH42m0HpWn4ip6plBhTo0X3MixhsZeysrMf3ERAz2TB6R
JyHcmYj981JfnF5B8roT4fZFs3TUTcq3nkSo+7gL82Kon8fiQ22zhbOxC42X
5mO5kuJttTWUr3J89FyO5Ki9JH0V+TDPWDTAQJMwmw/V7Rr5Am2yX42P51oj
J6ySInkafCx9MXeA9C7Kby0+pi7nusWymf4hHzJ7xoY9O0P1Y8zHjrRJZe/u
Mf0kPvZqz/imm0L9SCs+Ni/9cMRqGNE5fIwVKNcMFJI+bnxIVpzw2sNm+o18
hBQs9DCdQjiUjzGyvrr1a2k8j49/z209V10g/QR8JLa5tATuoH53Bh9uopGn
nibSepPDR/acwK8NrjSfuM8fn6SODNtC/EV8rJ/WYLpUm+Yv4+NWrELJ1Woa
X9Gnj8rqQ3PzyL8SPi49/tu21on8UctH1PPR/+k+pPnq+fAojDNrNKR6aOYj
B7GazuuY/h4fNybmqh3VpXzs5OP3goN7n79k+p18vK9s9Lb/TvXVw8dd/c9b
UgqY+k/CrXctk/d+IiydhKDnXTV6T6h+5JLw3sIleqUjza/YN15aN2+gHNUD
OwneoVk/FZYx9Z+EuytaDR/JEF0jCTm3ZqaHl1O/USsJXQ5f9+d/JPuRhIKw
Yxs3B9J44yQMaH9TxM4k+WZJuJFxb8WvXLLfKglj5HdNnlVAmJOECF+W7dVo
ms8tCU/+TbpwbBbpy03Cjyuj3Y8vovwKTUJWY4Ik6TZhXhKSry3ZNvUvxUfQ
N9+eIyeeqVE8MpKwxekk9zyLqf8kHMAyxdcyTP0nYU+pUT5rERP/Pn2ntiXU
l9N8ZUkYrPApRSJm4p+Ecb8h43eE+CVJOHvNu1t5GuVLbRL03/p/HdpI9tT3
+a9RuqrOk+LdnIRBjlKvPb8z8U+CXrXu1i8C8kdnEgwmmf7KPUu4OwkJJ09d
1/5I+vckQcc1Ye5PVyb+AljE6A/cX0PxkRbAS9mreVsAU/8CxHZ8SDmvRfWt
KMC2qwYBkV5UH2wB3D10J3dXEb+aAO/Nz8vf/EPx0xBgcvRYvzojyj8tAa6P
m/Nl6ENm/Rfg0RVhzfAKJv4CZG6reP7AgPxjJsAhwZ/oh/8IWwlQ1ut7Va6F
eV8ggEd+ucMn5nvhJsD8O23mLtkUD24f//BVWaYeTPwF2JOVVTjdnMbzBFA+
5GAaaEL6CgRQqFq6jfcfzZ8hQOmPtQsiyykfcgRYvd1wXNA15r2NAJerkjiH
85j4CxBqJOvXdYjoZQLsrC4cd/Mc6V8hwIeajvN37Jn3OQI0BZctmTqG6LUC
iOc/ks/OIX3rBRhhXnlek9mPNvf57/b+jp8viN4uwJBp2uUHtpO+nQJcTbnL
UR5O83ULsHtEb/o/xh89Aji0PuuMDKbxLCFUdr/yaBjHxF+IQwGTx+RVk3/k
hFhQ9/sF+zH5R1GIxcPVx3lvZOpfiO5zNm/yw5j4C/G2t+hLpxfzXkCIhoYd
Tl0PKX+0+ubbmWd4dT7tByFE8pHR9pW99P0yFuKD8oewPybM/l+I10+f/OEW
0H7eSoiqDRsyPqyg/RtHCLm10gtuDSPsJoSqyvKdUn9oP88VosLn3UvLFOb8
L0Tel/8ypXjMe30h5mWFOIwfTvtVgRC/xNu+7rAk/TKEMF6+SU4wk9775Aix
azmvKuk7fZ/FQtTcS9HMcqP7gyIh3jvt8rsRTe/9y4TIMM/8vred3hdWCHHO
q9xMv4TuXyRCOE6ytej6SO/9aoVotjlxVOE4nafqhThw7UbRzOF0nmzu87+5
TbplKZ1P24WwteWUlAnp/NopRPm+vLpSAzpfdgsxd+RJfctzdB7uEcLt9aAx
30yIn5UMBa5MzqwIun+STsbSys8JHHOmH5QMm1V/r9V2E1ZMxp7fIQbvOHS/
yE7G72LBD48AkqeWjMFLLsyWbaPxGsm4OMFo9TErkqeVDP9dA/4UF9J5HX3z
/RJV75Cn+0TjZPz4vGKQPtOfMkuGc3j2pNer6b7SKhkRUiNKjzL9ME4yDsYG
qW6bRfeNbsmwLzl0kXuY6Nxk9ORtyDyzg/hDk7HG2eB3eQnNz0vG3AvXIZdM
+gqSIZ/47sBQddIvIxmyyj5rJ7QQzknG5gZUvxxJ/Q9xMsq/HcnOWE3yipKR
5N8ymG3F3NcmI/Fq2viXd8m+ij7/Hv6Rem4u079Jhmej1rljTsRfm4wwlfgV
d1II1ycjbd+Saa+30X1yczI0vpWLM6PovrU9GSuXm13jM/I7k6H+x2xhkZDm
706GZvfi7NgmovckY4b+qHUjYomflQLOyGXLnAfT/bV0CobcPp/1MId5D5CC
V8mha3KXEFZMwfCRlQnDBEx/KAV3Gjc/XF5AWC0F9noNr2RTmX5RCj4+L0jw
USOslYKSiSdMFj1n+kcpmBc3LV3vJN1fG6fgQmR+0ocuyi+zFOy5cNZnThET
/z79ZmdtHT2G4sVJgU5bcHToT8p/txQoDX+z9+QtwtwUnL/ckXVyF8U7NAXy
Qbe/LJ/LxD8FYS/arp3VZu5/UiBczD1S2ET1kJGCOusrzY6eFL+cFPgd2lDa
a8Lcz/fpP0HfWsi8fy7qw3alXsXnmH5tCpJzj/35qc3EPwVtQbmtBV/JH5IU
FPuJbo7dQ/Gt7eMfdbJFx4zpZ6dA4rWe66VL/Y7mFOx3KP+nVEX9kvYULMgz
2BXIJdyZgr/Sm9gRdYS7U3Az3jTjjQH1N3pScKOm2uduBdP/T0XRrHkvtd5R
/0Q6FW8DM21Sq6k/IpeKQ407dpvqEL9iKoRjVj179YYwOxX7JRGCCUx/Si0V
uxdvSli0n7BGKu4NOD9tShPpr5WKWksb78LjJB+p0Lt/8J3DIKIbp2LR5c2f
5khTv8UsFTZysi9HWpA/rFLx5VvV0AU7CHNSYf/9p32jP413S8W1Jxfnrq1m
+i2p+HD/bZzxFfJ3aCosfnik1N1l+i+pqDA8xCnmULwEqfi+R0c3fSXNn5GK
gilrup6NIP/kpMJWRjlt4SCSJ07F4x9D5x6vpX5QUSruv5RaNekT814lFZ+E
0wI27qT5KlLxVK1NsIXFvF/p85fN1eHmEsK1qSgZqnRu5XbKh/pUmG3mnS7U
J/7mVLzba/mf6yiS356KMxtNY2M2MPFPhZXKogvdt4jenYpIKBVVvCbck4o5
W+//bFtP9rDSkDd89dQHkdSfk07DnZmjLvrIP6X4pyH+ISvc9B7lg2Ia5AOD
f3v/JXnsNAzzNwmcmklYLQ2229Z0Xoyi+TXSkK1tu/+rDMnXSsP94wPm9lQw
70fS8E77gPyTToqPcRq0OyZ4DHRl+qlpWDfdVrukh9ZTqzQo38uJUK+j9YGT
hmLz87pX6mg9cEuDQ1eBatM+pv+TBimN5SO7XtL3KTQNWZyDa+LeUn3z0vDt
WZYWR4ewIA0Ju0KeedTS/XBGGoJWf9oU/f/1n4ZT/v8FlIxi3melYfg2a6P7
BwkXpWHUo80f/XyZfn0aVCae9f48hfKrIg2SLd/VJ9sQlvTp/7lWT2o2zV+b
hoj00id/FMi++jQ4x8cPODyd1pfmNMxMNnl8JJfWr/Y0DDo1ZlLtR7K3Mw1y
4xVOPB5JuDsNJfG31oQvJft60vB44Os/7/6RP1giXJoTv2D7JrJXWoQpRzTi
jA7QfkFOBPUWOe6iGMKKIoREXlNsfUTrMVuEFw9tv2ifI6wmwgAnhV8qucz3
X4SGp0FTc4tIvpYIotzHk6NMmPcjIih2ydZJaVF8jUVo8Xvc8eQ6E38RNFem
CxLuMvEX4fcWm6SXOUz8Rdg6+HalqTdhNxHe2C7Vfv6Xuf8XYVpHTENvKvkj
VITn5Y8z5+1i4t833rSmtWo86S8QYd7G6b+O72C+/yKAHT124Xsm/iIMbPrc
ylYi/4tF0Lka0fRpNM1fJEKpyyDnVz9p/jIRJJfqKlsn0X15hQijP7YGnfrF
/B5NhGE6HZzrH6l/WCuC/0CTYXu/Uz+yXoTVYcffLCulfkmzCAFn/lybWEi/
B2sXwTdN2N6dRb8H6xRBy8Am8a1GYk1//EWYVeq8Z+oc6of1iPB325EV9gdz
Kf7pEN3xGaIoT/NJp6PNrQvfy6lfI5eOJ6cv/l3kQb9PU0xH4BFr/T/B1H9k
p0Nj3t474TL0HlMtHetN5I9Pf079KY10FFzf9dfUxb9fvlY6zpzQMFJi9EU6
hm5cLDLdcEDvfxcEu/A=
     "]]}, 
   {Hue[0.9749516849970554, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3c81d//11Cioa2tzLaS0n4mlUJWikrIJlz72td173WvO2ihPg1tGdFQ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     "]]}, 
   {Hue[0.21101966249684523`, 0.6, 0.6], LineBox[CompressedData["
1:eJw1W3k81N0X1i5tpEWbpBTalJLw1pMWijJIadPYIlnGPvYxYxgMSSWlMiql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     "]]}, 
   {Hue[0.44708763999663503`, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mXlYjG0bxgdFlihrvGTs2SMpUc4UIktKyZZpQXvTvtc000wzNdVYyxJJ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     "]]}, 
   {Hue[0.6831556174964248, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3c81d//v21t0tC+0lAakqT9LA2KEgoN2SPi2pu7XdcllFJKt4mG0dTS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     "]]}, 
   {Hue[0.9192235949962146, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3k81N/3FiqVSiX5pGUqldKiFS16KopCU7JEMXYVGvvOzBjMYtCuRY0W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     "]]}, 
   {Hue[0.15529157249600445`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9e3c81e/7/4mGtqRS7+S0JC1NGvSklDZFRuEgM3I49jzOcYZjtrUkLQ2l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     "]]}, 
   {Hue[0.39135954999579425`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9l3c81e/7x0+kVJJoqFTSkiQN0sBLU9toUMYhqxTH3rw5B8dxjFLRUKdU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     "]]}, 
   {Hue[0.6274275274955841, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnlcjN37xydFIaTwFCI8SEJRitBHQgiRlKimvRSmfdqnmpqpZipUypqy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     "]]}, 
   {Hue[0.8634955049953739, 0.6, 0.6], LineBox[CompressedData["
1:eJw1W3lczF8XjkiRZCm7Rkjyi4rIlieJsiQqWiwjpb2mfa+ZpmWaphVJtqwl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     "]]}, 
   {Hue[0.09956348249516367, 0.6, 0.6], LineBox[CompressedData["
1:eJw9WmdYk0vTjmLBHhUVUSE2BI+FYsGC3CoCIiqCBRuGXgSJ9E4IJSEJRUTE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     "]]}, 
   {Hue[0.3356314599949535, 0.6, 0.6], LineBox[CompressedData["
1:eJw9enlczN/3/7yzVZayfBTCKEshoihLeWohpAWlBU2JkqVp32tmmpmmmaZS
UrINQtYKkUhjKdnLGlnGniWytCl8+z2c188/Hs/OvWe995wz97xG+QYtWaPG
YrEaurFY/+//f/+a5riMWByf3Ggyh/4Az5Y3KUb/ZRNWB0/WrMtLSa34h7Wh
ao4rXCyTE30Qku8Il5803kFYF5dHe3fIfqbQej0Ubtup0/AtnuhsNMivfd21
SEhYH/c0/+y4OzCR8Gi41+3ryffZS/vHYlDKpVNh704RNoTmKeMlASmXCI+H
z4Vbn1pPKQlPRPW6UTcKR58nPAmWI69ZazdcJGyC8vUp15oirhGeAqeZ+lPG
c64QnophUi321QqGnymKsg3D+uQw2Awp4WE/mqZWE54G3uYx11doM/pMh+zN
m+7LXlUQNsf+eTMHjTRisAUu+WXdi2tm9JmBTTHJ1aedGf4zMXbbGoOzdxh9
ZmFO/NBbS4ouEJ6N/D4lD9kBZwhbYoeiKr4imcFWMDz8YaRmDcNvDl40r6jJ
NmbkAS63RP7620gfHrDwq2viAX2G/1z0mzXexrGziuhzMXfAn2aHG4x91hic
V3pi3Rjix7NGXn5G5N9+DH8bxGw69PtjO+nPs8HHYoe7364y9tui47Ho0Pqj
zH5bbHgU6jzcibHXDi6nbu7+z4bRzw6HFdd3qYIYe+ahl2ZQklPTaaLPg/UN
1seXXxn6fDh1yJ6FHqok+nw8/jw5hlVPmGWP5oxUa6duDN0eZ10Mn2zzu0z0
BZg21yw+KYrRfwGqbs/7pn2QsX8h1I3+prASGf0XYnj218QKP+Y8LMJC4wFT
P74nzFsE9QK/zbVmDN0BZUFD+LdsGf86wEg1Y4JfwlWiL4b75LvW4xxIHm8x
+tz3SZliX0Z0R3j5BMS+OlhOdEdMUVfaL9zM3A8neJxs8GnVI8xzwpfGFSVP
9Rj/O8O90TbefT7ZB2cM7a9mZmF7g9Y7Q2VuLFGKSF+lM7Y3B4TN60V0lgsW
26cFt80i/8EFHvlDJZIr5H+eC+rVR3VUMfdJ6YLQhq3LNg+5SfuXYESM/fan
14k/lqCj4ahxvjojfwmKDwwV4T35Q7kEexsdRTwrJj5L8WhiL8fyNkb+Ukz2
dBS8dmH8vRSnGyOG1leR/5RL0eCk0rTWYM7HMjyumKQ88u0s7V+Gxuwj5drx
jL+X4ePOsfJ122m9chl222aPNqotpf2uaFKbaOO3ks4fXPF2ZPGNHxGMv12h
nH3jzvYgWq90hU3MtVEpSw/SfjdM1c+6fOxDEe13w3mvASl7dQ/Tfjds6b7Y
SGMK0ZVueDXpx6g9l4pp/3LEra7Vt5XQfcdyePVsKmg/r6D9y2Erdpp33Xo3
7V+Ow5nt7+UFubTfHX/1+7NbNLJpvzsqW8fvb7HaTvvdsfztli+VE4i/0h35
r0qV7+Yw588Dleelb5f40HmCB6LqtoZF9CB7eR44te/3js82x2i/B3ZELDp5
vYgwyxNWex5bnmH8DU8Y7NppXS9g/O+J6v3bz49bRvFWeiI6Z9GMpAVMfvGC
bO5Ex9P9mfh7YZRaVubeLcx99ELm5fH3Nt2k/K/0wqnd1p/L1U/S/hUIOvtr
wpIBJbR/BTpbOk8/2MTkkxWomXgg5spXxv4V6CcwuyLed5z2r8SU1x5rfpvv
p/0r4eKnvXOwQT7tX4m6AHuPgTpM/FZCa9bLfZMeHqL9qzDb9cBI+J2g/atQ
ELyOPXIA+Ye3CrV/1BWWm5n4rYJ5gZ561PbNtN8bER4Li0O9Q/7VS3hjUsSm
s6f8KL48b/T5Ncr1oVcm7feGxxyHiDWiFKqvHBTM1Z6bNzXqH53NQY6GQd7X
mD2kDwf+4Y87ci6TfhwOehT+7XHYhfzF40AWP6nscBLZq+BgxZ31q5zU6Pwq
OeCnf9eoSaH7oOKAs9hy2sRc4sfywQe/P4qXk/eRfB+YvCqTd////vDB9zJe
4bs5GSTfB93tDH8N8hP905/ng3tGB02nKhn5PniS3ZDQq6GA5PtguV1ye8a0
LJLvg0DNJmNP76Mk3xc3SrPeS2eQvmxfaJdJN41tIP/CFz+rA0dxcneSfF8I
vs8w6N+f/MPzhfqZ4vol3cg+hS+uVRzYEbOL+iOlL5pDJp0aPJX4q3zR33hI
8BQLyjes1TC6Jz+6y5IwezWOfLcc7B/OnOfVSHVt+VxfTvmTsxp9Y62D5xym
fMhbjaKQRvXfFpRPFasxjDeLt2PgdZK/GtMuf/x06x7lQ9VqhMqkwn56TH31
A0dqXLX0O+U3th/urNyUPOw71X/4IazT9qkgkvTj+CHN8vySinVMvfKDp+cH
rsyV8rXCD9Kbg+ZlB5I+Sj+MyC8Z8quZ+iuVH+6d8l7w6AVTP9bg1scFZ1Zw
SF/2Gqzzdvm+e9Mtkr8GO784Tp6SQfw4a9BsfmTYi9NMfejCI/N/BiwifRRr
cNlva+be20y+WIP9AXHTnq6g/KRaA++fk/c47DpH8tfiZ9WnTM5Ispe9Ft2T
ihv1LzH5YC0WTSjeWXKkkOSvReXlYcmNV+g+8tbC7qzaC80yHslfi2FT4peN
fkDnWbkWSbkmHRfX0X1XrYV3SMCjINYWun/+cPnpOO7H8D3/MNsf6PHOv7H9
KN1nfzR//+7ZXEb9NMcfE2adb706nO4zzx+/Lr9f1WFA91fhj/z2J3tFr7f+
W6/s4qcarPG0O/FX+WNZqNV6tudekh+A1Ye0udyVdH/YATi29eqXQ++iyf4A
bHrb62rkEMovnADYI7vXz8wVJD8AFvv7a0x+Kib5Adj1zPHygioXsj8Azo7K
lqy4wyQ/AE/nzxGe6knrWevQ72lHduvIfLJ/HTQrw84krN1O9q9D0BOjIc84
7uT/dWD/sNwZJNlF8tehrNdxqwNLZSR/HSYcLffVuu1P8tfh1N3L439bmpL/
14HDMjYu+HyM7A/EqtAJNr1mVJD8QKiJlVl3RytJfiDG646+Mr7HJbI/EGdm
PXc5XXCR8k8gjvCLl8yef/UfVgTi4tJVF/6XUU3+D0T1W5/eutlXyP5ALE08
2df2HdFZ67G22N67gHed5K9HYfqDPmOzCGM9Bn/c41qxkPhz1sPHZ2M5u/Ea
yV8PbsWo6jd3SD/FejSf+lP8sAfpp1yPJ+dePu7QP0Py10OZ1Po89z3RWRuQ
Jnnx1vt/pA97A2Z2sz4ptKwk+RsgN/Kw7v6V/MHZgOfO2WVDBpM9vA0w4iR/
m8K+TPI34K/BLaNl24iu3IDOaw25e93IHtUGtEfp+UoX3yH5G3Hk6+wFerE1
JH8jTj9TRLmuqiX5G5G4j7X2txphzkaY+6iHTRlAmLcRDZeylQXqtF+xEesc
L5f+9LhJ8jdizq/dogV65C/VRqju6rY9D6gi+ZsgeFia7LGMif8mrHdudZDK
SH9sAmeLmdFoAyb+mzDu7/uPb34x8d+EyUcWl4mHXiD5mwDs3/zrIa1XbsKX
2sc2g2IIqzbhQozpoo6fxJ8VhO3bncxtvYkfOwgtAmMPz3bSB0G4Pljh+GAL
+ZcThBHjv7wbq07x4QXhb/+Q2rIOskcRhDqPzPFjypn4ByH08Hyt9B9EVwVB
49DNe94lpA+Li/qL8nt6qwhrczFoxnOLP9/pvLG5UHdYuGOoirAJF/Y6jb5V
z8lecOFfHdKxdOm5f9iZi8Yhq/IEvmQfh4s1BxJeB4QS5nKhaxdvD2fm/HDR
ba5X3ScLsi+D29XB6a5Ia6bzouAioDdvaNp4Op9FXKQ9EY6RmhBdyYXntFxP
jwkU3xoupvi+15Cmkf0qLrbwfh0MH0T2N3FhkhEkW8HEkxUMddGPyvkVxWR/
MD787/cuffNcsj8Ye10/J163pfxoEozrtlohmjMpvyIY27NUusPtKF85B2O+
/FJ26fd0sj8YpgM8im8mUz7nBmPx13dHja/sI/uD4adz1Mt9LOXTjGD8MbF1
mzaT8q0iGAt/TlwnKKV+rigYbt9MhmZWUz1SBsNbPjstZx/Vq5pgCMp6NwqO
Uv+jCsa2koLAlxHx/3BTFz/PcfZNXrvI/hAc4llkJp/Q+UfXDsGTzsSaI27U
37JDsPiIXm4vL/p9aRKCnIU/TywdRv00QlBT0mx1ew7VV+cQRFz88T68L9Mv
hKCZc3WA2lXC3BDInCWs6t/U3/FCMDT4VMDMYOKXEYKYz4evXQuj+qwIgUGA
RmDxpSNkfwjaTgiLH62hfk4ZAm1vxfK5q+h9qCYErvu3RgqeMP1WCC6wzEa/
DdlB9odgcNbBNLE/Y38obB35oodKOdkfij78U8297zL9YCjOTByyzrgX1XOT
UHiInmWFa5J/EYpfN6d45r3IoviHonNrwtcHXiFkfyg+vxn5Y+GxIxT/UOzf
sCZdqnmK4h8K4zcRhf69C+j8h2L03C9bLF4oKP6haNi2L6D1Swmd/1BEbn2X
ntP7BJ3/UFiZbgqbFXuIzn8oWvbv0zDtIHmqUPhK6o88RDmd/1AM+FBinDuN
8gsrDOMGF5lo/qH8rh0GmaRltN7/6H6yw1AdUPlkwS3KpyZhKLIb2mlbRPcN
YSjv5vnGo43yuXMYRDv0b27PY/J1GHwytptJNlB+5nbt7zy67T+ru2R/GFrH
LXoo2X6L7A/Dhn0OO0MnET9FGGqVuRdPHSd6URi0/zrnefYkfsowWO7uvlBy
gXBNGIaFHIs+5kz8VWE4+yu3csVMwk1hGFn/5dLh/qQfKxw6panD9brdI/vD
MXfNG3Nb/gOyPxzp8YGzuonvk/3hcJLt/FWqRusRjsjjVrsGBRJ2Dgf34M74
yV6EOeFwV8yPy4gn+dxwcOZck9jsI3154Vhy4tm2udGM/eGY6BI0f3zRDbI/
HFE5J9vnvqL8WxQOzRzB6D1Swspw/PdjfkjVPib/hXedB82jd9yJrgrH8KUn
xYF3KZ5N4Qi0SRxgrE/5mxUBq9jsUfWnKV9qR+CBcuuvFAemH4jAPnvdwRub
CZtEdPVzG8ea9KT1iICdpWCb2yuS7xwBTTXdkvvXSX9OBDI6jpne+kyYG4GK
O9FJmzOY+h2B4pKiXt3m3ib7I/Da+9KY3tOJrojA87lnOn8/IX8VRaBjOsTv
q8m/ygicG7/WpXU44ZoIDB/t+6pa8ZDsj8D7BK3A07aEmyLg0D1rpLeijuyP
hNcGzt7XhY/J/kjc4bK3v3tNdHYkqq7Xr0yPfkL2R+K/6KDdpU5ERyR8L+73
uT3tGdkfCc386j+f39aT/ZHY+cuipVcz7edG4qzKITrQkeTxIrGnKuuCVxXx
y4jEZ8fSac++EFZEIjZlqJBzn/xRFInhvRxEPacy5z8SC0denLKolM5XTSRS
X3464sOi86qKROuxAd1V1XSemyJhVBL++GAh+YsVhdYGS3PbIlqvHYVHE7Zs
f7vsEdkfBbvGfR/LlOQ/kyiIh3+afeAP8UMUHMrDrwZNJrpzFC7ppuUZLSfM
icI0w5Ccqku0nhuF9v2GqQfsCPOiUNAhGmczheRnROFE/Mt1j40JK6Jw5IJk
U/Ri8kdRFMp2lpXmDCT/KaOwwW9QifAp8auJQpZqstu3AYRVUagtCXqv05P2
N0Xhre0ER/VlpB8rGnfvqucUiMhe7Wio+t+alnqT4seORofhjZY5MoqvSTR8
+w+UO5QRRjSu7ql+zOtN652jkbKs5+IUJt6caKgdjukMZ+zjRsMmn7fEtTf5
nxeN2wZvQ0/uI5wRjaPD7FTnztN9UERjp9XNIPNrzPmPxtx2++iCADoPymg8
7v0n7kQC8a+JRp/9H9fMiiG6Khq8pHXyoTq0vykab8Y4bLV+RPeRFQPHcnd1
u0C6v9oxGD90uXIIqL9kx+DbD4Wd8gvlD5MYjDDL6PM7ivl9FIMSvSFXS7pT
f+XchcM2R9qVMr8XYsDyl5V5jaP+jhsDV94snfpdhHkxmBL9Y49BJu3PiEHf
HyM6YzNJviIGYV71xc+HkX5FMTCfqiM1cmLyXwzMhrkcuD+M7KmJQbf5rbNZ
FpRPVV36L7TfZswmfzTFoM0sPUsxgs4HKxb2/YTKF2pM/GNhZKrj7/KYzhc7
FmvNW6fsCiFsEgu1wb+Dlvek9YiFfl9f3yLmvDrHYojC+oTpR+LPicUbxPus
uUbx5caCcyzodyGbqX+xyJ3e4ZO+iHBGLCaaxw08cpfJf7F4ubusYH4D1d+i
WEx6l38g+zDZp4zFhD8vfl9+Sf1wTRf99MP3yyyY+MciwTthY/5BJv6xGPW1
Y6rxEKb+xeHrvY9N+SeIv3YcUrIyTmusIzo7DiduZJutmE37TeKg+23tKa9h
zO/TOIyzfTPjmQbFwzkO1Za3hzxpoXrBicOxp7ZrtzP1ihsHwd5H4XvzqL7z
4rD27dqZvCzinxGHc+cRFydlfs916TN58E0dCZP/urBZtscnKXP+4xDvWxmw
ik3+qInDkpQpL7X+kj2qOPjzHxvJggg3xSF0QDHL8Tfpw4rHj31PZw2/QudN
Ox6VPTJe9+cw/U88jjzQcF10g86fSTw270psvhTG/D6NR89rwZNnuDD1Px6y
DS/bFucz/U88DNsSvp/dwfQ/8RgenruoTpep//HIqHctK89j7I9HhH7xk/f1
jP3xWK+WN3ZrPZ3vonic3hIrPs/8HlPGY8Ito5LaSvJ3TTw+eAct+bGcsCoe
0ydItvaLJfua4tHm+NPj5Aum/0uAsDkx8n+zqB/VTkCR1QWZ+bjzZH8CDGyU
8WYTiG6SgOsXrud8P8+8TyVgwPGPq+VpJ8n+BGTFbBxRsZX4cxLwsebr54ur
mfgnYPCX8V7bjJn3iwTMqVQueh1O8clIQJzzu5vFNkz/l4BxCsPX//2hfFiU
gMncnV6QM7//EmA7SKuaP5Hp/xLg37YoKHcW7VclwPz9qPw1/Qg3JeDei+Fz
E8S0npWInlL3FbOZeGknYkJIh0J0h+SxEzFiwZSb0XOY/i8RWtpaMYXXCSMR
MRcHNl5i6rNzIlbzX3eK8ok/JxF+I6dFansw8U/E0XEmJf0eMPFPRHbCRCsX
M6b/ScSKM8FfTNYz/V8iRin/VN5pon6rqEvfMQu0Zmxh3hcSMUDzqV4zn/r7
mkQku84JqbhPWJUI1gbsn8mn+DUl4rFvfsa2MYRZPFQ97/l55Db6/avOg3CM
k+d+K+oPtXn46NBnq84Ewro8bLYf9H5dLWE2D9Uhct0m3tl/2JCHs/om45Qu
lP9NeOB+b3vNl5f9wxY8FL9FRPdWwuDh+ZMH484aFv7D9jy4tJf1XHiCfg85
8/DpnPclb2vS152HzhLD0LBc+v3G4eGy08vex3oG/sMBPHw1HpUUrU/vm1we
apdv+/Ia9P4VxYNJWviF7G/0+4nHg86CoJSMAUX/sISHtfVGr+3i6X0wg4cJ
3aa2nnSh/bk8LB2kbz1xO+mv4MEouUew6S66LwU8/Ozxc4x9LfmjiIcpFQ6X
TQvJH6U8xJ6r5EtCyB5ll/62f9cEgt5PqnkIjv9V/rCe4lHDw8Tnk3tZH6ff
f3U8fFi6s35o1XGKLw8zny06/7f84D/c0KVv66Qbb1PovbWpK15/hzQYjjj9
D7fxcL9890o5j+xn8TEr+MUXczXSV52PZjXh+Y8TiK7Nxxf7UX6HY4m/Lh+F
Sw9uU/1H33uw+bhdO/fc3naaJxnyUdfj2sR9rgKKPx/sRT8iOs6lUfz5EPUf
83G+Lb1Hg4++C4vGnjLbSPHnY1KzlnvGFXovd+ajUdAqNW+keZw7HwHdR4b0
ETHzKD6++W5ef9SP5oUBfEQlTdN+F02Yy0e3IctP+ZvTPCCKj5F1YoeNNcw8
n48XdhLlThFhCR9Lo56cXj2a5gEZfDy5tenli/70HpHLh9tnbsCLFqIr+JiT
mbhsYhjNGwv4uJOUp9Y6guYRRXzsX2rd6/kj4l/KR37j1EUtF5j5CB9+RR2Z
a14RruaDc+Cu0usVzT9q+Ch4oxj5S0Tzkzo+OjKG/dh/nvir+Mhe2X/soick
v4GPnRfyLLfn0/y1iQ+v2g051RE0r23j497sWoltAPN9hwANMRnnP42n9eoC
tBxM/DDzPr0naQtwO1TM7ZhE7026AhiN17odl33gH2YLsIEXMcRsI72PGQrg
/CpA+u4RzddMBAi4MOj4LBd6T7IQIKR85FLzNPInBHje57POrQU0z7YXwPrL
tF15hRRvZ0GXvx77mILen9wFeNbj2KCzyTS/5QjQx3T9b34V2RMgQOks5VT7
5+RvrgAm3raLJuXQPC2qSz9XL4vLmUz8BYBp3d2mGpqPSQQY5aGX+SWb4pEh
QGdHr/ja6+TfXAHOxgblPnxM+igEqDaffch9AMWjQICV9b53Fj9i4i+Aof9j
weUiOn+lAhyu3zbhOMg+pQBnwtzazz2heUa1AEdSJ17SsSH7agSIWp9jPKWS
3rfqBPhfrU1k36/0HqgSwEZj0NXJdjRfbhCgRmfymTsa9N7WJMDekX3XrVlL
72dtAtQ+XbJn0yGKFysJ8Sv7ernl0rxZPQnnfL516k3aSvFPgpM8S74KpJ9u
Eiaqejp+KaHvudhJ2HG6RuFg6Un3PwknnpuPWTDPh+KfhBcaqsfbXfIo/kkY
s1LiuvsqvbchCa+GrsrTOEXzUvsufbZXPnijF0zxT0I3q7c3vzbRPNY9Cdd+
z7Ofu43s4SRBtPRGn69/6XuHgCRETu/h+vszvQ9yk3Bsxq7+6UX0nhaVBJf7
8b+zjx+g/J+ExmE6g92a11D8k9Cm8eRm6XJ638tIguOefjkeMpr/5ibhZs4E
k/ofORT/JOQ/PO13+hvxL0iCIO9MhcXynZT/kxBanpWkm+9A+T8J5TpzlxR4
bqH4J0Fn0cI19ck0z6tOQsdDg+HnbtJ7bU0S8hrGs9lX6X2xLgk/Jj95ZNgm
ofgnYVionWAUi77XaOiyb3mfpAQL0q8pCdrNAW3PXvIp/yfB6o6brmM1vVez
hHipo+o4XEH9nLoQO/SOGwflMu+BQuzVMO9zoZCp/0LIunnODwym329sIWIq
ch44nqJ6ZijEIQ/ZCO4Keo80EcLD5mLz2RlUzyyEWNvP1OmOL/WLECIycojB
3a1UP+2FaNp9/NSQc1R/nIUQh7U/fX2H6q+7EB88MsyLKqhec4TQ+rDm8pME
qo8BQtxd+YxbvZDqM1eIha4ZboM/Uj2PEmLIr11PCweSPjwh/H8fGy7g0jxW
IoT66CWiQ0HJVP+FqFI76+BjR/UrV4hgzx7HWyZSvVMIce1KgvXu/lKKvxCu
AefnaxcTLhLi26ruJzbPp/fkUiHs1eoTBxkw34MIEZcyebFwN+W/aiFyDj3g
2rfQ+avp8sdCA9ud/6P1dUJM1RolT2uj86YSwmjk41e/3pG/GoSoefR0pfVw
wk1CuNt4fDl8ld6D24TIs4rNySrhUfxF+PpD8/KzLTTPUBch3Oi4psyC5h/a
ItzLnx48NZPyga4I2HrrrM09ug9sEQxnFapV6pH+hiKEdcQNLQ6g+mAiwo6+
sefMzOn7AgsR9PZrLz+Wx3wvJMKoI61l8clEtxfB/82t9f31qT44i/B601n/
h1yy310EtbSCJYrJhDki+DXVtrRX0Pc3ASK8Tdy79OY4+r6KK8J4zdK4kQep
/kWJcHT400u1a5nvN0RYbdb/Wm2ghOIvQpTxUp2Jr5n4i3DlxsVXw9bmUfxF
uLnoGlx86fwpRNC4+H7U4GrqXwtEkFdc9F5xnbn/IgyJOKx/yZTuX6kIDWZT
l7y8IqL4i5A0P7riywnyV7UIwp+Lm1blRf1bXyNCv+OXXlZIqR7UiXD31MJN
Y6VUT1UipB9PKyzcSfW2oYu+S109vgf5o0mEnZnCUS0jyN42EWo7j2zKeiil
/C/Gkov65cOXk3x1MRyO9ujrMoC+Z9EWA8VnI7WkVC90xbixv7le9Jz6M7YY
mXwLv+pYyseGYjyqTbf3O0X9mYkYCfv90k/bUP9gIYb2kCVtA/tRPYMY5z2O
Nf96T/rZi+Hyd9LZHZmUD53F6Hhs8zXjLuV3dzEs+bzabx9IH44Yt9Wqut8f
lETxFyM5f+o79zORdP/FeCB+Z+PrQ98vR4nxvM7qsP4vMd1/MV4rI4w1jDIp
/l37xTZLZ/emfjdDjP9Gu161tKXvL3LFiP+SnnxPQv2rQoweJ3gzLXfR75UC
MeZ3O/pdEhFD8RfjQEt5YdxFmveViuH2Z+bRoXfp94tSjAnryqeZ9aXvIarF
OJK2yzFyBNWvGjE+iT4bv46j7yPqxHgYbHVRrKTvn1RiqFn6hr6cSvW5QYzi
butH2WSkU/zFqJw+U21IE82j2sQIfvg93P4ZU/+T8Wam4ZXWSXR+1JMxYY5Y
b7JuHN3/ZLz9e7xi1Uaq17rJmHyRrxH4h+Zp7GRo3WnouYlF/aNhMrYefjFy
5ls6rybJeDTp8cCVkfT9nEUyVphZ2d9cxHxflIw8HHXL86P+yj4Z4Vc0YwaX
UX/lnIxIj69/eWupf3JPxtkk//HnFlI/x0nGGIeNFbfOMf1/Mq56XZOfd6D+
i5sMiWn1hSxjokcl49AD3qGfbsz3vsmwLgptMPhDWJIMW99zGztvUT7KSMb0
D7qCy05M/5eMI8KA+t9p9P2VIhlq4nl2r5KpnyxIRtuSN52jXJn+Lxl++5su
aY+l/rI0GYU509UFn4iuTMbLCyYDZq8genUy9Gpnjcuxp36/JhnnYl+77mO+
p65Lxm0kNP23mvyrSoar0RnukiOUTxu67EuIqtviT/mhKRkdmg15Q53oPrcl
gx05+qhInfkeXgJ+lPOUY0+oX1SXYLb+mcSMExQvbQl0HI+3Cwvp+1BdCQ57
XHhw2pnyJVuCr2b6eTYtdJ4NJZjb+Vbf4x3lSxMJ2lX88AtqlC8tJBg8eNJ/
Gyuo/0KX/Dd22nOOUn22lyBpV02nwXaq584SfPiLIXtaqd65S9A3Kn/IJHvm
/kswffb5ZpufSyj+Emi7Zrzkh1B+5UrwYop7yFBHyi9REgSF2MT/zKXzzpMg
pPKoVZ0R5TOJBNNKtt4xOkn5LEOCBU69G++eJ3quBCdNz/R4P5PqnaLL3qC+
I5zm0HkukCD1BGfg/FdU74sk8MvZHxc5l+pPaZe9Dq1rAh7Q7yulBGYxZi9C
5FTvqiXYYTK0faMrxbNGghP3F6eLebS/TgLv8k8a7v1oHq2S4OKWi3ZcV5LX
IMHk6mdn0xdQfmiSwEjLg9s8mN4X2iTwf3/fLvk6M/9LwbUan063LfRepJ6C
vTmdLk3FzPcgKQhVhtnV9Sa6bgo8JlfNG/CM+jF2ChZsNS7bK2P6vxRw//cS
aztJnkkKPue0qz1SkDyLFAzc2yJl/WbmByko36LNk70kbJ+CfWFRnVpB9H7o
nIIJrBU7PlgSP/cUjLzSL55VzrwvpsDz4bl+wx1K/+GAFKh97Xz3iMP0fykI
sr7xfPVSkh+VgvvZHn0P9SQ6LwWryxY8N9Ai+yQpqN9g6azXi95LMlJwUtdq
+pUcwrkpmOZ98NWLsYQVXf5KzbYsHEb6FaQgYHHo8H5+xL8oBTaZqsyk0XT+
S1NgWflxxdPPzPw+BbnHlrfXTqP3l+oU1LytdvnuROe/JgU+73pGLP9K+tel
YKJxtUEEm+xXdelvOenmxELCDV381cLdLpsRv6YUzBv8d9BBbYpPWwpMi84u
LQ6g/pclRYpw2U6ekPRXl+LQC7cT1Z3M+58UlrMnWs/JoPdbXSkmeXkcOtSD
mQ9LYV9lXmnykt7LDaVo3Prf6F6xNM8xkcK9+VBI/BJ6z7SQYrNe+5iqvsz7
uRSJ0S2fHZrofdZeCq2/DgejXtL7qLMUi6+3Z21g3tfdpVCrOK9V1Z2Zr0vh
NTTh0Hxfeo8NkCL9vwe9h7ky83YpVoumJma3Eo6Soofrmkj3WFrPkyLJu05Q
9IqwRArbepj/3sfMI6XYturEoZISmvfkSiFp6W9quIWZz0rxreCxaKk5zfsK
pFilrlFcNecpxb8Lb7PSnzHpOcVfinMGOiNeMFgpRZT9gsAJY2h9tRS6DVfO
GxnSvKlGinLb91N6mRL/Oin2hjiHruhH80aVFMELzjQeL6Z5ZIMUE+btc/vh
+ILi38VPeDSoVk9F8ZdixPyqR4OcSB5Lhukszb6rrcgedRkiwpw6X/vSfFRb
Bq2Zb1gv7tI8S1eGsd97x8h+Ep0tg4ZBi6bxK8KGMtwJnry9VzMzL5Ph9PjT
GUc1Sb6FDFN6/G/zjYGkH2RoHdPdeXwd0e1laNCb9iv+ONGdZYh+c6dssRnZ
5y6DtV/LNjUnwhwZeFlxxz1Okz8DZCi4HmDAXfiK4i+DgZrdaKO1ryn+Mgzr
e2Si1oA3FH8Z2vsnBtVtIyyRwfFj7UDuhLcUfxmeag3UFHsQPVeGBY1uxZmR
xE8hw31FI89uPskrkMHMSytjYhDhIhlGv6pb3k+fcKkMtc7vjwv8ab9Shks/
Kxu6hZC8ahla3vsGZoa8p/jLcHjjt/d7It5R/GUwzhPe8O5BdFUXblFmhaTR
/oau+IzacDv8IeEmGXI+7qzcl0T722R4oNO5/ZMd7WelovDc3h2H04iunood
Fqc7Tb8T1k7F8hzNXB3dBop/KhZ/LBVqa3+g+KeCNcLT74LxJ4p/Kg6wciTq
xR8p/qkQ296aencjrbdIBSwbym+6E0Yq3pQkWoY4Ebbv4m/vFvjDjfY7d/Hj
P9i3bhvJd0/F20rtUM1OwpxUXF57MXq7GuGAVKheFe9Osyb7uKlYIV2Gjm5E
j0qFf0rTk/puJI+Xisa4d3u3hJE8SSoGddMR3X9AOCMVfTUGVNztRvblpmKG
7/ef7SlEV6TiSf2vY20WxK8gFcF5HvNP/Cb5RanQax0g7WVN8ktTsbZkY96W
HoSVqXh+MqC9eDXtr04Fp1UY9fcc8a/pkie8UnHAgOTXpUKutuWgaQxhVSrG
zFjj7H+T1jek4ul6ww9zGP83peJWudri85W0vi0Vam96li6L/0zxl+PG0gfT
Da8QVpfj5FSb++29CGvLcXj6g5kz5xPWlYN9Z2No2HnCbDneHrg6qWwqE385
rjU+GXv5GhN/Oc7nuy2yn0V0Czn6zNZPnyEmDDmwWm3hu6JGir8cNT5Ns0t6
f6X4y2EwyNY5eGITxV+Opi13um02IcyRo/zo6O8LT36h+Mtxr+C//+mspP1c
OaLrM3/PdyUcJYdo96dPbBlhnhzjdwx7NYPhL5Hj1HLjF2MfEL8MOYyTh5lP
9CKcK4fJw0pLLR5hhRxx8sKKoHrSv0AOt/ZxMW6VRC+SIzHHoaPPXqKXynH/
Vo7G4+tEV8qx8c11iwcqolfLMe3inm6F3QjXyLHbXv9+5H9M/OXQNOzW7aY/
+V8lx8oTXp6YTesb5DD3vRhT9YroTXIozvbImDCE7GuTw2Zw0NGVtmQ/Kw2m
bNWVEU9IH/U0WJZsOPe8hLB2GgbPL9eur6L1umnYe7u/gYke8WOnIfCixqdr
twgbpuH4tT0d814QNknDiqJVDW3thC3ScM2536g9C75R/NOwY3DQysCPRLdP
Q6ZycuLXN4Sd09DHyjTLehCtd08DPzfd4YAdE/80GL44GppvSjggDZ4qU/6O
WCb+aTh46pD5CAkT/zS8+7nFqWMH2cdLw6KgnmZpY4kuScPJb0NW73hG/sxI
Q6m2/lXv7YRzu/bPeK1XsoOwIg3yxq4fIYVM/NMgzNj1yGoy8StKw5V1NW+c
zxIuTYO0+zyN4ldM/NOgvsrIQzGJ4lWdhjkWqa28g0z805CvdSf9poDW16Wh
m6uvQeZLoqvS4PxXz/paExP/NGT1L4wefpxwUxp2+n0drzpDuC0NvV4pc3ff
JcxKh0f+7Tc3sul8qafDspy9mXOP8pN2OuoDc498n0L3WTcdiQd3um1OoPXs
dDzePSNyVRHRDdPROObD5aEZRDdJh+y4Ro4aj+yzSId28qI/IaHM/U+HqZmn
1fPsD3P+Dy7PzA4=
     "]]}, 
   {Hue[0.5716994374947433, 0.6, 0.6], LineBox[CompressedData["
1:eJw1WnlYjN8XH3uIskRlK0LJElmSpY+kUkpFScIoWrRN+7TPTNvMNI2RKLJM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     "]]}, 
   {Hue[0.8077674149945295, 0.6, 0.6], LineBox[CompressedData["
1:eJw9WnlczN33H3uWlGzZs0QpFCIP8hYplCIlSqa0Scu07zUzNUvLVKIUYiyl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     "]]}, 
   {Hue[0.04383539249432289, 0.6, 0.6], LineBox[CompressedData["
1:eJw9Wnk81O3XRoV2bQ+lZVpIVLRL0dVKUqEFJY19iYx9yDLDjBljDJVKixKS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     "]]}, 
   {Hue[0.27990336999410914`, 0.6, 0.6], LineBox[CompressedData["
1:eJw1W3lczN/3HkvJXrKEMJUlESkqS3paJBFFklJNpX3Rvi/TtM0002Iva6KE
UNkiamwppIXInj0+IrIU4tfv9T3XP15Pzzn33PO+955z7jIqrptWu/flcDht
/Tic////f/86DEc666qH6jtX0R+gbSz4y7GwMfwflMPZ9gefvnyxJl4epXvk
m94sKSF+JO7kc1J//SwirARHtbS2w11KJK+M71f6bENkHmEujhSutl07Moiw
KszvbShTn5hIeDJKh1g5rhUcITwVZQLz5ooNTF8dGqppu0V12wlrQO2w5ke9
n0x+JuTObV64+zHjZ+Fge1fyA11r6p8WFhc9H+Q1O5f4OZh56tvcV+Iywtoo
Tb2kHrmniLAORmln+W5NZPJzYZeR+Ctv+AHC8xCc7HLiw+5dhHVx7GdTH71c
ENaDb+IeUdWhfWRfHyOVvt+oaD9EeD42Vp5aJPmQRngBqt0P/uhojyH9hTCY
NDL0etw+wosQEtqiGfD9IGEDbDl1fZxxMcOL4Xxy6oNpfQoJG2Lq1iG3H38X
EwZc+uuo3VU49j/MB34OO5cbdPsQ8UYI6rv4Rd2ioP/1h2+ELyMXPD729xj1
zxjDQ6qXel7dS7wxSpX+K1qkvpl4E9TXWKh2VkQTbwLL/Xefjn2cTO2bYu80
5fY9swjzTRHTkCFeqe5J+kvQ73l00qXuHNJfgtzE+5N3Tj1AvBm+vXX34Fcc
Jt4Mn1ZEXliTdpz4pfgien00bxDJ85fi3cvxF4aWici+Ocxqgh1cRu0g++Y4
c8Zs6dH8UuKX4cd9D9s+U08TvwyZ53Xs73VcIN4CYWkbLwYOqyTeAmrNBv81
ZF8kfjlSq9Y8eRx9nfjl+JYRm7Ag+QbxKxB357OFKu8W8StgqjhhnpPcbeIt
0f/KqtxnS+uIt8TnBQWtfcc0EL8S/dvbf9yeU0/8SvTzTbt/9TnJc1bh9q66
U6mV1B5/FXactFaPXk32OFaI3/Y8Mtub9GGF3/uWfZj4j9mzws+SZuvdhdRf
aa/83Z4p+75fJn1r+Kg+mrdvzTXSt4bJ6e1ftRKYv9Z4j+hzj15Xk741Hr3K
vR0kZf6txheDGaMUZhOP1eD6z9EvtSXMXw3LIX3DS52pPelqOFStiGsG8Zw1
uHX68vnhTUx/DWTXV8TnhFD/+GsQODp9+YFgwtI1+JPWUGxQx8bPBpXzVXN4
DZdI3wZJOQO1RkjOkr4NHPuvCnA2qSB9GyzdMFaaW0PynLV4sPeC6rVcGm+s
xfztF67ETb1C+mtxfOK/0CGDWP/XQk7y6OafmWz8bTFLsc/rZJUa0rdF+es9
jQkDb5K+LeTqR6S5z64lfVsEaSpkVjay77cO1Xmy4bJ84rEO3c9Gdt86R/OD
vw46ms9C5vcjLF0HpVGKNybw7pG+HeCoM9dKjjDswHVOavr4ic0nO7yuejrf
4kAT6dthlL/20n5NjaS/Hjr+MjJruWz+rMcLl8L8ZXeZ/nqIGzSmhX0neel6
zEzUyHiwjPXfHmULt17qr0g87LGnqUEaJGkmfXu4L5nVvkuBsNQeESsb3aZK
7pO+A2SUf5kExDwifQcI8v5mZHY/JH2H3vj8oqgyjeSlDphVds29W/su6W/A
15NTFivXPCD9DVBzGH7KI+Mx6W9Aie9bW+lLpr8BZca5F58NJXmOI85Mnrjx
zFri4Yg43fEvl2qy/jsiNO2WpE2e5KWOeHNDpkJ+DfWX44SfrneN9N63kL4T
cscXy35pJ3m+Ey67mp2cq0u81AlVr8wUWl6QfxxnzFSpePP8M+u/MzjO6gFx
q5n/ztjVOaxvwGWyJ3XGktPxujO51D8OD1OHGyS/WUf95/Kw83K/w9tvsvZ4
qOVsHx90gngeD7k7TdZ71BPm89D4U8F33HlqL4+HMedWONT2sPHiwTy8VrVU
j3ArD3+fO1RV76D5xHFB7e9bCfzDNP+4LnDav37EAUU2H11g9ebh3PI8kue5
YLiXYfrdvzRf+C7wqr33erwayee54EiW0bDTPwhLXYDfTz7ZyzD7Lgg3KT96
/Tub/66Y25S5YlQO+ct1xZWHV1+1TGP+uyIZSQOVLhDmuWJQ3mRLb2M2P1yx
5Kvj07qNT8m+Kwz3n+gyu0VY6grupusvJnx6QvZdEbRuo1v+Wjb+bjDa/jXP
NITZd8NPudOP0p3YfHKDu+m9meY2JM9zw84RN/xH7WHj64ap0QZ77FcSznOD
wsmhX5+dYd/fDa+tTG+dmUX+trqBo3z2rJ4XrU/ORjyPHsC1nkjxgbsRLSMQ
WnqVvjc24v3OW/eWyd0h+xuRf5Sr3ZjD4vNG/BAvEhyrp/iftxFP46fuSHWh
+CfdiLEzC93U+1I+bd0Is4Sil2FnWH3ijpHP2ksnjztM9t3xZ5e8l0wki8fu
uFHBWTZwHbXHc8f6L02atxOkZN8d/gYT77ptIpznDsVmaav2QtKXumNX0GoD
GQPiW92xv29NscZoiuccD6zRmlOroEf5gesBo/vC7ZoikocHBtf+N/ecZRXZ
90D+tNpLpmVXyb4HMnOixs3Qpe+R54HK2VL1VUr0PaQeiD+1d6jCJ2q/1QN7
T96ZPF/3BNn3REqb9QeJcTnZ90RRrm3Wz0vMvidWFI6/7dpI7fE8MXp6z2zX
N8y+J24dGvdmbSPljzxPzNh/w7o+jOVbT8i8VFA7+ZPyT6snVl9JvvZ6Hsuf
XojMTFwY9ZryDdcLFqN/pHhfoPoAXpijpfjGMo7a53lBeViBz8WNlG/4XjCv
bs9/f4XqhTwv/Bsfqh/wjOaL1Av+JzV3/R1P863VCzfFKu8NbrP5540PD15d
UB7H5p83Bp2fonj1IMsH3ji7bcq1rI/UH543VLSGyeXrs/zijYv3C0+o9Sc+
zxvnx4a7tiVTfpF648CQM9vXV1J/W72hNPpffb0eyz8+CIvoHNPzktn3Qe2O
QQWarsy+D7QN7omDXpI9ng9Wnnyv7zyd2ffB0G9KV6PMCef5YOnOJ3PNt9D3
kPpgXIrJnKTlhFt9oHPIedBMDvWH44vaoUXPly2i/nB9sejumCVWrSyf+uJG
0QrL+8XE83yxQ6Pv+7pdtD75vthSsMwv8hf1N88XCd0a87KPs3zvi7i72j49
HJJv9YUkMUWXd4TlPz88brRxuzqHxX8/vOou+BijwOKPH9ZuuWzP/0Txg+eH
1tSzH3g+LD/5wVLLzFmzgeJhnh/6LRK/OzuBsNQPTZ77DFojWsm+H3Rdmgfz
ml+QfX8cuWGfMW7ES7LvD7Xld23n+RKGPy7HL74UuZYwzx8DZxpmx/2l9vj+
UPqRv1p/Cou/vfyxAI3KtGdk3x9Tdvsbzd5A+q3+uNnTb0N7M2FOANbMupPH
DWX2AzBPd8JFlyrqHwJgfVh9n94AsscLwEC+hpF3N7XPDwD3rv4/10TSzwvA
nOCZHtmFr8h+AOqm//fw00fCrQG4VVtU35L7muxvwrvLw1vUGghzN6G1YpXk
3Iw3ZH8TXi98Eprzg3jeJtz2q7+hU0yYvwmxP3/r9Q8m+bxNGH9Cjqdj+Jbs
b4L9RMORYy8Sbt2EKy9unx0mbSP7gViSO212/2fv/4flAzHj56a9uouI5wbC
ZsqoxoszCWsFwqk6QtvhIWEEYuCYPWeeGBC2CsSQvOvT3nRQe7xA+Ft8exSu
RjgwEBuLReYPwwnzAyG3XNl48OkP/8PZgbinCLe34f+RP4Goq3ZPeqxGuKRX
f+CwwA2JJC8NRDmUF1r+R7ghEF0Fi1ztGqn91kCMDpD0lGYT3xGIX8cchbuy
qT1OECwt552VHidePgiehRs2nq0gzA3C8C9uxc0xJK8VhIJ7+4wyjAkjCAvN
z67ULiZsFYRJb6TqP64z/4OAE+Epct7EBwYhbvqKdw0lzP8gfP/P4b6SE/HZ
vfyG/K3Je5n/QfDpHizkDGb+B+HHG/vjNQofyf8gGFs2ygyoY/4HoVo3bvPk
dpJvDcKSoG+jL3wl3NHb/09ddQozSJ8TDNXwJQHtqcTLB8N4zYL3+kyeGwz/
VR8X7ZjP/A+GsvT1k0ERZA/BON3GU/ncRP5YBUPtqdoyhWvE84Kxx0E6rXk2
8z8Y55O6Wj9eJMwPxo25H3eG9zD/g/FhhNusKb+pvbxee9nya/dso/lVEgzv
7kab6GGEpcHgd8Xt1D73jvwPhk3MiRt17wm3BuOHycKO0JMk3xGMau/P3iNG
UvucEMwc6x0S+5fk5UPw6uGmQTFDiOeGIOm0qtqSLuK1QiBKDpYoRRKPEMzO
rVjrX8nmfwhWTLByHXqGMC8EyZzm1hObSD8wBJuHmEpTtdn4h+DIw5g3+4wI
Z/faL2zqF2tK8nkhaOenlex/S+u3JATPr0+wPPOG1r80BPUDUtd6mBNuCEGf
OQau3P9YvAmBTdeLhqZ5xHeEwGLz0wqXChb/QrFbbPvA8CZh+VDUzyl8l3uD
xcNQ3OixWT+IR1grFPvnuFWOfk7tIxSTB753cKsmbBWKI0N2aLSLCPNCscrP
bFrVFLIfGArFUt8Brwaw+BWKj2kqhcNOkXx2KNQu/xAPGcPiWSguBHydwK0n
+ZJQGK3Z+V+lLIuvobheE5Q/+wD1ryEUP3tko+fEsXgfigfrHfObOiied4Si
6LJWnMJwln/CsDWoqyP3PmH5MFj6rKs/dp3a54bhxgB15+0Ssq8VhqU591de
OEQYYTDQNO/ZsIiwVRj8wjT6RUxi+SoMdx9+VylSZP6HoVhpvLvTSWqfH4ZF
F35Mtgsgf7PD0Pe7wf7XFcz/Xv1Vfn3bzdn4h0FYtWlAvpDF9zC4j8g0nLeP
jX8Yrk9JsRi7mvRbw3D7SP2wA5sId4QhZm3lENlhpM8Jx9ETwvkGT2i+yoej
5MRaxT0X2PwPR/+YAr/Fuiz+h2PDvlOTOqbQ/EQ4VIesub2U9c8qHG9973MO
PSfMC4fROH/NowqEA8ORsbPy+vU86g8/HK7duZm8UuZ/OFJPzimLDGPzPxxT
WoTjmnwJl4RD9HiUwokqtv7D4fDmn2uEMuGG8N79/PgLCnNY/O9t/5dJ0mUD
0u8Ih++Om33eqDL/I5A78NljHQPC8hF4qyO1MjFm+S8Ctfq/DTqDqD2tCBw/
+OTWYB0W/yIQ4X9Iof0vYasI7E+OL3hrxeJfBMIOjS+pG0U4MALqe4peZbaw
9R8BjUlfUvo7svUfgX7dkj8z3jL/I+D3Zcs1XhyLfxGwUX+bXa7B/I/ApMVP
ev7dIP2GCMSWlr/pSiV7rRE4P9rms/9T4jsikGoZP0/jCPGcSIwwPLByaRDL
f5FQUp56IvEty3+RaNx1MObgCBb/I+Ek0J9SOJDlv0gcS1fs5DSy/BeJpB38
qh8LCfMiIW+bO0XE8ntgJJ5vm/giw5/F/0ho6U6zWX2Hxf9IlFvP3HVvN+Wn
vEj4bNa7JQ1pJ/8j0XbfYa/rZpb/IhGzRLlsmhXhhkjskbW1Oz6b+R+JntyA
neI5LP9H4rBsYUi9H8v/UQg5d3iQpjvpy0fh+9hNDvwzhLlR2Mo7ftI7j/nf
y9/rn224gvkfheytDoPHHWXjH4X9DbVDMraw8Y/CtFl1e23P0ngFRsG7xDr3
3msaX34UDnycmHJlHuHsKIy8HzPj5Tu2/qPQ4lrgMauAcEkUpOKsD3l1LP5H
4bAgnhMxi+JJQxQeaOS8mxRD8aw1Cua/p219OZLFvyjMb1nxXaeRxf9o/Fyh
/N1iMYv/0bC9W6oyQJXFv2hIHy071WLF4l80tBW6X+gksvo0GsZa66KCHdn6
j4bXWN358c9Z/ovGE9VLsqrybPx723ux+/E0FTb+0VgjvwpNa9n4R2PkpLHG
8xRJPi8a14/fMz3L6reSaNydO3n4wFUkL43GYgtrnR1pbPyjYfPK3+rBalb/
RKPvoRV2xawe64jGpnlVPdNGs/kfgypf73PF1qz+jUG1o93fc9PZ+o/B9A+1
no632fqPAa8jOtp6OFv/MbCO3jMidiUb/xjoyz7wcSph/sfA7dD+unA+q39j
oP1jsp5wIcnzY9DKH+a/O5LVvzEoazDS8R3L/I/B6Y/vWyrbSb8kBufvjBk0
2YbVvzHoPMBzPu/C6r8Y5HGe1bovJPutMfi6o7JYT4X5H4Nf4hPzLwpY/R8L
C9kMb7MYFv9isSb35uKr8Ww/Eosj1+STpj9i4x+Ljt+3f729yvJfLB6sLP0b
cZDmj1Us+uaH/m41YPk/FuOKP6uuZfu3wFjkypjn9/yj+ciPxf5SF4eTP56T
/7HQOJv51mgG7bfyYuEaEiC8bkK4pFe++regJIvkpbG4+Cst/sNkaq8hFv39
R1+6nsH2m7HwNNzuw42i/VpHLBZEc1V3OJA+Jw5GrmtfxabSflU+DsM/R9aP
yqDzOm4cvvSrSd/zhfS14vDmx9+UB0lsfxiHeS/CnBxWEraKw2nOdnsLWcK8
Xn3h2bU6Xcz/OMR+fPZptRrzPw7np35d0TaW+psdB+cPAStfMz4vDo1TPKba
nyX9kjgEJiyQf6RMvDQOh7rN9u/3If2GOMzi9rk76yjth1vj4LGlpp/CefKn
Iw7SGpuXIeeJ58TjSbf43PcFxMvH4+iLlowHhcRz49G59Uyr3U7iteIx9HM/
xYPv2Hl1PPJdL4eLt9P5o1U8rLrOzduuSTwvHjb1l8f1syccGI8AZ8uHOUvZ
+Wk8qoR6K0auJZwdj9Si9z0fvOm8My8ern0iZJ9nEV8Sj0mhbzSfrGPn2fGQ
u7O4wXsotd/Q23+JoFPFgvkfj9JEy+DuKcz/eOzfvTqQm02YkwCHL+uXKJgx
/xMweMDnt6tekj1uAg7bGzatGUP2tBLgfSxGNGY/u29IwJG567JkD5I9qwT0
CTWY9roPOy9IwBjHukmcsTTfAhNQEv+8W2cMO79IwKAXofHTFdn4J2Da8ulq
HsfZ+CfgrX/j8HxvWk8lCXh9YLLVr1IW/xOgabdo5DETVv8lIGdru0bFClb/
JeDyzi+NmVJW/yXASGg6eHcTO3/go+taVF11FvFyfDhOXeglYfWjPB+vfJZd
Kg0ieaVePMg0Y3ERyw98iMWppX12ElbnY7Xlky9Kv9l+gQ+1WpMX3AXE6/Nh
0f02oGIq2z/woZ9dUVW2juTN+VhTe7LjJDuPseKjcfjTF1HnSd6Oj+XV5SKj
hew8hA+Re2xEyw3qrxcfPtrVS4ZrsHqTj/vrqldzNImP5ONEjpeHYjKrP/mY
N25E0el4wkI+PN3cbQs6WD3Kh66ZxzAjU2ovh48hh26Iaz6y/MxHx/Pm46ZW
xBfxcWhrzc8sFVav8nHq92WZhkPEl/PhKtZetNOY1e98DPqzUjiqiuRrer/X
hwUnruqw/Swf+2cOGNhWQriFj2WX99l/bWH7Wz60O/L2pl8i3MaH2/ua7tIC
ar+Dj2+lmihcQLiLj5ePBj5qdSN5TiJKraPcr0+kfCCXiB26X7+lD2f5MBEW
LrIBkywovygl4rj7mUlnWD3ITYT631U8nU3Eqyfi2oP+B/NZ/aiViLaAf16C
SpLXT4SV1R57UzdWPyVi78HKvCofkjdPxPwei5iVP1g9mYgMVSunu2sov9sl
4joaHgdVsPoyETXtk54URhL2SsS3Myjr3s/OGxJx4WiPk9ESqh8jE5G/UxDl
bMnybyLGLxw5bB/Lr8JEmNrukrW/xurxRDQvm3Gn/zjCOYkY8stw5g5r+l55
idhZEjZ/XRt9z6JEGG7T6967no1/b3uP5MOKp5B+eSIWVmdmtYxk+TsRGhFO
Fv7u1N+aRHj2PdX3hAPhht7+z7q5sOMh6bck4tmow/ZblOh7tCbich/5q3Gv
Sb6t9/tyBgTF9CG+o9ffBZpV/14S35WIz6v7fsaKTzT+AriqrmrQiSYsJ4D4
zbvwS30IywsQUTtjhIEftackgMbfwI/Fp1h9LECsXtT2PqOofXUBlpdVnfvj
SbyWAA912zbPY+dr+r18QbX/qU/s/EQAFSeVESYj2PgLICj17HpRz+opAeIf
7u6eNZfatxMgQDZ3it4Rap8nwP4n1jsiIgl7CTDac/gIhaGEAwXQNZLRbB9C
OFKA/Hc3pmhMJcwXYIBk/Wv+LGpfKED7/BspORtZPSoAt+lWkedMmj85Auzt
a1/gYUbfJ69X31jm3mU2/4p6v0/z6RwFXXZeJ8CHxucp3yxIv1yA4S9Ni2O2
EpYK8GD62Dw9V2qvRoBvI+bKTqol3CBA2r9Bo88+IPkWAXQOuggGj2f1rQDo
N6qy0Ji+V5sAr08bi7dOZOd9ArgP1tlzzoz4LgEmyZlXhOex868k5PzTvbO+
jrBcEl7ze3atS2L7wSQM5y2x0u5h6z8J1rUbt9Z9ZPvDJLSfnuyzwpa+p3oS
/rsaKPzFzge1evk1/+TPsf2gfhLiS84NM13F6uckXDhoxC0zZeOfhAFiB4kh
2x9bJSGqOXTiNn9ab3ZJiFwUuffVUna+mgRtNTt5g07ivZLQt3n+49t2rN5O
wtJJ4VzRPuIjk5B2b0FWPzu2/0rCBvkJz7STCAuTcK/e9tS0+RQvs5Ow72PC
ZcE+4nOSMEW1S1Gnju3Pk8BLDBmyIJOt/ySoVOqp7xrD1n8S/NuHyZ27yeJ/
Ei7d/9njfoDl7yQE1l2dsf4X5beaJJx50Shs1mD5PAmzualDm00p37QkoXPV
0IQNOiy/9/andsEe1bWE25Lg/MXMYsZpFv+T8GvCy7vjeOR/VxKOmO+t7ePK
4n8yJijaX//3kuTlkjGiwc5tnyw7D0rGN55A3Yqdpyol49AYTf++7DyfmwwP
U8XOsDKSV0/Gkzs/1VoL2H4pGb6Vq8sTJhCvn4wDw4xbT9Sy+4Pe9hdKPJew
/Zh5MrZf7VbPzKH5ZJWMg+VCa9e5LP4no/OC1laDLFoPvGSUTf+zwbCGrf9k
SKplfjYeYfE/GXElr72eCwhHJuOeavfKRXps/Sejw6E7wS6VsDAZVn8XrxrP
J5ydDMehy+3VfxLOScZ/zhc/71Ik+3nJKBnt/PJZGeGiZNQss4pO8mLnFb39
0dX7sk+J1nN5MhqLdzfYb2HnF8kIvZTZUriLcE0ybm0672xuS/oNyUh4+1AQ
Z8jWfzIGbn3sLFCn9lqToW4ZbyJjTrgtGTKhg1N0BpF8RzKi1+msW5VCfFcy
NBojDxq/Yef/Kej/ZtDQ2e2E5VJ64/OAoj3MP/kUrCp8uowfQ1gpBbMu8seW
XSPMTYE0/LbTp0rC6imouHNm7GPZzzT+Kbh8NjaTa0L29VNwoFrlyAxb4pEC
87VKsaciiDdPwRiTA0Z3dQlbpWDrnU1zHQoI26UgUSPvcXR/0uelQKSgtevX
C+K9UjAy8N7zzgss/qdAd5K8wbMalv9TUNJ8zG/dTcL8FOwpSzoWMo7aE6Zg
1xih/f05hLNTcMwYEyU3qP2c3v6NGLZIYEJ8XgrSLRTmR00nXJSC+ASZURvu
Ei5JgW8MZ/DXUWz8U/Dx3AfZq7cJS1Pg9mWQ73T2PWtS0ON/90PxcNJvSIHC
w5SYP4dIviUFjUNz51XKd9D4p+CK1aqZMm2E21LQUDaldk0D4Y4UTCr89yvq
IOGuFPgc+zsh/RFhTipidA/NXNdKWC4Vrhkr9U9VkX35VNTe2Hxo1zOyr5SK
7ynunHH9CHNTYVTkVLC0go1/KqI5r76te8XyfyqCzt4LevyBxf9UDKg3m6Ur
InmkYqk0z6Z1KWHzVBw8MCt4wXbCVqk48EFx+oyTLP+n4ktgVowLqw95qfj5
LTTF3Z6t/1572R+DXRez8U+FxgGnn4J7bP2n4ppv0afjmuz8KRXpx65qxZdQ
/BGmomywhfxjJ3Yek4pNz6bWm/9h9V8qJP8cU/Rl2P1cKi688uxuDCJ7Rako
fLK+5So7zyxJxSAfeZl0dr5YngrRzzvrjSaw/J+K4mvKtx4NZuOfirp/s8vN
rrL1n4pXBwzlzdj5VksqVEr2rVvN8nFrKuauGuY5z5L4tlQIYyAKWs7Wfypu
2hSYD2f3eV2pWLD18LbK9Wz9p+H2qWHXRPYkL5eGoz3ayoYV7Dw0DcvHJ1fw
TrHxT8PBX+XWfl/Y+KfB8bByPHcNYfU0rB3yvh9HjtrTSoP59l2Vqn8J66fh
Q/uvu1c8SR5puPL0h2VtAlv/aahpHLT87Ak2/mnImh2u/JTVu3ZpKLzYz8lv
LIv/aRi60Paicihb/2koPejX834sG/80SOf86u93k41/GmL2Lt4+8CWr/9Mw
2mrG2KblLP739scn6krDAxb/07Bm3p+S6rus/ktD0Ko5nY+7WfxPQ+3LZ0mf
z5D9ojRM+jZ3xGdt0i/p7e+Ua8uiE1j9l4ZM/gcbHyVab9I0DPZIcn5oTOut
Jg23PpqpRIwmviEN/VYv2j5YhnBLGtobDk85JWDxPw2+OwUTiiJIvy0NFcqd
tpEb2finof5osfkVY+pPVxrSp0o1atl+gCPEjh/6bT8DWPwXQmN6n0ldw9n4
CxFTExZi3YfklYTQ9Nva+jeA1X9CzOJPLr82iO3/hLAM/mGracPyvxDNwxya
xKxe1BdiufV7E71Qtv8TImnY9pEn9pK8uRBlo6WFRwxZ/S/E4a0lS+tdCdsJ
MbDiWLp5JztfF6LdoPr+H1+2/oWw8lkQGsHO7wOFyPrEcdXTZvFfiPqH5lVB
zSz/CxE//q/jjEVs/IW4OKD61BYRq/+F4L581+mqzvJ/L69qkWL4kt1PCDH/
4PaN3Uas/hfie8X49k1MvkSIeZ1jLDYqs/UvRNRM0cCHz1j+F6LwnL5R8im2
/xPinqJa/kUW7xqEaFt7PFNpOuEWIU7fa1oZsIXV/0KMfzB7W3Un2/8J0f/x
xXd5T9n+T4gtnc++JXxg9b8QO8uauG8G0PfgiPDn+WmdKez7yImQNGvRzAPr
Wf4X4cgvi1Mrz7H1L4KCZM2ej4dpvnFFcBZt/mA/kOanughyCoLKRYaEtURY
80d6x02d5PVF6Lf8aNYcF5b/RVAboxbSWUDYXIRk6xdpFzLZ+hfhR3N5niLL
J3YiPKsZE/Utge3/RKib8Obr7fNs/EUo/nrI5O1x0g8UofJU34/W79j4i7Bl
8PiRynpkjy9CUNyM3FYF6q9QBI+bbm2y0whni8BxVyg5bEryOSIIRztNPnuP
7f9E2G5V/jR2F1v/IqzKNqlVvMHqPxFO3B7qsa2T5X8R9icEJP8QUHtSEXwL
RzV0jSB7NSIsOIxcNx+2/xPBNiJ4mUEby/8iGNoOUF/UQu23irBIvf/VP1NY
/SdCaGm/gqkyhDtEuCAykp3D4meXCHt3KD4YyfbHnHTMbZhwWfsdW//piHdU
XuzL6mH5dDw+lbWg8CLb/6Xj7YgZrZGH2fpPx+QGZ62TWrR+1dOx0+3Lz1pV
tv7TUXVz88R2bVb/p6Pb92BN20HabyAdMwbavFLpT/sL83RsOfpl7KZftJ+x
SkdevRJv1Hji7dIxZPGXX9sfE89LxxmFl/ouY9n5XzrcIjovl9Wy+/Z0KIbK
KjQ+Zed/6bDmPNn33xm2/0uH99yB8Aym/gnT4TM263D7MnYfl44jqlo5MTHE
56TD97f94KYjbP+XjoFLf80cwc4fi9JxPl/ZWHYLe6/Qiyc+qf5YSfu78nSY
8ZLMNgrZ+X066uxcTl7XpPPfmnT02aF7+M9LOk9uSMdY7uzSG26EW9LRNnGM
lfFSOn9uTUej8sNb+VZ0ft3W66/7svDYuyTfkQ7HlJCciKt0f9GVjmhe9+zw
v+z+Q4zMxUG3ng4hXk4MD6Hj6OAuwvJi+JX7zbe+TOfhSmJo1DT6N7Wx+wEx
3P7OnXG/js7f1cUIns9R4zTT+0AtMSwXBiVky9J7ZH0xLGyOBPRMY+8LxdDq
VDgg3EW8uRgpU+/YRAYQbyXG+/8+m2YPJGwnxgvn+7ttPtD7RZ4YrXMdZjlK
6H2ilxh9PObK/Naj946BYow7nX5ZJon4SDGqLrqNef6GvR8X42txcuLL6yQv
FCPqtFrlphUkny2Gi1aGuEee7OX0+jvzmeK1avI3T4yJ6TJ7+nQSLhIju37/
uA9q5H+JGAIDW49JP4gv7/WnoPb78xr2nl+MS5nLXgeaUPs1YhT3NTvTN5n8
bRBjlqvLkl1z6X6lRYyWmm1TJSNJv1WMc4cVAy+HEt8mBqe4M/vqbLLfIcaE
3g36KPb7iS4xeMM6Nn4+x36/IMHXhRO6N04kfTkJdt/SidXZx+7DJBiiX9E5
1pDmm5IE/ju5BVeE7H5Egs6Oddc/V5O+ugSL1g9zfgp2XyKBeddzOXkOYX0J
lIc0S5+w+QUJurbtHXP3EWFzCQIjT3p0qtB6sJLg5FZFt0m5NN/sJFD0PLfn
sQ3NX54EBRf+jC5oIX0vCUxzVPttnEHygRIciNj2e9lqWm+RElxcproyr5Hd
v0nwo8YFc9h9uFCCPmZh2zXT2HskCRpOqWkbjyecI0F+fOvW6AXsvacE5bKf
Uix1iC+SYKu9U9n6Puy+rre/s+X5pwoIl0sQtqNuyYWthKUSzLz23ffGC+pP
jQTru9+HByiw+3wJJstV7bsiIvkWCZK5B048YfcvrRIsTjrs1OBEfJsEE2w4
v9PYfVGHBBWBO+7Us/v9Lgm8IqxDrs9k9z8ZeNI1TXnaXMJyGfC7/DrMgr0v
k89Ak9OBa1Z7Kb4pZaCn2Gzxnzp2/5OB9WUx41y7qX31DNwx1D3W/op4rQzc
npTfv6iE2tPPwOxlMU1+V9n7gQxYHh8VnsHeu5pnIP5M/tDAZvaeKgOD23u2
xkdTvrDLwM3Bda5t+ex9UQY85ypLvg5h538ZvfHlpFjdi723yMBp/UNHjI6w
878MSLbdjy+Zyd7fZODvqr4JJ1pY/M+A8lrbfEWWD7IzMOhp1BTv2+z+JwNf
qtQfmoFwXgY+HM86K/OHxf8MrFnR0P08jr3XyIDjgFuN9taEyzPg24fDn7ye
sDQDmqY8id0IwjW935PHXW73nZ3/ZSDhrMlnFXa/1pKBXdE3dzvuYu87MiDV
s5pav4nWS1sGFmquaw4rJ9yRgXR75b1+zYS7esc7erWMynTCnEwIBxT1TbhJ
60kuE5Ij/CBFLxb/M1HbKbf52QiSV8rEr+N9H52cTPLcTBh7DupjMJTWm3om
pqUFD7SsZ+s/E3ek/UouCCje6GeCe9j016Id7P40EyYpq9US2P2zeSbKL35K
tyij+GKVCSeLObdNnEjeLhP+c2Ia93tTvOFlQre4r//oJRQPvTIxt4R3tSKB
+MBM5MlGp0Z5Ex+ZiYM9FyprmDw/E/MS2gL510lemAnn/1at9Iyh+JudiQ0P
xlhrylD/czLR8mbqYZNYwnmZ2Nb33deKySz+ZyLBr3u/yIJwSSZW/pgXrSCi
+FueieqChe3/PlG8l2bi8I2v+bNYvqzJBL/OW8XwJbvPzsTHZSpl57oJt2RC
54e+Ylkli/+Z8OaqvKoSUX/bMmEZMq/RWIfsdfSO1+apP98+Z/E/E6avl5z7
N5+9/8/C+c2LT6xzIyyXhcIQj20qoZT/5Hvx4r/+Mtvp9xxKWWiaJAzY60W/
x+FmYfpxq0llVfT7GPUsqCvtGTrtCP0eUisLanplFUe2nqfxz8LqjnB3IzeS
RxaGmqtdkNeqrPo/nPFOow==
     "]]}, 
   {Hue[0.5159713474939025, 0.6, 0.6], LineBox[CompressedData["
1:eJw9e3dczt/7fyj1NrMLJSTZme+M8pQVkRQKpWgPdbfv9n0379VdZEQ0ZIRU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     "]]}, 
   {Hue[0.7520393249936888, 0.6, 0.6], LineBox[CompressedData["
1:eJw9enlczN/3f9aiEB9L9iFLEbIllTxlK5SEFlSTtGid9r2mqWmmqaZQWhFC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     "]]}, 
   {Hue[0.9881073024934821, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3lczd3zv/aSJbKEcO3ZUyGyvOuxhNBCpUSL0t5t3+ve1rt0K0qS7aIS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     "]]}, 
   {Hue[0.22417527999326836`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnlczs33/yPRbY0sFSVEyXKHkBa9CsnaokhJG+3lat/rqmvpWroqZQkh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     "]]}, 
   {Hue[0.4602432574930617, 0.6, 0.6], LineBox[CompressedData["
1:eJw1W3k4lN8XnyKhjcqSNrRJybQrlY+KSIuQXYaQ3dh3xswwY6xtltZplzYl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     "]]}, 
   {Hue[0.696311234992848, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3lczN/3HrJk+Sg7CRUShbEl+5NoJW20yqi0y7ROezNNs1TTppAsLUK2
hBAtylrWJArRiJQ9S2Tt1+/lvL/+8Xqce+5ZnnPvPfO+l7rLVqvNvVksVrsC
i/X/f//707H8EK8ot+zT7uX0D/D+drLszn97CCuiet/TqzY5cYSVscO9rbYx
8RDhEdDaFSBXssohPAYmk8Qvqm2KCKvi/B2eqFfGAcJqOP8zOXrUnqyL/7AG
FGUCH9ZFe8KToXDxp1uct4iwJgQPXoXtNdtGWAuD13xIrW07QHg6Xn90mGA3
/xhhHfyt8Fo643oe4Zk4/CrXs9+9/YTZ0L8ljjfuKic8G7VJK8x5+0sJz4HZ
ihdjb7ucJzwXT82CBqz9cJbwPNz6smporAKjPx+rFsgfpo69QFgX39Z9a5g6
vZLwAjz6tsR5UAmD9aCyaGPzlUZGfyH0Mxx3pJ26SHgRBr9l9U3+VER4MZ6v
z3vtKmDiW4K9d6WPIj8UEF6KP4aelxpUdlJ+lyHzk9bPjJ9zCC/H6oK3i74m
pNF4QF3OM1r9K/8f5gODBl4qmXotleT66NPv8s43k61Iro/oxGNKt9dPJfkK
sA101++IyiX5CnjeXb4su/MUyQ2wt9n656mSDJIbYEDru7ajN7LIn5UY3T70
+agKo3+YvxInZt8wd7Vj4lmFraVm7k3JR0h/FXq/KosOi2PmN8Q4/roEedpR
khsihf99xCXWCZIbYf8zp+Uf6qg++Ea4HRLZt7JwJ8mNsUO5mb2vVIfsG2Pi
Lv0p0w0EJDfBjYp3ysouiaRvgh2GtZYvrjDzm8JjduRTTbPDJDfF2LQOddU4
8pdlBqX2vV8K5zH+m0Gj82+v22O3k3w1ap1YP9yvRpL91RDMmlbw+79cys8a
4O+n+G5tWk/8NfBPX15Ve2M/yc2xbWn4jVfPjpLcHFM7LLwaTc+QfC0e9HO+
o+p4geRrUVpapfviRgXJLfBN5qbjyqX1CQtUV7vVOfudovEWyB/dYXVsVck/
XGmBUFuj+F+iKtK3xP3J7QV791WSviXGX36YJRGTnG+Jr7smzvmofZn0LbFO
8CbEd+U10rfCgUVmC/dl1pC+FQKlOJx29hbpW2HGp/9+ufW+TfpW+DI4Y0id
yl3St8b92/3yzw66R/rWOLnYpHvnxjrSt8bfowZ6ymySV1rjffOlX+MkND/L
BvVt7k8nH2Ls2yDyoJad9virpG+DQ08+N6mMZuzbQElnffoj6xukvw6GpZdX
zjxB8WAdeIUX7GTDr5D+Ohy7MbLqWxDNX7kO4wZcVXNYfJP012PHzE6v5kqa
D+txOGTJBCMFJv71sD6b759Zyfi/HuaTmtVZCfWkb4uh5l9+z71US/q2KBll
uvfDX8J8W5T9UnW4PuI+6dtihMrmP1Z8wiw7xD227OUwg9G3Q53WMn27gYy+
HWZbz8k7ZU640g4XP47s2/SdMMseH6tUtGL4TP7t0Tkxa6qTNmG+Pd7pPXQz
O8no2+P3mvJzkUcZfQfINQUHL0Yy8Tvg6cxPdtUdd0jfAS+f1wSzFlM+Kh3A
Hz1o47cfTP04wmKBx/Hb0xl9Rxx4r+f0ZgGTP0fc7iwbcjeO5qt0hLJ9c7ZD
HvnHcoLtyN3J9S9pPJxgJJxnE/23mvSdoDtHx02nkOHPCf5DDZYuPM7UzwYM
bHSfZnGbiX8D5m/4ZNFlT/7wN0A/VHHcORemfjYg3n/g3fEnGf6dsXdQWera
CLIHZ6R5r/ygG3yJ9J2x9N2VkcmraX1VOmPRk/2bh5XSemRtxOE3DXZsEa1X
bMSWXa3tD+VppL8RFVsXJTXu2UH6G2Ff1bzuxEfmPOagYiYKeGsv/sNqHCRq
9vaybKb6BQeOhZa29Qlkn8OBX9KNR3OPldP8HCzccHO20gzyN4eDM30ml+hr
kH4lB7vHJl/00SC+5BxM+11iceIk7QesTRjW31mlrJD2I7VNuLSa3zDPopjs
b4I06M5k7aGnyf4mJOwsDZJyEsn+JuSfX7tpu1M62d+EVVHZN+5UMvFuQvWz
30+Oi0+S/U2Ibp/mNqWC/Ge54LvG110dDkz8LrDzuqKscIn8Q4+88JlikBLJ
OS6w14yNSl1cRvZdsNTcS2n6tEKy7wKNfSOUFMW0X1e6oPC3Cru1H+3HchcI
jF9dsaunfLJcMeSz+oErrZQvNVfUnHBd0gxmP3IFp0lBYh99ney74vnzm7oz
lQnzXTHmik7dj09UTzmuKEjz37xhGVPvruh44Wj99gTVq9wVvYc6h5yaS3KW
Gxa9NxfarqD1qOYGqz4fJM9XkxxuYD1YtF/pFM3PcUP+g0fjj9Ux68sNvnvy
0hIvUH3nuEF9tcn892FU/5Vu6BX0UGfRV1ofcjc8svlzOlmH2X82Y4+WqFRX
SPuZ2mas1LY0HPDgAdnfjOdHvu+u59F4zmZcS/+jq+JGmL8Z4w/6vPXRJ/2c
zUjalx3sc4pw5WbYDzDw79tJ88k3wyWvPFXfo5Hsu6Mlb97sjQ2E1dwhMnuy
45DqE7LvDqOmzPzt7o/IvjueNfaXjI+m8Xx3HPjr7fU4nXCOO/q7DTfXGU36
le6wSH1VkTGyiey744Z72USNLYRZHrh77/r95kYar+aBaWnpi/fffUz2PTD0
W+tR6RvGvgckiskOE8aRnO8Bzqgd1tv8Ced4wHyTbNNJaxpf6QHd17M2JTeR
f3IPDP+QppPzgInfE42l5b/W9aXxap74qVDkzHvH2PeE9Fjr1xd1jH1PpElS
9k4+20D2PRFf2mxx6A/lN8cTluEJN502PiT7nnAf4uT8PJex74kjrVVToiIY
+164c86700CR8qHmBad3vXsF9qf54YXqBpF7YyNhjhdeOR8LOHSB/OF74c+v
2ZI5NYRzvCBdvfDMJzcm/14w97SRdemSP3IvuB/yW1Ddypyf3rj06YdK6h7y
X80bn+wzrJ6vZOx7I/7AMF8FJfKX443OapU/21xoPN8bfx8lyCzP0Pw53vCu
EMzp7cDk3xt7DD9JxA2E5d4I9Dnwo/8O8o/lg34aL7xfejL154OG8ssffgxi
6s8HZUe2W0ZceUr2fTBm8aE7T1cy/Ptg9YTGxOm6lL8cHwiDj45YXsXY90HJ
YN681KtM/n3QuKSpcLEpxcfyxTWTrkHlVoTVfOEfrHNUtYGJ3xdOJqMnn/9D
+eL4Qm9m/9UlkUx/5Ysx3JuzFIMJ5/hi19VZbS4ypl/xRfDBzAL/ZbS/yH0h
mdD41aCIOf+34ITG36p3/9t/tmCdh8Pn38VMP7IFE+vKUsymM+t/CxTOmT/L
uUn+8Ldg6mRRSv4Gpv62YETaLq1Fqkz9bYFj9OOtOnwaL9+C+zFLhAEBNJ7l
h5evjEyibtL8an6Q3huc1hFK8cAP3qJV5guuM/H7oWDWqy/B2xn7fvDY+PHe
kG0M/37IFg41bbRk7Psh+rl3ZjuTP7kfDn90csri0fysrZC5fq1X/ENYbSv6
r0hVWvWB/MFWLGre+Ip3lebjbMXH7L3HOV3M/rcV6aZz32znM/H36I8zm2Q1
n+n3tqKXY73suBOz/26FoeWsh0obmP6Hi5MrnGbtiab9XpmLrmdb8v+0MHxw
8X3dpbxge5qPzcXI7bvX9hnH9DtcGJherO4eQ9iCi7n1I42Dr9B8HC5SR24/
d9WIzgsuFwtXVCmUPqPzhM/FvOXCvbldJE/lQi5vbY/cTv19DhfDJzzdcFqf
xhdxofngTHzmVeZ84+L3mKDHDu6Uv1ouFh1wYa9SIH/lXOT+JzFbwab8dHDh
tmzoj6pEyifLH1oOx3UnOVK9K/tjz9xbP351MevRH7Ks27mmW2g9sv3x0Z9T
usmc1hv8cU3yWr94I2ELf1T53mRXLHpG8fvjU0fm59PvSJ/rj/o52j4+ZoT5
/rhSG/rYN53Wc6o/2JV3OuynkjzHH0X121wM/5K8yB+vHe6WTrIje5X+yIT/
kHkj5RS/P9rvtoRzu5spfn80Xi0ZneNH8g5/pI28cl3x83OKPwAlLt51BVYv
KP4ATDyq97i2k7BaAPR8DnmlS19S/AEI+2OoXrGTMAKw5O3A1ROfEbYIgNLY
DTYJyq0UfwD6jbQ9mDGd5NwA1Ppr3x3o2ELxB+Dp+hG9n/8h/1ID8NONOzUj
iPKXE4DO+wbTXxuTvCgA4axRO3eHUXyVASjO1OR8v8PEH4BnJhPUtSSkLw/A
F7Z7ri6L8tURAD/VCwv2VzHnbyCG1Q0acJdN8ykHoq1PYf2TPTSfWiBSu7sC
dupQvtiBeKmV21rjSv4jEEGLjF/MWk3YIhCs377Cp5cIcwIx4q3ond4Z0ucG
wnqN4uLffoT5gYjmCFMKTWh8aiBaD7gfebOVcE4gnNZETNpqSeOLArGk0qLQ
ahTJKwORcOHxqhYTym9tIGZ6Jk/e0E1YHoi7VRUtHlzioyMQujkNOxomkJwV
hGtrVh+RxBNWDkKH/BBvUV/CakFwjd9+7c9zsscOwto4O5c8CcN/EMz8Ncc/
1WH4D8Kw6w+GNIcx/AdhgW1236bCVxR/EM4a6lzzOdpO8QfB0i2Cr96LcGoQ
ts0eZtE5qo3iD4LXocu2gmbSLwpC58Wdr+YokbwyCDrC4x7XZIRrg7DmlPoS
6y80nzwILLVY1tp7JO8Igmp3n5gZ5oRZwViFS7YGlwkrB0MpusB8XSxhtWD8
yCx7an6C5mMH4+SpCwNSer2m+IPBtuj0rWXisQjGVP8fvUv6kZwTjC+LP2Wp
M5gbjNJxidM/ZBLmB6MusTOg7Drh1GAsHTv98MZOmi8nGLZpYy1/3yNcFAxP
wbmn5ZY0vrIHb99xouIxyWuDMd9izqBRW5j4gzGXNaxCcw8Tf088J9zzTD5T
PlkhSE960dBymbByCBKSu7MFFwmrhSDcZeth2X3C7BBIowxucq4z/Ifgygoz
cfsDhv8QaLxfuYOVwtR/CJZE3J05dTZT/yHY1NWlM30vU/8hiJrYLM6cydR/
CO4NKS1+eppZ/yHYbznO46Iq9T9FIShqixs89x2z/4VA7npiVFMF7Y+1ITCp
qPgeMon2T3kImhQujXzbQrgjBFMj2Gefs5n1z0P3fA0DEy2SK/MQamSwZMp9
ph/iQarPdxQvp/OCzUNl0x4lHyFzPvMw+U2QrXlfOn8seOC80ZMO+EvnIYeH
jLPn+xoy5zuXhxSHFZ7G2kz/xMPm+sNzj+nRfKk8tPZZ219/N9NP8WCvd+jm
0QPUPxTx4Hb31/iUF8zvGx60zxj8rnEjXMtD4dN6Hd/DzO8dHkw73P8LG07+
d/Dw8GF3c/lIpv8LRVEhZ9U4ezrvlEORfiRuBXchE38oVGdfEhZ0Uz/JDsWU
xhkrH76j8QhFl4Lxuaz5hC1C0Turc3A4i+mXQxGmdXOY71LS54Yi035q9uLB
lH9+KNKG6O9LNGfOv1A0TU2bMM+P+T0VitWpm2YcjiZ+ikKh7GvT134x09+G
4qjv7l0zWyi+2h5/CtR1RjP9qzwUj5TWvy+0Z/gPxcRPA8yP86ieWGGINTjQ
ovCbsHIYcsvXbfgzk9n/w3BYIHX8NI8wOwxrhlcabram+kUYLpsv81Z0Yvb/
MGwoz/VT+UJyThg6jiZsGbWGqf8wZDnHh13dR/XND8OhM4cOfMwl+6lhmLkx
8Usa8/srJwyjTa4uVztN8RSFYQI39sD4IOb3TRgEs6w+Rh8mXBuGGOF9zzop
83szDNm/lk2b8JqJPwyrYz7eV1lB9lnhyM3vfeHNLSb+cAy6lKYgUCGsFo7r
1evCphQz8Yejxk5SevgRYYQjPVP1cfMowhbhaBly1mt9KWFOODTrl96zKWDi
DwcMfruGD2PO/3C8MMort4tm1n84GtJ4NRd9qf/ICceMx89dbzP9Q1E4dowf
EGGpRvLKcAwcNeWVnYg5/8Lx+SFreMsROn/k4dAuud/w+i3tXx3hyHtVMeRU
IclZERiffkzlUBtz/kVg8MnaT0fKmf4nArse9148YCvT/0TgyUbl+bUNzP4X
gdr7ssTue8z+F4F5vyIdJu4nfU4E2huTv/1oIMyNwJ+fOPOF2R/5EdAespk3
R0j5SY3AqkPh0JhLOCcC+5frdtxdy5z/ESgWXEr/9ZJwZQQidld8cQoiXBsB
uUOs5num3uQRiEq12HlkANP/RYC/ec+i8dbU77AikTa8emRIB9WDciTkilMW
ZKxh6j8SXNHyp/m7Gf4j8W5y7MXLF0gfkRj+t8xP+TvVi0UktHlp88x6Mf1v
JKxZ7Rf0F5OcG4mflz0lT5Yz/W8k1poobRqsxtR/JNYdcOOfc2F+z0fidl/L
V4sdmP63B6exjVIVmfUfibGZDp03JEz9R6LwwtR+jceZ/T8SB3dt3rN2BPnT
EYmYFq0+qpHM+o+CqsDqsc95Wi/KUYjYphkTO4XGq0VBvdV9VinjPzsKjcfq
/GvCmfqPgpP7SbmijPJtEYXSKwtndNgy9R+FFA4rb4E6YW4U7utIgj3eMOs/
CndX6676Ykv5TI1C7tEDoc53mfMvCk/HCdcrmTD89+hv/jTa9CnNVxmFi9vG
DD04heE/Cmt/bblpPZvk8iig4vbCRykM/1Gw7svStyln+I/GeY1nbgMHMus/
GhNaxN8fH2C+B0XjzZRXs8cy39PY0Ui65eu8Tpv2W0QjcOleZ9sSkltE49nZ
bxuG76XzixONuLZrG06eYc6/aJxaXqGaVcx834+G0vji1W+/0vfO1Gi4qA5y
0J1O8pxosB70ufJsBX1fLIrGgb5K7y8vp9+HldHIlZnOvnOdxtdGIz7g2tWf
SfR7UR4NN/a4cxaVJO+IxtWkpUZHHtP9DisGy57lpe3xo+/vyjH42rVOLcuC
fo+qxeD9bMfZklSSs2NgL8q1s5jA3DfEQN0qVLP0PH3ftoiBteDtiBVdpRR/
DBp+FpusjaLvv9wYpM4ZLWtOIMyPQc1kNYPfS89R/DG48Te2ISb7MMUfgwHu
CgkcE/peX9Qz3iO7T0vFEYo/BpFVJQW5p+i+sDYGp2XDRH8yaT55DHZPnDz4
4UC6L+iIgWXbrYp+I+h7NouPswPMTBRu0/dnRT6q4ldPrbpH3/OV+ch2aL8b
o0T8jOEjhL/WYO024kONj87x/EExUup3tPgYPqWmYcog4pvNh8qoceNuphDW
40OR1Xb3yiXm+y4f22ef3iH9S/VkzMf6gKsKXTsIW/Bx7I6ysZqQsB0fNt+d
dlwOZL4H8jF7dvyri8z3FU8+vNZmB9gkUP/A5UO72LNtlRGND+Vj6KuQV17M
90A+H6r6E78esCG5tEc/NKKzKZ3kqXyMvVXz5dBXmj+Tj8gLWc5Dj9D3kRw+
Xldb14rnUXwFfCwIi9p1uRflo4gPzQy3s04LSb+E39MvNL1Z4kbjK/moK3T2
ePWd6qmajzk/HXe/vU/z1/IR9Vc6ctAgqvdGPhw+TUwcLGO+p/Gx56CdvaEX
zdfOx5lJ63f6Mvx08OHsdHvQtas0fxcfNZbZ5+LD6f6AJcBBw9DTufm0XhQF
kD9YqWmymPpRZQGq9rrUT2fuC8cIsE11wrHMxbSe1ARYydO9ekdM9rQEmBB0
mvX7PcnZAkwfebnFxoH81RPALsNuw7PzzH2bAB8XieJufiNsLECCgs8DjeO0
3iwEWCrQOVIwlu5j7AQQj05f0Ocb3S9zBHBtfxqxyJruczwFCNDu1V+4ZtPF
f/wL8LXM1a/XH3qfEipAdm6HybxRdH/OF+Det9H7UjS2/BsvFaCpoLxg3zSS
p/b4ay/Sfngq5588U4CLqXE1SmHF/3COAFtf/rIz0C35hwsEuPt89vhtniQv
EuDV0YaVP7fQ+40SAdLLvTP0qwhXCqB/4CCb73HmH64WIN7oxIupl+i9Sa0A
DQu/jVPpuvQPNwpwVHiOO5xX9Q/LBVB1W7Vwv2XFP9zew8/rrLS8qF3/cIcA
RnbPTqhPpfcJXQLsUT1XLb+75x9mxaJfXj/jlmx6H6EYi79bnDiDrtP7BuVY
7GvKnRr/lt7njInF85UfD4p7Z//DarG4lOZeUDac3gtpxWJt7W0Tl4P7iP9Y
eDxvKr8usiX+Y6Fl+uJ6DJfePyAWaR+Sora/JvvGsfBdcK8qUyfiH7aIRad6
qtaKBYHEfyz0zb+4ziih9y+cWGjazV7UPIbeg3j2+Ptr6f7OLno/w43FR9vq
rsLxlJ/QWKhu+fzE6DON5/fou+0JfvWe5pPGYmTCo3mz5pA/qbF4oncrPukc
vRfKjEXwqtLWrGtC4j8WU4pfB3f5kLwgFg59vLq8pqcT/7H4M874bvpef+I/
FqwSYbyFRwDxH4vq/JkD3AuTaf3HYsLK8saX3XHEfywat1x0P+5N760aY1HW
8vO9jxG9Z5L3jHd7svT7NXov0x4LiX1ruvlG8r8jFitvWOw/vO408R+L34cL
nSyzDhL/QmR++dW0ScmC1r8QC34HGi2I2kbrX4jZaVpdtq15tP6FOO6y8tj5
PnQeqQnxYq9OiJUonPgXYtJ8lfeKPvR+hi2EolqnV5EBrR89IaKvVGTfMd5N
/AsRs3ulVqM75ctYiE0p0Qm2A31p/Qth2G/bxG3X6f2ZnRDtxT5rX3bS+zGO
ENYW4SEVmVRvnkLM9fwwrMaK1i9XiKK5xbfq79J9bKgQF+4Z5b/5tYvWf4+/
KtZdkV/pvlwqxGaNT3W3WgNo/QvxJPS56+4j+bT/C5G+fH2DyUHiK6dnPN/q
voRD9+8FQuy4utzJp5Pum4uEmKa1TGmRKt1Hlwhxfo7pnKPPD9L+L0RG+65r
XcWUz2oh1J/+V/xj93na/4X4HMoavOELnfeNQnBlubeD26g/kAsR4TxCfeEm
un9uF0JTY+nm0Ey6L+8QIpH3/ip3A92ndwkRd9TOexODWXEYnTZu6tYntJ8q
xuHi4sXaZ9KpP1COg6azCscylt4XjYlDqJKH+qVQqge1OGwI9rVha5J/WnEQ
KdY9+n2E/GHHQXtN2e0F48gfvTikrVtje1iT3qchDkKf/IYF6fSezzgOl7+P
MBjuRfujRRzel/D03SvpvZZdHNyUeetur6d64cRh8JcV+XMtaP16xmFJVhtv
83Uurf84qNh+G3ZbSu+3QuMQLR5W3pLO8B+HgYtCbFyeZBP/cTg86b8tv2KJ
z9Q4nDrE1hxuRf1UZhy2aLp+39ibue+Pw1Ldg5y5adTPFfTkI0/nhHggxVsU
B6ntrlmmGZTvkjjcn3prdtp74rcyDtM6Fo66N4PqpToOp43fN3/5SvmujQPb
6lZuGJ/qvTEO9dLLT4p1qN+Tx6FK9kkhiHk/2R6HLPV6s5ftVO8dcZi5cf5m
y1YZrf84nDvvbSy0W0/8i9BW/CffYBG9P1MUQZP1IcnrG9WrsggT/rJ/ZjvQ
/jNGhN2Pklv+G5lK/IvQN7TNRT+F/NcSgWc6/M9JVXofwRZh9H9h6RXn6b2D
ngh/s5LQz4B5LyXC6h39YpqN6bw3FmHNu/4jr3gz/bQIReI8g6e7qB+1EyHz
79hlvVOZ81+EI5FSbYcRNL+nCJa8x61rLEnOFaFZ79eZZWWkHyqC38IHCmkH
mfdpIkz+NKxdOJDen0hFsFCJu+Y9j+SpItiYdFgkrKP+IlOEetMtS1JsqT5y
ROBz7/ldziJ5gQhX+z3MEL2m/qpIhP1GmiP3bqX+q6QnH0eiX3LfMu8jRPDX
sd7Lmkv9UbUINy2faG+roH6sVoRc9td8FNH4xh77O7EvtIl5zyFCxU57H4/p
hNtFYMnyqj/pUr/YIUL59eohz1fSfF0ibHGyNulVxbxfE0P0mPuWHUH5VhTj
TsT1t49U6PeRshi7NXq1tFtTPsaI8XKw+prL5cz6FyN6fZveGAHt51piPFrC
v8ktdib+xejtExTMzokm/sWws1le6JRN5wvE2PzydeT8jkziX4wohRm8wx+p
3i3EeLZ/jp3fD8J2YlhOdmlgz6T1xBHjpk2uStMBqjdPMTL1rng/0qPfM1wx
BrWtXj4hjeINFeO5bn1A32jmfZcYRtyp+XvO0nipGF94T83kD6heUsWYoXHi
eE1/ej+ZKUb/h25WSh203nPEmNgcsPFmALP+xTi0JtlXMYPWd5EYcyp9Fkxw
JVzSk++3nx8qOdL+WimGTbfjeMEeqt9qMcqfsDK3/6Xfa7ViLCjc8HjjOdp/
GnviPTHT/JgpxS8Xgz/Od/KPZtp/28Xoe8ayra9nAfEvxneda5/dT9D51SVG
jfukuP0n6TxmSbA5TPjyZ3bhP6wowdCK0cZKn6g/UpYAPqY71+YTHiPBINel
6ieZ/lZNgqrDqi9mJ9P7Xy0JrB3Ew0d8o/2ILUGRkb99Wn9v4l8CkwsGM03/
o/4TEngO7SM6brGP9n8JQpz/Nj2so/7EQoI3/pw5+V3UH9tJEKu0VfVbMfU/
HAl8Py3SvP2S+l1PCRKVKq9VeCUR/xJ0f1x/NDac3huHSvDAdMO2+x8oH3wJ
LoexB08ZRfmTSnD1dM2yjwuZ/l+C+TOaVBx/03mdKcHeZ9f8gpfReZ0jQbt5
VNCZc9SfFkggcn9Rz+bS+VIkgTdPedD3w/T7o0SC7PfrLU4Fkv1KCfQreSca
mX6kWoLrHqnXdo+n/qlWAjezG5kzz1F+GyXY7Z2w+Ma5qH9Y3sOXaEi9qZDe
m7dLEDr5rfaHM5SvDgk2+F54e3Ys9b9dEnyuHXF70DjmfbsU69Nn9pW8pd8X
ilJE7B+60GPXdeJfijt5eUK157XEvxStTk/aRRfvE/9SjKo6cym0mLCWFCXZ
+8QlrHriXwrP7EG67VWE9aRYcy7nw+QkwpBC1nr6jqk2YWMpjg3P36+0tpH4
l8Lhv14v9IweE/9StCnyx12ybSL+pVj1zXDKBwMa7ylFgv+MvY+qCXOlcNT+
+3p/EM0fKkVZGXt7IJv85UtxQGtMK7sPyaVSTFwRaexuTPqpUuRfSbue6/Do
H86Uoj507NyOyeRPjhTHuSf+69v+9B8ukOLpzHdLNKrJvyIp8vymdX8bIv+H
S6RQzBMMLI5p+YcrpXCOEN6ctZJwtRTWb8o+VjsSrpXicP7ybX3eEG7sye/2
7wsa3AjLpcipCXVx3EW4XQoV4di2W5+fE/9SRH6JObSk70viXwrzUXFW+2wJ
s+KR+Tk1wWTjC+I/Hp3jLaZfCSN95Xi8m1E5/jKH5h8Tj8CklfXW30muFo9r
9/r1kf4iuVaPvPa6esNQmo/dM/8EnbZ3fUiuF4+0zl8OA9gkRzxC16seU1tG
/hjHw3xEn9Pl60hu0TNf54O5gpckt4uHaZ9HpjWDWon/eFyoXlY09QSN94yH
YOdCxyWRNJ4bj/f1pZYCU5KHxuMiv0//5yakz4/HxqdZf2IW0nhpPM4k5u3+
spjGp8Zjsbhg+uMmwpnxELE1tviWEs6JR/YSr5if6YQLeuLz3r5av5LiLYrH
rmGen1syCJfEQ64x7t6iATS+Mh4Ph/2yzqth+I9HC2uv3xBdhv94PP8Su3pS
MI1vjEftioFzV5uRv/Ke+E+EWVlJCLfHY/j51ofzKgh3xCMo3TjBuIbhPx4R
JZbap7gUPysBZk+8rztaviL+E7DcbIqVeAdh5QQoGAmyOH3aiP8e+WJHZ7kl
YbUE7Dr+4Yn9EMJaCahJK740dCRhdgJerri2qmoYYb0EnPJbq9YnguwjAbYz
lhu2vCN7xgn47DCx4uOkduI/ARv38xSykgjbJaDO88bpdqvXxH8CPsq1bOfE
E/ZMwCXdQJ9n0W+I/wQ4d0RrzG0l/dAEWE3icO+8JcxPgPeV+w8W3abx0gQE
11TPVzR+S/wnYMkS3YYCG8KZCVi6rM3154R3xH8CnmlMOFN6nXBBArZO6Fo1
4uZ74r/H/0Lt9/ozO4j/BIzacVkrR5VwZQLy92TYumcSrk7AC81Xda/TCNcm
oCxs0sHKW4QbE5Dc9+Y4fbtPxH8CNM+MUivvIHl7AnbbLOINDyB5RwLay8/O
HNNEuCsBbssUb27s9Zn4T8TL9JjHvDKSKyYifnBKcGMtYeVEzGpcERSmTePH
JOJXZEfc23qyp5aIDQrfpnZpfyD+E3Hub/cXxwDC7ESkKX5e+ruN8qOXiH08
ExTsoXwiEUW9h/kaTiRsnIiMMdbH6rcSHxaJKAksVfcdTHK7RMzXLdwVtIow
JxE1Mx69f19L2DMRnFfdGeZTyB43EUEPf9V53qf6CE1E4MQbRwslND8/EWO7
I9oyXlM9SBOx/JnHJsNSGp+aiKQH0aNX+ND4zETkLB7vWaDD8J+IkBwv8ecs
hv9E5NsNuTfGjvwp6tG/7fuz2I/kJYl4d1HPRM7EW5mIz13eHTp/yF51IjQr
XvVu/Uq4NhGVm6t/LnWl8Y2JeDYtvaV8NGF5T34P+TsuCSPcnohTkRcDh80i
3JEIR8Pidxwzst+ViKMz80Z0exBmyaAoHq0XWU1YUYaCWSN5taHEn7IMmqeV
Do7eRfU8RgbXxLd5Sp6E1WRYUGfLyn1G+loyRAhmvi97QvbZMmi9dn2guoKw
ngxXlyZZFR+lfEKG9XVjY+fxKF5jGVhTzEemZxC2kEHn1503s/8jbCeDfyMv
u2kI8cWRoWvInL0Oswl7ynApmycbeJb2G24Pnlf66mQb7S+hMmh87Z6lsJEw
X4Y+vtWTKupoP5LKkKmUUuc9juSpMuT6rph2WJdwpgz5CkqK7XIanyNDq760
dFIByQt64lm42mnkYLJfJMOtd4WGrXEkL+nxx/F3795XaT+ulCFknqfu0HOE
q2V4dLYueuxy2u9rZUgeUaHS+o45/2WoHZY652cdyeUy8NcVPy2qYvZ/GV7H
Zl70fUTyDhl2nfS4Nnkqs//L4NHp0/2um+SsJHBszNZutWXO/yTwA1PVDA8R
Vk6CUvCZa6JE5vxPwt0fKpl+lsz5nwTtNTo13ZOpv9FKQnBR08qH2YTZSXAt
fL5jy2DCekm4882EN1fjGfGfhFnVOyaVfXlC/Cfh8VZj9ZTv1F9ZJKFJbFfY
4cD0f0lYK6tJycqifoyTBHaVyUTXdw+J/ySwugffMzzxgPhPwuQ1F88M1mH6
vyT80MzoXfa//i8JV1w6tSSa94j/JCzut/7Nn5eEU5MwgbvhU8NcGp+ZhNB5
4ntooflykmCya7ZObjbhgiTYn6up+jGB7Bclwc/o64zFs0hekoTfV7buPtdF
81Um4XT0JDe5F+HqJBxgu155N4Ls1yYhW7y1qvkI9d+NSWj1t/h2YO4d4j8J
snlvP8eWUL/engSzzK0Ztl+vEf9JcEp+q9DnJN0XdCXhYNhuc+9WGs9KRrtF
h9a+OyRXTEZa5U7hkpeXif9k2PbyTn3b+wrxn4z9Rnt4XGeaXy0Zd8YXhWsN
rCH+k7EkGFMMf9wi/pNhI/SxfjjgKvGfjALjDxUn/hJGMmLZ/HnTO0jfOBmR
s9zvt1hWE//JCBqjdWr/QpLbJeOE892OpxKSc5KhsmJEnwXzSO6ZjNG3fQ8W
xFJ+uMnYbRg1qm4d2QtNxsSNc5UOJZE+PxmLPa8Nj71A8UiTMUane7eDIeHU
ZGgrC5bXz6fxmcm43f6Lt/3GTeI/GVof9qxUTyD7BT3+T/ZuGN1A44uS8XD0
j4DyvWS/JBmndl1I+tGL5q9MxpCIXfmNqoSrkzH893pJ8yzKf20yTP8a+DX8
IP3GZMzY+F+1oJv+/7A8GRGPn304+pb4a0/GXO/7RhOuEO5IxvUFvUK7K8if
rmQMuL40pnUM+ctKgYZOjmN9X8qXYgoMhqo8e7PvLvGfgvJNkcqs/lS/Y1KQ
1XdG87RDVN9qKTAtPt65w4vWn1YKhDvjTq9bRZidAkxZt8LxJPP7LwWa2+ct
UL9WR/ynIGPHUTWNtXUX/w+B5fht
     "]]}, 
   {Hue[0.9323792124926413, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnlczN/3x6OQbKUQWQZFlihrCr1kC1HaKZpKC23Tvtc00zTTNoVSWRMR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     "]]}, 
   {Hue[0.16844718999242758`, 0.6, 0.6], LineBox[CompressedData["
1:eJw1mnlczc0Xxy/yyJ49hGRLlgqlRH1sSegprULd9n3f99tyu1u3skS2hEoi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     "]]}, 
   {Hue[0.40451516749222094`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9Wnk8lN/3n3aUEi1SSjsVTTtt3lqFCinKLvs69p0ZY5jBDKVFG5NK2qWN
tIyStKPFVh9TWpSUFEnb1+/VeX7+8Xo795xzzz3LPfc8xrsEWLr1ZrFYzX1Y
rP/7/e+nzXBqm5NRX5tD1+kPiHrfV+nkWSlhBfxXEuXWtvo4YRUobgi68Mu5
kPAwiOcWWn5NP0JYHUsva8+Imjef8BiMLnBuuvzoguE/rIWhz/9z5P2QEp6A
1E0t1t6NZwlPgmKu8Zw5884TnoId+8JCH/UqIayNA9sEkiHKMsLTkDVr8EGN
pZcJz4Dx53EG2meuE9bDyC+suy7SUsJsrOEM6M2dcoPwLAw/mjt69EuGPhuZ
6gXFI+wY+XOg5z1r97FRtwjPxTnxgJvFpjcJz0P4zf1xm/sy9Pk49efD7JjL
DF4AzoCS8T98GayPbj2TrIcGjD4DlEW81/x+mNnPQljo+CV84zD7X4R7AZdz
z1UUEF6MOw9NdtytLyS8BMfN015GXmfoS3GmURI4Q/8EYUN8Cd39fuiEI4QB
jdkdm8d6hvzDXECrSWNXrVo6+csISwcOyStLyPuHuUbYfKhQbckbJj6W4ZDC
OtVDgoNEX4biC93JLpP5RF+OvmoZghXXtxJ9ORaubzA8+XUb0VdAea+XkWXK
SaKvwMV5IkWXU5eIvhLexfeWBFheJfpK7JzuprjxTDHRV6FGlj5Laddloq/C
N5stPvNfEmatRpTL+FHHrlN8cldjY9TrWvvPTPwao1TLv7XGO5XoxpgW7Z7R
smUP0deg3oIbOvtaDNHXoO4dJ8H8426imyCwn2X9mShGvgkk/BMr94oZuina
Xth9HR13guimeFyj+Gza6O1EN0O6QtF9S2Pm/MxgL59jE2ldRPS12FT/W+Hm
74tEX4uvs6Q+j1iHib4OA3VMPv9USSP6OpzplbfvmgOX/Lsekx9FCi4MOkb+
XY+jl6fvmxF0jujm2HlUaGFdS/kIc4T6v/BamU/5xzXHCUG54kZTii+ZOTSU
5t2Z/OEi8VuAFbRx+3yr08RvgZpMN1MfULxxLcAPHPH2jusm4rfAZo3zqxW3
7SZ+SxQq3VOdrk3xCEv8qutl1Toui/gt0bisd+2M33ReMktorS64Eno2g+zf
gA3t3K/n3oT/w9iAgwa2Cy7+2EvnsQGLJs7sr7ZDQvwb8PzGNIcy1bPEb4XN
069kT3tB8QArbBM53+3aVED8Vvi66XvL3bmnid8KWt8zxX/SGf6NsAuOfzaw
Mpf4N0K47MPufsrniH8j3vZ1/ZGjSOtlGzE4x/eccvQV4t+EC5t2DxDkXyP+
Tbj+Kr/O2YDRvwmvj3tcu/wfYdkm2PZ90nfoWJLPssa132ccpzoQhjXYZm7D
x8nPE7819nWGb7C+z/Bbo/jTouqw0URn2UCx+499X1faD2xwK9R+4pT2cuK3
wUO3X7VTX98gfhtc+5Jxq9voJvFvRrnt88Gpu2XEvxk6Fuq+fH4p8W/G6GXf
Nrj/pXiWbcaT9iPsvBkkj7UF0xSXt/T6SHRswXqeR1a6P+2HuwWLlogWzz98
gfi34MZQ3ehCJbKHZQt2nwETxo4+Rfy2UHpTNu/0G8Z+WzxYaHvs2UyG3xYL
t7+9O/EwU7/s4GNarZ5flEX8dljwazfvpC3VF64dqqY3pFvbMv6zQ1m6Wd/Z
7dnEbw/fL9H1MzmM/+0R5BUnWXeYqZf24GXPN1paRPVBZo/M24GDx+nSflkO
2Pxro9L6QU4U/w5Yezr82r6ELcTvgGc13cc680H8DsjZVxn6asthyh9H7J7k
vezUHspXOKJ6i0keL+8S5Y8jZEp/T8r3MPnriAnF88rHLmPuCyfEp2/9sQ4n
/2EtJ+xd/XWlQi+6P+CEyKdzb+Q9PvgPOzlBdfDxTxfXHCX5TjivLj1eeHTX
Pyx1gnhh653ohgOkzwlh+k1GRQY5/7DcCX3l4m+bj9N9wHLGwTPPlXfNOvoP
azljZV1+7ocF5F84I3BQ2PmvueRPJ2f0Luv6PieW8a8z7P2n7dKcRf6ROqPc
szv14Aeq3zJnjPAafKLOnOhyZ/jxXMPMVpE+lgu67JQObWlj9LtAUrR1bLsD
1Ve4YPOtn1lajpmk3wW6IyxzdBdmkv0umD7RQHPPfbo/pC64EbMjxEhG95vM
BeKGpkleLXQ+chcELOh/5YN7MOnfCs8PlcEGAyj+tLZCocyhdNcGildsRVrE
iP2t88+Q/q2oMjxUcOkZyeduhcourwQTNq2XboXqSaX5mkVMvG9Fm3pA6K7x
lG/yrWgVno09+ofyk+WKjIQX9eGLbpN+Vzyxyj2w/0cZ6XeF8Ktn/6POVA+c
XKEkG3xr6u5bpN8V571O5X64R/xSV8TPbKn/+4upF67IudmZmRdG6+Wu+JO+
znfCJpLPcsMNR40MaSxhLTeoqe/+7bGN9MENIyqH5kawiN/JDVmGWeduL2X0
u0H/hY+Knz/ZI3XDoP2fG8xqiV/mBhuzR73jGipIvxsazB2Cf8Yz9csdcxXq
THZupv1quUPp4e+fF30Jwx3iYweL5jQSdnJHwVtH1fzehLnu0B3eZ1EfY7qf
pe74u6zXlXfN1L/I3HEwOaB24i6iy91hVaj25kD+ddLvAdvjee5WARTvWh5Q
mBS/epcixTc88N1x3pF+/tT/OHmgUy9SizuK6iXXAwUzu/UGzqB6KfXA8+T4
mpHuzPl7INC97qB0NJ2P3APjpoT3GraRqb+eqNbmaO6eyJy/J7qT7mXbzGTs
90TmAOPD7CxGvyeyyhcFWvsy/Y4n5ps4XCoPpf1KPbEgUjMpjEv3gcwT2tO7
bdLrGf2eWHY3uVDjCdPfeCFi6t+tlf2OkX4vPA+yymF/oPOCF8RmNxY03iL7
nLzgu3fkBNVKks/1gknBwuMeE8mfUi8k5ZpcHDXgDun3wrlJB5dnpt0l/V5I
HBtz66kuxQPLGxNmj+0rf03rtbzx09S3cNGge6TfG+8s98Xo360k/d6oU168
tOP4A9LvDYt3jxWUfxC/1BsR4680rVpB8mXeKOx82G/aJzpfuTeODxl5+JuI
0e+DeSNejDs3iok/HyjtzFur0ovsgQ/cjwmq165h4s8HZ149vtC5k7kffZC4
7tta5cfkH6kP+l86qPe4ibmvfPDm5gO9WBGdl9wHempT+E/Kmf7DFw/eb3lV
8oLOW8sXQb+cV+QsYeqPL+qTBl3+do7uKydfjI551VivT5jri7ZhE5d+dqV4
l/pi0bmcmsph1E/JfFFhc1qzSkr3o9wXb3j993tcYfpvP3S8W6X22Jjqq5Yf
vi2uMdLZTP0w/CDQNd2ZsZfqsZMfLq9aNvbmGer/uH44O6p5rueAMNLvh9Lc
yB3jwqaQfj98EI0J9tmeTPXXDx81Oy7uzaN6zPKHTqTWxpeldH9q+aPL8rxC
jTVzn/pDedrqjDnvt9P9549uI5WFzyuZ/tYfJ8ta/AR+tB+pP57fVvoZPZnu
S5k/HOY/Gh5lRPVe7o/87ktf/ujlkf4AlJm+9P9Tspf0ByBBf1uxy9k00h+A
bYvi1P4MdSP7A6Cw9pTlqufMeycAptrzWnfEkX+lAbj8fuq65SoUP7IAnO/d
bvPpGJN/AVi9xDBy3Dqm/nEQWbx3EptP/Coc3FjrrNicy9QDDj55j9yr3Eb1
lM3BYp0iaUUhyQMHm3oPjPDqovXmHLzJHwoDf7oPnDgoOT53ztsHxM/hQGF5
0JSR4bSey0HvZI0zdRHU/2Zw4LqDGzTnORNPHPSf0v/zWXn+P1zAgUfD+mWa
n6jeyDgwDEhfH6ZF/W8lB+/WBkgjf1I9lXNgP81X46+Y6ksbB8pzCiqGraJ4
ZAXi/ZLFOoJVKWR/IJ5wfr91UUom+wOhM/6C35kqwT9/sAMx355jkjKMiY9A
lIoXLDAcRv40D0T4+qYA81lMvAaiYjJ/4dZGimdOIGLM4l/XeFN+cgPx9dl/
fR8UR5L9gXhYEjP8ylzqR6SBuB238Pfo73QeBYEoN7q9u2UWc78EYn+MTeAH
QQnZHwix/Sk/9TWE5YFwr72uHRpJ/WxbIOy7l74KWkL+ZgVh8JYmr+V3qH6o
BGFG1coJwjfEr9VD7/TRNKshOjsIga8FK89MYO6HIGgs2h4cbUzxYB4EDpub
fPwV+dcpCMaJ5+vWriR+ThAqzrQf/POTqd9BSH/W/veBCcnLCEJd3utn9+Yw
93kQdtVpmjRl0PqCIHguOaW9hMPEdxA+7DNt+7KW+CuDIK0u0/MaS/EkD8Ig
0/1HtI0ItwXBbVmYQbo+c/8F49ot9rKhy+l9pxKMGSNGlzm/YephMHjnxU1v
wui82cGofrRwxzAB9R8IRlz/6rEPP1K8mwej9X6X2k3RQ7I/GDP7y1tE2++T
/cHQE4Uc3KpTRfYHI9W/YNnXt4QzghHi+nqo3SG6b6TBkBwxGR5ygHBBMDqt
+qlxOx+T/cFgmXdMmDrwKdnfgzfN7dt9lejyYDic02iYb0/0tmB0fEu3+lv8
hOwPgU98y7iSQlqvEoLmF1cT/acSXSsEdsrXjSSVhNkhqA5aGdVcShghyDTi
6Pi/rSf7Q2D7680epyv/kf0hUOC0r/Cb+YLsD8Ga6ScrI1gNZH8I5tXXvXyl
Wkf2h8DczEzr6kaSJw3B1LgpfM0LhAtCYPhsUuGRPFovC8H8lMZtLoa1ZH8I
9vneXFnPryH7Q7Dbb6s9ZwWtbwuBq+vNopBKOg9WKC6vHvD64rRnZH8oYjgG
7+1OMfaHwkB3yIzQbJLHDsWcKtHI/Q7Ej1C8m3J5nrUNYfNQ9Hth+2aeJ/E7
heIH62LHL0Y/JxSXZp9Q1YsjzA3F2AmaphrziT8jFP1fqe/O/0v2SEPR+ltW
8uoaY38oFiVPqB76guiyUIyTpDk9HMP4PxR//TXCJ6QTlofiy6NF92M/0H7a
QnGvcO/p7elkDysM39TP7l9tROtVwrD0/auL+58x9ochwnjUQrdX1WR/GK57
3GhFMsULwjCl6nqX63Rab94jL0Yvs20F0y+FQfIuW3dYI/VTnDB0KgrMF+4l
zA1Da5RBd8M46ocywuC+fmorq4KwNAwqvn+fTyulfCsIwwpl64hNEqoPsjBk
rPcYttuR6k1lGB6lifTT1zP9VhgGd6g/tb9B9aMtDBezd/1YzvTzrHAkXrdK
jEsg+SrhSH04b+znCrqvtMKRdfNq4PqHlN/scCxp2/EzyJIwwiFu7Kuo1U3r
zcOxUjTq9itH5r0SjuBj24L6pzP3XzjatxW8UbOhfpEbjsXXNJYaZVA9ywhH
UenoiZ39aX/ScFR3mPAMlciegnDUT978vWYfM48Kx57lpuLheVSvKsPhkF44
zPI91St5j/x7HhojJlE/1xYOg+pecaOUmPlpBIaoduh0z2fqfwQCVmwYtsub
6UcjcD7/x4Lt00k/OwIZ+6aq3frC1L+Inv5Dz1vOvC/MI+C2/9HvJXfpfeMU
gQV62WmzLKn+ciJwWm1iW2o5079EYNJX9kqrBXQfZkRAfUiSd9P4CLI/AgVN
dQq/XT3/3a8FEdhhrdRZUEfzR1nP+r/G8uS3NO+ojMCunSMrTybRvFwegWez
958XlJ75h9si8PrLpHCjAmb+GQntQ4GeOi40z1CJREDnorvPnA/9w1qR2B2w
6qKnN93v7EgYn3uku9hlH93/kfDavjv3Yyn1D+aRsLMoU3bKJX6nSIweM+nF
+YHUL3Ai0cfAVh7FfN/gRsLowJRmxSU0z8mIxOyplosbsnj/sDQS1WmCTKtQ
6icLIjEkfW1l0tNTZH8kTOzmDnirQ/OaykjEVvrXbTq3kfwfiY03v1lPOsbc
f5GIWDnQSuMuMx+Pgq1yVeryV0RXicJ3Dud+gSdz/0dhkMGiSZ6zKB7YUShc
NO55tx4zr4zCOHXfK7/YNL83j4JC4YiX85dT/+IUhYFeuTel5tRvcaLw9tKq
8/LD1P9zozB/vdap4jLq3zKi4Ocw7fCH1fvJ/1FwSds/zqM/j+I/CnYDHBdz
n20k+6PgPzj7acka6rcqo1BquNTKTUTxLo+C/OKtc6b3ab7SFoWHwb8V97Zs
Jv9HI8LINjxbdxfZH43RngdKbQJo3qwVjWvP5TM+avHJ/9HYYthWueYiza8Q
jc7LJpkvzzL9XzQmB+ZYeFZSfDlFQ/Gh5eSSyKvk/2hs9ir77Ceh+OVGw7Q8
7pE8+xr5Pxre+rObwo/S9x9pNIw/+Tx9v4X4C6Jxbu+0pxUl9D1MFo3TlmuC
VwWTvMpoVHsvzS6Mpe9V8mjcPuHW59dR+l7WFo1JFy81ScZQ/LBiMFbubNFV
SPGoEoOAHW+tvApzKf5jkLVG64liB8Ufu2d9SG+lBUeY+WAMXoeXX5ixt5js
j0FZx8jIA+b0PcEpBooTMzyaZjHxH4OD1ov2qBSTfm4PvW52yvlE+n6QEQPL
k2XFl3Xpe4A0Bh4nlJOjc2heWRCD9JcTf/zRZ95XMTAWBv+VOdD5VcYgzujb
mXRj+r4mj8GKn9r3H3jeJvtjEFJnmPC5s4rsj0XataTweb2fkf2xaOv646s6
5AnZHwtTl0t/Ko0Js2OR7X1u59ICwojFI6sfkEsfk/2xMKs4/tr/YDXZH4s7
Lhr7MytJHycWs5fZmafbEubG4tz+QaNKhtH6jB5sX93WLntI9sfCZ/fTy8PD
75P9sajWN1Cr2XWX7I8FGromX8+/Q/bH4oL954+bG4kuj0XQn4zlc8feI/tj
sX13WGWmUyXZHwfToMI8x1rSpxKHJe7L7Mf/94jsj+uJ97FOkq+0X3Ycfkzs
6hTp0H4Qh6j0sc87Zj4g++OgdXq2tu93kucUh8Dc4XLl2UTnxGFb2HGz3pq0
H24cVJuO7pz2m/yVEYcrrQXLb12jeJXGoSznlWbXZ/qeWxCHXwH9latSmPiP
Q0DzUHaGLb2fK+PQ79vNoVc6KB/lcZh98ZfvYD7FT1scutVr2S2/mO+h8Tjt
Gn56UADpU4nHCtFnRQGP4kkrHhtam+YeuUTfZ9nxiA21tOZF0n4Rj7iq/BVz
YsvI/nhsO6H71qSOsFOPPDN+jkF8Bdkfj9S/1UOfjCDMjceFz/Er9XXJXxnx
iJhQoTnxC/lHGg/rO1+vWEbT+RfEo/Puhys8HaLL4sFS4mTOsWT8H4/Qlxyj
spmM/+NxS5ETkMej82+Lx8leL152BJB/WFwoeMUb1y0l+QpcJPZVjB4ZTfJV
uJh26XSdCov8pc5F7N1fVWtXE12LC89r2765GBC/Nhds6yUrTliTfDYXceUH
VMPtia7PxfH3jt1fjxI/uFh2RSFozVyiG3PhUlN7c5ANk09cPFGLf/RIh7AN
FwvPcg9YHyF+Jy4GnXsfVvuO8seTC+k7h8n7zCg/OVxsOFe8O70P4QguNvYS
8DlrSR6Xi6rQUezactIv5KLLq+FATTDhDC4uaq+aUqdL8rO46DY5k7aCRVjK
xfoVS7XzOmk/+VzMdl2a8c6R7C/gYvmIyqcFcSSviAttM51Y4yeEZVyo/Z2s
obGT+Cu40NkYP/p4Hu23kov7NmOm6s2p/Ydre86/u7GjuC/VKzkXxlV+Yy9N
pPXNXLCcH2ztyH9K/ubi1LcCFe1+tL6LC96j5Uf1fxOdxcMsPR3dNC2Sr8DD
Xk11x5aDz8n/PHyD56V7nS/I/zwEvO8bdzSWsBYPn+b+PPzdvIH8z8MCT8N2
9nHCbB7MS5r06kL/I//zkL14v4ekljB4iPWa5NC/gOQZ9+iznHY41YL0m/Nw
9GlH6mNv2p8ND6abeLFD/qsh//fsZ8x0E7YL2ePJw9MG+/MXjMg/HB6mr/6j
Pvsa4QgeggY8YT3LY+pvz343avz1YfJByIP8d8Px9O/kjwwe5g7ZrWawg/E/
D9E5J4uPzaHzlvKQeKR8cdJMiqd8HnYaDVHvcKX6WcDD2+DWIgcNklfEQ/eU
lr7LSogu4yHt6E1NY3PKrwoeeu14oiVYR/Wlkodnm61eRelSvajlwWvKPQ9p
KZPfPAjqz/kpHyP5zTy83zDCxO8E4TYeXK4tebZak+zr4uFjapH29hjiZyUg
YXL2eb9IwgoJmMt6UvOqjP6fRSUBfnmjB2ZYUz+tnoDI6s73n6uoHmoloGK6
cT/TAKp32j3r9R/LWALC7ARolvNrHz6j/esnwG29/bcTH0kfErDlorj8ywo6
D+MEWFnfndy+kc7bPAHFr336rV1KdJsEXG+4N2v5GapnTgngsNQ3xegw+Z+A
iKMTbbaJyR+cBOz+JDGYuY/OIyIBPKFDibWM1nMTcK3z+xqfCbRemIA6170G
b7Yz93ECpmBQTmcu0bMSYKPG379El6nPPfpSilR5/Wl9fgKW3tGfeVCZ4rUg
AdrH5hbs3VdH/k+A0EBVfcJZwrIEzAlsv3V1KK2vSIDDrBipux7Fd2UCFgV8
vGg0kvKpNgGsJtu5EXr15P8EnP+5TvOjjPibE7DOaZyq2iXab1sCgvJ/1U9r
pHjtSoDMdZb2V6ZesPjoF9Ka6xRE6xX40JjoYffXgOgqfNw5vGpAewPVD3U+
Eo5ND6tVpXzT4uPsq8kpto1E1+aj1HG9Xu0r2j+bj5TVT9elGxHW56PZYuFa
yRLaL/hIsjrxntdI9hjzcWgiC2cfk73mfKQ1m//odYfqhQ0fD2eMGy1QbiT/
96w3TG/2vEX1w5OP+idLNwv0X5L/+Vi3Znwoz/4V+Z8Pi8VbEi3dCHP52O4Z
VvflwGvyPx+53a0lh9cQzuDjUevT+Azlt+R/Pr66RCt8yiMs5aOuZJfcaH8z
+Z8P3+eftvzIIlzAR8OyWJcZH96T//nISQpR/vbiA/mf3/OeTVi3U5dwBR+D
5pc82pRK6yv5EAaqrayTkLxaPlZ7x36psiG6vIc+4JZ0/wbCzXxMbtF+LWXT
+jY+PunNCzZMfUf+5+NE9N+LEe9o/6xEWJdUfKkZT1ghEQbvqtPuZ70h/yei
ZcGj7R7ddB7qiRjTv0ZeZUdYK7Hnvbw0xMK/ifyfiJst4yo1BxCdnYgLVewz
u94QXT8R2/xmGk+zI4xE1Fa69/muSuuNE7Hm6cqhmcnkH/NE/Bm+x0h3Kq23
ScRgi7OKSgXkX6dEKLX5PzVrkJP/e/ZjMSNpyAbCnETM6jDOaQ2i+IlIRM3p
EQ+nD6X44SbiFvfFqBMrKd6EichWX3V8Zm+Kx4xEiEd51F1eQ/malYjqpU/f
X28mLE3EKYPEbDsbiu/8RFQOF5iGsig/ChJheOrnkIXbKT+KEvG1LPE7bxDd
b7JE+IX1bvgUTPFb0bO+tqba/yrttzIR7AzNP0l2hGt77L1cPzstnuyTJ8K+
v2PvpxvJnuZEbKxbMXuSBq1vS0TG3OrUsW1E70rE+SxRUOVhwiwB0h8+PN7K
Iv0KAnRE+fQenMfc/wL0Pat6p7iczkddAINTTUamNsSvJcC99x9v2r0hf2gL
MDDC0K7tO/mPLYCr+0Tv/gMpnvQF+LLL+Gv5WPI3BNg254rv1Vbyr7EAZRNq
/V7sIGwuwO2U/nm9RtF6GwFMBju4Kw8n7CTAI8cz2/qZEvYUwEyP+6bXN+Ln
CKD0QCa5cIFwhAAHD7f+vnqIMFeAQ9vexh1yIywU4PmZ9jf+VwlnCIBv2j4V
70l+lgAlgREtr5qY/BeAn1i1Y64u4XwB9uls+eNmQ/YWCGC70jZezsgrEuDw
1nvJFsWEZQIolN2wFe0jXCGA4qbh+e/r6PwqBSjgBfy6tpJwrQCZoq8fvx0i
LBfA+HxS/Ykm4m8WIP5g+WmLH4TbBKi/bT5ilxftr0uAhbIr86q7aH+sJMh7
jXv2fi3Zp5CEfs/3ZV73Jn6VJLw+6vNi3iDC6klQPxNvV3aUsFYS5pRI9p+L
In7tJEw3T9hyh6mX7CS4Hin61M3UH/0kdKzS8KvNIYwkaPzc+XTIEsLGSZCJ
HzbV7aP9mSfh54l+qr2LSJ5NEhzFY9OOiam+OSVhV27vr/uNqP559ujTOXVg
kBPROUl46vYjorWdcEQSLnaKzbo7SB83Cc2pY5KbvYkuTMJG3VrdmoNEz0jC
y2kLeLoxTP1PwrVN/o3fImh/0iRsOLvYk/2M7M9PwiW7Z6cO9aPzKUiC0az6
vJAZlB9FSUhX9D40+jPlrywJC91aL4QeJnpFEk61NMxxtCdcmQR31mw3roDy
rTYJL9R2s8evo3yVJ6F+RPS92GrK1+YkHPmr2rfTnOpXWxLsLrhd6pjH5H8S
9CzPrledR/pZyfi0Rf3qjFXEr5Dc0y+ytNQ+MvmfDPVBly1a1xJWT8b08knG
hy9RfdFKRsMaiKoeMv1/MtpjtWYquxCdnQzD37WdjveY+z8Z/lMtzq/dQPUT
yYjf2ffSaj3qN4yTMYk1tfT6beb9l4xm+1mHpo1j+r9kBO27XzyykeYPTskw
+9vYcsCM+lvPZLzZzr63ZRIzb0nGzqic4sEtTP+XjGLDT11bAglzkxGt0TtQ
yYF5/yWjaF/ugT0Dmf4/GUcWRg2I/o/kZyVj4sQ132M6aD/SZJzSXH5g2xri
z0+G63XT51c2MPU/GQcM050H+hIuSobDU8MEVaZ/kvXsxzp1m2pvsr8iGQkr
VIpvR1M/Wdkj38Bi1J43JL82GWG5ykYtzwjLk9HpJfYUDqfzau7xR/T9L77h
RG/rOQ+lNVZ6W2i/Xcm4dXzcg4lsZv4lxFBn8wFT3jHvfyHSI/UXDp9B8lSE
KPp1v5/4AZ2HuhCZ2gd2Ze9g5mNCHBj4d/nNAOb9L0Re+uQhS+7T/tlCmHz5
7qy+nrC+ENF2ycetjhCGEFrTRVKDGYSNhXgiNXR40U76zIUwWOihoFhE/rYR
wmqQoc0JFXo/OAkRKmsXOy+i+Ydnz35G5tdsNGPmLUKcvLch5cJCwhFCvOy8
oLHgAb0fuEI4Ojwe16JJ+oRCeJ2/p9JRw/hfCL3KqzsfnGDef0LcnRnZ/NGF
ef8LoXwjaFhVHN3v+ULsvX+lLG480/8L0bhHrfR8J+EiIWSrB6wYdpSwTAi3
w9XBz50pHiqEULAYe9Qlh3n/C9GkUd0waAbRa3vO3/32gkBmvbznvG+rHvzt
T/qbhZjj688NUiD+NiHUd6pOX6JM/uwSotepE73qw5j+XwQbpYPjDG8x/b8I
t7YkT7I9Sf5UEUF89HdFfi3Zqy7C1fLPd5MVCGuJwA4xOmirQfK0RUizzdQT
LmbmpSLoK74aaMLo0xfBqZX7m/+L5EOE0/V9TLankn5jEYxF8qKOWrLHXIRq
b+UTRiVkr40IZ8Mbz0SDef+LEO5Qv6cFtN5TBHv2G7vpxwlzRMhUl6s92kzr
I0Qova+X/SCe6FwRtr7Snnj9MckXirDbL2OnoxrhDBE09fU4/t20PkuEnft/
/lK+RnSpCHXZeRpzVpJ9+SLYymytVq6l8ykQIbh01Hs/L9JfJIKk7Gqi82Za
LxNh6ZAFi1bwaX2FCJMsRngtX8bkvwhDGzMK5/jQ+dSK0NeUXbDhIvHLe+xb
fTy7XwXz/heBL/04+Md7Jv9FqLKedS9qNuVPlwj7r52++vks1QNWCs6d1c2t
imTyPwV5A5cXB7bQepUUPBx1Paq+kPJNPQWTd4qt/vtA9VArBTcSEz7jMuWT
dgoqdukpX2Pmk+wU2F3/OIlVQev1U1BdbPeIm8m8/1PQKpsbWD2Z1hunIChH
HFTLzC/NUxD6efHtUcZEt0kBd4l3eYob8/5P6fHvD3djpv54pqCPypReY6Yz
858UlHY6jCl1o/OLSMHh8kusAZWM/1PwInbkgK11dJ7CFKj03XdtaTfz/k9B
161NR9urSX5WCmaGtxwu+f/5bAqcLK9HhaUz878UKLmeu8dl5qcFKZD3f7cp
eSjZX5TS835fa1uux8x/es577GePv8z6ihRk5dQKjrwkemXPfqt2NqjfIntr
e/hT0nSwjeTJU/By0hW1ia603+YUyNorNRIuEG7r8c+zHX0MxjD5n4Jj1Utk
fXOY+p8Kz1Hq9w+LmPxPhURUetomhZn/psJk+/6JZ8/QftRT8avskebn68Sv
lQq9K539Tq+n9dqpmLDLukQwmNazU2Fqavlu7Hii66eiJPqWPYeRj1RI9RXV
z5Qw899UpGk5xxWMIvvMU8EWp29WLqL6bpOKKmdbE/dTzPeFVDwN/frt7GLm
/k+FkVvscL1sks9JxZh21/R1E0l+RCrKv+itkmxl5j+paL8bnK31mLCwZ7/1
pV8Te1E8ZKSi932L4soIyvesVIRp15fxJzD5nwrrKYucFjPz2PxUWNhcvm86
nXBBKv6me1W1+9L5FqXiXZDZuIdnmfl9Kpa1JTRoXiD/VqTi2J7dUSwB3VeV
qbB/dzLV7BB9v6pNBco1R4R/pu+D8lRc9VznbpNNuDkViXcyfVceoHldWyom
FZT2HhFI9K5UrOnTuGuMHjP/S4NJo/vMBzo0r1NIQ1uK35G0WOZ7SBqCVQ++
PO9F31vU03DC0c7Uw+MK+T8NtgdmzRDtLSf/p/X03ybStd9pv+w0bNTsHqiV
yeR/GqYJbwj/NjP+T8Pin/2sjWqZ+p+G0Kcd1VpWdL7maXhZ+kp3fgz5wyYN
0esnZ9w8T3SnNDyYlqur/Yjonmn4FPrj42Cm3+SkQS1uyzdRFvWbEWk4qasU
G1lM/Sw3DXNjz/YbFci8/9PwvHTqwutNtD4jDRdHXlsxt5T66aw0DNDTCC6X
E5amIdt73qbGw3Sf56ehxSytafgc0l+QhgnLardmn2T6vzTc12rWW6nC1P80
vBpm3W2VwNT/nv10phjW/aF4rUzDmfGlp379InptGjSuPT2dt4POS56Gw3cP
jF4hYvI/DQ2eI267p5D+tjTsjT4fMOYX4a40aI7o+pijQvHJEoPXmDnzsQvZ
qyDGgnSzpIltZJ+KGOUbFhd13WT6fzEKHyQrDpbTeWmJYXbF6v2KIfS+0Bbj
VNPMNQ+Y9wFbjJ067jb8d8z8X4wTfOOPz6/T+wVihM24vcHYk+QZi9H2d4HF
5fXM/E+M+R+LRs24QPu3ESMxu3Sh2IHxvxjT+J1N+z8w838xDF154xznkT0c
MfZc6fdtiirjfzF0U7ct8Z5GmCvG/vZRj1yGk73CHjzGtGI8m5n/iLFm0X9h
blzSnyWGq7XPnf4cwlIxBm7Lz63PZeY/YqxQ9fjoncT4vwfbe+xdN5uZ/4gx
rHV78su+RJeJkVHomZlvRbhCjKFzjXof+MP0f2Jc0hE5fa5g7n8xWpz32lu8
Zfo/MUxHHnrYj5mXN/fYV2h3yIXD3P9iyHbUKLdZUr51iaHR3NHRVkP1hiWB
+PbmAzqKVK8VJGidldWHXc/0fxLwWgsO1vdl+j8JIl6c/JN4k+n/JXiQPeVt
M9P/aktwaBEna+AGyge2BItz3jpVZNN+9SW4aPRuwd2XZC8kyPer6V+6krCx
BC9VFz0svkH+MZfAPixnz2IzigcbCUyHRVwrnEXx5CTBzbiQ9yIpM/+TIGNw
W9yXv8z8V4K5Oy+mOy8lHCFB+iGhyJGZH3Il4OQumiCpJyyUoLii1dDrLeEM
CW5oL3ktXEE4S4Kvb0LcclxJn1SCc+ttud7DKZ7zJchMUR4evIPypUCCJVs+
KD3Wof0WSVCt3b2Hs4CZ/0kw+PDjWcP1yb4KCToHP3gzOZzolRKk5AurpGOY
978ES/+UrxrAI3lyCabOFt2ffZ320yzB7Dq7P7Y3CLdJMN5rsc+Vucz7X4KH
M3a5VpTTflnpuDpd3vjFiegK6Zil6hhoydQDlXQcZTsXDv9D/lFPh/rdQdYn
zpF/tXpwrp92gyNh7XS0V11q/8Cn/GGnw0jT3GR+KenTT0fZBJ0c49NkL9LR
e63g8NvXDYb/A1PAzW4=
     "]]}, 
   {Hue[0.6405831449920072, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mXdcze/7xzOiZGQX8jkS0seISGS8SikjRUkLp9IW7T3OqXM6p9O2yko+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     "]]}, 
   {Hue[0.8766511224918005, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnlczN/3x8cSISRKRCKSvbIV4WVLSdpIEkaLNmnaFy0z1dTMVNMgJNuo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     "]]}, 
   {Hue[0.1127190999915868, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnk81c/3x2n7tIn6fCpKJSnaaaONV4tUKoqEpGsX4dp37sK9l3tdKiQt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     "]]}, 
   {Hue[0.34878707749138016`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnk81N3bx6dNpEWbtGvH3aJFlNRHWkTZSmjRpLLH2HfGzBjDMCiVVtNK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     "]]}, 
   {Hue[0.5848550549911664, 0.6, 0.6], LineBox[CompressedData["
1:eJw9Wnc81f/3VxpKQ6XSdKUkLSqlIU9SNBRKqORmR+nam8u9uMNqUlKSSiVJ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     "]]}, 
   {Hue[0.8209230324909598, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mHk81F/Ux4c2LUratA+pqH4llWjzkZJ2QinU2Mk29p0xCzPMoEVEopS0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     "]]}, 
   {Hue[0.05699100999074602, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnk81N/3xydtWkil0ifVJCmt2rXxihSlshZSxq5I9n0Zy4wZZtAmrSRF
m1RE+6QUrYjSpkkbibQKLV+/R+f+Pv98Hs/OXc7rnnvuue87xjhtsXBV4HA4
Dd05nP/7/7//WvVNrxXND37iepX+ATW2Otc/5mcQKyJkoqFGqJ6QWAVq++1v
qgWeJFbF4r6hafN0jhGrYWtBK1e170Vidah3GBkVZp0h5uKOmFNucyKPWAOr
hjfvki46QayJYadnv1NPZe21cKe4Zy5n/3niCXDu+UWiVcZ4IoZ+r2mZZl5E
PBnucU2VxdtziadiwR7RrnLRcWIdWFdpnoqKZTwdatq7bGZF5RDPQOXpjUft
A7YSz4S2n4ZRSCPzZxZWrlC8optTQjwbtx5+ny8/JiOeA4d+Rp0hA64Qz4X7
wONTp30vI9bF544srh7/NvE82F4bNqugmtnnw+j7iMhX028RL0BLzPz50wfd
JF6IK61/eiQNKSdehGc9ZoUrWd4h1sN19Ud7ZB53ifXBXx5+/rgXswPT52Dn
jqj7/5gP2K1v3v9uNrMvxgSV3/3WZ9P4/MUQZ2rrrfzJ5jPARKuaW3M/lpLd
AANcz/dYUHid7Ibw6lyp8GbCDbIbYn7bOqXfK6k9Zwm6tdbVaNXQ+vGXIL4q
tN3Cnq2fEexNO4cnjaf14xshNKrAZ7L9NbIvhca583s3RbP+S5HXHH7wrT1b
v2XgjI7tPz+N1o+/DCq7lg99cITZjWFSZjKwZDQx3xgHd0SHfdtA/nJMUJUy
beVtfdLDN4FY2bCbspjNvxzen/cVhfS5SvblsO0wy+i8xvqvQHnF/t3fQpl/
K9CpsLmw3aWA7KZwdbrCrd7B9Jni++qwrY3BTP9KmCsHPr8Zmk/2lZi15Ns6
sz80H2cVnqgXmfXQZuOvwsLrDXNLz7D+q/Hl/te+b+uZfTVEyEvX0Wb+mSH7
dYfWi3iywwyndhwP0npI+5FvhnFpdXb+zsQyM2heGly/8CjbT+bg6zdXJIse
UH9zOA88uHXL4krqbw5bp6bpT1tof8nM8XRiq083W7Z/LKBsqWQa6knjwwJ/
fGbr5R1h622BfRs/1B+YTvGRWeDd0fs71L6w+FmCl+SyvfIN5QMsseDv8Hlu
o5n/ljg4+a/sZRPZZZZ4svXugpsPmH4rjGgPt1yZyPpboUzt59rjsmLqbwWr
0f77DtjT+sus8E13eYhR41Hqb43XOx+b+A9Mp/7WUB0b2ZKSsZP6W8O823iz
8nximTXWtmqYdUvI0v/Xfw12HFp/N+pDxj/GGnh62yx1LSM7fw2GBj3iGkuI
ZWtg0a703ilrK/Vfi5f+Mo3Yfnup/1pIA0dKZnz2oP5rUZujq7BsjoDmX4v5
OxeN8FiRRf7boLaWDy1BEPlvgx22V/WVj2yn/jYQynt9F63ZRf1t8HBb+UiL
c+w8tUXvv6qGTn60n2ELQ4GtXs4Htn62MM2P0va4Q/kus0XIx/sr7umy+Nth
WN1Zi7A62k+ww5qc4M9hHNpPfDtMjjqzEb0fUn87nPFuOhBjSPuLsw7m4lYT
YS0x1kFSUlodf7OK+q/DsI/vTL9+JbtsHTLPaN2XVdH4HHtoH3UuUF1eQf3t
YZsQciRAh84/vj3U147jzSglltlD4dKgbbmf2P5bjyQ1bqJVHu0nrMftX3+G
39nE9t96nFU6PSdlOumTrYeNg2fGx2TKB84G5BmlSjba0PjYgO22Cu0Jc8gf
/gbM9j/6dvP5e9R/A9Zyuw3JOUx2jgOMPuz4dGsdWz8HHPS8E1XOZfnngDGZ
v6d1TiK9MgcsepvENzzF1p+HkwVfX4/5Q3q4PEzrZl0RYUoMHvbvN/47aBzp
4/Gg3NTqYj+Tnfc8GG6fNOTPHToPM3mwzB2n996T8lfGw7buq0u1H5FdzsPO
qEuTFnRj55cjPtt13RE0ab9wHZE2J2vEiz37aX5HRK9Znqjodojmd0R+fsmJ
qkPbaH5HKMUmjVIzOULzO+KSzcHDr51of8occbDluvrs72SXO6LHUPWyMaMv
0/xO6Cv2E1vW0HnJdQK3dsOz6HjyH0649eiq1tA7xDwn/Hk8NyvgL7XnO2Hs
HMNOpViyZzrhbP5MHZ1SGl/mhJK0F++/TrtE8zvh0JfvP9ZmsPPHGStsY6uH
7iHmOqN1UPisxc5Ur+AMboaXl4Y37ReeM94IDrU+v8D2tzM8OalD7U5QfmQ6
Q1fdqn6vJ9llzqi2HDTO8THtF7kzSg2PvVp/mu0fF0zZffaFhQ/tD64L6mRp
1za8ZPnkggqzYXeLamh8nguybz/e9d/+aprfBS77tR2Nf9B8mS5Q77no9LsR
NL7MBYvrZpf8WUX+y13AS/3yfEN3tv9d0dy774iho2k/cV3xY+HzgmfO7Dx2
xVS/Pm79WH7xXIEbM24XPyA73xWLt2g+GmJL/TNdUZXd/Uf9FVYvXCEp5DRn
aFN+yV1xfqn4WNUYdt9yww+Ti5X9LWi9uW7Y07bYyUSLze+GyY65yp80WPzd
sDjT8W7pFFaf3KA8rC4x8i3Vz0w3tI9Y1efZNFZv3GB8QlFlozOtr9wNHd8d
pOdd2PnjjsAif7XYIspvrju+Nz5Plhxi9dAdKlHne0U7sPi742ufEX9tuJTv
fHf4qZlMW5VFnOmOjkfTFm9/R/ktc4e5v0WjUwbZ5e6wk7dPfl/I9HugadCD
rP7aND7XA/4qo6M67Fg998BZlewvGgtY/D1w0GNL20Evtv888L62xiZuUg3N
74HshR/XGvcnlnlgxZX3L+pn036Re+DCrvWnqrVoPM5G2Hm9qfw0ku2/jTA0
3L08P5LWAxtxblu8V0cf2o+8jQgbWSNz5lF//kYE/FLLH/D6Ec2/Ee8mWe3K
TGf1YiOeypZl/TrA5t+I65tXrRArEnM2oVB2deJ9HRqfuwk1zsNmrfQnfdiE
kMo3S3Za0n7mbYJ5R4+1t4ex83kT0kYP61ufRv5mboKPO7//f7PYebsJuQqn
/+srpPHlmxC4OtxrVgGNz/FERTZvw+PjbP09caV9ebXjQWJ4QnXtOK9IV6bf
E1cLow+dKGf10RPWm56+t1pO9kxPHMlGyvkCpt8TA85cCPYQEss98dRmXlHM
ELb+Xtjz8KL2xlFMvxfWL7ucl+nJ5vfChU+dZUN0af/wvBCU0/ln8nL2PeCF
7u/+HtcbTZzpheaD9/v9GUz5IPPC1YazBsOeU37KvWDtd0ZngAKrn5vRy/nR
jO0sX7mbsT3VJtE4m9WfzZjTc83JNT8pP3mbceNSD4WpG1n92YzFG02H9Pan
epK5GTq+Q2Ze9DpN82/Golmymho53c/km7FlWf+wqT7Z+v/m98buy9ryoz0P
/WOuN6JK9o11q0/7x/DGkkBRwbWxhf+Y540Dk+vM+1rs/sd8b0jKUlt6f0z/
x5neaC/inEpUTv3HMm+oxm4KvvJq4T+We6NDP91HsD6K9G+BjmHd+2n8YzT/
FiyLM5h/+cUlmn8LHullTdk3lZi3Bedb91//onCB5t8CFZvsoU/0L9L8W7DH
zTcnzZz8lXWNlzjj1vXTl2n+LZjLO58nyL9O+n0w2tPuhuuke/9YxQfWolPW
B6ffJX98IFWt+rF2z51/rOODc2EuoS+G3yT/fPDpwMGFJZdu/WMzH/RbcLpf
Uyb15/kg6d71ee27y/+xjw/+LPQMsvlbSv77wEPXfes1N2qf6oOsllmyCwnk
T6YPFGpaVw3VJHu+D5rXvWjcoU39ZT7o4bCxNrCA9FT44NCrPcvX2t8gvT54
+rjErvuxq/+41Qe9uucfW2hO/nJ8Ibxn5Zxqf5v0+6IHx8LLL4v85frCJO3o
i0598kfHF1P2DvU+VFxG+n3RMPMbJ+YO+WPmi+1/83Zczy4h/b6wDctK37KW
2McXyZ9LtteJrpF+X0QVPLpX50b2VF+s1J3xZ68+rW+mL+YN6Dbsjw75k+8L
93ETzdLP0/wyX+Sp1Sa4lNL8Fb4YZNd9l1EI+Sv3xdZ+3MoFusStvrAxyOuj
NIDWk+MHP9VtFuKY+6TfDzyP78a9vWg9uH5o0d+9+f3NB6TfDypXlCTp+g9J
vx8C/+7oXDy+kvT7odeKl0nr5xLz/KB3Ym9V9BViHz9YnHs/TTWP+vP9UP+4
YuHgy1Wk3w9aX2K29TMme6YfnPeb72hoqCH9fhj8X3erv5eqSb8fvsi3pRZo
15J+PwwqfbvrpPkj0u8HR/X4sY1l1L/VDxGDJ0oXOD4m/f4oL8ufcDuEWMUf
0SbmnwaeovZcf5imHbZwrCXW8YfK2HbPcjkx/HEsMvRgk4T6m/njxRB55riV
z0i/PxzOjlMf0v0l6feH1iNX9fVbifn+iLTInWaxWk76/ZEqmRk0XFBP+v0x
9sbhoJnbyZ7vD5vdK9d5db4g/V3zBTTtXl9aR/r98Xlm28jzBs9Jvz/CvzlV
tIwnbvVH2OKaGXfXEHMC4PBryTn5ziekPwCVzhyDB+G0ntwAXK16cdM7nVgn
ANt6T/XzMyZ9CEDagTkl62c/Jf0BGDujoM1wAI3PCwDP0ShmRwq19wnAnHrr
uvVB1J4fgP5RAQVfJOR/agCiDN/d/rCM9GYG4HAW75m6KdPfZU/LKWgX0frJ
ApB65ea+HRtekf4AFL+ZozFoP62fPACL+MLUyD3ErQGYbtlkEmX1lvQHYvOT
y/LvgjekPxAdDS67Ug6SnRuImyq3OT+fvyP9gbBsdrwco9VA+gPBdbC7986d
2CwQyj53RidGEvMCMWTxCq3sN8Q+gTiguXn6hBeNpD8QW6eNqzw/lTg1EOPf
DNXftYvaZwZiW8V0US6XOD8Qpx9ufm9aSv7JAnHt/s7ZnYXEFYHQPblliequ
96Q/EJKssdOSPWj81kCIb/13SfqNmBOEvvOim7yn0PgqQbBftrKuYicxNwhZ
iR3Xle0/kP4gqB4Sh50xaCL9QXAQvKh5X0d2syD0yHAN8C4g5gVBZ/hw/dyv
NJ9PEA4nL33/6j3TH4Qd8mNFFz/RfKlB0JqgrL3YhfzPDIJblHRPyiTi/CAo
v+s5NKGT2suCkObXNGilG3FFEAz6rDDbEUfjy7v8H+QQp/2D7K1BWHm36dGJ
pUx/MF6VqAaM9iZWCcZJux23fFuJucF428skEDJinWCc+pHRecaT9CEY75JU
ho1dyvQH49jcGdGuhtSeFwx57by6rzvI7hOMT+polScS84Mx49w4cfsh4tRg
jBkzKaqqijgzGKMyx6l7naHx8oOxbqTVzzMsfrJgDAxr+3hhNnFFMPSfzy8L
G8/0B+PZSL8/c0NpvNZguAw6YHBGyvSHwOhrm/a9CBb/EIx1r//1RcL0h+D5
mKe7Zt5h+kPwumRlV5Fj+kMQX1pWpWlNdrMQfHmzUVm5jukPwX2zih1WM5n+
EJQ5SVfkDaX9ww9BsXuGzX+HP5L+ECxsW6a9f0oz6Q9BVlWHap9lLaQ/BA4X
LherPyCWhaBk2Lq3r0w+kf4Q3HzVMqMjgezyEIyMFv5XdJTGaw2BbPpt3wZb
snNC8dg7RNgzi+wqobC++GjzkN9k54Zip23Ohz7ziXVCEaChG3loJc2HUHys
Ka+uLGwl/aFwTjcbmRn+mfSH4tuumD3eAmKfUJhNniQc2u0L6Q+F/vW32VO6
E6eG4oX3TWP5bWqfGQpLjdPW3fcQ54fiFD+qpo8HsSwU5jULE215xBWhSFPz
H2eYRP7IQ1G069w++Uni1lCEms7T+/aNmBMG63T+5SdGxCpheDJ+qNzhHenj
hmHUtpr0QS20PjphkGzhT666xvI/DBdkuqWvNhCbheG8nseAwfkUT14YYg1V
rju5E/uEQRzWqmxSRMwPw9frf2JyVrP4h8HccGWSdQRxZhjMNIO8+r6l8fPD
oOyl8e72fWJZGCLr0g5MtaH9VRGGYadeadwxIpaHwbtfcKFgL9v/YVgm8D0S
d5uYE46tOvdy5J0s/8PReUQlqo7td244vnJ0HcKzaD6dcGzsOUtgkMv0h0NW
Mrf7ok9MfzgGWA6tuzWH6Q9HVY1JpfEPtv/Dkbr2Yv0GXaY/HMca1hpEzWD6
w+GaIROVprH9H46me09bBpwle344Hofd1NT7wfSHY49BYUNaN2pfEQ73+o2t
zYVMfzieK3VbFPuQnf/huNDprfqQy/RHYI9p1pchU2g8lQgIN8Q+KWfx5Ubg
baLzDy92vulE4K/35WHJ01j+R+DU8NyeM/NY/kdAc/hb57QCVv8iMHR6S/KF
nkx/BETcMaf2aLHzLwId8/PfbrrJ6l8Ezr3wLP88kjgzArrPZq+zWsTqXwQy
czoulzxl538ETo+QJ/lUsPM/As8/2j7Mu8nqXwTmcba2TM9k538EFjysqe/z
hOycSNgMvBOp+43qu0ok/j7vUSZ3IeZGQmVhWqORL9VXnUi49q92WmxEjEiM
656sMECdxjOLROEs4xNLhxDzIpGREbBr2gJW/yPBfWUj1w8nOz8SEw0fvSuu
pvlSI7FDoc+no5to/MxIdJPpPN69kzg/EmOaL2yLvkH3FVkk7pyrbfty7zXp
j0Q/nm5M9hhieSQsrXqPz1Ol9q2RsO9pM7HtCNk5URg+Qs9+rTu7/0TBc2E3
x1PT2f0nCjd65y8tSiF/daLw2/tLytZzxIjCzCMZ2efukf9mUUjWqVvfexqL
fxQCrgs9wntRe58oTLTv7Jw0kemPgjz4yKkp/iz+UQiXOmsaTmf5H4WP+zqk
a/qw/R+Fo7uTT2goEMuiUFX381p/XdqvFVFQ7Vx/dEQBsTwKt910NnSbQ9wa
hSd/R3oOlrD9Hw0fbYOSlY+JVaJxPLtOueUmMTca/p46hyvHsP0fDaXAB9fT
X5O/iMaaF3NCZhiTP2bRkOgGt9kupXzkRePn/MglnY+JfaLx+/Dx+oGmxPxo
mDfunbPKgzg1GrL98vbz75j+aHx+UJ11YyXTH40fmu7zz+oz/dG4cHpra89F
xBXR0LMNH9KriumPhv2mmsoLyUx/NB465cvuPSLm8DFm9gsjzhdiRT5mtNzy
X3GF6p0KH7WPRhpazyL/1PjY2xzcrzGHmMvHjcz7DdF7aP4JfIwdVOs5lJ3/
OnyoWH0tPvmLxtfl42qcpubSMHZ+8mHaTfnP+GpaX2M+gh+9Vhuxi50nfAzY
cyckx5La2/AxdL3B7puD2fnKx+rGt0rcdeSPBx/f1Qd43Ktg9YYP7tJDa8Z/
pv4hfGwZI6xQHczuH3wUZxV7eP+l/iI+di0J2Ws+nOpfKh+8hS9Lhf9RfUzn
Y1/5AYPHzqw+89Fm2tHxvYI4lw8Tq5rXHf1ZveZjd+Sk8S6N1L+Yj5w9Xvfj
lFj95mPDqCVR0YeJy/iw/1aVHbeG2lfw4a3t+7xkK3EtHzv2f3p8M4LVdz7M
5wUHHtpM3MCH41Jtd4dkVu/5sF5wwnrNfBr/Jx8BenNWtJsTc2KQWbK/Y7gp
sWIMun0+X+h7klglBndXDTSs1qP7iVoMLi/J+pp5lZgbg9mjH/Zd20ntJ8RA
bZLSl82KZNeJQT+lLcf9hGTXjUH4U6s22xPEiEGP3A0/ez4mNo6B2ZFShW5s
PLMYDK4c/+24J41nE4Mfay2/rVcm5sXA/uhxhafqxB4xuLTtTulZy68U/xg8
njXcf9Fw4pAY5O13XTNhFbt/xWDCH7vCS+dpPlEM1v1MRkALu4/FYNrV/ODu
E6h/etd8yvmjUEKcGYOlZZE+FTrEuTG48fL1jffTiPNjENOtwU/ViLg4BlO+
N29W8COWxSBBS/ODxirishhc1N0W/+wBzV8RA/M9ar83zSV7bQxSGuJWza0g
lsfAYuuPv+WHiRtisNfyTsLAJuLWLn8ElS/mXvpG8e/y51L9hZP6xJxY1H4z
XHZxGrFiLCZNPxH93IBYJRaFTrz0D4uJ1WJx99OMAfZ3aHxuLH59SnX8O5V4
Qiz2ZZ46qnOexT8WapYt3WuLya4biwcZkmr1VGLEoqdy/sD+m4mNY+Et7f9O
aSSxWSx6D296pXGBxT8WdWe1fw/Yyu7XsShumvi8ieWjRyxeDA5tVqph9+1Y
eH0VvGj0IQ6JxQbL2yrv31J+8GNRZijRa+vO4h8Ly6czAx+eY/kfix+XNn4s
sWT5Hwtt63s7f6gTZ8ZioncVvyqE2ufGYvqEIMWmxcT5sWj1XjbXYi+dp8Wx
6GuZu+iBFft+iUXRiAXvK37S+VMWi6lh2y1Pj2D5H4vq2KdF+lJqX9vVv8ep
Ybxyai+PxR6joe3fuWRviIXm9a+20ey+3hoL5y09TP3vEf+MRY/ly+JsdhJz
4mBWkaWays5vxTicS2nSsxlG/qvEYbv/+XDLFeSPWhx0H++oUJ3Hvg/iwOmI
iPzSj+V/HGS2j1x3bSLWicPQk89PNq9m+R+HHd1NWhqns/yPwzojm889klj+
d42/p8+iuOvseyoOqzJGWXv8ILaJQ7+kRrlvMc3Pi8MyV/9TA/qS3SMObnEd
6grPaT184uCwLce0/TxxSBwWVHqEm2ZQf34c5ldbzY08RP1Fcbj4vMegRduI
U+OQp1eo4uHB4h8HD/N77dWGLP5xuOTK2XdEi8U/Ds2zVSrmT2Dxj0Py1QVz
Lt9g8Y/DnkErTz3+Tesvi8Pr4V/abupR+7I41Beu887uxeIfh2tP2nOGNLDz
Pw4+wR/HBs+g9ZLHYbdh9rwHb9j5HwetyuHNBbvY+R8HA68rtgfuE/+Mg/6h
SYpR09j5H4+vVeV6kcbs/I/H1tzylc4D2PkfD3VP1ynDWb1Si0f1+91BUceI
ufHIbRsodAtk8Y9H443AOMV+LP/jETliq0JkJYt/PI6sURmuxM57xOPskbNp
3vuovXE8Lv2qHfJhBbFZPOoLVHNeabH8j8fpixzB1vcs/+OxaNTC7boXWf7H
Q6mhwr2OrY9PPLK1/6j338byPx5r2g1u9LpKzI/H6nLt+3NiaHxRPIShaZNv
s3qS2jXf2Xdzv6wjTo/HnznOFWv4rP7Ho3hMUHFdG61vbjyenh3Td3QicX48
+D2dZyk7s/ofj7GvhZqWcyjesngc75Nz8d4nFv94aBscWpPux+Ifj3RxcNqq
Ayz+8ei/61P/SGtW/+MRrV7SkuPO4h+PziqPtI23abzWeIQZjNQaOp7FPx5p
50qemkxn3/8CLMkeqNHnO7VXFGDZqdmycE32HiDAK+OA9XWXaf+qCfBB++ba
os3s/ifAOsPtTmEL6T41QQCh9uW/k9ez72UBJAaWg98NYPc/Ad6ZdmrbGNB5
AwFO2D2cs2IFsbEAT5Qf99zdxt7TBHippRu/KYDd/wQoMZQs16pi9z8BzDk6
14e9JPYQIGHNphvdepAeHwH0xb5t5aXEIQKEBj+uOFfP8l+A1BnrLRS3sPwX
YIvv8pHFA1n+C5AeovXDLJ3lvwA6rf3Oah9h+S+A9b1v3nkvWP539S8+u0H9
Hou/AEc0X46WNLH4C5AyV/XHBLY/ZQJM4lUmuLL1LhPghruG6U4bFn8BzvHP
jcguo/FrBWit+9P9NKtHcgF0TcuT14xk8RegTnfpr1dnKF6tAjQ0nj2S/Yv6
/xTA9Zjthd9LWfyFiDA7nB7Sg1hRiJapC+8LFFn8hTARZPhWG1J/NSFKeza/
PPGQnf9CrDBxXihl/k8Qoue3zI+/2XrqCHHYucL6jD6xrhD23FfpO6cRQ4gf
A6KuCExpPGMh7im0VNRWk/9mQhTaSWMSftF+sxEiT8L9sK6VxV+IicFR7V7n
WPyFuNHvjMPC6ex7S4iANJ8+99+QPUSIAysG7hzpwe7/Qvxybnpan0Qs6tKj
eiflzgHiVCGyRj1f2aeNOL3L3yXN8Tnd2PeZEK7P7j3js/eZXCHerT9U9SyP
fa8JoTBCcVzvC+RPcVf7hxuEzpqs/guRFv1VfUswq/9C+Ou/V5kkZt9zQsjL
l7l1tyWuFUJzlZvAppp93wlhvfpm5ZjXxA1CjO24z5spZPEXYvlkHl7tJv7Z
5Z/WmLsNnrTenAQM7tfL9DBrr5iAIuMNYxRZe5UEnOs8+/T3WFb/E6A6NOfy
C/b+yk1AVquS7ex6Fv8EfNh8pnQyWPwT8MswT/NQDYt/V3vp8C8pl1j8E1Bo
0W2DWgaxcQI8VxutsN9G/pkl4M3BGY5GycQ2CeifF2v0aBWr/wl4+rD9omop
+eORgJ+ua93Kb7H8T4B55oaBH8xZ/ifgcUH5gW0T2fd3AvZ1HOcNHkLrK0qA
48hh9v6q7D0uAQvePPrc5wmLfwL+xuoMK/Jj8U/AQ99vhle3s/gnYPXcRf0n
JbP4J+CAt66jxUXqX5yAj18nZoqL2PtdApSChsydIicuS8BzQaJFv1cs/glI
eVT5IY+9d9Ym4MvqTxEpTux9LwHtowWPVHOJGxJQe7gp7WELe+/r8m9m3aOy
dLL/TMDaU2XfHhuw9w8R9AP9clu2su9/EZpWaCxZ/pa9h4iwal5/LxM++aMm
wvx12Z42quz8F0FkOaW593L2/S/CyPmtxSca2XuJCPYzHY68n8XOfxFOlEZY
GLSz389EWPvqfu31DHoPMhZh2fydo5vvsvc0EfYHWviVfCK2EYGnfc19dCF7
XxLhbbKX6I6U2KNr/F+9whbnsfc2EaSBisW6C4lDRBi7uPGS9Dh7fxJB8sHY
/eUFsotEsL3e4Visz36PEkGwSmHk2Ce0nukiDCqPGsbxYL/PiZA8eLTH95M0
Xq4I5fds2yPr2XulCNaK50M72PtfsQgpz8Yoha2h9jIRXPpHTQ5OIXuZCJmT
fb1zFdnvOSLMKHmoNZ+dV7UijL4cO+BkX3b/F2HA5MWDTrD39AYRVvolTc1g
v6+0ivBL1WTp4580/k8RvnTcHrvVmJgjxrkhGXFljfR+pyjG9GHqPUZdIv9U
xHi22UGjCNReTQy9A8bLnVTY+7gYU3ULPii6EE8QY9TQb21LZrD4izGmxm/V
5DVk1xVD+XL2uSxXFn8xbg2c1KtwFNmNxYgI6hc8jL0Hm4lx0N+q8nQtjWcj
hiC22+22evb7ohhOF+8fcThN7T3EUA8xnGszn8VfjOOGOs7LIsgeIsaivfOi
Ny4lO1+MszW/I19Gs/iLIfP6e+2XFelPFcO9brxSlh2tT7oYO3MW3Xp8lb3P
ivH87NMNemlkzxVjYm1gqu1t9nulGP9tmHpwP/s9uVgMu+dn73fuZe+3Yny5
5ihaXE32MjGKeh755M7eXyvE2L3swUXN0dS+Voxhr/v/0NzA3nfFEI244jJI
iewNYsRn1EimTiR/WsVwPFW6o+A+jfeza/3GZHfElpKdk4jhERbjXE+SXTER
9aYN0UfvsPfwRCicKJ18o4lYLRG/vlxAzDX2Pp6IcYrHGsL2Uf8Jiej04LS1
7Wfv5Yl4ZLUkz3c4tddNxGD5GxOjTvZ+nojGkKRxL44QGyeiu5aZ6qEU0mOW
iNDJJ2cnxlJ/m0Rk9nzkOfMN2XmJ0Dj/89isbdTfIxEvZUesy46w9+ZEDChN
DJ1uQhySiFHyQctGtdJ4/EQsemG6zbSQWJQIWcLqazN/sPf4RMxwNDTs85TG
T09ElNNEl9uDaf7MRFwsO/MxJ584NxG7noXaJV4gzk/E1+WThAMH03jFidBy
FC9aOJdYloi4vvsOxRYRlyXiP6PgdbvziCsSceGv4wVXPs1fmwiDIr3bA+KI
5Ylo3vUtF2+JGxKRY+CSNHktcWsiDtiNvH5+A4t/1/zmDZefTSX/OEno4H9q
FrD3f8UkjDxltqGXC/s9IAkXRxYbLcshVkvC1l1+vAdvaf9xk/DgYf0Yt1z6
+4oJSXBd7l9bepVYJwlfR0yziL5Ef5+hm4SJHw018xYSIwlHL+zIiF5HbJwE
BblD2pKD9PceZklw6FM1a/xwYpskDEy3vSR0o/a8Lrtq7ZnwGmKPJFydwrl6
I4vm90nCpTe9X4x0JA5JwntX06A2T2J+EqK/J/u5/qX+oiQk1XkcPBJH9tQk
qPR/1XjFmji9qz1nauHnVaQ/MwkTDPcc2Cgmzk3Cfs6d8ZU9WfyTcHlB84lY
W7IXJ6HWPeJJPp/GkyXhkILAvVSJ5i9LQqPs2e2T1qS3IgnLffN/4R1xbRLs
CuKHbL5HLO9aj0OvcPwYcUMSVvubXqrOp/FakzDvw9kA5ULin0kQ7jx+v9s8
mp8jgXOJqCqP/b2RogSjtN8Gah4jf1UkOCquGDqL+a8mwc0c9TFvrag9V4LQ
2AvfKw/Q+BMk6Nljc7+yImIdCVRWD0lZLWfxlyCoUaY0W4n6Q4L61U9yMiOJ
jbv8eWH4t+YrzWcmwcDGoKhpQlpPGwkOzuCttTOk/OBJwEv4Pjr5AbGHBAuH
6Bz70ped/xLMUOMERJmy81+Cz4LZourj7O9PJOj3eGWHwWx2/kuQjW/rmsIo
X1Il6KuaIJLuZee/BIut53nOqmXnvwR9dvr3r77H6r8EMRX73drZeZkvQXS+
sEeGOct/CW59PHD710B2/kugcVKnxuEt6S+ToJvGyP0TW4grJFBw/Ms/JWLn
vwS+D34+OVNJLJdAR2vLvmQ2foMEiy4Nn7qkmZ3/EljX1/MnJrD8lyBKL+CW
+2l2/kvhsv3gII108l9Rii0J2x4cVmL1X4rePWbr17wnVpPCkstpUJQTc6VQ
LbootlpGPEGKjK1//phuYn8vJcWnmG+yV79ofl0pivsqXMh6w85/KcynZbsd
q2TnvxSTw58f+zuP2Eza9T11wtBOSvvBRoqYKc+lh2xofXhSFPhU3R3PZ/nf
pUfz/NTZ7HzxkWKpw4jofQOpf4gUH25E38gOIOZ3tXcYrzXFhVgkxUY9k9Pz
PFn8pdh0Yv/+s7tZ/KWo9jfwPjqEOFOKSRP6JWSsYPGXYv7Z00antdnf60gR
Unv0YlsocbEUd/ua6OtH0/1FJkX37MXm1U7s/i9FRO71nY192f1fijm/5uTM
c2b3Pyl8CxrOjZSw+58UHB234itL2P1PioNPU03nsO/RVikOb59urjmB+KcU
YRo1EaJcYk4y/E6uSxh1mN3/k3Fbo7nefQ/7e4BkvOXtKH/Mfj9VS8a2dcsV
JrDfT7nJKDl5otUzi93/knGdO67vshrKJ51kyAZwpu1LJNZNxnhxx8JfDez+
l4zWeQYn5HOJjZNxYK75n4nd2f0vGfemKK9oGUNskwybxZw4n///fTkZ+9U2
7ptaTevvkYys+aKgXkJW/5NRpFTwJuIMq//JaCt0/6PaxO5/ydijt6rFazzp
ESVDum/6p+ci9nt0Mpbe3L4pZQy1T0/Gahvv9z8GsL9PSwZ/xKuavtrs/peM
B4OmSEuK2O/1XXo27ts7Zx/L/2T8aG7kW99hf7+XjFNbR8w3GMPqfzJsly/D
kB6s/idjZbtCz5cTaX/WJmOV0rCe1rvY/S8Z75b1P2xhR/nQkIy5IuXeOwex
+p8M+Y9NbRmsXv9MxpXBgdvUQ1n9T0Hk7v961iux+18K2lc7vG8tZvU/BfmW
3IOh7D6gloLf35+/mvaHmJuC0+OkzU/ZfXVCCniTvl77lMLufymoWXpGY10n
tddNgcWDJ4PFeeQPUjDV6baJQld9/h/cMP0g
     "]]}, 
   {Hue[0.2930589874905394, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3lcjN/3H3tEQpGIsmYtClF4F5GQFm1CU9K+TPte0zQ107QiJGGyVkQi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     "]]}, 
   {Hue[0.5291269649903256, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3lczN/3zh7qI0ubNXtZ2mxZ0mPPEomS8DHte037XtPMNE3NtFhLQmWr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     "]]}, 
   {Hue[0.765194942490119, 0.6, 0.6], LineBox[CompressedData["
1:eJw9Wnk81N/31q5FTcknWkQpWpQi0fqUklQIlVQatKDS2HdmMWYso5EWbZpC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     "]]}, 
   {Hue[0.0012629199899052423`, 0.6, 0.6], LineBox[CompressedData["
1:eJw9W3dczd//byAzGRFCEjKLQj7WUyrRuqkILS0p1W3vunVHt3vrVogyszOi
jArFJRQZZSQU146MyCjz1+/hdb7+8Xj2Oq/X67zGOe/zep1zR3kGL/VRUVJS
alZVUvr////9a51fWfZtfXHA9vP0B9xY1j9s41Ip4e5A1d3TvnpbCGvAUSh8
b9LvKOGB+K/GZvmvutOEtXBsd1/LrJISwtow1BtwsDG6lLAOtLSNl+y8d4qw
LvKsPQ1VKxldD2a2kQafdM4THouEOztzxmacJawP15GDsy5+KCM8AYeUDtx5
ByZvEgy78b78tNhLeArCPrbs5BmUEzbEJ075p7VFcsJTIa/mdj9QeozwNGTm
XrSY9/4MYSM89e119MmnCsLGmP9KY8L2aGbvdIx7VF19zpLNfwbiHlU8Ud12
nPBMPD+l//bLgSOETRDy0XbPgms7CM+Co7V61CHleML/YXvguWVNb/MJz0Y3
4/IQK5UNhOfA9JLflASvXfP/4bn4UIhv5V1KCM/DwQsqsXOyjxCej+9ifsG2
M4cJA2YP7n1wTiY6D7h5te7u+idCkr8A7QK1K7OsC4i+ACXWdjefeuwgflOo
DIkpXbVuK9FN8W6cc9faR3uJvhDVact8N1/bRvSFqO14X7A/hOk3g7TOVHp4
41Gim2FI4aKqVU+OE90c5qE7exveI8wzR5SLaq8dJieIboGsl2V9NtUUE90C
IU8zQk13lxJ9EaojuuzhN50k+iKoX/7m9PLzKaJb4h5/5bhzajSeZ4kny6O+
WuucJvpizOztm1Pud4boi1EaWVt18g2b/xJ8+fLsvUYA2ctbgpV5b8c0LqP5
KFnBL2WfVVtoEdGtsPGzRGuDRiHRrXFWkpmtF8vmbw2N/Lv9XDezeNrAOc7T
/qDPPqLbQOTU9d34eJKnZAvXlvqC9y+Zf2zRNnXeWyO7g0S3wzX+vfNlNxL/
xZNnh1bTKuckt0iicxD08OgO5WUb/9HBgYbk7a80myIaz0GwMlfyTZPyW87B
bPHDzx1KbD3aI+iJxW1wCMMesVE6P7xqDxK/PfqWq7hN8Kb1J7dHsGXYZF05
2y+WopuZ+ouK+j3EvxT5B2bUzi+n/OItBTd921KLZeQv+VJUqHUVP4qlfFFy
wOHxVk4Hxuz8h+GAlz37cJ/HMX84wPu0y7LkYFoPcgdMVkwusXBj68MRr+6m
95kgovyAI/btuBUdEMDWgyPmdnz9rrSGR/yOmHFSzWdUVRbxO0H4TPmbXgjJ
gxM0mzU1TnJYvJ1wOilx0vjpFD+5E+I0e/bvp0tYaRkeiub6l5yj8ViG67cW
Skb03UP8y3DrRmSNaukh4l8GG9ukQaeSWf4tR94F30dzA8kfWA4He5PfdzqI
zluOE31maOln7yb+5eDk7flcuZfyWckZh4X7Ik8asPk7Y/8ep445KCd+Z8Qe
sz1aXHGM+J3hmLFm56o8mp/SCogv23G2Z1K+YgVUho9Ttv5J8ngrsD9p5/MH
ayi/5SuwSCabPuk/lt8rsTj+TWSWuz/xr4R7ngPnSOghyp+VGJ9SelU1jvJJ
vhLOjwUtLRE7KX9W4a31kJONqbGUP6swqsHwmQXbb3mrsKm1Pm3FUfr+yFfh
yauKlJDhlcTvApXv07Xq+tP+DxeEmJ/ftEnvIvG7wD+225mf664QvwveXcnV
enXmMvG7IjDbnru5qYr4XZH3NqmgizLJ47ni5svFyZITbP24YnJ9Tk9B1iXi
dwNfr6v5+q6kD27gFeaM5u5k/G7oqvLd3L0n0++G7okJlS8WEVZyx5dR9XtU
+10lfnfob0w8vSnvGvG7o+rCjLOvwgjL3XF31jAlIaqJ3wN3T8SuW/OM6Doe
yO0Qpf1nxfzhgdvfzhzZeozm5+EB79zGg/6GxM/zgLTLu+djP5H+fA+o7bX1
dskhLPfAZsvRqz6rkjyFB36eeer2/SPJU1qNMxNf9fn7jvyhsxq7U/vlbrvO
9pPVSDh9MDVwzgXSvxqXWh5MmXSJ/M1bDYu1EdKb75j+1WgvaD30y5rZuxq+
B8/m/DWsIf2rMYj/evKhfrdIvyeOa24dYiS8Tfo90dT/1+0I3CP9npCe0wm4
sfc+6ffEi031M8adfED6PbEqSkkWP4ZwvidizK9k14x+RPo98Z+x3qcNTg2k
3xP6bWPuX75K8pS8kB5we/enHcSv44W8kUoxizbQeHhB/nTmPE74Q9LvBcWc
fjcfqjaSfi9s1Op58Vslycv3gkdfxzxnR5In98KL/ooS6UQar/DC7xD1mR8X
Pyb93igeZTd/+RTCOt6o5B73XONC4+GNJwu65K7/S3QPb7g3hpe6DG8i/d4I
e6/OXzeO5pfvjQ6jXFNze5qP3BuPLbRQPJD4Fd6I++ZTub9KQfp9kCz8NK1q
5FPS7wOPwrhLe/yJDh88/z7vQh8rmo+HD6bqv/ih+Er+4fmgdVRemfc15n8f
uCZlvjtRQ3S5D4wMno3I+kzzVfhAq2Vew9gSkqfki09Xu3CbrhDW8YWNe8fp
uxvIHvjizJ/lOjfNWPx9sUu8tctK73rS74spvU+N1LhBON8X7gsins9NI365
L8xnqdRf7s/87wu3xV0S5q1l9q/BYeck+7cpT0j/GgQ0fCvarcrsXwOTyTtX
iTYQ9lgDPUdf7qUtNJ63Bmumrii4vono+WswsUevDeMqyF75GnxZUHFMM4zp
X4O6RNutEjUWfz/kOei/3L+X2e+HGYPivB+7kz/hB1nMVx9LHvnTww++Rw4c
Lz/H8t8PqiY2BjlLmf/9oHwgVxifx/zvB7tBSiXjjxJd4Yff6bI7F+yY/9fC
Rfe/TOPuTP9abPE9dWx9LMu/tXC1nnKK10bryWMtLp3V4BfMYPm3FqPvm3Sc
qCR78tfi++fhd54EMvvXIvHnuY2blchfirX4c65R5eBXZr8/EnXPOsR5Mv/7
oyTRbkHmTMLwx8NFz/octmP+98eGgKzGvy6Eef4YYP+8qUsy878/6roqNy0r
JH65PxKUjU68DWH6/fG0RnEgqZnFPwBvCpcPyR9KWCcAr7Rt5DmrWPwDELmu
SnEwj+kPwHSHkS+6DmLxD8DwUVbTHAPIX/kBqL1kW/Zaha2/ADROdx/cbxTt
Z4oAjK4svPlFdJf0r4O62ye75fcJ66xD7mfdpFs3CGMdNDqm2yQNrCP965Bm
LovgC4nOW4djH+/b7GginL8Of8rz5P7DCMs75TlqxMfVEFasQ5DR+NiZd2i9
KAViaLiu5zMfmp9OICZWHbmXG0T6EAjR9TDvwKHXSX8gVKJFc+btoe83LxBS
adLFYH36vuYHwtNtZeugYva9DYTNTq+hOgEnSX8gejvXDT2wlJ0/guCf8bJL
+6hN/7BOEPbZeG/W7sj/hxEEu/2p63a7SP9hjyDou7ydfFs9h/QHofaL/0gL
/dR/9PwgJE08r79+C51f5UG4qHa7Stad6gtFEMr2fRz0LqmM9AcjrVTdsiaB
zm86wdhq8mivfnIM6Q/Gyj4LBwxtmkf2B8NmF+/6o7sL/tF5weh3+Ny7Dvs8
0h+ME4mZnBEudP6VB2NLYPG0RB/Cik6c8Mt+xyY6Dypxka/3zcewms6jGlzs
6GunXr2Ezr86XMyRxOhamFE9ZMiFss2EUcVidl7kwlRzudrzlrP/MIeLprpK
6QQbGu/BhVX2pVm/BHTe5HIx47Hxwj+72PmcC59jpb8vb6X6MIuLW+fq+e0f
N5A9XPx5EP7VefL+f7iIi8vymW3CFew82cl/Ytq7FwPJ37Vc7L+0a27kaTov
K7houXBg2P4VdH5t5SL1waUrRmWsfgxB4Y4ck2Ifio9GCI6+dtzQM+8c2R+C
7UNcnKo20/wNQ/Bo3gPfydpERwiGGjol6qtWkP0hMOav2647hOgeIUi8MPBj
RCj5gxuCnWq9eTb9WX0QgvtjiyuirUh+Vgh+Px2sMVZC88nvlCfcueReDMkr
CsGdV9zVbp8of+QhWDa13s5oAtlTG4Lix6Z64htU3ypCsEog+hWWQfJbQ9B0
KGhSuiarj0NxsZY/k7uF6kWNULy2toit20T+1glFbc+qYS7XRP/yzzAUTjOy
Td9/2kbrMxTub/yMlmdI/mFOKIbMU7mftYf6Lx6hqBk+XF/kRedvbijq1Kxz
bG6x+jAUJla2sV9N9v3DWaE4O2Rv+NGkA7SeQ/FT+9yUwvVUjxaFYq3FsC1G
NVTPyjv1Tw/P1fKg9Vwbipxxn/wXnaF8VoRCpblOveI7sz8U5s57cnqms/wP
g+eFX/UXOVTPaIThykMztzTWX9AJw6zPPm0Xf1A+GYahx/esAMuRcWR/GJxO
9K4RzdlI8Q9Dy87x0y0Gkz89wrBN2NZ1RQ3lHzcMSR3vlTuGsX5EGNyUn5mP
9yR/Z4VBMDv+kaAkmewPw9/QA8eVc7aS/WHYyB2Dq1rFZH8Ywj9rOo4yoH5V
bRjKfY6+ll2m+kcRhqNuxc8Ec8j/rWHIW71t1hlf4lcKx5nRB10+zid/a4Tj
SmvQKMU16nfphOOIWlFd3hfqZxmGw2Ful7O2YTQe4Xjz3LnfqXvUz+KE46/M
9/xs9xMU/3AMV8yY8cSB5sMNh+7Bx5rN60g/Lxy+v4wPVfQieVnh2Lf6tqX1
Nop3fjiK4nfdK9lH44vCIfXmL1EqLST7w9E2Y8mAx5ZErw3Ht24XS061Uz9Q
0an/+egptXKqJ1rDsUNe07IqhOoJpQj8eh7Zf85Pqkc0IqB7Jf/JpN/0/dCJ
gI1NaI32dapfDCOQ/0rP6a8Dq48iMDEmZmDKWsKciM79tUCTk8vqpQjYD+r1
8UoLfa+4EZBYBBVzA1j9FIHNZ2NTHhueI/sj4LunY7LOOJp/fgQCnK4NclWh
fmNRBAxN4/ZENJF8eQRqzy850zef6sHaCPQw+zZPT5fqH0UEHljxW9apE26N
wFBrvcBvEvqeKkVip0trVNNMwhqRUD6V/7bVm+ojnUgYjIuMc7GkesswEqcW
zPnw4iurdyNx4O7sytVxZA8nEn1Wq18NGnGD7I+EYSmfZ1BP8+NGYrK0zzDN
5VTv8SIxe4KO9pBEqqezInH8UmXJjGqSnx+J/OkWc4z6EH9RJIqdpn6MjmL2
R+LwVtGa8jCKZ20kSm/0WHyojH3vI9H6w9bzwjTib42E1bK32xZOo3pRKQoG
W1rKOVPJPxpRqJW1l2SMIHt0ovCpbXuGCo/ohlGICy3lPBjE7I/Cq9rhEyeZ
kjxOFGRDjG9EZNeS/VHYE/H0UXQa+ZcbhaaQY7lGMeQfXhTeppUvfmdA/s6K
Qk6kiUHjEuLPj4LOj+eCMTLCRVHoE7rwpsp4Vt9GQVxaJX25hurb2k7+sd89
rwbTeEUUKn7Ztn5JI9wahePclbnr1hJWisY13uI/40ppPhrRuLhAh397JtF1
opH0YU/EiENUHxtG4wSnwdz1GmFEo/fsi/NG36PzGicaKxx7macYEt0jGvyl
VwKSI8g+bjScHIbMs7AkOq8Tx4f9iVpHOCsaEY9zPh2QEM6PRqPN77hfP++Q
/dG48O6k6WFdOi/Ko1H9JOjto1Q6T9ZGIzOlNi/nJjtvduIKJ605zcTfGo1c
pdYMg+k0X6UY/A6wVx9wm7BGDMb4uB/lG9B4nRjcM/vkMH4cyTOMwbN1m90l
R0gfYhBuushkQDzVO5wY9F7gcvXlSXZejsGhDs2IvZo0X24MgpRD9Z58IMyL
wYFBw5033yN5WTHYOM5sccFedp6OgV/zZTPzOmZ/DG68H5v+sY7ky2NwdnFo
zUPOTbI/Bk0vQg6NbKB8VMQg905Q7pvzlH+tMZg6ps5uSRaNV4rFTaPRKxtf
U7w1YvF+W2pgsCfrh8Ti0F/d5JitLP6xsKiQhk2aS/NBLNTySms87xI/JxYj
D7cVPppG8j1icaWzSKv4TXRuLJ5nJo0YfpDlfyxs+3y85CQgnBWLZs7lxof+
lC/5sQiOuPhTeJLlfyzcI+7XKi8ie+SxCFN61WExhPxRG4vTT89eWKJK81XE
YuyHP5Oe1BNujYXpard++u9Z/ROHbq+2ONWwekUjDuefdV2jMpb1Y+Kwstu2
q7JpVH8axkF07qDXF3tWH8ZB6YJyiWA91ZucODhaqp27qc3qtTiYHds16Vko
YW4cRmreaHyyiPodvDi0RBePO+7/nOyPwzcvtx5xL4meH4edffh9py0l/qI4
3Fj9YbHuFcLyOFirHKyZzaHxtXF4X2VbFGz9jOyPQ/zsLjvSLxNujcMYSZ8+
4QNJn1I8Xq8vieY9Jn6NeGgeCjw9pZT1Y+LhNur3b3kNYcN45H+rlHXTJH7E
Y784aMHZKpLPicfGrx7tz08S3SMe8oebtkz7+oLsj0dCz9vhom+EefEY9+nG
+kQpsz8eb8tXbzDrT/T8eJik9nc+8YLoRfHwtb/BXzHrFdkfj7af/FUbPhOu
jYezWDrEtIqwIh5RAY/1FrQRbo3HT4/1VsrrXpL9CRjZMiflTg3p00jAm4eF
VRX2hHUS8Nt53lKXyYQNE7B96J9BVjLyBxJwZuDQ709HMvsTcNT6ZN2ktUT3
SMCFU12emIaw+Cfg3M/YuGEfWf2egIdGum0if8qfrASM9s64V36E1fMJ6NW/
30xRA9GLEjBteXV4iBmLfwJ+rR73IdGD+hm1CbjYs9WWe5H1uxKgGHq17fdD
orcm4OPS44/yONSfUkrEg2KFo/prwhqJMFabtf/YI9qPdBKhbpN07vkP6icY
JsKs8vGk2Pts/0uEYdibzI9thDmJ2Lu8esy3KMIeiYBozbgusWz/S8SO75kP
xg5l/bNErD025YxWX1p/WYnQMEsdFu/G+pmJGHDmklXGRxpflAjT7/uDojxZ
fykRl3uHKg9/SvOvTYRKjzUJVxpovSoSobM8SiYwI3+3dtLt+yybLCe6UhLU
H4vaAjRovWskQffzRM0RItKvk4TnX3IMuqgy+5OQm2OmvSaI9QeTUKhqMmpF
PfFzktDv9+59Ns6EPZLQun2K1bLLNH9uEq4Ujik6/7/9PwmXuomSe7uSPVlJ
KD6r0ZRcTvPLT8KFkcpDIpRIXlESpAr1Ot9W1t/pxANqm7UfMvuT4FLQq5eZ
iPWbknD8v+sKoxKS15oEm8nXMrw0WP+Nh9/W4X0H1RG9Ow9bj3hUHtclugYP
rQFlYwJXUj5p8RDtLyrkzGD9Mh4CnxzZN3Ai5aM+D/5DR74v/cn2Cx7EfdxS
5t6l9WHCQ2mP+vrLrwiDh1AtvW+en2m8JQ9uav1mP6gheRwefFMWi3StSJ8z
D/JxTqf0r9B8PHiQZT/4VCal+frxUNYwaMGcfPIHl4clz3rKsveQv6J5UG34
1l66h+UfDwkdvybmPyL/i3kIGlp9xuEmiwcP3jMcH164Sv7P5WH09SvRgly2
PnnoeWNj7HARzaeAh4X9DoaLYsifRTy8OVHfv2Ya0ct4cP9bH710Nq1HOQ95
PVor6o8SvZqH4ar3b0YFkP21PFz5G5y/sQeNb+DhxdbtfRujia7gYcpo7fZ+
HuSfZh5ipqlwzB+Q/a08LPPw6VWXSfNp5+F5ftJk7WSyRykZuwq7zhFkkH+6
J+P34UyZMJ2wRjImr3oU1s7yWSsZ+ur92yecYPtDMl4Prg1a5UDnAf1kLH73
a2HWKXZeSoZ9TkL2kS2U7ybJEExYlJNUxe5XkqG3YVfrSW2SZ5mMLh+5l0Mr
iZ+TjDPxNhHuXJLvnAyjcwZ3zaJYPz4Zn0NCLUdqkb1+yTCt/c/cagfZy03G
p1Nv441Z/zc6GVvLh7k2R7D9NxnzBf1XpCoTFiejY2mCysAMim9WMnZe1un3
o4j8n5uM8ksDtIcVsPXZSS9Ns6zjEi5Ixsdl8YNy1hN/UTJMDKcbj0okXJaM
tmc1x09bEpYnY/eTU/+FBBN/dTKGnyjx3V7C1nMyLhx6UHQulOgNyWieN+b0
wMFsf09Gi/pvk5N6LP7JOH+/w8tSle13yYjcO+PAvWM0//ZkOPew0Q/rwva/
FCQP5oS3vyR69xRcKGnNmLmY8ksjBZPN91u6pRFdKwW9e8/Hh4WkXycF2mvT
HtSvJqyfgvurps4t+0zzN0zBmHfqh8fcp3iZpGBp/sTX4rWE0SnPIrLIo47y
wTIFbru95GEahDkpsD05x7h0FuWfcwo+ZijW1vxi+2sKzr+X+NWx+wu/FAj8
qt4uaaT5cDvllc6f4VBL9OjO+VzWe97yguznpeBWbyczqyVknzgF5i2c89st
CWeloO5k5qRHeiz+nfP9Wuk6JImt/xR8W1H1veweW/8pWBk2y8piDY0vSsHJ
GIPKScos/ik4Zau/zXQgux9MQWW6a88Hg8jf1Z3yJze0jXCi+NWmQMc+7HGN
M+GGTvnVdYUPurP1n4KmwWVqh2+x+Kdg2Qb9u41RRG/t9Ef5r0bJcMLtKbjR
2BQYbk/7rRIfnurXTHddIHp3PhTFhXY6Gew8yEfYG7XSTz0Ia/ExUZIruj+b
3VfwcW39Z17kQqLr83Gkt7Quo5bohnykbfxcEXmcsAkfBlM8zR0K2P0GH8rO
z3pcZeddSz5uCmaax+Ww/Z+PxRq2fYQTCDvzkaS+v/yACdnrwceFvKOuAUvI
/358/IlQTI+5S/s3l49qjegJTSNof4nmo+iu8mTJdLb/89Hnduio3FSqD8R8
aE/J/nnoAKtH+XBqeyDK1qT9J7dzvl8/jnDbzepTPmwut/142ZVwAR/fbIvy
zASEi/iQffZIsQqj+qWMj2E6QamPVhBdzkfmbs3vSSpUv1TzcbZHU+L5vdR/
qOVjreDpVLsAqnca+Dj4LaVAmEf1kaJzfro1Wl8ERG/mI+NZttS2nPV7+LDE
juN+/akea+fjZcuvxPkLSb+SAKoeNt4tdoS7C1BczW2N/Ez2aggw0NJi7LcO
Wo9aAkzdrlfY6sj2fwGOb7cvub+esL4A3dtCemx8R+MNBeh9NEpZ3sj2fwEE
ytpfjVzZ+VGAdb+Wj9XzZutfgB627Ysrqtn6F6A54Yv02Cean7MAFn9/r970
k9XXArTc1vZ9r0/1o58AOzaFx9YNJHu5AmhmG91/Opn8Ey3A/cok28sFrP4U
dNZ/VQaL8yk+YgGsdyzSDVQl+VkC7Op/KahInfydK+g8f684719L9HwBnv1I
FgSuJnsKBFjePW2ORwur1wXwMt976OAL+p6Vddr75fKt0C+sfyFA5uegTSGs
v1EtgPro2ldfdhC9VoDqRZ9yfsaQ/IZO+TH5PRKWsvu8Tv7s30LhNJLfLMCv
wvbEfiwfWwU4u9TO47cR4XYB5om3a3Ttye7fhDg/xMdSICV53YVICOrqqse+
1xpCKGQq4x+9oflpCbEpfdOC+yXsvlCIQ/Pb32/0ov1cXwgTrZQYsxb2/RfC
bWn9jfZlhE2EGGrwKmCpH7tfFKLZcoKf+m2SbynEtfCH++trCXOEqJRx1WaO
ZfEXokdxctFqa+L3ECKocmvauXzCfkJUqM0tePaOMFeIBdkW996eJRwtRFj7
oA/PrrL7SyGiYh2apbNIn1iIgP2OvIMP2foXQsn1g6WLhMbnCpE9p0TZvJLd
9wvhvbzM+Jg+7TcFQnBMK7VjzpA/ioTIcQuuKF5P9DIhpjr1G8p1ZO8DhIg/
8zin9CPRq4WQ9/K8VOpBuFaI3PETmnW06PvR0Dk/edMU24fs+y+EWnhKxegM
+t40C9G6y0GlPoLGtwqR4vyzqoOdf9qFKDj4pW3qNHb/LUJL31mhkex72V0E
3ds5YS4vWT0kgtmN2r7ylTQfLRH6uq/bvdKL3deK8MPC6lXoNcL6Iqw+bt6j
eQGrl0TY9rrKuOsVstdEhJDy5KYJQ1n9JMItc3XXMWYk31KEK3umKmqGET9H
hDXye3/TPtB4ZxHsNmVMyjjM3iOIUH29l+LEcMJ+IjQ01DXZhbB6s1NfcFer
3g2EozvnG7Msc8t0Vn+J4Bkp4R4qoHiKRQhXP9F2ZArrx4lw2W702wGfCeeK
UOx+J7NwP/HnizBtkdze6y/hAhFeOk9YP1yb5lMkwrHTggXt31n8RbgzaZ5t
ELNXLsK54ABZP1YPVoswenZQQjs7f9eKYBVubho8jOLRIMKLpD9lHevIH4pO
+87PSm0zoPg1i/D46NXSojns/CdCn3HG5RXsfNEugtqPgFRD9l5BKRULtLX7
qB9i579UWEs2/w09R1gjFSH6e6pvaLP6LxW9YqbLbi5j9V8qMkbYZBduY+e/
VBSGhaaNecXOf6n4sNNqjdcbopukwr/SaY7+J/a+IxWSxp8/J2iRPstUrO55
JUWjnOicVCyfdWC8yWbyh3MqzEyihwcnsvWfCpsLiPnDofXrl4qolRHRtptp
/XJTsWLg1dsRmmz9p2LquJIvA5aw9Z+Kz3tH/vymz9Z/Kiomfr0UMoP1I1IR
O9eyG7zZ9z8V7ov5HqNyWX82FdOPPR3Bv0vfg4JOe3JqCm+zfmhRKu4aGNtp
rqP4lqVifX3zqGtdWf2eirqyEfbziyi/qlPRbmyesaCJ9NWmwmHc78DHRqSv
oXO+zjc73Iay/T8Vr9SmpYvYe4rmTnnXNp7xGczqv048dtqPUTcof9pTAZl5
mRN7n6Ykxp/5s3yy9xG9uxiXLfVDnkYRXUMM78MjPYb1Z/EXo3BY6TLjUez8
L4bB37URvv0pH/TFKJ8TG1wvpHgairHofp3qgweETcSY8DutZHspe18khmnL
uXjZRpqvpRhTu7gcmdeN9ZPEMJt+fY/+QbLXWYxHullvbusQ9hDDJs2roFc/
Fn8x+j937/OhG9v/xZj8u0/0CNa/jhZj5ADrYyPd2foXw2VcY0/x/+Ivxq+T
ZSUWUwlniXGpp0XJxP40PlcM/66Pn2ovYOc/Mex72czg/6DxBWIcOy53HvKX
ff/F2GEcVHPfh+wpE+NO70Kh80kWfzHaFiS7HLnN9n8xdh178pTTyu4zxDBq
cr3XKGbxF+PnoZNdckLY/YYYB2oqml+wflCzGCrZXerrvhNuFUOpyXVp9ScW
fzE29BqafyqXxT8NmwqfJveaQvHrngbVbWtmP7pBWCMNwYpFqzTXs/ovDdfm
Zsu2Dyd+nTQ4XvLrdrI3i38a5Ldzb65eTtgwDUuqL+h1Gczinwb9XZOSmtSI
H2noe9Z0z9cRbP9PA9eyy0Z3Oxb/NMjsnTbXC9n6T4Peofcpnk9ZfzENrpIU
k9ljKB5+aUjt85Hznkf+56bhXFjjU387wtFpGH1MJjzXhd0/paHcbI/hdmt2
/k/D8OLFEStC2Pe/k+6pH58TxtZ/GhyOvYi4zO4j8tPQMefe++dcOm8WpKHG
gfcsgE+4KA0tL17f75pP58eyNNze1ZHf/ybd18nTkOEyz/FsGY2vTsPJrV9u
NXjQ/WJtp3y7fvwY9r64IQ2LBoxv27CesCINNoru18zP0/1pcxryh+3b8OQL
3Ye2pqHJsVU1zIXuj9vTcKpg84+DH+m+WUmCbY5Xv4/uRff73SVQ7fvxsPEj
uk/XkOBSIic48jP93kZLggEvnpmkzaDfz+hIoBatvvv0BHovoC+Bq/FDjTAn
er9tKEHP0qbVShcJm3Tqm3TAZow0l+Ivwen9bcavuyfN/xd/CbI5Qx+0LKbf
F3EkGGVgjMChyyn+Enih52jRK/o9jIcEJct6f2ndv4viL0GepKdXngr93oAr
gYT3/I2tMb1fiZbgYKOwYtOy/RR/CVQ2a6pdExVQ/CXopnk4RVRF9mdJ0DJ+
cMmh3/R7m1wJDIyyv4yfJ6b4S5C78M0ff1P6vVSBBBh4/nG2Mb1fKpLA2HvP
my/jsij+EhidT9ZUbKH3M3IJNLd12z2jnd47VEvw9F1fu00JFI9aCZp5x7iX
pPS+o0GCSuG6VOWp9PsJhQTLrcdbTxDS+45mCQb9GLHg+T323kOCCInrn8IK
8n+7BCf2KUVOecF+DyWFQRg+dfWg9zjdpXgh5q55t5t+j6EhxZLGyQ7/mW6i
+Esxp2dwRmlkGsVfiorki/Z6q+j9m74UZwdYLBgRvv0fNpTi0K4fYaaO9N7J
RIrwaS5+uzbS7xMgRUSJad/vhUS3lEJ/moN0ZzXxc6SYG7OSFyOg33c4S+H7
e6L5/iH0Ps1DilEbvL5a29LvMfykeHLg7f31R9dT/KXQbn7+ZmFUyj96tBRn
BpbZ+p+i+PCkuHIw6mPTFo9/WCzFlsVCzSJ74T+cJUX9aR/35Gp635Mrhe1Z
RdAbWeY/nC/Fa9PN145vo9//FEhx0mDtXt932bT+pUhcdEReIKJ8LpOi6vqf
Vf1/UPzkUrzbl/53QCytn2op9r7B2+efCdd26t/5M3BMP3oP0iDFESd+u/8v
em+jkKKsvcmuiL2vapYiKDNv/JGJ9P6mVYrIlq71wS2UT+1S6La9HfXhNeW7
UjpuC1/muHjTeuqejjbnpiWb3rj8s0cjHb9dgy8ZRFG+aqVDZFUYXr6L3nvp
pKP58pLIlfcyKP7p2HnjZ73/bPKvYTrePvP7rqjuQ/FPR2r6ad92f3oPh3QM
5lQv+ZlJ77Ms0zHm4hJnh7n0HpKTjqyxF/WufaP3as7pmKytYiTbyN7XpePs
w0ZFjtF5in86dLOKH9ZvuvAPc9MhN3J9GyOVU/zTcWyfbc5Bv8sU/3Q8mKuI
7LqH3mOJ02F+SE3r+iP6vVFWOjxGhfhEz6X3drnpUGzJe71wFL0Py0/HUtnN
pflzKH8L0vHoe8vEXY3svWI61EPfhuruy/6Hy9IRNKX1SmwV+UeejkzdgceL
A9P/4ep0lM+Q1m1aSflbmw7B7WzJ6j0Un4Z0vO7+9mZJOO1ninQErN0xStFA
79+a03EnP2nO8EKaf2tnPNY5x2t+ovXT3hm/miObJtyk3zMpZaB4YIHPPW3a
n7pnQLtt8aWe0mha/xmYxXWd95n93kYrA1syLa5zRTQ/nQy0PdT0OrWU3m/p
Z2BO48KV00zpPZ9hBrLjv0YfKdxM+38GWnSCSrQrdtP+n4HKq/fiJpZSPltm
YOy4zXv+zKX9lJMBycOXon3P6PenzhnoV+O4oWYj5aNHBj64Z/ccF0Z0vwz0
5vu7//dORus/A6f+G5/89S7NJzoD/Apec0Ax7We8Tnkjv74bMZz0izPQ3LzB
oLmG3i9mZUBPbWnHf560vnIzcN7l49URXPqe5mcgtDzIedp0+v4WZGB7qJP8
tgn1l4oyoGqZNcJrN/v+d9Jvhx3bdZG938hAzcGUQoskOm9UZ2DaM8HU8T3Z
+T8DdTuuB+nEE72hk/+v/qan7H2NIgNvTsR90HYj3JyBQeUrYvQYvTUDXQz+
PGhj/ar2DFy3/hCaksv6fzJodV3PqU+g80x3GcZu46x6OZjoGjKYXzf+VvaQ
9X9kuHwrJu3LK9b/kaH+YNXV7ZPY/Y8M3qNnFAdVEjaUYWWjKLq3Jev/yGA0
5b0Gwtj9jwzn1RWDC1l/y1IGSeyrjlOsf8uRgTd8Ytar+YSdZXiXdcIpPJD1
/2VY1y1vdZQV8fvJwH/f+2LYNTovcmUQvjk9zyia3f/JsP/K8thfownzZLiT
wG+JGs7qfxm2rtFeYPSJ3f/JMGTHk9yxNez+T4bXz+f0GrWV9f9lmP3+3Q2n
IqIXyFB3quZEJbt/KpLhp7NlPkdB9DIZpsU73Jhrwfo/Mpi1LLHT0GH3PzIU
tTy8WLuJ5NfKsHBm3MSZr9n9jwyTYgNubWD1tUKG2JEf4sa7EG6W4azofsPo
3ey+V4bA8/ULBKeoXmuXwVHVs2SYMav/M1Gndkyyqgs7/2dCTfXLiVvs9wQa
mbgyeGfDHX2Sp5WJEv61QY9nsfN/Jj7XBT25KKV80c9E9FKO6uloyjfDTPTX
Xu/wooPWg0kmhFYL7PsMp/40MlHTV/f+y3e3zv8fW43xAw==
     "]]}, 
   {Hue[0.2373308974896915, 0.6, 0.6], LineBox[CompressedData["
1:eJw9mnlcje/z/4+9rCHJHqJkeadCZHmhElGJNkmnpD2d9r3O3ulUpyRJSNaS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 1000.}, {-3.235888554462507, 2.1910890328990145`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5080032163373337`*^9, 3.5080115879582987`*^9, 
  3.508013854301716*^9, 3.508033661926035*^9, 3.5080438216945124`*^9, 
  3.508103587336161*^9, 3.508103623309161*^9, 3.5081036617996283`*^9, 
  3.533064135454769*^9, 3.5376723370894203`*^9, 3.5397447582709985`*^9, 
  3.5400516848123465`*^9, 3.5400938874191976`*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Simulation of Stochastic Differential Equations", "Section",
 CellChangeTimes->{{3.5275665581855845`*^9, 3.527566572345394*^9}}],

Cell["\<\
The automatic generation of code described above excels in cases where \
options and other financial instruments can be priced analytically or by \
means of a simple approximation (e.g., binary root search). However, there \
are of course many instruments for which no known analytic formula or simple \
approximation exists. To handle some of these cases, particularly those with \
American exercise, we aim to generate code to simulate stochastic \
differential equations (henceforth SDEs).\
\>", "Text",
 CellChangeTimes->{{3.527566919914274*^9, 3.527567039672124*^9}, {
  3.527567285464183*^9, 3.527567302937182*^9}, {3.537674468594279*^9, 
  3.537674474015821*^9}, {3.539895117096031*^9, 3.53989515483919*^9}}],

Cell["\<\
For our purposes, we consider it sufficient to simulate SDEs of the form\
\>", "Text",
 CellChangeTimes->{{3.52756736951499*^9, 3.5275673876680284`*^9}, 
   3.5412703094458256`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[DifferentialD]", 
   SubscriptBox["S", "t"]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["f",
      FontFamily->"Courier New"], "[", 
     RowBox[{
      SubscriptBox["S", "t"], ",", "t"}], "]"}], 
    RowBox[{"\[DifferentialD]", "t"}]}], "+", 
   RowBox[{
    RowBox[{
     StyleBox["g",
      FontFamily->"Courier New"], "[", 
     RowBox[{
      SubscriptBox["S", "t"], ",", "t"}], "]"}], 
    RowBox[{"\[DifferentialD]", 
     SubscriptBox["W", "t"]}]}]}]}]], "DisplayFormula",
 InitializationCell->False,
 CellChangeTimes->{{3.5275673891571136`*^9, 3.527567389174114*^9}, {
   3.5275674341626873`*^9, 3.5275674905239115`*^9}, 3.5278235993419137`*^9},
 FontSize->18],

Cell[TextData[{
 "Wherein ",
 Cell[BoxData[
  SubscriptBox["W", "t"]],
  InitializationCell->False,
  CellChangeTimes->{{3.5275673891571136`*^9, 3.527567389174114*^9}, {
    3.5275674341626873`*^9, 3.5275674905239115`*^9}, 3.5278235993419137`*^9}],
 " is presumed to be a Brownian motion, and ",
 StyleBox["f",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["g",
  FontFamily->"Courier New"],
 " are the drift and diffusion coefficients, respectively. In the \
implementation presented in the following slides, this is taken to possibly \
be a system of equations represented by vector-valued drift and matrix-valued \
diffusion functions."
}], "Text",
 CellChangeTimes->{{3.5275674956332035`*^9, 3.5275675459850836`*^9}, {
  3.5275676462388177`*^9, 3.5275677897770276`*^9}, {3.527567827218169*^9, 
  3.527567874907897*^9}, {3.527567950087197*^9, 3.5275679512632637`*^9}, {
  3.5278236263114557`*^9, 3.5278236430684147`*^9}, {3.5279676005319242`*^9, 
  3.527967606959135*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The General Scheme", "Section",
 CellChangeTimes->{{3.5275679254247866`*^9, 3.5275679277089167`*^9}}],

Cell["\<\
The general idea of what we want the generated code to do is quite \
straightforward: discretize the SDE in the time domain and simulate it. In \
the code we will present, we employ the simplest simulation method available\
\[LongDash]Euler\[Dash]Maruyama. However, the code is quite modular and can \
easily support other methods. \
\>", "Text",
 CellChangeTimes->{{3.5275680912102685`*^9, 3.527568153508832*^9}, {
  3.5275682655382395`*^9, 3.5275683117618837`*^9}, {3.5412703999740033`*^9, 
  3.5412704229203157`*^9}}],

Cell["But, some difficulties arise:", "Text",
 CellChangeTimes->{{3.5275684139887304`*^9, 3.5275684361900005`*^9}}],

Cell[CellGroupData[{

Cell["\<\
How do we specify an output? The value of the simulation at the final time \
step is sufficient in some cases, but there are instances where we will need \
something more complex.\
\>", "Item",
 CellChangeTimes->{{3.527568465246662*^9, 3.5275685103922443`*^9}}],

Cell[TextData[{
 "We certainly want to introduce support for more variables in the drift and \
diffusion coefficients than just ",
 Cell[BoxData[
  FormBox["S", TraditionalForm]],
  FontFamily->"Courier New"],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["t",
    FontFamily->"Courier New",
    FontSlant->"Plain"], TraditionalForm]]],
 ". Unless we allow additional variables to be specified when the function is \
called, we will need to generate\[LongDash]and compile \[LongDash]new code \
for any change in option or ambient parameters."
}], "Item",
 CellChangeTimes->{{3.527568582986397*^9, 3.5275686654771147`*^9}, {
  3.527823654864089*^9, 3.527823659720367*^9}, {3.541270445463605*^9, 
  3.541270487921034*^9}, {3.541270518118761*^9, 3.5412705267292533`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Basic Usage", "Section",
 CellChangeTimes->{{3.5275926477518225`*^9, 3.5275926499729495`*^9}, {
  3.539742770444301*^9, 3.5397427715953674`*^9}}],

Cell[TextData[{
 "In the above examples we showed how it is possible to use the functions ",
 StyleBox["generateCUDAKernel", "Input"],
 " and ",
 StyleBox["CUDAFunctionLoad", "Input"],
 " to  construct a ",
 StyleBox["CUDAFunction", "Input"],
 " for any derivative that admits a mathematical representation. Here we will \
show how to solve the SDE corresponding to those derivatives that do not \
admit explicit mathematical solutions. We shall use two functions to \
accomplish this task. First we determine ",
 StyleBox["sde=generateStochasticIntegralFunction[name,drift,diffusion,\
valueFun,solveFor,wrt,vars,fold,nSteps,method] ", "Input"],
 "which describes the SDE corresponding to the underlying process ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["S", "t"],
    FontFamily->"Courier New"], TraditionalForm]]],
 " of the derivative ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     StyleBox["f",
      FontSlant->"Plain"], "(", 
     RowBox[{
      SubscriptBox["S", "t"], ",", " ", "t"}], ")"}],
    FontFamily->"Courier New"], TraditionalForm]]],
 " we wish to solve for. Then we feed that result to a stochastic integration \
function that utilzes the GPU called ",
 StyleBox["CUDAStochasticIntegrate[sde,inputs,corrMat,nSamples:16384,seed:\
Automatic]", "Input"],
 ". We can see the result of that last calculation by using the ",
 StyleBox["Histogram", "Input"],
 " function to see whether its ",
 StyleBox["PDF", "Input"],
 " conforms to the usual expectations. Once we have found  values for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "t"], TraditionalForm]]],
 " we can calculate the discounted ",
 StyleBox["Expectation", "Input"],
 " of the derivative function ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{
      FormBox[
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "r"}], " ", "T"}]], "\[DoubleStruckCapitalE]"}],
       TraditionalForm], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"f", 
         FormBox[
          RowBox[{"(", 
           SubscriptBox["S", "t"]}],
          TraditionalForm]}], ",", "t"}], ")"}]}], ")"}],
    FontFamily->"Courier New"], TraditionalForm]]],
 " and so determine the option value. We will consider four cases: standard \
Brownian motion, an Ito process, a stochastic volatility model (the Heston \
model), and a stochastic interest rate model (the Hull\[Dash]White model)."
}], "MathCaption",
 CellChangeTimes->{{3.5088714447587147`*^9, 3.5088714549667144`*^9}, {
   3.539893889442814*^9, 3.5398941580521774`*^9}, {3.5398943020204115`*^9, 
   3.539894321380519*^9}, {3.5398943563725204`*^9, 3.5398944130767636`*^9}, {
   3.5398944979406176`*^9, 3.539894557669034*^9}, {3.5398945996054325`*^9, 
   3.539894795509638*^9}, {3.5398948263254004`*^9, 3.5398949409179544`*^9}, {
   3.53989497720803*^9, 3.5398950379585047`*^9}, {3.539899068469037*^9, 
   3.539899128931495*^9}, {3.539912764271392*^9, 3.5399128048957157`*^9}, {
   3.539912890143592*^9, 3.5399130387360907`*^9}, {3.539913203201497*^9, 
   3.5399132485030885`*^9}, {3.539913281489975*^9, 3.5399135713245525`*^9}, {
   3.5399136928995066`*^9, 3.5399137397461863`*^9}, {3.53991394069368*^9, 
   3.5399139500192127`*^9}, {3.541270729178833*^9, 3.541270793011484*^9}, {
   3.5412708614353976`*^9, 3.5412708684207973`*^9}, {3.54127092074679*^9, 
   3.541270956608841*^9}, {3.541271033725252*^9, 3.541271034425292*^9}, 
   3.541271093160651*^9, {3.5413518169937906`*^9, 3.541351885497709*^9}, {
   3.5413519342074947`*^9, 3.541351942552972*^9}, {3.541351974264786*^9, 
   3.5413520199293976`*^9}, {3.5413520979568605`*^9, 
   3.5413520982768793`*^9}, {3.5413522092802277`*^9, 3.5413522694506693`*^9}}],

Cell["\<\
First we define the simplest non-trivial SDE\[LongDash]a standard Brownian \
motion.\
\>", "Text",
 CellChangeTimes->{{3.5275921329083753`*^9, 3.5275921846533346`*^9}, {
  3.5399139727395124`*^9, 3.5399140055393887`*^9}, {3.5412709626641874`*^9, 
  3.541270966340398*^9}, {3.541352368038308*^9, 3.541352368885357*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"S", ",", "t", ",", "T"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"simpleSDE", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"generateStochasticIntegralFunction", "[", "\n", "\t", 
     RowBox[{"\"\<simple\>\"", ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Name", " ", "--"}], " ", "this", " ", "gives", " ", "the", 
        " ", "names", " ", "of", " ", "the", " ", "various", " ", "generated",
         " ", "CUDA", " ", "functions"}], " ", "*)"}], "\n", "\t", 
      RowBox[{"{", "0", "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Drift", " ", "coefficient"}], " ", "*)"}], "\n", "\t", 
      RowBox[{"{", "1", "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Diffusion", " ", "coefficient"}], " ", "*)"}], "\n", "\t", 
      RowBox[{"S", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Output", " ", 
        RowBox[{"function", " ", "--"}], " ", "this", " ", "is", " ", "a", 
        " ", "function", " ", "on", " ", "the", " ", "process", " ", "being", 
        " ", "simulated", " ", "which", " ", "values", " ", "it"}], " ", 
       "*)"}], "\n", "\t", 
      RowBox[{"{", 
       RowBox[{"S", ",", " ", 
        RowBox[{"{", "0", "}"}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Name", " ", "of", " ", "the", " ", "process", " ", "being", " ", 
        "simulated", " ", "and", " ", "initial", " ", "value"}], " ", "*)"}], 
      "\n", "\t", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", "0", ",", " ", "T"}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Name", " ", "of", " ", "the", " ", "time", " ", "variable", " ", 
        "and", " ", "start", " ", "and", " ", "end", " ", "values"}], " ", 
       "*)"}], "\n", "\t", 
      RowBox[{"{", "T", "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Free", " ", 
         RowBox[{"variables", " ", "--"}], " ", "note", " ", "that", " ", 
         "they", " ", "can", " ", "be", " ", "used", " ", "not", " ", "just", 
         " ", "in", " ", "the", " ", "drift", " ", "and", " ", "diffusion"}], 
        ",", " ", 
        RowBox[{
        "but", " ", "also", " ", "in", " ", "the", " ", "initial", " ", 
         "value", " ", "and", " ", 
         RowBox[{"starting", "/", "ending"}], " ", "times"}]}], " ", "*)"}], 
      "\n", "\t", 
      RowBox[{"#2", "&"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"The", " ", "fold", " ", 
        RowBox[{"function", " ", "--"}], " ", "we", " ", "just", " ", "want", 
        " ", "the", " ", "end", " ", "value", " ", "here"}], " ", "*)"}], 
      "\n", "\t", "512", ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Number", " ", "of", " ", "steps"}], " ", "*)"}], "\n", "\t", 
      "\"\<Euler\>\""}], " ", 
     RowBox[{"(*", " ", 
      RowBox[{"Simulation", " ", "method"}], " ", "*)"}], "\n", "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.527592186551443*^9, 3.527592475615977*^9}, {
  3.5278564219682493`*^9, 3.52785643478648*^9}}],

Cell[BoxData["\<\"\\nC:\\\\Users\\\\wolfram\\\\AppData\\\\Roaming\\\\\
Mathematica\\\\ApplicationData\\\\CUDALink\\\\BuildFolder\\\\mkellyloanlap-\
10816\\\\Working-mkellyloanlap-10816-4912-10>call \\\"c:\\\\Program Files \
(x86)\\\\Microsoft Visual Studio 10.0\\\\VC\\\\vcvarsall.bat\\\" amd64 \
\\nSetting environment for using Microsoft Visual Studio 2010 x64 \
tools.\\nCUDAFunction-6492.cu\\nCUDAFunction-6492.cu\\ntmpxft_0000291c_\
00000000-3_CUDAFunction-6492.cudafe1.gpu\\ntmpxft_0000291c_00000000-10_\
CUDAFunction-6492.cudafe2.gpu\"\>"], "Print",
 CellChangeTimes->{3.5278722028650446`*^9, 3.5279646434789824`*^9, 
  3.5376674650211477`*^9, 3.539744869209344*^9, 3.5397454976312876`*^9}]
}, Closed]],

Cell[TextData[{
 "Now we call ",
 StyleBox["CUDAStochasticIntegrate", "Input"],
 " with our SDE simulator, our inputs, and our correlation matrix to get \
samples."
}], "Text",
 CellChangeTimes->{{3.5275924825393724`*^9, 3.527592519760502*^9}, {
  3.541271125096478*^9, 3.541271125688512*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpleSamples", "=", 
   RowBox[{"CUDAStochasticIntegrate", "[", 
    RowBox[{"simpleSDE", ",", " ", 
     RowBox[{"{", "1.0", "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "1.0", "}"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.527592509897938*^9, 3.5275925508382792`*^9}}],

Cell[TextData[{
 "We can then quickly examine the distribution of the samples using ",
 StyleBox["Histogram", "Input"],
 ", and confirm that they are normally distributed (as expected)."
}], "Text",
 CellChangeTimes->{{3.5275925606618414`*^9, 3.5275925973949423`*^9}, {
  3.541271140057334*^9, 3.541271140808377*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", "simpleSamples", "]"}]], "Input",
 CellChangeTimes->{{3.5275925997410765`*^9, 3.527592603926316*^9}, 
   3.527856442897695*^9}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], RectangleBox[{-4.6, 0.}, {-4.5, 1.},
     RoundingRadius->0], RectangleBox[{-4.5, 0.}, {-4.4, 1.},
     RoundingRadius->0], {}, {}, {}, {}, {}, RectangleBox[{-3.9, 0.}, {-3.8, 1.},
     RoundingRadius->0], RectangleBox[{-3.8, 0.}, {-3.7, 2.},
     RoundingRadius->0], {}, {}, RectangleBox[{-3.5, 0.}, {-3.4, 4.},
     RoundingRadius->0], RectangleBox[{-3.4, 0.}, {-3.3, 6.},
     RoundingRadius->0], RectangleBox[{-3.3, 0.}, {-3.2, 4.},
     RoundingRadius->0], RectangleBox[{-3.2, 0.}, {-3.1, 1.},
     RoundingRadius->0], RectangleBox[{-3.1, 0.}, {-3., 1.},
     RoundingRadius->0], RectangleBox[{-3., 0.}, {-2.9, 7.},
     RoundingRadius->0], RectangleBox[{-2.9, 0.}, {-2.8, 8.},
     RoundingRadius->0], RectangleBox[{-2.8, 0.}, {-2.7, 15.},
     RoundingRadius->0], RectangleBox[{-2.7, 0.}, {-2.6, 21.},
     RoundingRadius->0], RectangleBox[{-2.6, 0.}, {-2.5, 18.},
     RoundingRadius->0], RectangleBox[{-2.5, 0.}, {-2.4, 24.},
     RoundingRadius->0], RectangleBox[{-2.4, 0.}, {-2.3, 47.},
     RoundingRadius->0], RectangleBox[{-2.3, 0.}, {-2.2, 62.},
     RoundingRadius->0], RectangleBox[{-2.2, 0.}, {-2.1, 73.},
     RoundingRadius->0], RectangleBox[{-2.1, 0.}, {-2., 68.},
     RoundingRadius->0], RectangleBox[{-2., 0.}, {-1.9, 94.},
     RoundingRadius->0], RectangleBox[{-1.9, 0.}, {-1.8, 139.},
     RoundingRadius->0], RectangleBox[{-1.8, 0.}, {-1.7, 133.},
     RoundingRadius->0], RectangleBox[{-1.7, 0.}, {-1.6, 175.},
     RoundingRadius->0], RectangleBox[{-1.6, 0.}, {-1.5, 205.},
     RoundingRadius->0], RectangleBox[{-1.5, 0.}, {-1.4, 210.},
     RoundingRadius->0], RectangleBox[{-1.4, 0.}, {-1.3, 265.},
     RoundingRadius->0], RectangleBox[{-1.3, 0.}, {-1.2, 321.},
     RoundingRadius->0], RectangleBox[{-1.2, 0.}, {-1.1, 295.},
     RoundingRadius->0], RectangleBox[{-1.1, 0.}, {-1., 389.},
     RoundingRadius->0], RectangleBox[{-1., 0.}, {-0.9, 404.},
     RoundingRadius->0], RectangleBox[{-0.9, 0.}, {-0.8, 451.},
     RoundingRadius->0], RectangleBox[{-0.8, 0.}, {-0.7, 514.},
     RoundingRadius->0], RectangleBox[{-0.7, 0.}, {-0.6, 519.},
     RoundingRadius->0], RectangleBox[{-0.6, 0.}, {-0.5, 524.},
     RoundingRadius->0], RectangleBox[{-0.5, 0.}, {-0.4, 598.},
     RoundingRadius->0], RectangleBox[{-0.4, 0.}, {-0.3, 591.},
     RoundingRadius->0], RectangleBox[{-0.3, 0.}, {-0.2, 631.},
     RoundingRadius->0], RectangleBox[{-0.2, 0.}, {-0.1, 715.},
     RoundingRadius->0], RectangleBox[{-0.1, 0.}, {0., 694.},
     RoundingRadius->0], RectangleBox[{0., 0.}, {0.1, 683.},
     RoundingRadius->0], RectangleBox[{0.1, 0.}, {0.2, 585.},
     RoundingRadius->0], RectangleBox[{0.2, 0.}, {0.3, 604.},
     RoundingRadius->0], RectangleBox[{0.3, 0.}, {0.4, 639.},
     RoundingRadius->0], RectangleBox[{0.4, 0.}, {0.5, 611.},
     RoundingRadius->0], RectangleBox[{0.5, 0.}, {0.6, 556.},
     RoundingRadius->0], RectangleBox[{0.6, 0.}, {0.7, 544.},
     RoundingRadius->0], RectangleBox[{0.7, 0.}, {0.8, 451.},
     RoundingRadius->0], RectangleBox[{0.8, 0.}, {0.9, 429.},
     RoundingRadius->0], RectangleBox[{0.9, 0.}, {1., 421.},
     RoundingRadius->0], RectangleBox[{1., 0.}, {1.1, 391.},
     RoundingRadius->0], RectangleBox[{1.1, 0.}, {1.2, 324.},
     RoundingRadius->0], RectangleBox[{1.2, 0.}, {1.3, 289.},
     RoundingRadius->0], RectangleBox[{1.3, 0.}, {1.4, 269.},
     RoundingRadius->0], RectangleBox[{1.4, 0.}, {1.5, 245.},
     RoundingRadius->0], RectangleBox[{1.5, 0.}, {1.6, 204.},
     RoundingRadius->0], RectangleBox[{1.6, 0.}, {1.7, 170.},
     RoundingRadius->0], RectangleBox[{1.7, 0.}, {1.8, 131.},
     RoundingRadius->0], RectangleBox[{1.8, 0.}, {1.9, 120.},
     RoundingRadius->0], RectangleBox[{1.9, 0.}, {2., 109.},
     RoundingRadius->0], RectangleBox[{2., 0.}, {2.1, 82.},
     RoundingRadius->0], RectangleBox[{2.1, 0.}, {2.2, 69.},
     RoundingRadius->0], RectangleBox[{2.2, 0.}, {2.3, 45.},
     RoundingRadius->0], RectangleBox[{2.3, 0.}, {2.4, 44.},
     RoundingRadius->0], RectangleBox[{2.4, 0.}, {2.5, 25.},
     RoundingRadius->0], RectangleBox[{2.5, 0.}, {2.6, 34.},
     RoundingRadius->0], RectangleBox[{2.6, 0.}, {2.7, 20.},
     RoundingRadius->0], RectangleBox[{2.7, 0.}, {2.8, 16.},
     RoundingRadius->0], RectangleBox[{2.8, 0.}, {2.9, 9.},
     RoundingRadius->0], RectangleBox[{2.9, 0.}, {3., 11.},
     RoundingRadius->0], RectangleBox[{3., 0.}, {3.1, 7.},
     RoundingRadius->0], RectangleBox[{3.1, 0.}, {3.2, 4.},
     RoundingRadius->0], RectangleBox[{3.2, 0.}, {3.3, 1.},
     RoundingRadius->0], RectangleBox[{3.3, 0.}, {3.4, 3.},
     RoundingRadius->0], RectangleBox[{3.4, 0.}, {3.5, 5.},
     RoundingRadius->0], RectangleBox[{3.5, 0.}, {3.6, 1.},
     RoundingRadius->0], RectangleBox[{3.6, 0.}, {3.7, 1.},
     RoundingRadius->0], {}, {}, RectangleBox[{3.9, 0.}, {4., 1.},
     RoundingRadius->0]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{-4.6, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{-4.6, 4.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.5397455194285345`*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic Option Pricing", "Section",
 CellChangeTimes->{{3.5275926477518225`*^9, 3.5275926499729495`*^9}}],

Cell["\<\
Let\[CloseCurlyQuote]s examine a slightly more complicated case by using SDE \
simulation to price an arithmetically averaged Asian option under the Black\
\[Dash]Scholes model.\
\>", "Text",
 CellChangeTimes->{{3.527592661907632*^9, 3.527592699894805*^9}, {
  3.541271168426956*^9, 3.541271174681314*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[DifferentialD]", 
   SubscriptBox["S", "t"]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "-", "q"}], ")"}], 
    SubscriptBox["S", "t"], 
    RowBox[{"\[DifferentialD]", "t"}]}], "+", 
   RowBox[{
    SubscriptBox["v", "t"], 
    SubscriptBox["S", "t"], 
    RowBox[{"\[DifferentialD]", 
     SubscriptBox["W", "t"]}]}]}]}]], "DisplayFormula",
 CellChangeTimes->{{3.5278510986917863`*^9, 3.5278512270581284`*^9}, {
  3.5399131683065014`*^9, 3.5399131830103426`*^9}},
 FontSize->18],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "S", ",", "t", ",", "r", ",", "q", ",", "v", ",", "spot", ",", "T"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"aaSDE", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"generateStochasticIntegralFunction", "[", "\[IndentingNewLine]", 
     RowBox[{"\"\<AsianOption\>\"", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"r", "-", "q"}], ")"}], "*", 
        RowBox[{"S", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"v", "*", 
        RowBox[{"S", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"S", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"S", ",", 
        RowBox[{"{", "spot", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"spot", ",", "T", ",", "r", ",", "q", ",", "v"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"#1", "+", 
         RowBox[{"#2", "/", "512"}]}], ")"}], "&"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Effectively", " ", "keeps", " ", "a", " ", "running", " ", "average", 
        " ", "of", " ", "the", " ", "price", " ", "of", " ", "the", " ", 
        "underlying"}], " ", "*)"}], "\[IndentingNewLine]", "512", ",", 
      "\[IndentingNewLine]", "\"\<Euler\>\""}], "\[IndentingNewLine]", "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.527592701471895*^9, 3.5275928652002597`*^9}, {
  3.5278564565704327`*^9, 3.5278564678601017`*^9}, {3.527857007819065*^9, 
  3.5278570083140306`*^9}, {3.527857154515854*^9, 3.527857157826983*^9}, {
  3.527857345253139*^9, 3.52785734539566*^9}, {3.527857439557547*^9, 
  3.527857439710382*^9}, {3.527857498628735*^9, 3.527857501034048*^9}, {
  3.527857629096779*^9, 3.52785763056026*^9}}],

Cell[BoxData["\<\"\\nC:\\\\Users\\\\wolfram\\\\AppData\\\\Roaming\\\\\
Mathematica\\\\ApplicationData\\\\CUDALink\\\\BuildFolder\\\\mkellyloanlap-\
10816\\\\Working-mkellyloanlap-10816-4912-11>call \\\"c:\\\\Program Files \
(x86)\\\\Microsoft Visual Studio 10.0\\\\VC\\\\vcvarsall.bat\\\" amd64 \
\\nSetting environment for using Microsoft Visual Studio 2010 x64 \
tools.\\nCUDAFunction-840.cu\\nCUDAFunction-840.cu\\ntmpxft_0000215c_00000000-\
3_CUDAFunction-840.cudafe1.gpu\\ntmpxft_0000215c_00000000-10_CUDAFunction-840.\
cudafe2.gpu\"\>"], "Print",
 CellChangeTimes->{3.527872268838044*^9, 3.527964682915238*^9, 
  3.5376677003526783`*^9, 3.539745584096233*^9}]
}, Closed]],

Cell["\<\
Once again we generate samples, after defining our inputs.\
\>", "Text",
 CellChangeTimes->{{3.5275928679604177`*^9, 3.5275929283978744`*^9}, {
  3.5412711955765095`*^9, 3.5412711959445305`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SpotPrice", "=", "35.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StrikePrice", "=", "35.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Expiration", "=", "1.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"InterestRate", "=", "0.08"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dividend", "=", "0.03"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Volatility", "=", "0.30"}], ";"}]}], "Input",
 CellChangeTimes->{{3.52759293444022*^9, 3.5275929685131693`*^9}, {
  3.5278571601639643`*^9, 3.5278571603678093`*^9}, {3.527857347632771*^9, 
  3.527857347826064*^9}, {3.5278574415941067`*^9, 3.52785744223981*^9}, {
  3.527857519476303*^9, 3.527857519695304*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"aaSamples", "=", 
   RowBox[{"CUDAStochasticIntegrate", "[", 
    RowBox[{"aaSDE", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "SpotPrice", ",", " ", "Expiration", ",", " ", "InterestRate", ",", " ",
        "Dividend", ",", " ", "Volatility"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"{", "1.0", "}"}], "}"}], ",", "131072"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5275929746415195`*^9, 3.527593008021429*^9}, {
  3.527858071866314*^9, 3.52785810804667*^9}}],

Cell["\<\
Then translate them into a price for a call in the usual fashion.\
\>", "Text",
 CellChangeTimes->{{3.527593012380678*^9, 3.527593025048403*^9}, {
  3.527593135372713*^9, 3.5275931395969543`*^9}, {3.54127120887327*^9, 
  3.5412712092892933`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
    RowBox[{"(", 
     RowBox[{"aaSamples", "-", "StrikePrice"}], ")"}]}], "]"}], "*", 
  RowBox[{"Exp", "[", 
   RowBox[{"-", "InterestRate"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.527593026682496*^9, 3.5275930445725193`*^9}, {
  3.527593130187416*^9, 3.5275931320645237`*^9}, {3.5275932956398797`*^9, 
  3.5275932981100206`*^9}, {3.5278576820917807`*^9, 3.527857686926936*^9}, {
  3.527857878017959*^9, 3.527857939569208*^9}, {3.527858053866287*^9, 
  3.527858056485496*^9}}],

Cell[BoxData["3.4504828860671792`"], "Output",
 CellChangeTimes->{3.5278722850910444`*^9, 3.5279647088447213`*^9, 
  3.537667881962837*^9, 3.5397458414989557`*^9}]
}, Closed]],

Cell[TextData[{
 "And compare to ",
 StyleBox["FinancialDerivative.", "Input"]
}], "Text",
 CellChangeTimes->{{3.527593055726157*^9, 3.527593060826449*^9}, {
  3.541271216408701*^9, 3.5412712168567266`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FinancialDerivative", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<AsianArithmetic\>\"", ",", "\"\<European\>\"", ",", "\"\<Call\>\""}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", "StrikePrice"}], ",", 
     RowBox[{"\"\<Expiration\>\"", "\[Rule]", "Expiration"}], ",", 
     RowBox[{"\"\<AverageSoFar\>\"", "\[Rule]", "SpotPrice"}], ",", 
     RowBox[{"\"\<Inception\>\"", "\[Rule]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<InterestRate\>\"", "\[Rule]", "InterestRate"}], ",", 
     RowBox[{"\"\<Dividend\>\"", "\[Rule]", "Dividend"}], ",", 
     RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", "SpotPrice"}], ",", 
     RowBox[{"\"\<Volatility\>\"", "\[Rule]", "Volatility"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5275930643616514`*^9, 3.527593123892056*^9}, {
  3.527856648665687*^9, 3.5278566531650887`*^9}}],

Cell[BoxData["3.331622126367285`"], "Output",
 CellChangeTimes->{
  3.5278722908800445`*^9, 3.5279647136049933`*^9, 3.537667912222863*^9, {
   3.5397458544226947`*^9, 3.53974585888395*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Performance", "Section",
 CellChangeTimes->{{3.5275931905128665`*^9, 3.527593191589928*^9}}],

Cell["\<\
Of course, the foremost question is whether or not the generated code can \
offer a substantial performance improvement. The answer on most systems\
\[LongDash]even with a modest GPU\[LongDash]is yes.\
\>", "Text",
 CellChangeTimes->{{3.527593195271139*^9, 3.5275932460240417`*^9}, {
  3.54127124576938*^9, 3.541271259785182*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"aaSamples", "=", 
    RowBox[{"CUDAStochasticIntegrate", "[", 
     RowBox[{"aaSDE", ",", 
      RowBox[{"{", 
       RowBox[{
       "SpotPrice", ",", "Expiration", ",", "InterestRate", ",", "Dividend", 
        ",", "Volatility"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"{", "1.0", "}"}], "}"}]}], "]"}]}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mean", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Max", "[", 
        RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
      RowBox[{"(", 
       RowBox[{"aaSamples", "-", "StrikePrice"}], ")"}]}], "]"}], "*", 
    RowBox[{"Exp", "[", 
     RowBox[{"-", "InterestRate"}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.527593248882205*^9, 3.5275932925207014`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0390022`6.042634098494585", ",", "3.4938954940989`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.52785813941625*^9, 3.5278723021950445`*^9, 
  3.5279647592026014`*^9, 3.537667975309171*^9, 3.5397458920258455`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AbsoluteTiming", "[", 
  RowBox[{"FinancialDerivative", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<AsianArithmetic\>\"", ",", "\"\<European\>\"", ",", 
      "\"\<Call\>\""}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<StrikePrice\>\"", "\[Rule]", "StrikePrice"}], ",", 
      RowBox[{"\"\<Expiration\>\"", "\[Rule]", "Expiration"}], ",", 
      RowBox[{"\"\<AverageSoFar\>\"", "\[Rule]", "SpotPrice"}], ",", 
      RowBox[{"\"\<Inception\>\"", "\[Rule]", "0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<InterestRate\>\"", "\[Rule]", "InterestRate"}], ",", 
      RowBox[{"\"\<Dividend\>\"", "\[Rule]", "Dividend"}], ",", 
      RowBox[{"\"\<CurrentPrice\>\"", "\[Rule]", "SpotPrice"}], ",", 
      RowBox[{"\"\<Volatility\>\"", "\[Rule]", "Volatility"}]}], "}"}]}], 
   "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.527593304444383*^9, 3.527593312859864*^9}, {
  3.527858145540831*^9, 3.527858149755581*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.6730385`7.279584901493075", ",", "3.2812608783586605`"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.527858142413919*^9, 3.527858150885583*^9}, 
   3.5278723079070444`*^9, 3.527964764293893*^9, 3.5376679534779882`*^9, 
   3.5397458896837115`*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Systems of SDEs\[LongDash]The Heston Model\
\>", "Section",
 CellChangeTimes->{{3.527850635803311*^9, 3.527850640135558*^9}, {
  3.541271290664948*^9, 3.5412712935561132`*^9}}],

Cell["\<\
Here we quickly take a look at how the Heston stochastic volatility model can \
easily be implemented in this code generation framework. First, let\
\[CloseCurlyQuote]s define the Heston model.\
\>", "Text",
 CellChangeTimes->{{3.5278506430877275`*^9, 3.5278506670881*^9}, {
  3.5278510653898816`*^9, 3.5278510932784767`*^9}, {3.5412712965532846`*^9, 
  3.5412712969853096`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[DifferentialD]", 
   SubscriptBox["S", "t"]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "-", "q"}], ")"}], 
    SubscriptBox["S", "t"], 
    RowBox[{"\[DifferentialD]", "t"}]}], "+", 
   RowBox[{
    SqrtBox[
     SubscriptBox["\[Nu]", "t"]], 
    SubscriptBox["S", "t"], 
    RowBox[{"\[DifferentialD]", 
     SubsuperscriptBox["W", "t", "1"]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[DifferentialD]", 
   SubscriptBox["\[Nu]", "t"]}], "=", 
  RowBox[{
   RowBox[{"\[Kappa]", 
    RowBox[{"(", 
     RowBox[{"\[Theta]", "-", 
      SubscriptBox["\[Nu]", "t"]}], ")"}], 
    RowBox[{"\[DifferentialD]", "t"}]}], "+", 
   RowBox[{"\[Xi]", 
    SqrtBox[
     SubscriptBox["\[Nu]", "t"]], 
    RowBox[{"\[DifferentialD]", 
     SubsuperscriptBox["W", "t", "2"]}]}]}]}]}], "DisplayFormula",
 CellChangeTimes->{{3.5278510986917863`*^9, 3.5278512270581284`*^9}},
 FontSize->18],

Cell["\<\
We make some replacements to account for the fact that Greek letters are not \
acceptable variable names in CUDA.\
\>", "Text",
 CellChangeTimes->{{3.5278506430877275`*^9, 3.5278506670881*^9}, {
  3.5278510653898816`*^9, 3.5278510932784767`*^9}, {3.527851268332489*^9, 
  3.5278512887166553`*^9}, {3.541271305433793*^9, 3.541271308904991*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"S", "\[Rule]", 
   RowBox[{"S", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
  RowBox[{"\[Nu]", "\[Rule]", 
   RowBox[{"S", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
  RowBox[{"\[Kappa]", "\[Rule]", "kappa"}], ",", "\[IndentingNewLine]", 
  RowBox[{"\[Theta]", "\[Rule]", "theta"}], ",", "\[IndentingNewLine]", 
  RowBox[{"\[Xi]", "\[Rule]", "xi"}]}]], "DisplayFormula",
 CellChangeTimes->{{3.5278510986917863`*^9, 3.5278512270581284`*^9}, {
  3.527851301720399*^9, 3.527851325789776*^9}},
 FontSize->18],

Cell["\<\
And then we simply set up the SDE as usual, the only difference being that \
this time we define multiple drift and diffusion coefficients.\
\>", "Text",
 CellChangeTimes->{{3.5278506430877275`*^9, 3.5278506670881*^9}, {
  3.5278510653898816`*^9, 3.5278510932784767`*^9}, {3.527851268332489*^9, 
  3.5278512887166553`*^9}, {3.5278513398705807`*^9, 3.52785136065477*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "S", ",", "spot", ",", "r", ",", "q", ",", "T", ",", "kappa", ",", "theta",
     ",", "xi"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hestonSDE", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"generateStochasticIntegralFunction", "[", "\[IndentingNewLine]", 
     RowBox[{"\"\<HestonOption\>\"", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "-", "q"}], ")"}], "*", 
         RowBox[{"S", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
        RowBox[{"kappa", "*", 
         RowBox[{"(", 
          RowBox[{"theta", "-", 
           RowBox[{"S", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], ")"}]}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Two", " ", "drift", " ", "functions"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"S", "[", 
           RowBox[{"[", "2", "]"}], "]"}]], "*", 
         RowBox[{"S", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
        RowBox[{"xi", "*", 
         SqrtBox[
          RowBox[{"S", "[", 
           RowBox[{"[", "2", "]"}], "]"}]]}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Two", " ", "diffusion", " ", "functions"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"S", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"S", ",", 
        RowBox[{"{", 
         RowBox[{"spot", ",", "theta"}], "}"}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"S", " ", "is", " ", "two", " ", "dimensional"}], ",", " ", 
        RowBox[{
        "so", " ", "we", " ", "have", " ", "two", " ", "initial", " ", 
         "values"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "spot", ",", "T", ",", "r", ",", "q", ",", "kappa", ",", "theta", ",", 
        "xi"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"#1", "+", 
         RowBox[{"#2", "/", "512"}]}], ")"}], "&"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Effectively", " ", "keeps", " ", "a", " ", "running", " ", "average", 
        " ", "of", " ", "the", " ", "price", " ", "of", " ", "the", " ", 
        "underlying"}], " ", "*)"}], "\[IndentingNewLine]", "512", ",", 
      "\[IndentingNewLine]", "\"\<Euler\>\""}], "\[IndentingNewLine]", "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.527850669433234*^9, 3.527850812539419*^9}, {
  3.527851016484084*^9, 3.5278510193862505`*^9}, {3.5278512359356365`*^9, 
  3.527851250301458*^9}, {3.527858320518676*^9, 3.52785832067802*^9}}],

Cell[BoxData["\<\"\\nC:\\\\Users\\\\wolfram\\\\AppData\\\\Roaming\\\\\
Mathematica\\\\ApplicationData\\\\CUDALink\\\\BuildFolder\\\\mkellyloanlap-\
10816\\\\Working-mkellyloanlap-10816-4912-12>call \\\"c:\\\\Program Files \
(x86)\\\\Microsoft Visual Studio 10.0\\\\VC\\\\vcvarsall.bat\\\" amd64 \
\\nSetting environment for using Microsoft Visual Studio 2010 x64 \
tools.\\nCUDAFunction-150.cu\\nCUDAFunction-150.cu\\ntmpxft_00001254_00000000-\
3_CUDAFunction-150.cudafe1.gpu\\ntmpxft_00001254_00000000-10_CUDAFunction-150.\
cudafe2.gpu\"\>"], "Print",
 CellChangeTimes->{3.5278723284620447`*^9, 3.527969420825122*^9, 
  3.5376681313087697`*^9, 3.537716829937149*^9, 3.5397460912012377`*^9}]
}, Closed]],

Cell["\<\
Defining parameters for the option to match those used above in the Black\
\[Dash]Scholes model.\
\>", "Text",
 CellChangeTimes->{{3.5278508318285227`*^9, 3.527850859719118*^9}, {
  3.541271328233097*^9, 3.5412713320413146`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SpotPrice", "=", "35.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StrikePrice", "=", "35.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Expiration", "=", "1.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"InterestRate", "=", "0.08"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dividend", "=", "0.03"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Volatility", "=", "0.30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Theta", "=", 
    RowBox[{"Volatility", "^", "2"}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Theta", " ", "is", " ", "the", " ", "long"}], "-", 
    RowBox[{"term", " ", "mean", " ", "of", " ", 
     RowBox[{"Volatility", "^", "2"}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Kappa", "=", "0.5"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Kappa", " ", "controls", " ", "how", " ", "strongly", " ", "it", " ", 
    "returns", " ", "to", " ", "that", " ", "mean"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Xi", "=", "0.10"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Volatility", " ", "of", " ", "volatility"}], " ", "*)"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5278508628252954`*^9, 3.5278509692383823`*^9}, {
   3.527858247408577*^9, 3.5278582480208883`*^9}, 3.527969472415412*^9}],

Cell["\<\
Then we simulate the SDE just as before.\
\>", "Text",
 CellChangeTimes->{{3.5278509843692474`*^9, 3.527850999819131*^9}, {
  3.54127133720961*^9, 3.5412713375296288`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hestonSamples", "=", 
   RowBox[{"CUDAStochasticIntegrate", "[", 
    RowBox[{"hestonSDE", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "SpotPrice", ",", " ", "Expiration", ",", " ", "InterestRate", ",", " ",
        "Dividend", ",", " ", "Kappa", ",", "Theta", ",", "Xi"}], "}"}], ",", 
     " ", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1.0", "0.2"},
        {"0.2", "1.0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
    RowBox[{"(", 
     RowBox[{"hestonSamples", "-", "StrikePrice"}], ")"}]}], "]"}], "*", 
  RowBox[{"Exp", "[", 
   RowBox[{"-", "InterestRate"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5278510007561846`*^9, 3.527851047250844*^9}, {
  3.5278583690597343`*^9, 3.527858375187759*^9}, {3.527858411978427*^9, 
  3.527858420073032*^9}}],

Cell[BoxData["3.549186111628115`"], "Output",
 CellChangeTimes->{
  3.5278723427940445`*^9, {3.5279695167984905`*^9, 3.5279695203708963`*^9}, 
   3.5376682246040983`*^9, 3.5377168473808937`*^9, 3.539746130019458*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["\<\
Stochastic Rate Models\[LongDash]The Hull\[Dash]White Model\
\>", "Section",
 CellChangeTimes->{{3.5278907576155357`*^9, 3.527890765515976*^9}, {
  3.5412713450820603`*^9, 3.54127135241348*^9}}],

Cell["\<\
Much like with the stochastic volatility model given above, we can easily \
implement a stochastic rate model using the same framework. We\
\[CloseCurlyQuote]ll implement the Hull\[Dash]White model with constant \
parameters, in which the rate process is given by\
\>", "Text",
 CellChangeTimes->{{3.527890776282774*^9, 3.52789080131278*^9}, {
  3.527891691175786*^9, 3.527891710710128*^9}, {3.5412713660262585`*^9, 
  3.5412713806980977`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[DifferentialD]", 
   SubscriptBox["S", "t"]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["r", "t"], "-", "q"}], ")"}], 
    SubscriptBox["S", "t"], 
    RowBox[{"\[DifferentialD]", "t"}]}], "+", 
   RowBox[{
    SqrtBox[
     SubscriptBox["\[Nu]", "t"]], 
    SubscriptBox["S", "t"], 
    RowBox[{"\[DifferentialD]", 
     SubsuperscriptBox["W", "t", "1"]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[DifferentialD]", 
   SubscriptBox["r", "t"]}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"\[Theta]", "-", 
      SubscriptBox["\[Alpha]r", "t"]}], ")"}], 
    RowBox[{"\[DifferentialD]", "t"}]}], "+", 
   RowBox[{
    SubscriptBox["\[Sigma]r", "t"], 
    RowBox[{"\[DifferentialD]", 
     SubsuperscriptBox["W", "t", "2"]}]}]}]}]}], "DisplayFormula",
 CellChangeTimes->{{3.5278510986917863`*^9, 3.5278512270581284`*^9}, 
   3.537716723323489*^9, {3.537716765174674*^9, 3.5377167664828043`*^9}},
 FontSize->18],

Cell["\<\
As in the previous slide, we replace some Greek letters with their English \
names to keep variable naming safe for CUDA, and setup the SDE as follows.\
\>", "Text",
 CellChangeTimes->{{3.527890776282774*^9, 3.52789080131278*^9}, {
  3.527891691175786*^9, 3.527891710710128*^9}, {3.5278918671039543`*^9, 
  3.527891894220009*^9}, {3.541271399306162*^9, 3.5412714049054823`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{
   "S", ",", "spot", ",", "t", ",", "T", ",", "q", ",", "v", ",", "theta", 
    ",", "alpha", ",", "sigma"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"hullWhiteSDE", "=", 
   RowBox[{"Quiet", "[", 
    RowBox[{"generateStochasticIntegralFunction", "[", "\[IndentingNewLine]", 
     RowBox[{"\"\<HullWhiteOption\>\"", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"S", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "-", "q"}], ")"}], "*", 
         RowBox[{"S", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
        RowBox[{"theta", "-", 
         RowBox[{"alpha", "*", 
          RowBox[{"S", "[", 
           RowBox[{"[", "2", "]"}], "]"}]}]}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Two", " ", "drift", " ", "functions"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"v", "*", 
         RowBox[{"S", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
        RowBox[{"sigma", "*", 
         RowBox[{"S", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"Two", " ", "diffusion", " ", "functions"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"S", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"S", ",", 
        RowBox[{"{", 
         RowBox[{"spot", ",", 
          RowBox[{"theta", "/", "alpha"}]}], "}"}]}], "}"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"S", " ", "is", " ", "two", " ", "dimensional"}], ",", " ", 
        RowBox[{
        "so", " ", "we", " ", "have", " ", "two", " ", "initial", " ", 
         "values"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "T"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "spot", ",", "T", ",", "q", ",", "v", ",", "theta", ",", "alpha", ",", 
        "sigma"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"#1", "+", 
         RowBox[{"#2", "/", "512"}]}], ")"}], "&"}], ",", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Effectively", " ", "keeps", " ", "a", " ", "running", " ", "average", 
        " ", "of", " ", "the", " ", "price", " ", "of", " ", "the", " ", 
        "underlying"}], " ", "*)"}], "\[IndentingNewLine]", "512", ",", 
      "\[IndentingNewLine]", "\"\<Euler\>\""}], "\[IndentingNewLine]", "]"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.527891896990964*^9, 3.527891960086276*^9}, {
  3.5278919964756193`*^9, 3.527892050315938*^9}}],

Cell[BoxData["\<\"\\nC:\\\\Users\\\\wolfram\\\\AppData\\\\Roaming\\\\\
Mathematica\\\\ApplicationData\\\\CUDALink\\\\BuildFolder\\\\mkellyloanlap-\
3140\\\\Working-mkellyloanlap-3140-5732-2>call \\\"c:\\\\Program Files \
(x86)\\\\Microsoft Visual Studio 10.0\\\\VC\\\\vcvarsall.bat\\\" amd64 \
\\nSetting environment for using Microsoft Visual Studio 2010 x64 \
tools.\\nCUDAFunction-683.cu\\nCUDAFunction-683.cu\\ntmpxft_00000e68_00000000-\
3_CUDAFunction-683.cudafe1.gpu\\ntmpxft_00000e68_00000000-10_CUDAFunction-683.\
cudafe2.gpu\"\>"], "Print",
 CellChangeTimes->{3.527969902494568*^9, 3.5376683645300894`*^9, 
  3.537669142500888*^9, 3.537669205566194*^9, 3.539746283442233*^9, 
  3.5399810801509905`*^9}]
}, Closed]],

Cell["\<\
We set up values for this model.\
\>", "Text",
 CellChangeTimes->{{3.52789208464262*^9, 3.527892100765336*^9}, {
  3.541271420873396*^9, 3.5412714227775044`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SpotPrice", "=", "35"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StrikePrice", "=", "35"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Expiration", "=", "1.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dividend", "=", "0.03"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Volatility", "=", "0.30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Theta", "=", "0.16"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Alpha", "=", "2.0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sigma", "=", "0.1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.527892102238122*^9, 3.527892162769153*^9}}],

Cell["\<\
And simulate the SDE to price the option in this model.\
\>", "Text",
 CellChangeTimes->{{3.5278921699734583`*^9, 3.527892184717682*^9}, {
  3.5412714310339766`*^9, 3.541271431385997*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"hullWhiteSamples", "=", 
   RowBox[{"CUDAStochasticIntegrate", "[", 
    RowBox[{"hullWhiteSDE", ",", 
     RowBox[{"{", 
      RowBox[{
      "SpotPrice", ",", "Expiration", ",", "Dividend", ",", "Volatility", ",",
        "Theta", ",", "Alpha", ",", "Sigma"}], "}"}], ",", 
     RowBox[{"(", "\[NoBreak]", GridBox[{
        {"1.0", "0.2"},
        {"0.2", "1.0"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.7]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Mean", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Max", "[", 
      RowBox[{"#", ",", "0"}], "]"}], "&"}], "/@", 
    RowBox[{"(", 
     RowBox[{"hullWhiteSamples", "-", "StrikePrice"}], ")"}]}], "]"}], "*", 
  RowBox[{"Exp", "[", 
   RowBox[{
    RowBox[{"-", "Theta"}], "/", "Alpha"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.5278921859013968`*^9, 3.527892257387246*^9}}],

Cell[BoxData["3.5438407023480836`"], "Output",
 CellChangeTimes->{3.527969948327448*^9, 3.537668466575388*^9, 
  3.5376691561742554`*^9, 3.5397464135786767`*^9, 3.539981092920721*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellChangeTimes->{3.479485737971568*^9},
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Summary", "Section",
 CellChangeTimes->{{3.5206844124937153`*^9, 3.5206844135778236`*^9}}],

Cell[CellGroupData[{

Cell["\<\
CUDAFinancialDerivative built-in and a GPU extension of FinancialDerivative\
\>", "Item",
 CellChangeTimes->{{3.5206844174362097`*^9, 3.5206844192353897`*^9}, {
  3.5376755034437532`*^9, 3.537675532371646*^9}, {3.5412714444757457`*^9, 
  3.5412714470818944`*^9}}],

Cell["\<\
CUDAFinancialDerivative parallelizes across GPUs and takes arrays as inputs\
\>", "Item",
 CellChangeTimes->{{3.5206844219026566`*^9, 3.520684423221788*^9}, 
   3.537675537233132*^9, {3.537675571741583*^9, 3.5376756051379223`*^9}}],

Cell["\<\
CUDAFinancialDerivative easily extensible using Add-Ons GPU Tools and \
SymbolicC\
\>", "Item",
 CellChangeTimes->{{3.5206844255040164`*^9, 3.520684426622128*^9}, {
  3.537675617146123*^9, 3.537675646753083*^9}}],

Cell["\<\
CUDAFinancialDerivative allows for the solution of stochastic differential \
equations\
\>", "Item",
 CellChangeTimes->{{3.5206844255040164`*^9, 3.520684426622128*^9}, {
  3.537675658502258*^9, 3.5376756768800955`*^9}, {3.541271457210474*^9, 
  3.5412714610816956`*^9}}],

Cell["\<\
CUDAFinancialDerivative solves multidimensional stochastic option problems\
\>", "Item",
 CellChangeTimes->{{3.5206844255040164`*^9, 3.520684426622128*^9}, {
  3.5376756866010675`*^9, 3.5376757099914064`*^9}, {3.5412714685701237`*^9, 
  3.5412714711462708`*^9}}],

Cell["\<\
CUDAFinancialDerivative solves stochastic interest rate models\
\>", "Item",
 CellChangeTimes->{{3.5206844255040164`*^9, 3.520684426622128*^9}, {
  3.5376757137897863`*^9, 3.5376757306614733`*^9}, {3.5412714787457056`*^9, 
  3.5412714819618893`*^9}}],

Cell["\<\
CUDAFinancialDerivative solves stochastic volatility models\
\>", "Item",
 CellChangeTimes->{{3.5206844255040164`*^9, 3.520684426622128*^9}, {
  3.5376757343648434`*^9, 3.537675744692876*^9}, {3.5412714898023376`*^9, 
  3.5412714904103727`*^9}}],

Cell[TextData[{
 "CUDAFinancialDerivative will be enormously expanded in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " version 9"
}], "Item",
 CellChangeTimes->{{3.5206844255040164`*^9, 3.520684426622128*^9}, {
  3.5376757511195183`*^9, 3.5376757744998565`*^9}, {3.541271512826655*^9, 
  3.5412715150827837`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellChangeTimes->{3.498358942487419*^9},
 CellTags->"SlideShowHeader"],

Cell[CellGroupData[{

Cell["Initialization", "Section",
 InitializationGroup->True],

Cell[CellGroupData[{

Cell["Color", "Subsection",
 CellChangeTimes->{{3.4989697046414385`*^9, 3.498969705113438*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "m8red", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m8red", "[", "a_", "]"}], ":=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.811765", ",", "0.117647", ",", "0.145098", ",", "a"}], "]"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.4989697097804384`*^9, 3.498969712600438*^9}, {
  3.4989703233394384`*^9, 3.4989703350494385`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Load packages", "Subsection"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<CUDALink`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellID->2129660918],

Cell[BoxData[
 RowBox[{
  RowBox[{"LaunchKernels", "[", "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5071378195223017`*^9, 3.5071378254288926`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Code", "Subsection",
 CellChangeTimes->{{3.5399793932765074`*^9, 3.5399794066832743`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CUDAParallelFoldList", "[", 
    RowBox[{"data_", ",", " ", "stride_", ",", " ", "n_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"src", ",", " ", "kernelName", ",", " ", "parallelFold"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"Divisible", "[", 
          RowBox[{"stride", ",", " ", "64"}], "]"}]}], ",", " ", 
        RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
      "src", " ", "=", " ", 
       "\"\<\n__global__ void parallelFold(Real_t *data, unsigned int nData, \
unsigned int stride)\n{\n\tReal_t runningTotal = static_cast<Real_t>(0.0);\n\t\
for (int ii=0; ii < nData; ii += stride)\n\t{\n\t\trunningTotal += data[ii + \
blockIdx.x*blockDim.x + threadIdx.x];\n\t\tdata[ii + blockIdx.x*blockDim.x + \
threadIdx.x] = runningTotal;\n\t}\n}\n\>\""}], ";", "\[IndentingNewLine]", 
      RowBox[{"kernelName", " ", "=", " ", "\"\<parallelFold\>\""}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"parallelFold", " ", "=", " ", 
       RowBox[{"CUDAFunctionLoad", "[", 
        RowBox[{"src", ",", " ", "kernelName", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"_Real", ",", " ", "_", ",", " ", "\"\<InputOutput\>\""}],
             "}"}], ",", " ", "_Integer", ",", " ", "_Integer"}], "}"}], ",", 
         " ", "64"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"parallelFold", "[", 
       RowBox[{
       "data", ",", " ", "n", ",", " ", "stride", ",", " ", "stride"}], "]"}],
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "data"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.507999277384507*^9, 3.5079993017659693`*^9}, {
   3.50799933419011*^9, 3.507999344767078*^9}, {3.507999454879233*^9, 
   3.507999563267449*^9}, {3.5079996255880547`*^9, 3.507999663045072*^9}, {
   3.507999697311739*^9, 3.5079997370706577`*^9}, {3.507999773736641*^9, 
   3.5079998113320923`*^9}, {3.507999881467486*^9, 3.508000132141801*^9}, {
   3.5080002058310738`*^9, 3.5080002107618217`*^9}, {3.508000248508871*^9, 
   3.50800027767837*^9}, {3.508000481921104*^9, 3.508000489161686*^9}, 
   3.508000728920384*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"srcf", "=", 
   RowBox[{"FileNameJoin", "[", 
    RowBox[{"{", 
     RowBox[{
     "$CUDALinkPath", ",", "\"\<SupportFiles\>\"", ",", "\"\<random.cu\>\""}],
      "}"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.537673063281372*^9},
 CellID->32775198],

Cell[BoxData[
 RowBox[{
  RowBox[{"CUDAInverseCND", "=", 
   RowBox[{"CUDAFunctionLoad", "[", 
    RowBox[{
     RowBox[{"{", "srcf", "}"}], ",", " ", "\"\<InverseCND\>\"", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_Real", ",", " ", "_", ",", " ", "\"\<InputOutput\>\""}], 
        "}"}], ",", " ", "_Integer", ",", " ", "_Integer"}], "}"}], ",", " ", 
     "256"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.537673066676372*^9},
 CellID->168599841],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CUDAMemoryBrownianMotion", "[", 
     RowBox[{"period_Real", ",", 
      RowBox[{"steps_Integer:", " ", "1000"}], ",", 
      RowBox[{"init_:", " ", "0."}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "mems"}], "}"}], ",", 
      RowBox[{
       RowBox[{"mems", "=", 
        RowBox[{"CUDAMemoryLoad", "[", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"period", "/", "steps"}], "]"}]}], "]"}], ",", 
           "steps"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"res", "=", 
        RowBox[{"CUDAMemoryGet", "[", 
         RowBox[{"CUDAFoldList", "[", 
          RowBox[{"Plus", ",", "init", ",", "mems"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"CUDAMemoryUnload", "[", "mems", "]"}], ";", 
       "\[IndentingNewLine]", "res"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CUDABrownianMotionPaths3", "[", 
     RowBox[{"period_Real", ",", 
      RowBox[{"steps_Integer:", " ", "1000"}], ",", "paths_Integer"}], "]"}], 
    ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"res", ",", "mems"}], "}"}], ",", 
      RowBox[{
       RowBox[{"res", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"CUDAMemoryGet", "[", 
            RowBox[{"CUDAFoldList", "[", 
             RowBox[{"Plus", ",", "0.", ",", 
              RowBox[{"mems", "=", 
               RowBox[{"CUDAMemoryLoad", "[", 
                RowBox[{"RandomVariate", "[", 
                 RowBox[{
                  RowBox[{"NormalDistribution", "[", 
                   RowBox[{"0", ",", 
                    RowBox[{"Sqrt", "[", 
                    RowBox[{"period", "/", "steps"}], "]"}]}], "]"}], ",", 
                  "steps"}], "]"}], "]"}]}]}], "]"}], "]"}], "&"}], ",", 
          RowBox[{"Range", "[", "paths", "]"}]}], "]"}]}], ";", 
       RowBox[{"CUDAMemoryUnload", "[", "mems", "]"}], ";", 
       "\[IndentingNewLine]", "res"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CUDABrownianMotionPaths4", "[", 
     RowBox[{"period_Real", ",", 
      RowBox[{"steps_Integer:", " ", "1000"}], ",", "paths_Integer"}], "]"}], 
    ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"mems", ",", "res"}], "}"}], ",", 
      RowBox[{
       RowBox[{"mems", "=", 
        RowBox[{"Map", "[", 
         RowBox[{"CUDAMemoryLoad", ",", 
          RowBox[{"RandomVariate", "[", 
           RowBox[{
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"period", "/", "steps"}], "]"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"paths", ",", "steps"}], "}"}]}], "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res", "=", 
        RowBox[{"Map", "[", 
         RowBox[{"CUDAMemoryGet", ",", 
          RowBox[{"ParallelMap", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"CUDAFoldList", "[", 
              RowBox[{"Plus", ",", "0.", ",", "#"}], "]"}], "&"}], ",", 
            "mems"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"CUDAMemoryUnload", " ", "/@", " ", "mems"}], ";", 
       "\[IndentingNewLine]", "res"}]}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CUDABrownianMotionPaths6", "[", 
     RowBox[{"period_Real", ",", 
      RowBox[{"steps_Integer:", " ", "1000"}], ",", "paths_Integer"}], "]"}], 
    ":=", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Subtract", "[", 
        RowBox[{"#", ",", 
         RowBox[{"First", "[", "#", "]"}]}], "]"}], "&"}], ",", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"CUDAFoldList", "[", 
         RowBox[{"Plus", ",", "0.", ",", 
          RowBox[{"RandomVariate", "[", 
           RowBox[{
            RowBox[{"NormalDistribution", "[", 
             RowBox[{"0", ",", 
              RowBox[{"Sqrt", "[", 
               RowBox[{"period", "/", "steps"}], "]"}]}], "]"}], ",", 
            RowBox[{"steps", "*", "paths"}]}], "]"}]}], "]"}], ",", "steps"}],
        "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CUDABrownianMotionPaths", "[", 
     RowBox[{"period_Real", ",", "steps_Integer", ",", "paths_Integer"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"nSamples", ",", "dOutput", ",", "hOutput"}], "}"}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"!", 
          RowBox[{"Divisible", "[", 
           RowBox[{"paths", ",", "64"}], "]"}]}], ",", 
         RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nSamples", "=", 
        RowBox[{"steps", "*", "paths"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"SeedRandom", "[", 
        RowBox[{"1234", ",", 
         RowBox[{"Method", "\[Rule]", "\"\<MKL\>\""}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dOutput", "=", 
        RowBox[{"CUDAMemoryLoad", "[", 
         RowBox[{"RandomVariate", "[", 
          RowBox[{
           RowBox[{"NormalDistribution", "[", 
            RowBox[{"0", ",", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"period", "/", "steps"}], "]"}]}], "]"}], ",", 
           "nSamples"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"CUDAParallelFoldList", "[", 
        RowBox[{"dOutput", ",", "paths", ",", "nSamples"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"hOutput", "=", 
        RowBox[{"CUDAMemoryGet", "[", "dOutput", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"CUDAMemoryUnload", "[", "dOutput", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Transpose", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{"hOutput", ",", "paths"}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CUDABrownianMotionPaths1", "[", 
    RowBox[{"period_Real", ",", "steps_Integer", ",", "paths_Integer"}], 
    "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"nSamples", ",", "dOutput", ",", "hOutput"}], "}"}], ",", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"!", 
         RowBox[{"Divisible", "[", 
          RowBox[{"paths", ",", "64"}], "]"}]}], ",", 
        RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"nSamples", "=", 
       RowBox[{"steps", "*", "paths"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dOutput", "=", 
       RowBox[{"CUDAMemoryLoad", "[", 
        RowBox[{"RandomReal", "[", 
         RowBox[{"period", ",", "nSamples"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CUDAInverseCND", "[", 
       RowBox[{"dOutput", ",", "nSamples", ",", "1"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CUDAParallelFoldList", "[", 
       RowBox[{"dOutput", ",", "paths", ",", "nSamples"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"hOutput", "=", 
       RowBox[{"CUDAMemoryGet", "[", "dOutput", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"CUDAMemoryUnload", "[", "dOutput", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"Partition", "[", 
         RowBox[{"hOutput", ",", "paths"}], "]"}], "]"}], "*", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"period", "/", "steps"}], "]"}]}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5400505532046223`*^9, 3.5400505532056227`*^9}, {
   3.540050777089428*^9, 3.540050795185463*^9}, {3.5400510030763535`*^9, 
   3.540051009536723*^9}, {3.540051102309029*^9, 3.540051105192194*^9}, {
   3.5400927928645926`*^9, 3.5400927999039955`*^9}, 3.540093792895791*^9}],

Cell[TextData[{
 "Define a minimal ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-to-C translator:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<SymbolicC`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5088706769141207`*^9, 3.508870676917121*^9}}],

Cell[BoxData[{
 RowBox[{"SetAttributes", "[", 
  RowBox[{"ToSymbolicC", ",", " ", "HoldAll"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", 
      RowBox[{"(", 
       RowBox[{"Plus", "|", "Subtract", "|", "Times", "|", "Divide"}], 
       ")"}]}], ")"}], "[", "args___", "]"}], "]"}], ":=", 
  RowBox[{"COperator", "[", 
   RowBox[{"op", ",", " ", 
    RowBox[{"ToSymbolicC", "/@", 
     RowBox[{"{", "args", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{"If", "[", 
    RowBox[{"cond_", ",", " ", "truestmt_", ",", " ", "falsestmt_"}], "]"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"CConditional", "[", 
   RowBox[{
    RowBox[{"ToSymbolicC", "[", "cond", "]"}], ",", " ", 
    RowBox[{"ToSymbolicC", "[", "truestmt", "]"}], ",", " ", 
    RowBox[{"ToSymbolicC", "[", "falsestmt", "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{"Power", "[", 
    RowBox[{"E", ",", "args___"}], "]"}], "]"}], " ", ":=", " ", 
  RowBox[{"CCall", "[", 
   RowBox[{"\"\<exp\>\"", ",", " ", 
    RowBox[{"ToSymbolicC", "/@", 
     RowBox[{"{", "args", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", 
      RowBox[{"(", 
       RowBox[{"Power", "|", "Log", "|", "Log10", "|", "Exp", "|", "Sqrt"}], 
       ")"}]}], ")"}], "[", "args___", "]"}], "]"}], ":=", 
  RowBox[{"CStandardMathOperator", "[", 
   RowBox[{"op", ",", " ", 
    RowBox[{"ToSymbolicC", "/@", 
     RowBox[{"{", "args", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", 
      RowBox[{"(", 
       RowBox[{"Erf", "|", "Erfc", "|", "Max", "|", "Min"}], ")"}]}], ")"}], 
    "[", "args___", "]"}], "]"}], ":=", 
  RowBox[{"CCall", "[", 
   RowBox[{
    RowBox[{"ToLowerCase", "[", 
     RowBox[{"SymbolName", "[", "op", "]"}], "]"}], ",", 
    RowBox[{"ToSymbolicC", "/@", 
     RowBox[{"{", "args", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", 
      RowBox[{"(", 
       RowBox[{
       "Less", "|", "Greater", "|", "Equal", "|", "Unequal", "|", "LessEqual",
         "|", "GreaterEqual"}], ")"}]}], ")"}], "[", "args___", "]"}], "]"}], 
  ":=", 
  RowBox[{"COperator", "[", 
   RowBox[{"op", ",", " ", 
    RowBox[{"ToSymbolicC", "/@", 
     RowBox[{"{", "args", "}"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", 
      RowBox[{"(", 
       RowBox[{
       "CauchyDistribution", "|", "ChiSquareDistribution", "|", 
        "ExponentialDistribution", "|", "LaplaceDistribution", "|", 
        "LogNormalDistribution", "|", "NormalDistribution", "|", 
        "WeibullDistribution"}], ")"}]}], ")"}], "[", "args___", "]"}], "]"}],
   ":=", 
  RowBox[{"CCall", "[", 
   RowBox[{
    RowBox[{"ToLowerCase", "[", 
     RowBox[{"SymbolName", "[", "op", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<rngState\>\"", ",", 
      RowBox[{"Sequence", "[", 
       RowBox[{"ToSymbolicC", "/@", 
        RowBox[{"{", "args", "}"}]}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", "UniformDistribution"}], ")"}], "[", "args___", "]"}],
    "]"}], ":=", 
  RowBox[{"CCall", "[", 
   RowBox[{
    RowBox[{"ToLowerCase", "[", 
     RowBox[{"SymbolName", "[", "op", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<rngState\>\"", ",", 
      RowBox[{"ToSymbolicC", "@@", "args"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", "TransformedDistribution"}], ")"}], "[", "args___", 
    "]"}], "]"}], ":=", 
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{"Release", "[", 
    RowBox[{
     RowBox[{"First", "[", 
      RowBox[{"{", "args", "}"}], "]"}], "/.", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"First", "[", "#", "]"}], "\[Rule]", 
          RowBox[{"Last", "[", "#", "]"}]}], ")"}], "&"}], "/@", 
       RowBox[{"Last", "[", 
        RowBox[{"{", "args", "}"}], "]"}]}], ")"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"op", ":", 
       RowBox[{"(", 
        RowBox[{"BrownianMotion", "|", "JumpDiffusionProcess"}], ")"}]}], 
      ")"}], "[", "args1___", "]"}], "[", "args2___", "]"}], "]"}], ":=", 
  RowBox[{"CCall", "[", 
   RowBox[{
    RowBox[{"CMember", "[", 
     RowBox[{
      RowBox[{"ToLowerCase", "[", 
       RowBox[{"SymbolName", "[", "op", "]"}], "]"}], ",", "\"\<step\>\""}], 
     "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<rngState\>\"", ",", " ", 
      RowBox[{"Sequence", "[", 
       RowBox[{"ToSymbolicC", "/@", 
        RowBox[{"{", 
         RowBox[{"args1", ",", "args2"}], "}"}]}], "]"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"op", ":", "Part"}], ")"}], "[", "args___", "]"}], "]"}], ":=", 
  RowBox[{"CArray", "[", 
   RowBox[{
    RowBox[{"First", "@", 
     RowBox[{"{", "args", "}"}]}], ",", 
    RowBox[{"ToSymbolicC", "[", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{"Last", "@", 
        RowBox[{"{", "args", "}"}]}], "-", "1"}], "]"}], "]"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{"x", ":", 
    RowBox[{"(", 
     RowBox[{"_Real", "|", "_Rational"}], ")"}]}], "]"}], ":=", 
  RowBox[{"CCast", "[", 
   RowBox[{"\"\<Real_t\>\"", ",", " ", 
    RowBox[{"N", "[", "x", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", 
   RowBox[{"x", ":", 
    RowBox[{"(", 
     RowBox[{"E", "|", "Pi"}], ")"}]}], "]"}], ":=", 
  RowBox[{"CCast", "[", 
   RowBox[{"\"\<Real_t\>\"", ",", " ", 
    RowBox[{"N", "[", 
     RowBox[{"x", ",", "20"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", "args_List", "]"}], ":=", 
  RowBox[{"ToSymbolicC", "/@", "args"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ToSymbolicC", "[", "args__", "]"}], ":=", "args"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True,
 CellChangeTimes->{{3.519143145136155*^9, 3.519143158676456*^9}, {
  3.5226006705823917`*^9, 3.522600734446045*^9}}],

Cell["Define a minimal CUDA kernel code generator.", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateCUDAKernel", "[", 
   RowBox[{"name_", ",", "f_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<__device__\>\"", ",", "\"\<Real_t\>\""}], "}"}], ",", 
      RowBox[{"name", "<>", "\"\<_compute\>\""}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<S\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<X\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<T\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<r\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<q\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<sigma\>\""}], "}"}]}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"CReturn", "[", 
       RowBox[{"ToSymbolicC", "[", "f", "]"}], "]"}]}], "\[IndentingNewLine]",
      "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"SymbolicCUDAFunction", "[", 
     RowBox[{"name", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<call\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<S\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<X\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<T\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<r\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<q\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<sigma\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", ",", "\"\<length\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"CBlock", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymbolicCUDADeclareIndexBlock", "[", "1", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"CIf", "[", 
          RowBox[{
           RowBox[{"COperator", "[", 
            RowBox[{"Less", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<index\>\"", ",", "\"\<length\>\""}], "}"}]}], 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"CAssign", "[", 
            RowBox[{
             RowBox[{"CArray", "[", 
              RowBox[{"\"\<call\>\"", ",", "\"\<index\>\""}], "]"}], ",", 
             RowBox[{"CCall", "[", 
              RowBox[{
               RowBox[{"name", "<>", "\"\<_compute\>\""}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"CArray", "[", 
                  RowBox[{"#", ",", "\"\<index\>\""}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<S\>\"", ",", "\"\<X\>\"", ",", "\"\<T\>\"", ",", 
                  "\"\<r\>\"", ",", "\"\<q\>\"", ",", "\"\<sigma\>\""}], 
                 "}"}]}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}],
    "\[IndentingNewLine]", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5087854758595247`*^9, 3.508785478780816*^9}, 
   3.508785879323867*^9, 3.5087859205519896`*^9, 3.5087859624301767`*^9}],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<GPUTools`SymbolicGPU`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5088723387262993`*^9, 3.5088723387303*^9}, {
  3.508872405469973*^9, 3.508872414869913*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateGPUKernel", "[", 
   RowBox[{"name_", ",", "f_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<__device__\>\"", ",", "\"\<Real_t\>\""}], "}"}], ",", 
      RowBox[{"name", "<>", "\"\<_compute\>\""}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<S\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<X\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<T\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<r\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<q\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<sigma\>\""}], "}"}]}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"CReturn", "[", 
       RowBox[{"GPUExpression", "[", "f", "]"}], "]"}]}], 
     "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"SymbolicCUDAFunction", "[", 
     RowBox[{"name", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<call\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<S\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<X\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<T\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<r\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<q\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"CPointerType", "[", "\"\<Real_t\>\"", "]"}], ",", 
          "\"\<sigma\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", ",", "\"\<length\>\""}], "}"}]}], "}"}], ",", 
      RowBox[{"CBlock", "[", 
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"SymbolicCUDADeclareIndexBlock", "[", "1", "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"CIf", "[", 
          RowBox[{
           RowBox[{"COperator", "[", 
            RowBox[{"Less", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<index\>\"", ",", "\"\<length\>\""}], "}"}]}], 
            "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"CAssign", "[", 
            RowBox[{
             RowBox[{"CArray", "[", 
              RowBox[{"\"\<call\>\"", ",", "\"\<index\>\""}], "]"}], ",", 
             RowBox[{"CCall", "[", 
              RowBox[{
               RowBox[{"name", "<>", "\"\<_compute\>\""}], ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"CArray", "[", 
                  RowBox[{"#", ",", "\"\<index\>\""}], "]"}], "&"}], "/@", 
                RowBox[{"{", 
                 RowBox[{
                 "\"\<S\>\"", ",", "\"\<X\>\"", ",", "\"\<T\>\"", ",", 
                  "\"\<r\>\"", ",", "\"\<q\>\"", ",", "\"\<sigma\>\""}], 
                 "}"}]}]}], "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
        "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}],
    "\[IndentingNewLine]", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5087854758595247`*^9, 3.508785478780816*^9}, 
   3.508785879323867*^9, 3.5087859205519896`*^9, 3.5087859624301767`*^9, {
   3.508872437114137*^9, 3.5088724543128567`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateFoldFunction", "[", 
   RowBox[{"name_", ",", " ", "fun_", ",", " ", "vars_"}], "]"}], " ", ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{"CFunction", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<__device__\>\"", ",", "\"\<Real_t\>\""}], "}"}], ",", 
     RowBox[{"name", "<>", "\"\<_fold\>\""}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<Real_t\>\"", ",", 
         RowBox[{"SymbolName", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
      "vars"}], ",", "\[IndentingNewLine]", 
     RowBox[{"CBlock", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"CReturn", "[", 
        RowBox[{"ToSymbolicC", "[", "fun", "]"}], "]"}], 
       "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", "]"}], 
   "\[IndentingNewLine]", "}"}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True,
 CellChangeTimes->{{3.519131094768708*^9, 3.5191311793434877`*^9}, 
   3.5191320627377853`*^9, {3.52785652126195*^9, 3.527856553095495*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateEulerMethod", "[", 
   RowBox[{
   "drift_", ",", "diff_", ",", "solveFor_", ",", "wrt_", ",", "buffer_"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"{", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"CAssign", "[", 
       RowBox[{
        RowBox[{"CArray", "[", 
         RowBox[{"buffer", ",", 
          RowBox[{"ii", "-", "1"}]}], "]"}], ",", 
        RowBox[{"COperator", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"COperator", "[", 
             RowBox[{"Times", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"\"\<d\>\"", "<>", 
                 RowBox[{"SymbolName", "[", 
                  RowBox[{"First", "@", "wrt"}], "]"}]}], ",", 
                RowBox[{"ToSymbolicC", "[", 
                 RowBox[{"Evaluate", "[", 
                  RowBox[{"drift", "[", 
                   RowBox[{"[", "ii", "]"}], "]"}], "]"}], "]"}]}], "}"}]}], 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"COperator", "[", 
             RowBox[{"Times", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"CCall", "[", 
                 RowBox[{"\"\<sqrt\>\"", ",", 
                  RowBox[{"{", 
                   RowBox[{"\"\<d\>\"", "<>", 
                    RowBox[{"SymbolName", "[", 
                    RowBox[{"First", "@", "wrt"}], "]"}]}], "}"}]}], "]"}], 
                ",", 
                RowBox[{"CArray", "[", 
                 RowBox[{"buffer", ",", 
                  RowBox[{"ii", "-", "1"}]}], "]"}], ",", 
                RowBox[{"ToSymbolicC", "[", 
                 RowBox[{"Evaluate", "[", 
                  RowBox[{"diff", "[", 
                   RowBox[{"[", "ii", "]"}], "]"}], "]"}], "]"}]}], "}"}]}], 
             "]"}]}], "\[IndentingNewLine]", "}"}]}], "]"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "1", ",", 
        RowBox[{"Length", "@", "drift"}]}], "}"}]}], "\[IndentingNewLine]", 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"CAssign", "[", 
       RowBox[{
        RowBox[{"ToSymbolicC", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"First", "@", "solveFor"}], ")"}], "[", 
          RowBox[{"[", "ii", "]"}], "]"}], "]"}], ",", 
        RowBox[{"COperator", "[", 
         RowBox[{"Plus", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"ToSymbolicC", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"First", "@", "solveFor"}], ")"}], "[", 
              RowBox[{"[", "ii", "]"}], "]"}], "]"}], ",", 
            RowBox[{"CArray", "[", 
             RowBox[{"buffer", ",", 
              RowBox[{"ii", "-", "1"}]}], "]"}]}], "}"}]}], "]"}]}], "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"ii", ",", "1", ",", 
        RowBox[{"Length", "@", "drift"}]}], "}"}]}], "\[IndentingNewLine]", 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"CAssign", "[", 
     RowBox[{
      RowBox[{"SymbolName", "[", 
       RowBox[{"First", "@", "wrt"}], "]"}], ",", 
      RowBox[{"COperator", "[", 
       RowBox[{"Plus", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SymbolName", "[", 
           RowBox[{"First", "@", "wrt"}], "]"}], ",", 
          RowBox[{"\"\<d\>\"", "<>", 
           RowBox[{"SymbolName", "[", 
            RowBox[{"First", "@", "wrt"}], "]"}]}]}], "}"}]}], "]"}]}], 
     "]"}]}], "\[IndentingNewLine]", "}"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5226007630936832`*^9, 3.5226007783645563`*^9}, {
  3.52260082475521*^9, 3.5226009622910767`*^9}, {3.522601027773822*^9, 
  3.522601140802287*^9}, {3.522601827818582*^9, 3.522601836034052*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateSimulationFunction", "[", 
   RowBox[{
   "name_", ",", "drift_", ",", "diff_", ",", "valueFun_", ",", "solveFor_", 
    ",", "wrt_", ",", "vars_", ",", "nSteps_", ",", "method_"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"CFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\"\<__device__\>\"", ",", "\"\<void\>\""}], "}"}], ",", 
    RowBox[{"name", "<>", "\"\<_simulate\>\""}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", 
          RowBox[{"SymbolName", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
       "vars"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<_start\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "\"\<_end\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<curandState*\>\"", ",", "\"\<rngState\>\""}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t&\>\"", ",", "\"\<foldValue\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t*\>\"", ",", "\"\<corrMat\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t*\>\"", ",", 
          RowBox[{"First", "@", "solveFor"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t*\>\"", ",", "\"\<_buffer\>\""}], "}"}]}], 
       "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"CBlock", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"CAssign", "[", 
          RowBox[{
           RowBox[{"ToSymbolicC", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"First", "@", "solveFor"}], ")"}], "[", 
             RowBox[{"[", "ii", "]"}], "]"}], "]"}], ",", 
           RowBox[{"ToSymbolicC", "[", 
            RowBox[{"Evaluate", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Last", "@", "solveFor"}], ")"}], "[", 
              RowBox[{"[", "ii", "]"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"ii", ",", "1", ",", 
           RowBox[{"Length", "@", "drift"}]}], "}"}]}], "\[IndentingNewLine]",
         "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<mint\>\"", ",", "\"\<ii\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<Real_t\>\"", ",", 
         RowBox[{"SymbolName", "[", 
          RowBox[{"First", "@", "wrt"}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{
         RowBox[{"SymbolName", "[", 
          RowBox[{"First", "@", "wrt"}], "]"}], ",", "\"\<_start\>\""}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<Real_t\>\"", ",", 
         RowBox[{"\"\<d\>\"", "<>", 
          RowBox[{"SymbolName", "[", 
           RowBox[{"First", "@", "wrt"}], "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{
         RowBox[{"\"\<d\>\"", "<>", 
          RowBox[{"SymbolName", "[", 
           RowBox[{"First", "@", "wrt"}], "]"}]}], ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Minus", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<_end\>\"", ",", "\"\<_start\>\""}], "}"}]}], "]"}]}],
         "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{
         RowBox[{"\"\<d\>\"", "<>", 
          RowBox[{"SymbolName", "[", 
           RowBox[{"First", "@", "wrt"}], "]"}]}], ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Divide", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"\"\<d\>\"", "<>", 
              RowBox[{"SymbolName", "[", 
               RowBox[{"First", "@", "wrt"}], "]"}]}], ",", "nSteps"}], 
            "}"}]}], "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{"\"\<foldValue\>\"", ",", "0"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CFor", "[", 
        RowBox[{
         RowBox[{"CAssign", "[", 
          RowBox[{"\"\<ii\>\"", ",", "0"}], "]"}], ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Less", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<ii\>\"", ",", "nSteps"}], "}"}]}], "]"}], ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Increment", ",", 
           RowBox[{"{", "\"\<ii\>\"", "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"CBlock", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"CCall", "[", 
             RowBox[{"\"\<generateCenteredMultiNormal\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"\"\<rngState\>\"", ",", "\"\<corrMat\>\"", ",", 
                RowBox[{"Length", "@", "drift"}], ",", "\"\<_buffer\>\""}], 
               "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Switch", "[", 
             RowBox[{
             "method", ",", "\[IndentingNewLine]", "\"\<Euler\>\"", ",", 
              "\[IndentingNewLine]", 
              RowBox[{"generateEulerMethod", "[", 
               RowBox[{
               "drift", ",", "diff", ",", "solveFor", ",", "wrt", ",", 
                "\"\<_buffer\>\""}], "]"}], ",", "\[IndentingNewLine]", "_", 
              ",", "\[IndentingNewLine]", "None"}], "\[IndentingNewLine]", 
             "]"}], ",", "\[IndentingNewLine]", 
            RowBox[{"CAssign", "[", 
             RowBox[{"\"\<foldValue\>\"", ",", 
              RowBox[{"CCall", "[", 
               RowBox[{
                RowBox[{"name", "<>", "\"\<_fold\>\""}], ",", " ", 
                RowBox[{"Join", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"\"\<foldValue\>\"", ",", " ", 
                    RowBox[{"ToSymbolicC", "[", "valueFun", "]"}]}], "}"}], 
                  ",", "vars"}], "]"}]}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], "\[IndentingNewLine]",
    "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.522601222420955*^9, 3.5226012260831647`*^9}, {
   3.522601333159289*^9, 3.522601462710699*^9}, {3.5226015025999804`*^9, 
   3.5226015238661966`*^9}, {3.5226015545959544`*^9, 3.522601633385461*^9}, {
   3.5226017138770647`*^9, 3.522601821817239*^9}, {3.5226018582493224`*^9, 
   3.522601927333274*^9}, {3.5226020011214943`*^9, 3.522602008619923*^9}, {
   3.5226021178451705`*^9, 3.5226021477918835`*^9}, {3.5226022167628284`*^9, 
   3.5226022193919787`*^9}, {3.526985392148291*^9, 3.5269854216230507`*^9}, {
   3.526987280388397*^9, 3.5269873172337093`*^9}, {3.526988679259028*^9, 
   3.526988684894025*^9}, {3.5269890707448606`*^9, 3.526989125607057*^9}, {
   3.526989324082776*^9, 3.526989441922773*^9}, 3.5272504898814*^9, {
   3.5278565797929907`*^9, 3.527856588210823*^9}, 3.527857315918991*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateSamplingFunction", "[", 
   RowBox[{
   "name_", ",", "wrt_", ",", "vars_", ",", "dim_", ",", "blockSize_"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"CFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "\"\<extern \\\"C\\\"\>\"", ",", "\"\<__global__\>\"", ",", 
      "\"\<void\>\""}], "}"}], ",", 
    RowBox[{"name", "<>", "\"\<_sampler\>\""}], ",", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Real_t\>\"", ",", "#"}], "}"}], "&"}], "/@", "vars"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<Real_t*\>\"", ",", "\"\<gCorrMat\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", ",", "\"\<seed\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<mint\>\"", ",", "\"\<numSamples\>\""}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\"\<Real_t*\>\"", ",", "\"\<res\>\""}], "}"}]}], "}"}]}], 
     "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"CBlock", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<mint\>\"", ",", "\"\<index\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{"\"\<index\>\"", ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Plus", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"CMember", "[", 
              RowBox[{"\"\<threadIdx\>\"", ",", "\"\<x\>\""}], "]"}], ",", 
             RowBox[{"COperator", "[", 
              RowBox[{"Times", ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"CMember", "[", 
                  RowBox[{"\"\<blockIdx\>\"", ",", "\"\<x\>\""}], "]"}], ",", 
                 RowBox[{"CMember", "[", 
                  RowBox[{"\"\<blockDim\>\"", ",", "\"\<x\>\""}], "]"}]}], 
                "}"}]}], "]"}]}], "}"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<curandState\>\"", ",", "\"\<rngState\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CCall", "[", 
        RowBox[{"\"\<curand_init\>\"", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"CCast", "[", 
            RowBox[{"\"\<unsigned long long\>\"", ",", "\"\<seed\>\""}], 
            "]"}], ",", "\"\<index\>\"", ",", "0", ",", 
           RowBox[{"CAddress", "[", "\"\<rngState\>\"", "]"}]}], "}"}]}], 
        "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<mint\>\"", ",", "\"\<stride\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{"\"\<stride\>\"", ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Times", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<gridDim.x\>\"", ",", "\"\<blockDim.x\>\""}], "}"}]}],
           "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<Real_t\>\"", ",", "\"\<_start\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<Real_t\>\"", ",", "\"\<_end\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{"\"\<_start\>\"", ",", 
         RowBox[{"ToSymbolicC", "[", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"wrt", "[", 
            RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CAssign", "[", 
        RowBox[{"\"\<_end\>\"", ",", 
         RowBox[{"ToSymbolicC", "[", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"wrt", "[", 
            RowBox[{"[", "3", "]"}], "]"}], "]"}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<Real_t\>\"", ",", "\"\<foldv\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<__shared__ Real_t\>\"", ",", " ", 
         RowBox[{"CArray", "[", 
          RowBox[{"\"\<corrMat\>\"", ",", 
           RowBox[{"dim", "*", "dim"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CIf", "[", 
        RowBox[{
         RowBox[{"COperator", "[", 
          RowBox[{"Less", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<threadIdx.x\>\"", ",", 
             RowBox[{"dim", "*", "dim"}]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"CAssign", "[", 
          RowBox[{
           RowBox[{"CArray", "[", 
            RowBox[{"\"\<corrMat\>\"", ",", "\"\<threadIdx.x\>\""}], "]"}], 
           ",", 
           RowBox[{"CArray", "[", 
            RowBox[{"\"\<gCorrMat\>\"", ",", "\"\<threadIdx.x\>\""}], "]"}]}],
           "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<__shared__ Real_t\>\"", ",", 
         RowBox[{"CArray", "[", 
          RowBox[{"\"\<_buffer1\>\"", ",", 
           RowBox[{"blockSize", "*", "dim"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<__shared__ Real_t\>\"", ",", 
         RowBox[{"CArray", "[", 
          RowBox[{"\"\<_buffer2\>\"", ",", 
           RowBox[{"blockSize", "*", "dim"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CDeclare", "[", 
        RowBox[{"\"\<mint\>\"", ",", "\"\<ii\>\""}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"CFor", "[", 
        RowBox[{
         RowBox[{"CAssign", "[", 
          RowBox[{"\"\<ii\>\"", ",", "\"\<index\>\""}], "]"}], ",", 
         RowBox[{"COperator", "[", 
          RowBox[{"Less", ",", 
           RowBox[{"{", 
            RowBox[{"\"\<ii\>\"", ",", "\"\<numSamples\>\""}], "}"}]}], "]"}],
          ",", 
         RowBox[{"CAssign", "[", 
          RowBox[{"\"\<ii\>\"", ",", 
           RowBox[{"COperator", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{"{", 
              RowBox[{"\"\<ii\>\"", ",", "\"\<stride\>\""}], "}"}]}], "]"}]}],
           "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"CBlock", "[", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"CCall", "[", 
             RowBox[{
              RowBox[{"name", "<>", "\"\<_simulate\>\""}], ",", 
              RowBox[{"Join", "[", 
               RowBox[{"vars", ",", 
                RowBox[{"{", 
                 RowBox[{"\"\<_start\>\"", ",", "\"\<_end\>\"", ",", 
                  RowBox[{"CAddress", "[", "\"\<rngState\>\"", "]"}], ",", 
                  "\"\<foldv\>\"", ",", "\"\<corrMat\>\"", ",", 
                  RowBox[{"CAddress", "[", 
                   RowBox[{"CArray", "[", 
                    RowBox[{"\"\<_buffer1\>\"", ",", 
                    RowBox[{"COperator", "[", 
                    RowBox[{"Times", ",", 
                    RowBox[{"{", 
                    RowBox[{"dim", ",", 
                    RowBox[{"CMember", "[", 
                    RowBox[{"\"\<threadIdx\>\"", ",", "\"\<x\>\""}], "]"}]}], 
                    "}"}]}], "]"}]}], "]"}], "]"}], ",", 
                  RowBox[{"CAddress", "[", 
                   RowBox[{"CArray", "[", 
                    RowBox[{"\"\<_buffer2\>\"", ",", 
                    RowBox[{"COperator", "[", 
                    RowBox[{"Times", ",", 
                    RowBox[{"{", 
                    RowBox[{"dim", ",", 
                    RowBox[{"CMember", "[", 
                    RowBox[{"\"\<threadIdx\>\"", ",", "\"\<x\>\""}], "]"}]}], 
                    "}"}]}], "]"}]}], "]"}], "]"}]}], "}"}]}], "]"}]}], "]"}],
             ",", "\[IndentingNewLine]", 
            RowBox[{"CAssign", "[", 
             RowBox[{
              RowBox[{"CArray", "[", 
               RowBox[{"\"\<res\>\"", ",", "\"\<ii\>\""}], "]"}], ",", 
              "\"\<foldv\>\""}], "]"}]}], "\[IndentingNewLine]", "}"}], 
          "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
      "}"}], "]"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.522602176091502*^9, 3.5226021803537455`*^9}, {
   3.5226022438683786`*^9, 3.5226023386467996`*^9}, {3.5226027493112884`*^9, 
   3.522602983289671*^9}, {3.522603029762329*^9, 3.522603183205106*^9}, 
   3.522603270755113*^9, {3.522603336036847*^9, 3.5226033378039484`*^9}, {
   3.522603371367868*^9, 3.5226034312092905`*^9}, {3.522603491203722*^9, 
   3.522603524857647*^9}, {3.526986455717052*^9, 3.5269864780251493`*^9}, {
   3.5269865083455687`*^9, 3.526986574712509*^9}, {3.526987327494176*^9, 
   3.526987390526682*^9}, {3.5269876329238997`*^9, 3.526987636046938*^9}, {
   3.5269878204345493`*^9, 3.5269878339691057`*^9}, {3.526988415147407*^9, 
   3.526988442295521*^9}, {3.526988731350288*^9, 3.52698873525179*^9}, {
   3.526988896086111*^9, 3.526988898906681*^9}, {3.526989133689012*^9, 
   3.526989138737986*^9}, {3.526989176432496*^9, 3.526989237200286*^9}, {
   3.526989283045439*^9, 3.526989307516272*^9}, 3.5269894532107058`*^9, {
   3.5269894970951757`*^9, 3.5269895723879623`*^9}, {3.526989737886445*^9, 
   3.5269897412002172`*^9}, {3.5272489256426287`*^9, 3.527248927571316*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateStochasticIntegralKernel", "[", 
   RowBox[{
   "name_", ",", "drift_", ",", "diffusion_", ",", "valueFun_", ",", 
    "solveFor_", ",", "wrt_", ",", "vars_", ",", "fold_", ",", "nSteps_", ",",
     "method_", ",", "blockSize_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "fixedFold", ",", "foldCode", ",", "simCode", ",", "samplingKernel", ",",
       "res"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"fixedFold", "=", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"First", "@", "fold"}], ")"}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#1", "\[Rule]", "a"}], ",", 
         RowBox[{"#2", "\[Rule]", "b"}]}], "}"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"foldCode", "=", 
      RowBox[{"generateFoldFunction", "[", 
       RowBox[{"name", ",", "fixedFold", ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a", ",", "b"}], "}"}], ",", "vars"}], "]"}]}], "]"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"simCode", "=", 
      RowBox[{"generateSimulationFunction", "[", 
       RowBox[{
       "name", ",", "drift", ",", "diffusion", ",", "valueFun", ",", 
        "solveFor", ",", "wrt", ",", "vars", ",", "nSteps", ",", "method"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"samplingKernel", "=", 
      RowBox[{"generateSamplingFunction", "[", 
       RowBox[{"name", ",", "wrt", ",", "vars", ",", 
        RowBox[{"Length", "@", "drift"}], ",", "blockSize"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"res", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"CInclude", "[", "\"\<CUDARandomVariate.cu\>\"", "]"}], ",", 
        "\[IndentingNewLine]", "foldCode", ",", "\[IndentingNewLine]", 
        "simCode", ",", "\[IndentingNewLine]", "samplingKernel"}], 
       "\[IndentingNewLine]", "}"}]}], ";", "\[IndentingNewLine]", "res"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5226039507810087`*^9, 3.522604113892338*^9}, {
  3.522604180975175*^9, 3.5226041815992107`*^9}, {3.5226043275945606`*^9, 
  3.5226043521389647`*^9}, {3.526987921963736*^9, 3.52698792446031*^9}, {
  3.5269884090033627`*^9, 3.5269884103383503`*^9}, {3.526989243559079*^9, 
  3.5269892622695847`*^9}, {3.527856603322028*^9, 3.52785660656813*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"generateStochasticIntegralFunction", "[", 
   RowBox[{
   "name_", ",", "drift_", ",", "diffusion_", ",", "valueFun_", ",", 
    "solveFor_", ",", "wrt_", ",", "vars_", ",", "fold_", ",", "nSteps_", ",",
     "method_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"code", ",", "cudaFun", ",", "res"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"code", "=", 
      RowBox[{"ToCCodeString", "[", 
       RowBox[{
        RowBox[{"generateStochasticIntegralKernel", "[", 
         RowBox[{
         "name", ",", "drift", ",", "diffusion", ",", "valueFun", ",", 
          "solveFor", ",", "wrt", ",", "vars", ",", "fold", ",", "nSteps", 
          ",", "method", ",", "64"}], "]"}], ",", 
        RowBox[{"\"\<Indent\>\"", "\[Rule]", "Automatic"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"cudaFun", "=", 
      RowBox[{"CUDAFunctionLoad", "[", 
       RowBox[{"code", ",", 
        RowBox[{"name", "<>", "\"\<_sampler\>\""}], ",", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"_Real", "&"}], "/@", "vars"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"_Real", ",", "_", ",", "\"\<Input\>\""}], "}"}], ",", 
            "_Integer", ",", "_Integer", ",", 
            RowBox[{"{", 
             RowBox[{"_Real", ",", "_", ",", "\"\<Output\>\""}], "}"}]}], 
           "}"}]}], "]"}], ",", "64", ",", 
        RowBox[{"\"\<ShellOutputFunction\>\"", "\[Rule]", "Print"}], ",", 
        RowBox[{"\"\<IncludeDirectories\>\"", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"NotebookDirectory", "[", "]"}], "}"}]}], ",", 
        RowBox[{"\"\<UnmangleCode\>\"", "\[Rule]", "False"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"res", "=", 
      RowBox[{"{", 
       RowBox[{"cudaFun", ",", 
        RowBox[{"SymbolName", "/@", "vars"}]}], "}"}]}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5226039507810087`*^9, 3.522604113892338*^9}, {
  3.522604180975175*^9, 3.5226041815992107`*^9}, {3.5226043275945606`*^9, 
  3.5226043521389647`*^9}, {3.5269857038674726`*^9, 3.526985832175695*^9}, {
  3.5269863073385572`*^9, 3.52698638718904*^9}, {3.5269866318928556`*^9, 
  3.52698663432502*^9}, {3.526989273125456*^9, 3.5269892735024242`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CUDAStochasticIntegrate", "[", 
   RowBox[{"sde_", ",", "inputs_", ",", "corrMat_", ",", 
    RowBox[{"nSamples_:", "16384"}], ",", 
    RowBox[{"seed_:", "Automatic"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "cholCorrMat", ",", "realSeed", ",", "dCorr", ",", "dRes", ",", "hRes"}],
      "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cholCorrMat", "=", 
      RowBox[{"CholeskyDecomposition", "[", "corrMat", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"realSeed", "=", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"seed", "===", "Automatic"}], ",", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2147483647"}], ",", "2147483647"}], "}"}], "]"}], 
        ",", "seed"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"dCorr", "=", 
      RowBox[{"CUDAMemoryLoad", "[", 
       RowBox[{"Flatten", "[", "cholCorrMat", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dRes", "=", 
      RowBox[{"CUDAMemoryAllocate", "[", 
       RowBox[{"Real", ",", "nSamples"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"First", "@", "sde"}], ")"}], "[", 
      RowBox[{
       RowBox[{"Sequence", "@@", "inputs"}], ",", "dCorr", ",", "realSeed", 
       ",", "nSamples", ",", "dRes"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"hRes", "=", 
      RowBox[{"CUDAMemoryGet", "[", "dRes", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"CUDAMemoryUnload", "/@", 
      RowBox[{"{", 
       RowBox[{"dCorr", ",", "dRes"}], "}"}]}], ";", "\[IndentingNewLine]", 
     "hRes"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5226039507810087`*^9, 3.522604113892338*^9}, {
  3.522604180975175*^9, 3.5226041815992107`*^9}, {3.5226043275945606`*^9, 
  3.5226043521389647`*^9}, {3.5269857038674726`*^9, 3.526985832175695*^9}, {
  3.5269858710946836`*^9, 3.526985974987801*^9}, {3.52698600909367*^9, 
  3.526986122048626*^9}, {3.526986697961989*^9, 3.526986746201148*^9}, {
  3.5269882480172377`*^9, 3.526988315508567*^9}, {3.526988365201483*^9, 
  3.52698836655923*^9}, {3.526988401175682*^9, 3.526988403512842*^9}, {
  3.5269884680450974`*^9, 3.526988495526359*^9}, {3.5269888741536617`*^9, 
  3.526988878289728*^9}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
Saveable->True,
ScreenStyleEnvironment->"SlideShow",
WindowSize->{1024, 768},
WindowMargins->Automatic,
WindowTitle->"High Performance Computing in Finance",
ShowSelection->True,
Magnification->1,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 15, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
       TextData[{"Style Definitions for \n", 
         StyleBox["Wolfram Seminars", FontSlant -> "Italic"]}], "Subtitle"], 
      Cell[
       StyleData[StyleDefinitions -> "Default.nb"]], 
      Cell[
       StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Definitions", "Section"], 
         Cell[
          StyleData[
          All, "SlideShow", StyleDefinitions -> 
           StyleData[All, "Presentation"]], PageWidth -> WindowWidth, 
          DockedCells -> Cell[
            BoxData[
             GridBox[{{
                TooltipBox[
                 ButtonBox[
                  StyleBox[
                   RowBox[{"  ", "\[EmptySquare]", " "}], FontSize -> 20, 
                   GrayLevel[0.7]], Appearance -> None, 
                  ButtonFunction :> (
                   FEPrivate`NotebookToggleFullScreen[]; {}), Evaluator -> 
                  None], 
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "SlideshowToolbarText", "TooltipToggleFullScreen"]]], 
                StyleBox[
                 RowBox[{
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[FirstPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageFirst", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipFirstSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LeftPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPagePrevious", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipPreviousSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[RightPointer]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageNext", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipNextSlide"]]], 
                   "\[InvisibleSpace]", 
                   TooltipBox[
                    ButtonBox[
                    StyleBox[
                    RowBox[{" ", "\[LastPage]", " "}], FontSize -> 25, 
                    GrayLevel[0.7]], ButtonData -> "ScrollPageLast", 
                    Appearance -> None], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "TooltipLastSlide"]]]}], 
                 ButtonBoxOptions -> {Alignment -> {Automatic, 
                    FEPrivate`If[
                    FEPrivate`SameQ[
                    FEPrivate`$OperatingSystem, "Unix"], -0.4, -0.5]}, 
                   Appearance -> "Palette", 
                   ButtonFunction :> (FEPrivate`FrontEndExecute[
                    FrontEnd`FrontEndToken[
                    FrontEnd`ButtonNotebook[], #]]& ), Evaluator -> None, 
                   FrameMargins -> 0, ImageMargins -> 0, ImageSize -> 
                   Medium}], 
                
                DynamicModuleBox[{$CellContext`cells$$ = {}, \
$CellContext`tagFind$$ = False}, 
                 TagBox[
                  DynamicBox[
                   PopupMenuBox[
                    Dynamic[
                    0, With[{$CellContext`nb$ = ButtonNotebook[]}, 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; If[$CellContext`tagFind$$, 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowHeader", Next, 
                    CellTags, AutoScroll -> False], {#}], 
                    Do[
                    
                    NotebookFind[$CellContext`nb$, "SlideShowNavigationBar", 
                    Next, CellStyle, AutoScroll -> False], {#}]]; 
                    SelectionMove[$CellContext`nb$, After, Cell, AutoScroll -> 
                    False]; NotebookWrite[$CellContext`nb$, 
                    Cell["", Deletable -> True, ShowCellBracket -> False], 
                    All]; NotebookDelete[$CellContext`nb$]; 
                    SelectionMove[$CellContext`nb$, 
                    If[$CellContext`tagFind$$, Previous, Next], 
                    Cell]]& ], $CellContext`cells$$, 
                    StyleBox[
                    RowBox[{
                    DynamicBox[
                    CurrentValue[{"CounterValue", "SlideShowNavigationBar"}]], 
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "SlideshowToolbarText", "SlideshowToolbarCounterText"]], 
                    DynamicBox[
                    
                    CurrentValue[{
                    "MaxCounterValue", "SlideShowNavigationBar"}]]}], 
                    "ControlStyle"], Appearance -> None, ImageSize -> 
                    Automatic], ImageSizeCache -> {50., {6., 18.}}], 
                  
                  EventHandlerTag[{
                   "MouseDown" :> 
                    Module[{$CellContext`cnt$, $CellContext`nb$ = 
                    InputNotebook[]}, $CellContext`cells$$ = {}; \
$CellContext`cnt$ = Apply[(
                    NotebookFind[$CellContext`nb$, #, All, #2, AutoScroll -> 
                    False]; CurrentValue[$CellContext`nb$, {
                    "CellCount", True}])& , {{
                    "SlideShowNavigationBar", CellStyle}, {
                    "SlideShowHeader", CellTags}}, {1}]; $CellContext`cnt$ = 
                    Apply[If[$CellContext`tagFind$$ = # == 
                    0, #2, #]& , $CellContext`cnt$]; 
                    SelectionMove[$CellContext`nb$, Before, Notebook, 
                    AutoScroll -> False]; 
                    If[$CellContext`tagFind$$, $CellContext`cells$$ = 
                    Map[# -> StringJoin["Slide ", 
                    ToString[#]]& , 
                    Range[$CellContext`cnt$]], 
                    Do[NotebookFind[$CellContext`nb$, 
                    "SlideShowNavigationBar", Next, CellStyle, AutoScroll -> 
                    False]; SelectionMove[$CellContext`nb$, Next, Cell, 
                    AutoScroll -> False]; AppendTo[$CellContext`cells$$, 
                    ReplaceAll[
                    NotebookRead[$CellContext`nb$], Pattern[$CellContext`s, 
                    Blank[StyleBox]] :> With[{$CellContext`ss = Join[
                    Take[$CellContext`s, 1], 
                    DeleteCases[
                    Rest[$CellContext`s], 
                    Alternatives[
                    Blank[String], 
                    Blank[][FontColor, 
                    Blank[]]]]]}, 
                    
                    Condition[$CellContext`ss, 
                    True]]]], {$CellContext`cnt$}]; $CellContext`cells$$ = 
                    Replace[
                    Part[$CellContext`cells$$, All, 1], {BoxData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> $CellContext`c, TextData[
                    Pattern[$CellContext`c, 
                    Blank[]]] :> RowBox[
                    If[
                    
                    ListQ[$CellContext`c], $CellContext`c, \
{$CellContext`c}]]}, 1]; $CellContext`cells$$ = 
                    Thread[Range[$CellContext`cnt$] -> \
$CellContext`cells$$]]], PassEventsDown -> True, EvaluationOrder -> Before, 
                    PassEventsDown -> Automatic, PassEventsUp -> True}]], 
                 DynamicModuleValues :> {}]}}, AutoDelete -> False, 
              GridBoxItemSize -> {"Columns" -> {Automatic, Fit, Automatic}}]],
             "DockedCell", CellDynamicExpression :> If[CurrentValue[
                EvaluationNotebook[], {TaggingRules, "DisableController"}] === 
              True, Null, 
              (FrontEndExecute[
               FrontEnd`FrontEndToken[
                FrontEnd`InputNotebook[], #]]& )[
               Switch[
                ControllerState["Apple IR", {"B1", "B2"}], {True, 
                 Blank[]}, "ScrollPagePrevious", {
                 Blank[], True}, "ScrollPageNext", 
                Blank[], None]]], Magnification -> 0.75], 
          ScrollingOptions -> {
           "PagewiseDisplay" -> True, "VerticalScrollRange" -> Fit}, 
          ShowGroupOpener -> False, MenuSortingValue -> 1300], 
         Cell[
          StyleData["DockedCell"], Editable -> False, Evaluator -> "Local", 
          PageWidth -> WindowWidth, CellFrame -> {{0, 0}, {0, 0}}, 
          ShowSelection -> True, CellMargins -> {{0, 0}, {0, 0}}, 
          CellElementSpacings -> {
           "ClosedCellHeight" -> 0, "ClosedGroupTopMargin" -> 0}, 
          DynamicUpdating -> True, CellFrameMargins -> {{0, 0}, {0, 4}}, 
          ContextMenu -> None, ComponentwiseContextMenu -> {}, 
          ShowStringCharacters -> False, LineBreakWithin -> False, 
          Magnification -> 1, Background -> GrayLevel[0.97], 
          TooltipBoxOptions -> {TooltipDelay -> Automatic}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], MenuSortingValue -> 1, MenuCommandKey -> "1",
              FontFamily -> "Georgia", FontSize -> 36, FontWeight -> Plain, 
             FontColor -> RGBColor[0.796078, 0.0705882, 0]], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{90, 100}, {10, 100}}, FontSize -> 54], 
            Cell[
             StyleData["Title", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], MenuSortingValue -> 100, MenuCommandKey -> 
             "2", FontFamily -> "Georgia", FontSize -> 24, FontWeight -> 
             "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{90, 100}, {100, 20}}, FontSize -> 32], 
            Cell[
             StyleData["Subtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], MenuSortingValue -> 200, 
             MenuCommandKey -> "3", FontFamily -> "Georgia", FontSize -> 20, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.2]], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 120}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 26], 
            Cell[
             StyleData["Subsubtitle", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DateSection"], CellMargins -> {{30, 0}, {12, 24}}, 
             ShowStringCharacters -> False], 
            Cell[
             StyleData["DateSection", "Presentation"], 
             CellMargins -> {{90, 20}, {2, 36}}, ShowStringCharacters -> 
             False, FontSize -> 21], 
            Cell[
             StyleData["DateSection", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Sections", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Chapter"], CellMargins -> {{27, Inherited}, {8, 34}}, 
             CounterIncrements -> {"Chapter"}, MenuSortingValue -> 2410, 
             FontFamily -> "Georgia", FontSize -> 28, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098], CellTags -> "Chapter"], 
            Cell[
             StyleData["Chapter", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 60}, {20, 30}}, FontSize -> 36], 
            Cell[
             StyleData["Chapter", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> 0, MenuSortingValue -> 1200, 
             MenuCommandKey -> "4", FontFamily -> "Georgia", FontSize -> 24, 
             FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "Presentation"], CellFrame -> None, 
             CellMargins -> {{80, 14}, {30, 30}}, FontFamily -> "Georgia", 
             FontSize -> 34, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["Section", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[RightGuillemet]", 
             CellGroupingRules -> {"SectionGrouping", 40}, MenuSortingValue -> 
             1300, MenuCommandKey -> "5", FontFamily -> "Georgia", FontSize -> 
             22, FontWeight -> Plain, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{80, 60}, {12, 20}}, FontSize -> 25], 
            Cell[
             StyleData["Subsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> "\[RightGuillemet]", 
             MenuSortingValue -> 1400, MenuCommandKey -> "6", FontFamily -> 
             "Georgia", FontSize -> 20, FontWeight -> Plain, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{88, 60}, {0, 12}}, FontSize -> 22], 
            Cell[
             StyleData["Subsubsection", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "MoreExamplesSection", StyleDefinitions -> 
              StyleData["Subsubsection"]], CellDingbat -> None, 
             ShowGroupOpener -> True, 
             CellGroupingRules -> {"SectionGrouping", 45}, MenuSortingValue -> 
             2100, FontColor -> RGBColor[0.636862, 0.0564706, 0.]], 
            Cell[
             StyleData["MoreExamplesSection", "Presentation"], 
             CellMargins -> {{88, 60}, {20, 12}}], 
            Cell[
             StyleData["MoreExamplesSection", "SlideShow"], 
             WholeCellGroupOpener -> True, 
             CellMargins -> {{88, 60}, {20, 12}}]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], MenuSortingValue -> 2000, MenuCommandKey -> 
             "7", FontFamily -> "Georgia", FontSize -> 18], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{80, 20}, {12, 12}}, LineSpacing -> {1.25, 1}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["Text", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MathCaption"], MenuSortingValue -> 2010, 
             MenuCommandKey -> "8", FontFamily -> "Georgia", FontSize -> 18, 
             FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["MathCaption", "Presentation"], 
             CellMargins -> {{120, 12}, {6, 34}}, LineSpacing -> {1.25, 1}, 
             FontSize -> 20], 
            Cell[
             StyleData["MathCaption", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "IntegrationMathCaption", StyleDefinitions -> 
              StyleData["MathCaption"]], CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Integration", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["IntegrationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}, FontSize -> 20], 
            Cell[
             StyleData["IntegrationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, 
             CellFrameMargins -> {{10, 0}, {0, 5}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "AutomationMathCaption", StyleDefinitions -> 
              StyleData["IntegrationMathCaption"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Automation", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[0.811765, 0.117647, 0.145098], 
                  BoxFrame -> 0, FrameStyle -> None, 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}], 
            Cell[
             StyleData["AutomationMathCaption", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 20], 
            Cell[
             StyleData["AutomationMathCaption", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Comment", StyleDefinitions -> StyleData["Text"]], 
             CellMargins -> {{0, 12}, {2, 24}}, 
             CellFrameMargins -> {{0, 0}, {0, 3}}, CellFrameLabels -> {{
                PaneBox[
                 FrameBox[
                  StyleBox[
                  "Comment", FontFamily -> "Helvetica", FontSize -> 9, 
                   FontColor -> GrayLevel[1], FontWeight -> Plain], 
                  Background -> RGBColor[1., 0.647059, 0], BoxFrame -> 1, 
                  FrameStyle -> RGBColor[1., 0.647059, 0], 
                  FrameMargins -> {{3, 3}, {1, 1}}], ImageSize -> 56, 
                 Alignment -> Left, FrameMargins -> 0], None}, {None, None}}, 
             MenuSortingValue -> 2200, FontSize -> 14], 
            Cell[
             StyleData["Comment", "Presentation"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16], 
            Cell[
             StyleData["Comment", "SlideShow"], 
             CellMargins -> {{30, 12}, {12, 12}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{60, Inherited}, {Inherited, Inherited}}, 
             StripStyleOnPaste -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             MenuSortingValue -> 1700, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             CellMargins -> {{120, Inherited}, {
               Inherited 1.75, Inherited 1.75}}, LineSpacing -> {1, 5}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["DisplayFormula", "SlideShow"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Items", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Item"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2700, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["Item", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["Item", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemParagraph"], MenuSortingValue -> 2710, FontFamily -> 
             "Georgia", FontSize -> 18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["ItemParagraph", "Presentation"], 
             CellMargins -> {{120, 90}, {12, 12}}, LineSpacing -> {1.25, 0}, 
             FontFamily -> "Georgia", FontSize -> 20], 
            Cell[
             StyleData["ItemParagraph", "SlideShow"]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ItemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2720, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.25]], 
            Cell[
             StyleData["ItemNumbered", "Presentation"], 
             CellMargins -> {{116, 20}, {12, 12}}, FontFamily -> "Georgia", 
             FontSize -> 20], 
            Cell[
             StyleData["ItemNumbered", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subitem"], CellDingbat -> "\[RightGuillemet] ", 
             LineSpacing -> {1.5, 0}, MenuSortingValue -> 2730, FontFamily -> 
             "Georgia", FontSize -> 16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["Subitem", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 21], 
            Cell[
             StyleData["Subitem", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemParagraph"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2740, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemParagraph", "Presentation"], 
             CellMargins -> {{136, 90}, {10, 8}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemParagraph", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubitemNumbered"], LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2750, FontFamily -> "Georgia", FontSize -> 
             16, FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["SubitemNumbered", "Presentation"], 
             CellMargins -> {{136, 20}, {10, 10}}, FontFamily -> "Georgia", 
             FontSize -> 18], 
            Cell[
             StyleData["SubitemNumbered", "SlideShow"]]}, Open]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input and Output", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], MenuSortingValue -> 2020, MenuCommandKey -> 
             "9", FontSize -> 18], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Input", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], 
             CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
             LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> 
             RGBColor[0.269993, 0.308507, 0.6]], 
            Cell[
             StyleData["CellLabel", "Presentation"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "SlideShow"], 
             CellMargins -> {{12, Inherited}, {Inherited 1.5, Inherited 1.5}},
              FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShort"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShort", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaShortInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaShortInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLong"], FontFamily -> "Helvetica", 
             FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLong", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["WolframAlphaLongInput"], FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["WolframAlphaLongInput", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], MenuSortingValue -> 2030, FontSize -> 18], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Output", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], FontSize -> 18], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{120, 10}, {7, 12}}, FontSize -> 18], 
            Cell[
             StyleData["Print", "SlideShow"]]}, Closed]], 
         Cell[
          StyleData["MSG"], FontSize -> 16]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles of Links", "Section"], 
         Cell[
          StyleData["Link", "SlideShow"], FontSize -> 21], 
         Cell[
          StyleData["SearchLink", StyleDefinitions -> StyleData["Link"]]], 
         Cell[
          StyleData["FunctionLink"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Special Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Picture"], CellMargins -> {{100, 100}, {20, 20}}, 
             ShowStringCharacters -> False, MenuSortingValue -> 5000, 
             Magnification -> 1], 
            Cell[
             StyleData["Picture", "Presentation"], 
             CellMargins -> {{100, 100}, {20, 20}}, Magnification -> 1], 
            Cell[
             StyleData["Picture", "SlideShow"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "PictureCaption", StyleDefinitions -> StyleData["Text"]], 
             CellDingbat -> "\[FilledUpTriangle]", 
             CellMargins -> {{114, 100}, {15, 4}}, ShowStringCharacters -> 
             False, MenuSortingValue -> 5100, FontSize -> 14, FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["PictureCaption", "Presentation"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16], 
            Cell[
             StyleData["PictureCaption", "SlideShow"], 
             CellMargins -> {{114, 100}, {20, 4}}, FontSize -> 16]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "Presentation"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["OverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "Presentation"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["OverviewSection", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChapterTagline"], CellMargins -> {{60, 90}, {15, 0}}, 
             MenuSortingValue -> 2420, FontFamily -> "Georgia", FontSize -> 
             20, FontWeight -> "Plain", FontSlant -> "Italic", FontColor -> 
             GrayLevel[0.3]], 
            Cell[
             StyleData["ChapterTagline", "Presentation"], 
             CellMargins -> {{90, 90}, {15, 0}}, FontSize -> 24], 
            Cell[
             StyleData["ChapterTagline", "SlideShow"]]}, Open]], 
         Cell[
          StyleData["PlotLabel"], FontFamily -> "Helvetica", FontSize -> 14], 
         Cell[
          StyleData["NonPrintButton"], 
          CellMargins -> {{128, Inherited}, {16, 0}}, FontFamily -> 
          "Helvetica", FontSize -> 12, FontColor -> GrayLevel[1], 
          ButtonBoxOptions -> {
           Background -> RGBColor[0.811765, 0.117647, 0.145098], 
            ButtonMargins -> 4}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"]], 
            Cell[
             StyleData["Program", "SlideShow"], 
             CellMargins -> {{116, 48}, {16, 16}}, FontSize -> 18]}, 
           Closed]]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Screencast", "Section", 
          CellChangeTimes -> {{3.520687019071189*^9, 
           3.5206870238431892`*^9}, {3.520687323526189*^9, 
           3.520687328236189*^9}}], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData[
             "LargeChapter", StyleDefnitions -> StyleData["Chapter"]], 
             CellMargins -> {{27, Inherited}, {8, 34}}, MenuSortingValue -> 
             2430, FontFamily -> "Georgia", FontSize -> 30, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeChapter", "SlideShow"], 
             CellMargins -> {{100, 10}, {15, 100}}, FontSize -> 48]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeChapterTagline"], 
             CellMargins -> {{27, 60}, {30, 20}}, MenuSortingValue -> 2420, 
             FontFamily -> "Georgia", FontSize -> 26, FontWeight -> "Plain", 
             FontSlant -> "Italic", FontColor -> GrayLevel[0.3]], 
            Cell[
             StyleData["LargeChapterTagline", "SlideShow"], 
             CellMargins -> {{100, 60}, {30, 15}}, FontSize -> 32]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeOverviewTitle"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 24, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]], 
            Cell[
             StyleData["LargeOverviewTitle", "SlideShow"], CellFrame -> None, 
             CellMargins -> {{100, 100}, {20, 60}}, FontFamily -> "Calibri", 
             FontSize -> 36, FontWeight -> "Bold", FontColor -> 
             GrayLevel[0.4]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeOverviewSection"], CellFrame -> None, 
             CellMargins -> {{120, 100}, {10, 10}}, ReturnCreatesNewCell -> 
             True, FontFamily -> "Georgia", FontSize -> 22, FontWeight -> 
             Plain, FontColor -> RGBColor[0.811765, 0.117647, 0.145098]], 
            Cell[
             StyleData["LargeOverviewSection", "SlideShow"], CellFrame -> 
             None, CellMargins -> {{120, 100}, {10, 10}}, 
             ReturnCreatesNewCell -> True, FontFamily -> "Georgia", FontSize -> 
             30, FontWeight -> Plain, FontColor -> 
             RGBColor[0.811765, 0.117647, 0.145098]]}, Open]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["LargeItem", StyleDefinitions -> StyleData["Item"]], 
             CellDingbat -> "\[RightGuillemet] ", LineSpacing -> {1.5, 0}, 
             MenuSortingValue -> 2700, FontFamily -> "Georgia", FontSize -> 
             18, FontColor -> GrayLevel[0.2]], 
            Cell[
             StyleData["LargeItem", "SlideShow"], 
             CellMargins -> {{100, 20}, {10, 10}}, FontSize -> 26]}, Open]]}, 
        Closed]]}, Open]]}, Visible -> False, FrontEndVersion -> 
  "8.0 for Microsoft Windows (64-bit) (October 15, 2011)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
PrivateNotebookOptions -> {"NotebookAuthor" -> ""}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[630, 23, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[612024, 10127, 106, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[613400, 10163, 106, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[619719, 10346, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[627515, 10580, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[854160, 14905, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[863564, 15159, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[899662, 16198, 106, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[955186, 17634, 130, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3177704, 54369, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3182480, 54499, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3208085, 55111, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3218245, 55386, 64, 1, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3226607, 55614, 106, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[3229066, 55689, 106, 2, 1, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]},
 "Basic Operations"->{
  Cell[628268, 10605, 1677, 30, 85, "MathCaption",
   CellTags->"Basic Operations"],
  Cell[676852, 11859, 1559, 26, 67, "MathCaption",
   CellTags->"Basic Operations"],
  Cell[690363, 12134, 1521, 26, 50, "MathCaption",
   CellTags->"Basic Operations"],
  Cell[854331, 14914, 1717, 33, 98, "MathCaption",
   CellTags->"Basic Operations"],
  Cell[955383, 17642, 2018, 34, 222, "MathCaption",
   CellTags->"Basic Operations"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 3321278, 57892},
 {"Basic Operations", 3322673, 57923}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[630, 23, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[697, 26, 91, 1, 192, "Title"],
Cell[791, 29, 204, 7, 78, "Subtitle"],
Cell[CellGroupData[{
Cell[1020, 40, 2159, 48, 226, "Input",
 CellID->548981389],
Cell[3182, 90, 608296, 10014, 217, 557592, 9181, "CachedBoxData", "BoxData", \
"Output"]
}, {2}]],
Cell[611490, 10107, 377, 8, 66, "PictureCaption",
 CellID->243026665],
Cell[611870, 10117, 117, 5, 139, "Subsubtitle"]
}, Open  ]],
Cell[CellGroupData[{
Cell[612024, 10127, 106, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[612155, 10133, 93, 1, 99, "Section"],
Cell[612251, 10136, 506, 9, 59, "Text"],
Cell[612760, 10147, 591, 10, 59, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[613400, 10163, 106, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[613509, 10167, 47, 0, 124, "LargeOverviewTitle"],
Cell[CellGroupData[{
Cell[613581, 10171, 187, 3, 99, "Section"],
Cell[613771, 10176, 504, 7, 62, "Subsection"],
Cell[614278, 10185, 115, 1, 46, "Subsection"],
Cell[614396, 10188, 103, 1, 46, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614536, 10194, 62, 0, 99, "Section"],
Cell[614601, 10196, 352, 6, 50, "Subsection"],
Cell[614956, 10204, 350, 6, 42, "Subsection"],
Cell[615309, 10212, 367, 7, 42, "Subsection"],
Cell[615679, 10221, 330, 6, 42, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[616046, 10232, 244, 5, 99, "Section"],
Cell[616293, 10239, 151, 2, 59, "MoreExamplesSection"],
Cell[616447, 10243, 79, 1, 51, "MoreExamplesSection"],
Cell[616529, 10246, 217, 5, 51, "MoreExamplesSection"],
Cell[616749, 10253, 152, 2, 51, "MoreExamplesSection"],
Cell[616904, 10257, 174, 6, 52, "MoreExamplesSection"],
Cell[617081, 10265, 281, 8, 52, "MoreExamplesSection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[617399, 10278, 458, 6, 99, "Section"],
Cell[CellGroupData[{
Cell[617882, 10288, 204, 3, 62, "Subsection"],
Cell[618089, 10293, 283, 8, 60, "MoreExamplesSection"],
Cell[618375, 10303, 174, 6, 52, "MoreExamplesSection"]
}, Open  ]]
}, Open  ]],
Cell[618576, 10313, 154, 2, 99, "Section"],
Cell[618733, 10317, 134, 1, 73, "Section"],
Cell[618870, 10320, 107, 1, 73, "Section"],
Cell[618980, 10323, 109, 1, 73, "Section"],
Cell[619092, 10326, 98, 1, 73, "Section"],
Cell[619193, 10329, 237, 5, 73, "Section"],
Cell[619433, 10336, 249, 5, 73, "Section"]
}, Open  ]],
Cell[CellGroupData[{
Cell[619719, 10346, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[619808, 10351, 187, 3, 99, "Section"],
Cell[CellGroupData[{
Cell[620020, 10358, 504, 7, 62, "Subsection"],
Cell[CellGroupData[{
Cell[620549, 10369, 256, 6, 84, "Item"],
Cell[620808, 10377, 179, 4, 48, "Item"],
Cell[620990, 10383, 198, 4, 84, "Item"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[621237, 10393, 115, 1, 62, "Subsection"],
Cell[CellGroupData[{
Cell[621377, 10398, 269, 5, 84, "Item"],
Cell[621649, 10405, 307, 5, 120, "Item"],
Cell[621959, 10412, 560, 14, 156, "Item"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[622568, 10432, 103, 1, 62, "Subsection"],
Cell[CellGroupData[{
Cell[622696, 10437, 266, 5, 84, "Item"],
Cell[622965, 10444, 91, 1, 48, "Item"]
}, Open  ]],
Cell[623071, 10448, 1212, 39, 176, "Input"],
Cell[624286, 10489, 162, 2, 48, "Item"],
Cell[CellGroupData[{
Cell[624473, 10495, 1585, 38, 203, "Input"],
Cell[626061, 10535, 197, 4, 35, "Output"]
}, Closed]],
Cell[626273, 10542, 143, 2, 40, "Item"],
Cell[CellGroupData[{
Cell[626441, 10548, 775, 18, 122, "Input"],
Cell[627219, 10568, 223, 4, 35, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[627515, 10580, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[627604, 10585, 64, 0, 99, "Section"],
Cell[627671, 10587, 130, 3, 36, "Text"],
Cell[CellGroupData[{
Cell[627826, 10594, 439, 9, 50, "Subsection"],
Cell[628268, 10605, 1677, 30, 85, "MathCaption",
 CellTags->"Basic Operations"],
Cell[CellGroupData[{
Cell[629970, 10639, 1404, 34, 118, "Input",
 Evaluatable->False],
Cell[631377, 10675, 45071, 1170, 349, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[676497, 11851, 352, 6, 42, "Subsection"],
Cell[676852, 11859, 1559, 26, 67, "MathCaption",
 CellTags->"Basic Operations"],
Cell[CellGroupData[{
Cell[678436, 11889, 5893, 132, 501, "Input",
 CellID->637417305],
Cell[684332, 12023, 5629, 97, 332, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[690010, 12126, 350, 6, 42, "Subsection"],
Cell[690363, 12134, 1521, 26, 50, "MathCaption",
 CellTags->"Basic Operations"],
Cell[CellGroupData[{
Cell[691909, 12164, 5994, 137, 550, "Input",
 CellID->155820295],
Cell[697906, 12303, 6150, 105, 362, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[704105, 12414, 307, 4, 42, "Subsection"],
Cell[704415, 12420, 283, 6, 36, "Text"],
Cell[CellGroupData[{
Cell[704723, 12430, 721, 20, 64, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->1041024209],
Cell[705447, 12452, 360, 9, 64, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->286474932],
Cell[705810, 12463, 2302, 55, 253, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellID->132174553]
}, Open  ]],
Cell[708127, 12521, 145839, 2372, 254, "Output"],
Cell[853969, 14895, 130, 3, 26, "Text"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[854160, 14905, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[854249, 14910, 79, 2, 99, "Section"],
Cell[854331, 14914, 1717, 33, 98, "MathCaption",
 CellTags->"Basic Operations"],
Cell[856051, 14949, 809, 14, 419, "Input"],
Cell[CellGroupData[{
Cell[856885, 14967, 947, 24, 122, "Input"],
Cell[857835, 14993, 808, 20, 61, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[858680, 15018, 443, 11, 32, "Input"],
Cell[859126, 15031, 180, 4, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[859343, 15040, 728, 17, 114, "Input"],
Cell[860074, 15059, 135, 2, 35, "Output"]
}, Closed]],
Cell[860224, 15064, 149, 1, 37, "MathCaption"],
Cell[860376, 15067, 1592, 51, 230, "Input",
 CellID->721040315],
Cell[CellGroupData[{
Cell[861993, 15122, 285, 6, 68, "Input"],
Cell[862281, 15130, 1222, 22, 61, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[863564, 15159, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[863653, 15164, 176, 2, 99, "Section"],
Cell[863832, 15168, 1197, 24, 253, "MathCaption"],
Cell[CellGroupData[{
Cell[865054, 15196, 182, 2, 59, "MoreExamplesSection"],
Cell[865239, 15200, 212, 5, 40, "Input"],
Cell[CellGroupData[{
Cell[865476, 15209, 1626, 49, 218, "Input"],
Cell[867105, 15260, 1630, 49, 75, "Output"]
}, Closed]],
Cell[868750, 15312, 372, 9, 69, "MathCaption"],
Cell[869125, 15323, 1461, 33, 318, "DisplayFormula"]
}, Open  ]],
Cell[CellGroupData[{
Cell[870623, 15361, 53, 0, 59, "MoreExamplesSection"],
Cell[870679, 15363, 1159, 30, 128, "Input"],
Cell[871841, 15395, 72, 0, 67, "MathCaption"],
Cell[871916, 15397, 2068, 64, 457, "DisplayFormula"]
}, Open  ]],
Cell[CellGroupData[{
Cell[874021, 15466, 193, 4, 59, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[874239, 15474, 593, 13, 40, "Input"],
Cell[874835, 15489, 1793, 36, 144, "Output"],
Cell[876631, 15527, 534, 10, 29, "Message"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[877214, 15543, 125, 1, 59, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[877364, 15548, 448, 12, 68, "Input"],
Cell[877815, 15562, 1896, 38, 818, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[879760, 15606, 216, 6, 60, "MoreExamplesSection"],
Cell[879979, 15614, 447, 13, 95, "Input"],
Cell[CellGroupData[{
Cell[880451, 15631, 93, 2, 40, "Input"],
Cell[880547, 15635, 357, 7, 39, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[880941, 15647, 1170, 30, 122, "Input"],
Cell[882114, 15679, 4453, 113, 236, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[886616, 15798, 257, 7, 60, "MoreExamplesSection"],
Cell[886876, 15807, 1402, 45, 203, "Input"],
Cell[888281, 15854, 156, 4, 40, "Input"],
Cell[888440, 15860, 49, 0, 67, "MathCaption"],
Cell[CellGroupData[{
Cell[888514, 15864, 325, 7, 68, "Input"],
Cell[888842, 15873, 1252, 23, 86, "Output"]
}, Closed]],
Cell[890109, 15899, 42, 0, 37, "MathCaption"],
Cell[CellGroupData[{
Cell[890176, 15903, 662, 17, 122, "Input"],
Cell[890841, 15922, 8748, 268, 715, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[899662, 16198, 106, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[899793, 16204, 458, 6, 99, "Section"],
Cell[900254, 16212, 1241, 20, 222, "MathCaption"],
Cell[901498, 16234, 561, 10, 68, "Input"],
Cell[902062, 16246, 4206, 128, 647, "Input"],
Cell[CellGroupData[{
Cell[906293, 16378, 204, 3, 62, "Subsection"],
Cell[CellGroupData[{
Cell[906522, 16385, 2069, 52, 176, "Input"],
Cell[908594, 16439, 2881, 87, 143, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[911512, 16531, 214, 6, 52, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[911751, 16541, 692, 14, 95, "Input"],
Cell[912446, 16557, 2864, 37, 1411, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[915347, 16599, 312, 8, 32, "Input"],
Cell[915662, 16609, 384, 7, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[916083, 16621, 1249, 31, 114, "Input"],
Cell[917335, 16654, 3026, 76, 161, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[920410, 16736, 259, 7, 60, "MoreExamplesSection"],
Cell[920672, 16745, 380, 9, 68, "Input"],
Cell[921055, 16756, 118, 1, 67, "MathCaption"],
Cell[CellGroupData[{
Cell[921198, 16761, 464, 9, 68, "Input"],
Cell[921665, 16772, 1163, 20, 86, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[922865, 16797, 515, 10, 60, "Input"],
Cell[923383, 16809, 1125, 19, 86, "Output"]
}, Closed]],
Cell[924523, 16831, 42, 0, 37, "MathCaption"],
Cell[CellGroupData[{
Cell[924590, 16835, 713, 19, 122, "Input"],
Cell[925306, 16856, 5416, 161, 715, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[930783, 17024, 207, 3, 62, "Subsection"],
Cell[CellGroupData[{
Cell[931015, 17031, 2421, 59, 284, "Input"],
Cell[933439, 17092, 1974, 26, 786, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[935450, 17123, 218, 6, 52, "MoreExamplesSection"],
Cell[935671, 17131, 331, 8, 40, "Input"],
Cell[CellGroupData[{
Cell[936027, 17143, 1299, 31, 122, "Input"],
Cell[937329, 17176, 1585, 40, 86, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[938963, 17222, 259, 7, 60, "MoreExamplesSection"],
Cell[939225, 17231, 380, 9, 68, "Input"],
Cell[939608, 17242, 118, 1, 67, "MathCaption"],
Cell[CellGroupData[{
Cell[939751, 17247, 511, 10, 68, "Input"],
Cell[940265, 17259, 1308, 22, 86, "Output"]
}, Closed]],
Cell[941588, 17284, 42, 0, 37, "MathCaption"],
Cell[CellGroupData[{
Cell[941655, 17288, 810, 20, 122, "Input"],
Cell[942468, 17310, 3070, 93, 715, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[945599, 17410, 208, 3, 62, "Subsection"],
Cell[CellGroupData[{
Cell[945832, 17417, 2254, 49, 343, "Input"],
Cell[948089, 17468, 1519, 20, 411, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[949645, 17493, 148, 5, 52, "MoreExamplesSection"],
Cell[CellGroupData[{
Cell[949818, 17502, 1317, 30, 122, "Input"],
Cell[951138, 17534, 841, 11, 204, "Print"],
Cell[951982, 17547, 1002, 23, 61, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[953033, 17576, 257, 7, 60, "MoreExamplesSection"],
Cell[953293, 17585, 275, 6, 40, "Input"],
Cell[953571, 17593, 160, 2, 67, "MathCaption"],
Cell[CellGroupData[{
Cell[953756, 17599, 461, 8, 40, "Input"],
Cell[954220, 17609, 881, 16, 61, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[955186, 17634, 130, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[955341, 17640, 39, 0, 99, "Section"],
Cell[955383, 17642, 2018, 34, 222, "MathCaption",
 CellTags->"Basic Operations"],
Cell[CellGroupData[{
Cell[957426, 17680, 791, 17, 68, "Input"],
Cell[958220, 17699, 138089, 2271, 319, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1096346, 19975, 1030, 20, 87, "Input"],
Cell[1097379, 19997, 699278, 11530, 249, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[1796694, 31532, 908, 19, 87, "Input"],
Cell[1797605, 31553, 674798, 11130, 249, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2472440, 42688, 426, 8, 32, "Input"],
Cell[2472869, 42698, 644, 10, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2473550, 42713, 565, 10, 32, "Input"],
Cell[2474118, 42725, 581, 9, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2474736, 42739, 460, 8, 32, "Input"],
Cell[2475199, 42749, 534, 8, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2475770, 42762, 685, 11, 32, "Input"],
Cell[2476458, 42775, 329, 6, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2476824, 42786, 415, 10, 32, "Input"],
Cell[2477242, 42798, 610, 9, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2477889, 42812, 442, 10, 32, "Input"],
Cell[2478334, 42824, 335, 6, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[2478706, 42835, 262, 6, 32, "Input"],
Cell[2478971, 42843, 698672, 11519, 231, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3177704, 54369, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3177793, 54374, 134, 1, 99, "Section"],
Cell[3177930, 54377, 725, 11, 203, "Text"],
Cell[3178658, 54390, 191, 4, 48, "Text"],
Cell[3178852, 54396, 721, 23, 34, "DisplayFormula",
 InitializationCell->False],
Cell[3179576, 54421, 979, 22, 141, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3180592, 54448, 107, 1, 99, "Section"],
Cell[3180702, 54451, 530, 9, 141, "Text"],
Cell[3181235, 54462, 115, 1, 48, "Text"],
Cell[CellGroupData[{
Cell[3181375, 54467, 271, 5, 84, "Item"],
Cell[3181649, 54474, 770, 18, 157, "Item"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3182480, 54499, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3182569, 54504, 151, 2, 99, "Section"],
Cell[3182723, 54508, 3727, 83, 522, "MathCaption"],
Cell[3186453, 54593, 328, 6, 48, "Text"],
Cell[CellGroupData[{
Cell[3186806, 54603, 3133, 69, 473, "Input"],
Cell[3189942, 54674, 697, 9, 204, "Print"]
}, Closed]],
Cell[3190654, 54686, 293, 7, 71, "Text"],
Cell[3190950, 54695, 334, 8, 40, "Input"],
Cell[3191287, 54705, 317, 6, 79, "Text"],
Cell[CellGroupData[{
Cell[3191629, 54715, 168, 3, 40, "Input"],
Cell[3191800, 54720, 5486, 95, 242, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3197335, 54821, 109, 1, 99, "Section"],
Cell[3197447, 54824, 316, 6, 79, "Text"],
Cell[3197766, 54832, 541, 17, 34, "DisplayFormula"],
Cell[CellGroupData[{
Cell[3198332, 54853, 2101, 47, 392, "Input"],
Cell[3200436, 54902, 665, 9, 204, "Print"]
}, Closed]],
Cell[3201116, 54914, 205, 4, 40, "Text"],
Cell[3201324, 54920, 745, 16, 176, "Input"],
Cell[3202072, 54938, 526, 13, 95, "Input"],
Cell[3202601, 54953, 256, 5, 48, "Text"],
Cell[CellGroupData[{
Cell[3202882, 54962, 632, 15, 40, "Input"],
Cell[3203517, 54979, 163, 2, 35, "Output"]
}, Closed]],
Cell[3203695, 54984, 207, 5, 40, "Text"],
Cell[CellGroupData[{
Cell[3203927, 54993, 940, 21, 149, "Input"],
Cell[3204870, 55016, 189, 3, 35, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3205108, 55025, 98, 1, 99, "Section"],
Cell[3205209, 55028, 340, 6, 79, "Text"],
Cell[CellGroupData[{
Cell[3205574, 55038, 868, 24, 149, "Input"],
Cell[3206445, 55064, 255, 5, 35, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[3206737, 55074, 996, 22, 141, "Input"],
Cell[3207736, 55098, 288, 6, 35, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3208085, 55111, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3208174, 55116, 186, 4, 99, "Section"],
Cell[3208363, 55122, 389, 7, 79, "Text"],
Cell[3208755, 55131, 947, 31, 69, "DisplayFormula"],
Cell[3209705, 55164, 353, 6, 79, "Text"],
Cell[3210061, 55172, 598, 13, 135, "DisplayFormula"],
Cell[3210662, 55187, 380, 6, 79, "Text"],
Cell[CellGroupData[{
Cell[3211067, 55197, 2919, 72, 453, "Input"],
Cell[3213989, 55271, 691, 9, 204, "Print"]
}, Closed]],
Cell[3214695, 55283, 239, 5, 40, "Text"],
Cell[3214937, 55290, 1408, 37, 257, "Input"],
Cell[3216348, 55329, 182, 4, 48, "Text"],
Cell[CellGroupData[{
Cell[3216555, 55337, 1410, 37, 152, "Input"],
Cell[3217968, 55376, 216, 3, 35, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3218245, 55386, 64, 1, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3218334, 55391, 204, 4, 99, "Section"],
Cell[3218541, 55397, 454, 8, 110, "Text"],
Cell[3218998, 55407, 1015, 32, 68, "DisplayFormula"],
Cell[3220016, 55441, 388, 6, 79, "Text"],
Cell[CellGroupData[{
Cell[3220429, 55451, 2812, 69, 419, "Input"],
Cell[3223244, 55522, 711, 10, 204, "Print"]
}, Closed]],
Cell[3223970, 55535, 172, 4, 40, "Text"],
Cell[3224145, 55541, 683, 17, 230, "Input"],
Cell[3224831, 55560, 198, 4, 48, "Text"],
Cell[CellGroupData[{
Cell[3225054, 55568, 1306, 35, 152, "Input"],
Cell[3226363, 55605, 183, 2, 35, "Output"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3226607, 55614, 106, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3226738, 55620, 96, 1, 99, "Section"],
Cell[CellGroupData[{
Cell[3226859, 55625, 273, 5, 48, "Item"],
Cell[3227135, 55632, 241, 4, 48, "Item"],
Cell[3227379, 55638, 222, 5, 48, "Item"],
Cell[3227604, 55645, 280, 6, 48, "Item"],
Cell[3227887, 55653, 272, 5, 48, "Item"],
Cell[3228162, 55660, 260, 5, 48, "Item"],
Cell[3228425, 55667, 255, 5, 48, "Item"],
Cell[3228683, 55674, 322, 8, 48, "Item"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3229066, 55689, 106, 2, 1, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[CellGroupData[{
Cell[3229197, 55695, 61, 1, 99, "Section",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[3229283, 55700, 95, 1, 62, "Subsection"],
Cell[3229381, 55703, 411, 10, 64, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3229829, 55718, 35, 0, 46, "Subsection"],
Cell[3229867, 55720, 122, 3, 36, "Input",
 InitializationCell->True,
 CellID->2129660918],
Cell[3229992, 55725, 176, 4, 36, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3230205, 55734, 96, 1, 46, "Subsection"],
Cell[3230304, 55737, 2482, 51, 608, "Input",
 InitializationCell->True],
Cell[3232789, 55790, 318, 10, 40, "Input",
 InitializationCell->True,
 CellID->32775198],
Cell[3233110, 55802, 522, 14, 40, "Input",
 InitializationCell->True,
 CellID->168599841],
Cell[3233635, 55818, 8309, 214, 1148, "Input"],
Cell[3241947, 56034, 119, 5, 48, "Text"],
Cell[3242069, 56041, 170, 3, 40, "Input",
 InitializationCell->True],
Cell[3242242, 56046, 6698, 194, 554, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True],
Cell[3248943, 56242, 67, 0, 67, "MathCaption"],
Cell[3249013, 56244, 3900, 95, 446, "Input",
 InitializationCell->True],
Cell[3252916, 56341, 228, 4, 40, "Input",
 InitializationCell->True],
Cell[3253147, 56347, 3953, 96, 446, "Input",
 InitializationCell->True],
Cell[3257103, 56445, 1105, 26, 230, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 InitializationCell->True],
Cell[3258211, 56473, 3966, 98, 419, "Input",
 InitializationCell->True],
Cell[3262180, 56573, 7172, 163, 824, "Input",
 InitializationCell->True],
Cell[3269355, 56738, 9306, 208, 905, "Input",
 InitializationCell->True],
Cell[3278664, 56948, 2479, 55, 392, "Input",
 InitializationCell->True],
Cell[3281146, 57005, 2445, 55, 257, "Input",
 InitializationCell->True],
Cell[3283594, 57062, 2414, 54, 311, "Input",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
